searchData={"items":[{"type":"task","title":"mix benchmark.visualization","doc":"Runs visualization performance benchmarks.","ref":"Mix.Tasks.Benchmark.Visualization.html"},{"type":"task","title":"Usage - mix benchmark.visualization","doc":"$ mix benchmark.visualization [--small|--medium|--large|--production]","ref":"Mix.Tasks.Benchmark.Visualization.html#module-usage"},{"type":"task","title":"Options - mix benchmark.visualization","doc":"* `--small` - Run a small benchmark with fewer data points (default)\n    * `--medium` - Run a medium-sized benchmark\n    * `--large` - Run a large benchmark with more data points\n    * `--production` - Run a comprehensive benchmark for production analysis","ref":"Mix.Tasks.Benchmark.Visualization.html#module-options"},{"type":"module","title":"Raxol","doc":"Raxol is a feature-rich terminal UI framework for Elixir.\n\nIt provides a comprehensive set of components and tools for building\nbeautiful, accessible, and responsive terminal applications.","ref":"Raxol.html"},{"type":"module","title":"Features - Raxol","doc":"* **Modern Component Library**: A rich set of pre-built UI components like buttons,\n  text inputs, tables, modals, and more.\n\n* **Accessibility Support**: Built-in features for screen readers, high contrast\n  mode, and keyboard navigation.\n\n* **Theming System**: Customize the look and feel of your application with\n  consistent theming.\n\n* **Responsive Layouts**: Create layouts that adapt to different terminal sizes.\n\n* **The Elm Architecture**: Follows TEA (The Elm Architecture) for predictable\n  state management.\n\n* **Event Handling**: Comprehensive event system for keyboard, mouse, and terminal events.","ref":"Raxol.html#module-features"},{"type":"module","title":"Getting Started - Raxol","doc":"To create a new Raxol application, you need to define three core functions:\n\n* `init/1`: Initializes your application state\n* `update/2`: Updates the state based on events\n* `render/1`: Renders the UI based on the current state\n\nHere's a simple counter example:\n\n    ```text\n    defmodule Counter do\n      @behaviour Raxol.Core.Runtime.Application\n\n      require Raxol.Core.Renderer.View\n      alias Raxol.Core.Runtime.Events.Event\n\n      def init(_opts) do\n        {%{count: 0}, []}\n      end\n\n      def update(%{count: count} = model, %Event{type: :command, data: :increment}) do\n        {%{model | count: count + 1}, []}\n      end\n\n      def update(%{count: count} = model, %Event{type: :command, data: :decrement}) do\n        {%{model | count: count - 1}, []}\n      end\n\n      def update(model, _event_or_msg), do: {model, []}\n\n      def view(model) do\n        Raxol.Core.Renderer.View.column [padding: 1] do\n          [\n            Raxol.Core.Renderer.View.text(\"Count: #{model.count}\"),\n            Raxol.Core.Renderer.View.row [gap: 1] do\n              [\n                Raxol.Core.Renderer.View.button \"-\", on_click: {:command, :decrement},\n                Raxol.Core.Renderer.View.button \"+\", on_click: {:command, :increment}\n              ]\n            end\n          ]\n        end\n      end\n    end\n\n    # Start the application\n    Raxol.run(Counter)\n    ```","ref":"Raxol.html#module-getting-started"},{"type":"module","title":"Architecture - Raxol","doc":"Raxol is built on the Elm Architecture:\n\n1. **Model**: Your application state\n2. **Update**: Logic to update the state based on messages\n3. **View**: Pure functions to render UI based on the current state\n\nMessages can be generated by user interactions (like button clicks) or\nsystem events (like terminal resize).","ref":"Raxol.html#module-architecture"},{"type":"module","title":"Components - Raxol","doc":"Raxol provides a rich set of built-in components in the Raxol.Components\nmodule. Common components include:\n\n* Buttons\n* Text inputs\n* Tables\n* Progress indicators\n* Modals\n* Dropdown menus\n* Tab bars\n\nEach component follows consistent patterns for styling and behavior.","ref":"Raxol.html#module-components"},{"type":"function","title":"Raxol.accessibility_settings/0","doc":"Gets the current accessibility settings.","ref":"Raxol.html#accessibility_settings/0"},{"type":"function","title":"Returns - Raxol.accessibility_settings/0","doc":"A map of current accessibility settings.","ref":"Raxol.html#accessibility_settings/0-returns"},{"type":"function","title":"Example - Raxol.accessibility_settings/0","doc":"```elixir\nsettings = Raxol.accessibility_settings()\nif settings.high_contrast do\n  # Do something for high contrast mode\nend\n```","ref":"Raxol.html#accessibility_settings/0-example"},{"type":"function","title":"Raxol.current_theme/0","doc":"Gets the current default theme.","ref":"Raxol.html#current_theme/0"},{"type":"function","title":"Returns - Raxol.current_theme/0","doc":"The current theme map.","ref":"Raxol.html#current_theme/0-returns"},{"type":"function","title":"Example - Raxol.current_theme/0","doc":"```elixir\ntheme = Raxol.current_theme()\n```","ref":"Raxol.html#current_theme/0-example"},{"type":"function","title":"Raxol.run/2","doc":"Runs a Raxol application.\n\nThis function starts the Raxol runtime with the provided application module\nand options. The application module must implement the `Raxol.Core.Runtime.Application` behaviour.","ref":"Raxol.html#run/2"},{"type":"function","title":"Parameters - Raxol.run/2","doc":"* `app` - Module implementing the `Raxol.Core.Runtime.Application` behaviour\n* `opts` - Additional options for the runtime","ref":"Raxol.html#run/2-parameters"},{"type":"function","title":"Options - Raxol.run/2","doc":"* `:quit_keys` - List of keys that will quit the application (default: `[{:ctrl, ?c}]`)\n* `:fps` - Target frames per second (default: `60`)\n* `:title` - Terminal window title (default: `\"Raxol Application\"`)\n* `:font` - Terminal font (if supported)\n* `:font_size` - Terminal font size (if supported)\n* `:accessibility` - Accessibility options\n  * `:screen_reader` - Enable screen reader support (default: `true`)\n  * `:high_contrast` - Enable high contrast mode (default: `false`)\n  * `:large_text` - Enable large text mode (default: `false`)","ref":"Raxol.html#run/2-options"},{"type":"function","title":"Returns - Raxol.run/2","doc":"The return value of the application when it exits.","ref":"Raxol.html#run/2-returns"},{"type":"function","title":"Example - Raxol.run/2","doc":"```elixir\nRaxol.run(MyApp, %{initial: \"state\"}, title: \"My Application\", fps: 30)\n```","ref":"Raxol.html#run/2-example"},{"type":"function","title":"Raxol.set_accessibility/1","doc":"Enables or disables accessibility features.","ref":"Raxol.html#set_accessibility/1"},{"type":"function","title":"Parameters - Raxol.set_accessibility/1","doc":"* `opts` - Map of accessibility features to enable/disable","ref":"Raxol.html#set_accessibility/1-parameters"},{"type":"function","title":"Options - Raxol.set_accessibility/1","doc":"* `:screen_reader` - Enable screen reader support\n* `:high_contrast` - Enable high contrast mode\n* `:large_text` - Enable large text mode\n* `:reduced_motion` - Reduce or eliminate animations","ref":"Raxol.html#set_accessibility/1-options"},{"type":"function","title":"Example - Raxol.set_accessibility/1","doc":"```elixir\nRaxol.set_accessibility(screen_reader: true, high_contrast: true)\n```","ref":"Raxol.html#set_accessibility/1-example"},{"type":"function","title":"Raxol.set_theme/1","doc":"Sets the default theme for Raxol applications.\n\nThis function sets the default theme that will be used by Raxol components.","ref":"Raxol.html#set_theme/1"},{"type":"function","title":"Parameters - Raxol.set_theme/1","doc":"* `theme` - A theme created with `Raxol.UI.Theming.Theme.new/1` or one of the built-in themes","ref":"Raxol.html#set_theme/1-parameters"},{"type":"function","title":"Example - Raxol.set_theme/1","doc":"```elixir\n# Use a built-in theme\nRaxol.set_theme(Raxol.UI.Theming.Theme.dark())\n\n# Create and use a custom theme\ncustom_theme = Raxol.UI.Theming.Theme.new(name: \"Custom\", colors: %{primary: :green})\nRaxol.set_theme(custom_theme)\n```","ref":"Raxol.html#set_theme/1-example"},{"type":"function","title":"Raxol.stop/1","doc":"Gracefully stops a running Raxol application.\n\nThis function can be called from within your application to exit gracefully.","ref":"Raxol.html#stop/1"},{"type":"function","title":"Parameters - Raxol.stop/1","doc":"* `return_value` - Value to return from the `Raxol.run/3` function","ref":"Raxol.html#stop/1-parameters"},{"type":"function","title":"Example - Raxol.stop/1","doc":"```elixir\ndef update(model, :exit) do\n  Raxol.stop(:normal)\n  model\nend\n```","ref":"Raxol.html#stop/1-example"},{"type":"function","title":"Raxol.terminal_info/0","doc":"Returns information about the terminal environment.\n\nThis includes terminal size, color support, and other capabilities.","ref":"Raxol.html#terminal_info/0"},{"type":"function","title":"Returns - Raxol.terminal_info/0","doc":"A map with terminal information.","ref":"Raxol.html#terminal_info/0-returns"},{"type":"function","title":"Example - Raxol.terminal_info/0","doc":"```elixir\nRaxol.terminal_info()\n# => %{\n#      name: \"iTerm2\",\n#      version: \"3.5.0\",\n#      features: [:true_color, :unicode, :mouse, :clipboard],\n#      ...\n#    }\n```","ref":"Raxol.html#terminal_info/0-example"},{"type":"function","title":"Raxol.version/0","doc":"Returns the current version of Raxol.","ref":"Raxol.html#version/0"},{"type":"function","title":"Returns - Raxol.version/0","doc":"A string representing the current version.","ref":"Raxol.html#version/0-returns"},{"type":"function","title":"Example - Raxol.version/0","doc":"```elixir\nRaxol.version()\n# => \"1.0.0\"\n```","ref":"Raxol.html#version/0-example"},{"type":"module","title":"Raxol.AI.ContentGeneration","doc":"Content generation capabilities for Raxol applications.\n\nThis module provides AI-powered content generation for various aspects of\nterminal UIs, including:\n\n* Text suggestions\n* Command completions\n* Help content generation\n* Documentation generation\n* Interactive tutorials\n* Contextual hints\n\nThe generation is configurable and can be adapted to different contexts\nwithin the application.","ref":"Raxol.AI.ContentGeneration.html"},{"type":"function","title":"Raxol.AI.ContentGeneration.generate/3","doc":"Generates content based on the specified type and prompt.","ref":"Raxol.AI.ContentGeneration.html#generate/3"},{"type":"function","title":"Options - Raxol.AI.ContentGeneration.generate/3","doc":"* `:max_length` - Maximum length of the generated content (default: 100)\n* `:style` - Style of the generated content (default: :neutral)\n* `:tone` - Tone of the generated content (default: :neutral)\n* `:context` - Additional context for generation (default: %{})\n* `:model` - AI model to use for generation (default: :default)","ref":"Raxol.AI.ContentGeneration.html#generate/3-options"},{"type":"function","title":"Examples - Raxol.AI.ContentGeneration.generate/3","doc":"iex> generate(:text, \"Create a welcome message\", max_length: 50)\n    {:ok, \"Welcome to the terminal! How can I assist you today?\"}","ref":"Raxol.AI.ContentGeneration.html#generate/3-examples"},{"type":"function","title":"Raxol.AI.ContentGeneration.generate_help/2","doc":"Generates a contextual help document based on application state.","ref":"Raxol.AI.ContentGeneration.html#generate_help/2"},{"type":"function","title":"Examples - Raxol.AI.ContentGeneration.generate_help/2","doc":"iex> generate_help(%{current_view: :editor, command_mode: true})\n    {:ok, %{title: \"Editor Mode Commands\", content: \"...\"}}","ref":"Raxol.AI.ContentGeneration.html#generate_help/2-examples"},{"type":"function","title":"Raxol.AI.ContentGeneration.generate_tutorial/2","doc":"Generates an interactive tutorial for a specific feature.","ref":"Raxol.AI.ContentGeneration.html#generate_tutorial/2"},{"type":"function","title":"Examples - Raxol.AI.ContentGeneration.generate_tutorial/2","doc":"iex> generate_tutorial(:keyboard_shortcuts)\n    {:ok, %{steps: [...], interactive: true}}","ref":"Raxol.AI.ContentGeneration.html#generate_tutorial/2-examples"},{"type":"type","title":"Raxol.AI.ContentGeneration.generation_options/0","doc":"","ref":"Raxol.AI.ContentGeneration.html#t:generation_options/0"},{"type":"type","title":"Raxol.AI.ContentGeneration.generation_type/0","doc":"","ref":"Raxol.AI.ContentGeneration.html#t:generation_type/0"},{"type":"function","title":"Raxol.AI.ContentGeneration.suggest_text/2","doc":"Generates text suggestions based on current input context.","ref":"Raxol.AI.ContentGeneration.html#suggest_text/2"},{"type":"function","title":"Examples - Raxol.AI.ContentGeneration.suggest_text/2","doc":"iex> suggest_text(\"print(\", context: %{language: :python})\n    {:ok, [\"print(\"Hello, World!\")\", \"print(value)\", \"print(f\"Value: {value}\")\"]}","ref":"Raxol.AI.ContentGeneration.html#suggest_text/2-examples"},{"type":"module","title":"Raxol.AI.PerformanceOptimization","doc":"Runtime AI features for intelligent performance optimization.\n\nThis module provides AI-driven performance optimizations including:\n\n* Predictive rendering - Intelligently determine what needs to be rendered\n* Resource allocation - Dynamically allocate system resources based on usage patterns\n* Component caching - Smart caching of frequently used components\n* Prefetching - Predict and preload content likely to be needed soon\n* Adaptive throttling - Adjust refresh rates based on current activity\n* Runtime profiling - Continuously monitor and analyze performance patterns","ref":"Raxol.AI.PerformanceOptimization.html"},{"type":"function","title":"Raxol.AI.PerformanceOptimization.analyze_performance/0","doc":"Analyzes performance and suggests optimizations.","ref":"Raxol.AI.PerformanceOptimization.html#analyze_performance/0"},{"type":"function","title":"Examples - Raxol.AI.PerformanceOptimization.analyze_performance/0","doc":"iex> analyze_performance()\n    [\n      %{type: :component, name: \"data_table\", issue: :slow_rendering, suggestion: \"Consider virtual scrolling\"},\n      %{type: :pattern, issue: :excessive_updates, suggestion: \"Implement throttling for search inputs\"}\n    ]","ref":"Raxol.AI.PerformanceOptimization.html#analyze_performance/0-examples"},{"type":"function","title":"Raxol.AI.PerformanceOptimization.get_prefetch_recommendations/1","doc":"Recommends components for prefetching based on usage patterns.","ref":"Raxol.AI.PerformanceOptimization.html#get_prefetch_recommendations/1"},{"type":"function","title":"Examples - Raxol.AI.PerformanceOptimization.get_prefetch_recommendations/1","doc":"iex> get_prefetch_recommendations(\"user_profile\")\n    [\"user_settings\", \"user_activity\"]","ref":"Raxol.AI.PerformanceOptimization.html#get_prefetch_recommendations/1-examples"},{"type":"function","title":"Raxol.AI.PerformanceOptimization.get_refresh_rate/1","doc":"Gets the recommended refresh rate for a component based on current activity.","ref":"Raxol.AI.PerformanceOptimization.html#get_refresh_rate/1"},{"type":"function","title":"Examples - Raxol.AI.PerformanceOptimization.get_refresh_rate/1","doc":"iex> get_refresh_rate(\"animated_progress\")\n    16  # milliseconds (approximately 60fps)","ref":"Raxol.AI.PerformanceOptimization.html#get_refresh_rate/1-examples"},{"type":"function","title":"Raxol.AI.PerformanceOptimization.init/1","doc":"Initializes the performance optimization system.","ref":"Raxol.AI.PerformanceOptimization.html#init/1"},{"type":"function","title":"Options - Raxol.AI.PerformanceOptimization.init/1","doc":"* `:optimization_level` - Level of optimization to apply (:minimal, :balanced, :aggressive)\n* `:features` - List of features to enable","ref":"Raxol.AI.PerformanceOptimization.html#init/1-options"},{"type":"function","title":"Examples - Raxol.AI.PerformanceOptimization.init/1","doc":"iex> init(optimization_level: :balanced)\n    :ok","ref":"Raxol.AI.PerformanceOptimization.html#init/1-examples"},{"type":"function","title":"Raxol.AI.PerformanceOptimization.record_component_usage/1","doc":"Records component usage for optimization analysis.","ref":"Raxol.AI.PerformanceOptimization.html#record_component_usage/1"},{"type":"function","title":"Examples - Raxol.AI.PerformanceOptimization.record_component_usage/1","doc":"iex> record_component_usage(\"dropdown_menu\")\n    :ok","ref":"Raxol.AI.PerformanceOptimization.html#record_component_usage/1-examples"},{"type":"function","title":"Raxol.AI.PerformanceOptimization.record_render_time/2","doc":"Records component render time for optimization analysis.","ref":"Raxol.AI.PerformanceOptimization.html#record_render_time/2"},{"type":"function","title":"Examples - Raxol.AI.PerformanceOptimization.record_render_time/2","doc":"iex> record_render_time(\"user_profile\", 25)\n    :ok","ref":"Raxol.AI.PerformanceOptimization.html#record_render_time/2-examples"},{"type":"function","title":"Raxol.AI.PerformanceOptimization.set_optimization_level/1","doc":"Sets the optimization level for the system.","ref":"Raxol.AI.PerformanceOptimization.html#set_optimization_level/1"},{"type":"function","title":"Examples - Raxol.AI.PerformanceOptimization.set_optimization_level/1","doc":"iex> set_optimization_level(:aggressive)\n    :ok","ref":"Raxol.AI.PerformanceOptimization.html#set_optimization_level/1-examples"},{"type":"function","title":"Raxol.AI.PerformanceOptimization.should_render?/2","doc":"Determines if a component should be rendered based on current conditions.\nUses predictive rendering to optimize performance.","ref":"Raxol.AI.PerformanceOptimization.html#should_render?/2"},{"type":"function","title":"Examples - Raxol.AI.PerformanceOptimization.should_render?/2","doc":"iex> should_render?(\"large_table\", %{visible: false, scroll_position: 500})\n    false","ref":"Raxol.AI.PerformanceOptimization.html#should_render?/2-examples"},{"type":"function","title":"Raxol.AI.PerformanceOptimization.toggle_feature/2","doc":"Enables or disables a specific optimization feature.","ref":"Raxol.AI.PerformanceOptimization.html#toggle_feature/2"},{"type":"function","title":"Examples - Raxol.AI.PerformanceOptimization.toggle_feature/2","doc":"iex> toggle_feature(:predictive_rendering, true)\n    :ok","ref":"Raxol.AI.PerformanceOptimization.html#toggle_feature/2-examples"},{"type":"module","title":"Raxol.Accounts","doc":"The Accounts context.\nManages user accounts and registration.\n(Currently uses an in-memory Agent for storage)","ref":"Raxol.Accounts.html"},{"type":"function","title":"Raxol.Accounts.authenticate_user/2","doc":"Authenticates a user by email and password.\n\nCurrently checks against plaintext passwords stored in the agent.\nIn a real app, this should use password hashing.","ref":"Raxol.Accounts.html#authenticate_user/2"},{"type":"function","title":"Raxol.Accounts.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Accounts.html#child_spec/1"},{"type":"function","title":"Raxol.Accounts.get_user/1","doc":"Retrieves the full user map by user ID.\nNote: Inefficient O(N) scan of the agent state.","ref":"Raxol.Accounts.html#get_user/1"},{"type":"function","title":"Raxol.Accounts.list_users/0","doc":"Returns the list of registered users.","ref":"Raxol.Accounts.html#list_users/0"},{"type":"function","title":"Raxol.Accounts.register_user/1","doc":"Registers a new user.","ref":"Raxol.Accounts.html#register_user/1"},{"type":"function","title":"Examples - Raxol.Accounts.register_user/1","doc":"iex> register_user(%{email: \"user@example.com\", password: \"password\"})\n    {:ok, %{id: ..., email: \"user@example.com\"}}\n\n    iex> register_user(%{email: \"user@example.com\", password: \"password\"})\n    {:error, %{email: \"has already been taken\"}}","ref":"Raxol.Accounts.html#register_user/1-examples"},{"type":"function","title":"Raxol.Accounts.start_link/1","doc":"","ref":"Raxol.Accounts.html#start_link/1"},{"type":"function","title":"Raxol.Accounts.update_password/3","doc":"Updates a user's password after verifying the current password.\nUses user_id to find the user.","ref":"Raxol.Accounts.html#update_password/3"},{"type":"module","title":"Raxol.Animation.Easing","doc":"Provides easing functions for animations.\n\nEasing functions control how an animation progresses over time.\nThey can make animations feel more natural by varying the speed\nat different points in the animation.\n\nAll functions take a progress value between 0.0 and 1.0 and return\nan eased value in the same range.","ref":"Raxol.Animation.Easing.html"},{"type":"function","title":"Raxol.Animation.Easing.ease_in/1","doc":"Standard ease-in.","ref":"Raxol.Animation.Easing.html#ease_in/1"},{"type":"function","title":"Examples - Raxol.Animation.Easing.ease_in/1","doc":"iex> Easing.ease_in(0.5)\n    0.25","ref":"Raxol.Animation.Easing.html#ease_in/1-examples"},{"type":"function","title":"Raxol.Animation.Easing.ease_in_cubic/1","doc":"Cubic ease-in.","ref":"Raxol.Animation.Easing.html#ease_in_cubic/1"},{"type":"function","title":"Examples - Raxol.Animation.Easing.ease_in_cubic/1","doc":"iex> Easing.ease_in_cubic(0.5)\n    0.125","ref":"Raxol.Animation.Easing.html#ease_in_cubic/1-examples"},{"type":"function","title":"Raxol.Animation.Easing.ease_in_elastic/1","doc":"Elastic ease-in.","ref":"Raxol.Animation.Easing.html#ease_in_elastic/1"},{"type":"function","title":"Examples - Raxol.Animation.Easing.ease_in_elastic/1","doc":"iex> Easing.ease_in_elastic(0.5)\n    0.5","ref":"Raxol.Animation.Easing.html#ease_in_elastic/1-examples"},{"type":"function","title":"Raxol.Animation.Easing.ease_in_out/1","doc":"Standard ease-in-out.","ref":"Raxol.Animation.Easing.html#ease_in_out/1"},{"type":"function","title":"Examples - Raxol.Animation.Easing.ease_in_out/1","doc":"iex> Easing.ease_in_out(0.5)\n    0.5","ref":"Raxol.Animation.Easing.html#ease_in_out/1-examples"},{"type":"function","title":"Raxol.Animation.Easing.ease_in_out_cubic/1","doc":"Cubic ease-in-out.","ref":"Raxol.Animation.Easing.html#ease_in_out_cubic/1"},{"type":"function","title":"Examples - Raxol.Animation.Easing.ease_in_out_cubic/1","doc":"iex> Easing.ease_in_out_cubic(0.5)\n    0.5","ref":"Raxol.Animation.Easing.html#ease_in_out_cubic/1-examples"},{"type":"function","title":"Raxol.Animation.Easing.ease_in_out_elastic/1","doc":"Elastic ease-in-out.","ref":"Raxol.Animation.Easing.html#ease_in_out_elastic/1"},{"type":"function","title":"Examples - Raxol.Animation.Easing.ease_in_out_elastic/1","doc":"iex> Easing.ease_in_out_elastic(0.5)\n    0.5","ref":"Raxol.Animation.Easing.html#ease_in_out_elastic/1-examples"},{"type":"function","title":"Raxol.Animation.Easing.ease_in_out_quad/1","doc":"Quadratic ease-in-out.","ref":"Raxol.Animation.Easing.html#ease_in_out_quad/1"},{"type":"function","title":"Examples - Raxol.Animation.Easing.ease_in_out_quad/1","doc":"iex> Easing.ease_in_out_quad(0.5)\n    0.5","ref":"Raxol.Animation.Easing.html#ease_in_out_quad/1-examples"},{"type":"function","title":"Raxol.Animation.Easing.ease_in_quad/1","doc":"Quadratic ease-in.","ref":"Raxol.Animation.Easing.html#ease_in_quad/1"},{"type":"function","title":"Examples - Raxol.Animation.Easing.ease_in_quad/1","doc":"iex> Easing.ease_in_quad(0.5)\n    0.25","ref":"Raxol.Animation.Easing.html#ease_in_quad/1-examples"},{"type":"function","title":"Raxol.Animation.Easing.ease_out/1","doc":"Standard ease-out.","ref":"Raxol.Animation.Easing.html#ease_out/1"},{"type":"function","title":"Examples - Raxol.Animation.Easing.ease_out/1","doc":"iex> Easing.ease_out(0.5)\n    0.75","ref":"Raxol.Animation.Easing.html#ease_out/1-examples"},{"type":"function","title":"Raxol.Animation.Easing.ease_out_cubic/1","doc":"Cubic ease-out.","ref":"Raxol.Animation.Easing.html#ease_out_cubic/1"},{"type":"function","title":"Examples - Raxol.Animation.Easing.ease_out_cubic/1","doc":"iex> Easing.ease_out_cubic(0.5)\n    0.875","ref":"Raxol.Animation.Easing.html#ease_out_cubic/1-examples"},{"type":"function","title":"Raxol.Animation.Easing.ease_out_elastic/1","doc":"Elastic ease-out.","ref":"Raxol.Animation.Easing.html#ease_out_elastic/1"},{"type":"function","title":"Examples - Raxol.Animation.Easing.ease_out_elastic/1","doc":"iex> Easing.ease_out_elastic(0.5)\n    0.5","ref":"Raxol.Animation.Easing.html#ease_out_elastic/1-examples"},{"type":"function","title":"Raxol.Animation.Easing.ease_out_quad/1","doc":"Quadratic ease-out.","ref":"Raxol.Animation.Easing.html#ease_out_quad/1"},{"type":"function","title":"Examples - Raxol.Animation.Easing.ease_out_quad/1","doc":"iex> Easing.ease_out_quad(0.5)\n    0.75","ref":"Raxol.Animation.Easing.html#ease_out_quad/1-examples"},{"type":"function","title":"Raxol.Animation.Easing.linear/1","doc":"Linear easing (no easing).","ref":"Raxol.Animation.Easing.html#linear/1"},{"type":"function","title":"Examples - Raxol.Animation.Easing.linear/1","doc":"iex> Easing.linear(0.5)\n    0.5","ref":"Raxol.Animation.Easing.html#linear/1-examples"},{"type":"module","title":"Raxol.Animation.Framework","doc":"A general-purpose animation framework for Raxol terminal UI applications.\n\nThis module provides a comprehensive animation system that:\n- Supports various animation types (easing, physics-based, keyframes)\n- Respects reduced motion accessibility settings\n- Provides smooth transitions between UI states\n- Offers standard animation patterns for common interactions\n- Manages animation timing and rendering\n\nThe framework automatically adapts to user preferences for reduced motion\nand will provide alternative non-animated transitions when needed.","ref":"Raxol.Animation.Framework.html"},{"type":"module","title":"Usage - Raxol.Animation.Framework","doc":"```elixir\n# Initialize the animation framework\nAnimationFramework.init()\n\n# Create a simple animation\nanimation = AnimationFramework.create_animation(:fade_in, %{\n  duration: 300,\n  easing: :ease_out_cubic\n})\n\n# Start the animation\nAnimationFramework.start_animation(animation, :element_id)\n\n# Update state with animation progress\nupdated_state = AnimationFramework.apply_animation(state, now)\n```","ref":"Raxol.Animation.Framework.html#module-usage"},{"type":"function","title":"Raxol.Animation.Framework.apply_animations_to_state/1","doc":"Update animations and apply their current values to the state.","ref":"Raxol.Animation.Framework.html#apply_animations_to_state/1"},{"type":"function","title":"Parameters - Raxol.Animation.Framework.apply_animations_to_state/1","doc":"* `state` - Current application state","ref":"Raxol.Animation.Framework.html#apply_animations_to_state/1-parameters"},{"type":"function","title":"Returns - Raxol.Animation.Framework.apply_animations_to_state/1","doc":"Updated state with animation values applied.","ref":"Raxol.Animation.Framework.html#apply_animations_to_state/1-returns"},{"type":"function","title":"Raxol.Animation.Framework.create_animation/2","doc":"Create a new animation.","ref":"Raxol.Animation.Framework.html#create_animation/2"},{"type":"function","title":"Parameters - Raxol.Animation.Framework.create_animation/2","doc":"* `name` - Unique identifier for the animation\n* `params` - Animation parameters","ref":"Raxol.Animation.Framework.html#create_animation/2-parameters"},{"type":"function","title":"Options - Raxol.Animation.Framework.create_animation/2","doc":"* `:type` - Animation type (:fade, :slide, :scale, :color, :generic)\n* `:duration` - Duration in milliseconds\n* `:easing` - Easing function name\n* `:from` - Starting value\n* `:to` - Ending value\n* `:direction` - Animation direction (:in, :out)\n* `:announce_to_screen_reader` - Whether to announce to screen readers\n* `:description` - Description for screen reader announcements","ref":"Raxol.Animation.Framework.html#create_animation/2-options"},{"type":"function","title":"Examples - Raxol.Animation.Framework.create_animation/2","doc":"iex> AnimationFramework.create_animation(:fade_in, %{\n    ...>   type: :fade,\n    ...>   duration: 300,\n    ...>   easing: :ease_out_cubic,\n    ...>   from: 0.0,\n    ...>   to: 1.0,\n    ...>   direction: :in\n    ...> })\n    %{\n      name: :fade_in,\n      type: :fade,\n      duration: 300,\n      easing: :ease_out_cubic,\n      from: 0.0,\n      to: 1.0,\n      direction: :in\n    }","ref":"Raxol.Animation.Framework.html#create_animation/2-examples"},{"type":"function","title":"Raxol.Animation.Framework.get_current_value/2","doc":"Gets the current value and completion status of an animation instance.","ref":"Raxol.Animation.Framework.html#get_current_value/2"},{"type":"function","title":"Parameters - Raxol.Animation.Framework.get_current_value/2","doc":"* `animation_name` - The name of the animation\n* `element_id` - Identifier for the element being animated","ref":"Raxol.Animation.Framework.html#get_current_value/2-parameters"},{"type":"function","title":"Returns - Raxol.Animation.Framework.get_current_value/2","doc":"* `{value, done?}` - A tuple with the current animation value and a boolean indicating if it's finished.\n* `:not_found` - If the animation instance is not active.","ref":"Raxol.Animation.Framework.html#get_current_value/2-returns"},{"type":"function","title":"Examples - Raxol.Animation.Framework.get_current_value/2","doc":"iex> AnimationFramework.get_current_value(:fade_in, \"search_button\")\n    {0.5, false}","ref":"Raxol.Animation.Framework.html#get_current_value/2-examples"},{"type":"function","title":"Raxol.Animation.Framework.init/1","doc":"Initialize the animation framework.\n\nThis sets up the necessary state for tracking animations and\nintegrates with accessibility settings.","ref":"Raxol.Animation.Framework.html#init/1"},{"type":"function","title":"Options - Raxol.Animation.Framework.init/1","doc":"* `:reduced_motion` - Start with reduced motion (default: from accessibility settings)\n* `:default_duration` - Default animation duration in milliseconds (default: 300)\n* `:frame_ms` - Frame duration in milliseconds (default: 33)","ref":"Raxol.Animation.Framework.html#init/1-options"},{"type":"function","title":"Examples - Raxol.Animation.Framework.init/1","doc":"iex> AnimationFramework.init()\n    :ok\n\n    iex> AnimationFramework.init(reduced_motion: true)\n    :ok","ref":"Raxol.Animation.Framework.html#init/1-examples"},{"type":"function","title":"Raxol.Animation.Framework.start_animation/3","doc":"Start an animation for a specific element.","ref":"Raxol.Animation.Framework.html#start_animation/3"},{"type":"function","title":"Parameters - Raxol.Animation.Framework.start_animation/3","doc":"* `animation_name` - The name of the animation to start\n* `element_id` - Identifier for the element being animated\n* `opts` - Additional options","ref":"Raxol.Animation.Framework.html#start_animation/3-parameters"},{"type":"function","title":"Options - Raxol.Animation.Framework.start_animation/3","doc":"* `:on_complete` - Function to call when animation completes\n* `:context` - Additional context for the animation","ref":"Raxol.Animation.Framework.html#start_animation/3-options"},{"type":"function","title":"Examples - Raxol.Animation.Framework.start_animation/3","doc":"iex> AnimationFramework.start_animation(:fade_in, \"search_button\")\n    :ok\n\n    iex> AnimationFramework.start_animation(:slide_in, \"panel\", on_complete: &handle_complete/1)\n    :ok","ref":"Raxol.Animation.Framework.html#start_animation/3-examples"},{"type":"function","title":"Raxol.Animation.Framework.stop_animation/2","doc":"Stops a specific animation for an element.","ref":"Raxol.Animation.Framework.html#stop_animation/2"},{"type":"function","title":"Parameters - Raxol.Animation.Framework.stop_animation/2","doc":"* `animation_name` - The name of the animation to stop\n* `element_id` - Identifier for the element being animated","ref":"Raxol.Animation.Framework.html#stop_animation/2-parameters"},{"type":"function","title":"Examples - Raxol.Animation.Framework.stop_animation/2","doc":"iex> AnimationFramework.stop_animation(:fade_in, \"search_button\")\n    :ok","ref":"Raxol.Animation.Framework.html#stop_animation/2-examples"},{"type":"module","title":"Raxol.Animation.Gestures","doc":"Gesture-driven interactions for Raxol animations.\n\nThis module provides a system for detecting and handling gestures in terminal UI,\nwhich can be used to trigger physics-based animations.\n\nSupported gestures include:\n* Swipe (rapid movement in a direction)\n* Tap (quick press and release)\n* Long press (press and hold)\n* Drag (press, move, release)\n* Pinch/zoom (simulated in terminal context)\n* Multi-tap (multiple quick taps)","ref":"Raxol.Animation.Gestures.html"},{"type":"type","title":"Raxol.Animation.Gestures.direction/0","doc":"","ref":"Raxol.Animation.Gestures.html#t:direction/0"},{"type":"type","title":"Raxol.Animation.Gestures.gesture_type/0","doc":"","ref":"Raxol.Animation.Gestures.html#t:gesture_type/0"},{"type":"function","title":"Raxol.Animation.Gestures.get_animation_objects/0","doc":"Gets the current state of all objects in active animations.\nThis is used for rendering.","ref":"Raxol.Animation.Gestures.html#get_animation_objects/0"},{"type":"type","title":"Raxol.Animation.Gestures.handler/0","doc":"","ref":"Raxol.Animation.Gestures.html#t:handler/0"},{"type":"function","title":"Raxol.Animation.Gestures.init/0","doc":"Initializes the gesture system.","ref":"Raxol.Animation.Gestures.html#init/0"},{"type":"type","title":"Raxol.Animation.Gestures.position/0","doc":"","ref":"Raxol.Animation.Gestures.html#t:position/0"},{"type":"function","title":"Raxol.Animation.Gestures.register_handler/2","doc":"Registers a handler for a specific gesture type.","ref":"Raxol.Animation.Gestures.html#register_handler/2"},{"type":"function","title":"Examples - Raxol.Animation.Gestures.register_handler/2","doc":"iex> register_handler(:swipe, fn %{direction: :left} -> handle_left_swipe() end)\n    :ok","ref":"Raxol.Animation.Gestures.html#register_handler/2-examples"},{"type":"function","title":"Raxol.Animation.Gestures.touch_down/2","doc":"Handles a touch/mouse down event.","ref":"Raxol.Animation.Gestures.html#touch_down/2"},{"type":"function","title":"Raxol.Animation.Gestures.touch_move/2","doc":"Handles a touch/mouse move event.","ref":"Raxol.Animation.Gestures.html#touch_move/2"},{"type":"function","title":"Raxol.Animation.Gestures.touch_up/2","doc":"Handles a touch/mouse up event.","ref":"Raxol.Animation.Gestures.html#touch_up/2"},{"type":"function","title":"Raxol.Animation.Gestures.update_animations/1","doc":"Updates all active physics-based animations.\nShould be called on each frame.","ref":"Raxol.Animation.Gestures.html#update_animations/1"},{"type":"module","title":"Raxol.Animation.Physics.ForceField","doc":"Force field implementation for physics simulations.\n\nForce fields apply forces to physics objects within their influence.\nTypes of force fields include:\n\n* Point (radial forces emanating from a point)\n* Directional (constant force in a direction, like wind)\n* Vortex (spinning forces)\n* Noise (random forces based on position)\n* Custom (user-defined force function)","ref":"Raxol.Animation.Physics.ForceField.html"},{"type":"function","title":"Raxol.Animation.Physics.ForceField.calculate_force/2","doc":"Calculates the force applied by a field on an object.","ref":"Raxol.Animation.Physics.ForceField.html#calculate_force/2"},{"type":"function","title":"Raxol.Animation.Physics.ForceField.custom_field/2","doc":"Creates a new custom force field.\n\nA custom force field uses a user-provided function to calculate forces.","ref":"Raxol.Animation.Physics.ForceField.html#custom_field/2"},{"type":"function","title":"Options - Raxol.Animation.Physics.ForceField.custom_field/2","doc":"* `:function` - Function to calculate force (fn object, field -> force_vector end)\n* `:properties` - Additional properties for the function (default: %{})","ref":"Raxol.Animation.Physics.ForceField.html#custom_field/2-options"},{"type":"function","title":"Raxol.Animation.Physics.ForceField.directional_field/1","doc":"Creates a new directional force field.\n\nA directional force field applies a constant force in a specific direction,\nlike wind or gravity.","ref":"Raxol.Animation.Physics.ForceField.html#directional_field/1"},{"type":"function","title":"Options - Raxol.Animation.Physics.ForceField.directional_field/1","doc":"* `:direction` - Direction of the force (default: up)\n* `:strength` - Strength of the field (default: 1.0)","ref":"Raxol.Animation.Physics.ForceField.html#directional_field/1-options"},{"type":"type","title":"Raxol.Animation.Physics.ForceField.field_type/0","doc":"","ref":"Raxol.Animation.Physics.ForceField.html#t:field_type/0"},{"type":"function","title":"Raxol.Animation.Physics.ForceField.noise_field/1","doc":"Creates a new noise force field.\n\nA noise force field applies pseudo-random forces based on position.","ref":"Raxol.Animation.Physics.ForceField.html#noise_field/1"},{"type":"function","title":"Options - Raxol.Animation.Physics.ForceField.noise_field/1","doc":"* `:strength` - Strength of the field (default: 1.0)\n* `:scale` - Scale of the noise (default: 0.1)\n* `:seed` - Random seed (default: random)","ref":"Raxol.Animation.Physics.ForceField.html#noise_field/1-options"},{"type":"function","title":"Raxol.Animation.Physics.ForceField.point_field/1","doc":"Creates a new point force field.\n\nA point force field applies forces radiating from or towards a point.\nPositive strength = repulsive, Negative strength = attractive.","ref":"Raxol.Animation.Physics.ForceField.html#point_field/1"},{"type":"function","title":"Options - Raxol.Animation.Physics.ForceField.point_field/1","doc":"* `:position` - Position of the field (default: origin)\n* `:strength` - Strength of the field (default: 1.0)\n* `:radius` - Radius of influence (default: 10.0)\n* `:falloff` - How force decreases with distance (:linear, :quadratic, :none) (default: :quadratic)","ref":"Raxol.Animation.Physics.ForceField.html#point_field/1-options"},{"type":"type","title":"Raxol.Animation.Physics.ForceField.t/0","doc":"","ref":"Raxol.Animation.Physics.ForceField.html#t:t/0"},{"type":"function","title":"Raxol.Animation.Physics.ForceField.vortex_field/1","doc":"Creates a new vortex force field.\n\nA vortex force field applies spinning forces around an axis.","ref":"Raxol.Animation.Physics.ForceField.html#vortex_field/1"},{"type":"function","title":"Options - Raxol.Animation.Physics.ForceField.vortex_field/1","doc":"* `:position` - Center of the vortex (default: origin)\n* `:direction` - Axis of rotation (default: up)\n* `:strength` - Strength of the field (default: 1.0)\n* `:radius` - Radius of influence (default: 10.0)\n* `:falloff` - How force decreases with distance (:linear, :quadratic, :none) (default: :linear)","ref":"Raxol.Animation.Physics.ForceField.html#vortex_field/1-options"},{"type":"module","title":"Raxol.Animation.Physics.PhysicsEngine","doc":"Physics engine for Raxol animations.\n\nProvides physics-based animation capabilities including:\n* Spring simulations\n* Gravity and bounce effects\n* Friction and damping\n* Collisions\n* Particle systems\n* Force fields\n\nThese can be used to create natural, organic animations that respond\nto user interactions in a physically plausible way.","ref":"Raxol.Animation.Physics.PhysicsEngine.html"},{"type":"function","title":"Raxol.Animation.Physics.PhysicsEngine.add_force_field/2","doc":"Adds a force field to the physics world.","ref":"Raxol.Animation.Physics.PhysicsEngine.html#add_force_field/2"},{"type":"function","title":"Raxol.Animation.Physics.PhysicsEngine.add_object/2","doc":"Adds an object to the physics world.","ref":"Raxol.Animation.Physics.PhysicsEngine.html#add_object/2"},{"type":"function","title":"Raxol.Animation.Physics.PhysicsEngine.apply_impulse/3","doc":"Applies an impulse force to an object.","ref":"Raxol.Animation.Physics.PhysicsEngine.html#apply_impulse/3"},{"type":"function","title":"Raxol.Animation.Physics.PhysicsEngine.create_particle_system/4","doc":"Creates a particle system at the specified position.","ref":"Raxol.Animation.Physics.PhysicsEngine.html#create_particle_system/4"},{"type":"function","title":"Raxol.Animation.Physics.PhysicsEngine.new_object/2","doc":"Creates a new physics object with the given properties.","ref":"Raxol.Animation.Physics.PhysicsEngine.html#new_object/2"},{"type":"function","title":"Raxol.Animation.Physics.PhysicsEngine.new_world/0","doc":"Creates a new physics world with default values.","ref":"Raxol.Animation.Physics.PhysicsEngine.html#new_world/0"},{"type":"function","title":"Raxol.Animation.Physics.PhysicsEngine.new_world/1","doc":"Creates a new physics world with custom settings.","ref":"Raxol.Animation.Physics.PhysicsEngine.html#new_world/1"},{"type":"type","title":"Raxol.Animation.Physics.PhysicsEngine.physics_object/0","doc":"","ref":"Raxol.Animation.Physics.PhysicsEngine.html#t:physics_object/0"},{"type":"function","title":"Raxol.Animation.Physics.PhysicsEngine.remove_object/2","doc":"Removes an object from the physics world.","ref":"Raxol.Animation.Physics.PhysicsEngine.html#remove_object/2"},{"type":"function","title":"Raxol.Animation.Physics.PhysicsEngine.set_boundaries/2","doc":"Sets the boundaries of the physics world.","ref":"Raxol.Animation.Physics.PhysicsEngine.html#set_boundaries/2"},{"type":"function","title":"Raxol.Animation.Physics.PhysicsEngine.spring_force/5","doc":"Creates a spring force between two objects.","ref":"Raxol.Animation.Physics.PhysicsEngine.html#spring_force/5"},{"type":"function","title":"Raxol.Animation.Physics.PhysicsEngine.update/2","doc":"Updates the physics world by one time step.","ref":"Raxol.Animation.Physics.PhysicsEngine.html#update/2"},{"type":"type","title":"Raxol.Animation.Physics.PhysicsEngine.world_state/0","doc":"","ref":"Raxol.Animation.Physics.PhysicsEngine.html#t:world_state/0"},{"type":"module","title":"Raxol.Animation.Physics.Vector","doc":"3D vector implementation for physics simulations.\n\nProvides basic vector operations needed for physics calculations.","ref":"Raxol.Animation.Physics.Vector.html"},{"type":"function","title":"Raxol.Animation.Physics.Vector.add/2","doc":"Adds two vectors.","ref":"Raxol.Animation.Physics.Vector.html#add/2"},{"type":"function","title":"Raxol.Animation.Physics.Vector.angle/2","doc":"Calculates the angle between two vectors in radians.","ref":"Raxol.Animation.Physics.Vector.html#angle/2"},{"type":"function","title":"Raxol.Animation.Physics.Vector.cross/2","doc":"Calculates the cross product of two vectors.","ref":"Raxol.Animation.Physics.Vector.html#cross/2"},{"type":"function","title":"Raxol.Animation.Physics.Vector.distance/2","doc":"Calculates the distance between two points represented as vectors.","ref":"Raxol.Animation.Physics.Vector.html#distance/2"},{"type":"function","title":"Raxol.Animation.Physics.Vector.dot/2","doc":"Calculates the dot product of two vectors.","ref":"Raxol.Animation.Physics.Vector.html#dot/2"},{"type":"function","title":"Raxol.Animation.Physics.Vector.from_spherical/3","doc":"Creates a vector from spherical coordinates.","ref":"Raxol.Animation.Physics.Vector.html#from_spherical/3"},{"type":"function","title":"Raxol.Animation.Physics.Vector.lerp/3","doc":"Performs linear interpolation between two vectors.","ref":"Raxol.Animation.Physics.Vector.html#lerp/3"},{"type":"function","title":"Raxol.Animation.Physics.Vector.magnitude/1","doc":"Calculates the magnitude (length) of a vector.","ref":"Raxol.Animation.Physics.Vector.html#magnitude/1"},{"type":"function","title":"Raxol.Animation.Physics.Vector.negate/1","doc":"Returns the negation of the vector.","ref":"Raxol.Animation.Physics.Vector.html#negate/1"},{"type":"function","title":"Raxol.Animation.Physics.Vector.new/3","doc":"Creates a new vector with the specified components.","ref":"Raxol.Animation.Physics.Vector.html#new/3"},{"type":"function","title":"Raxol.Animation.Physics.Vector.normalize/1","doc":"Normalizes a vector (makes it unit length).","ref":"Raxol.Animation.Physics.Vector.html#normalize/1"},{"type":"function","title":"Raxol.Animation.Physics.Vector.scale/2","doc":"Multiplies a vector by a scalar.","ref":"Raxol.Animation.Physics.Vector.html#scale/2"},{"type":"function","title":"Raxol.Animation.Physics.Vector.subtract/2","doc":"Subtracts the second vector from the first.","ref":"Raxol.Animation.Physics.Vector.html#subtract/2"},{"type":"type","title":"Raxol.Animation.Physics.Vector.t/0","doc":"","ref":"Raxol.Animation.Physics.Vector.html#t:t/0"},{"type":"function","title":"Raxol.Animation.Physics.Vector.to_string/1","doc":"Converts the vector to a string representation.","ref":"Raxol.Animation.Physics.Vector.html#to_string/1"},{"type":"module","title":"Raxol.Auth","doc":"Authentication module for handling user authentication and authorization.\n\nThis module provides functionality for:\n- User authentication\n- Token generation and validation\n- Role-based access control\n- Session management","ref":"Raxol.Auth.html"},{"type":"function","title":"Raxol.Auth.cleanup_user_session/1","doc":"Cleans up a user session.","ref":"Raxol.Auth.html#cleanup_user_session/1"},{"type":"function","title":"Raxol.Auth.create_user_session/2","doc":"Creates a new session for an authenticated user.\n(Session logic currently commented out, returns :ok)","ref":"Raxol.Auth.html#create_user_session/2"},{"type":"function","title":"Raxol.Auth.get_user/1","doc":"Retrieves user information by ID (Calls Accounts).","ref":"Raxol.Auth.html#get_user/1"},{"type":"function","title":"Raxol.Auth.get_user_by_session/1","doc":"TODO: Review if needed, Accounts.get_user/1 exists\nRetrieves a user by their session ID.\nReturns the user or nil if not found or session is invalid.","ref":"Raxol.Auth.html#get_user_by_session/1"},{"type":"function","title":"Raxol.Auth.has_permission?/3","doc":"Checks if a user has permission for a specific action (Placeholder).","ref":"Raxol.Auth.html#has_permission?/3"},{"type":"function","title":"Raxol.Auth.has_role?/2","doc":"Checks if a user has the required role.","ref":"Raxol.Auth.html#has_role?/2"},{"type":"function","title":"Raxol.Auth.validate_token/2","doc":"Validates a session token and returns the associated user ID.\nWARNING: This is a placeholder and insecure. Needs proper implementation.","ref":"Raxol.Auth.html#validate_token/2"},{"type":"module","title":"Raxol.Auth.Permission","doc":"Permission schema for role-based access control.","ref":"Raxol.Auth.Permission.html"},{"type":"function","title":"Raxol.Auth.Permission.changeset/2","doc":"Creates a changeset for a permission.","ref":"Raxol.Auth.Permission.html#changeset/2"},{"type":"function","title":"Raxol.Auth.Permission.system_changeset/2","doc":"Creates a changeset for a system permission.","ref":"Raxol.Auth.Permission.html#system_changeset/2"},{"type":"module","title":"Raxol.Auth.Plug","doc":"Plug for handling authentication and authorization.","ref":"Raxol.Auth.Plug.html"},{"type":"function","title":"Raxol.Auth.Plug.authenticate_user/3","doc":"Authenticates a user by email and password.","ref":"Raxol.Auth.Plug.html#authenticate_user/3"},{"type":"function","title":"Raxol.Auth.Plug.call/2","doc":"","ref":"Raxol.Auth.Plug.html#call/2"},{"type":"function","title":"Raxol.Auth.Plug.init/1","doc":"","ref":"Raxol.Auth.Plug.html#init/1"},{"type":"macro","title":"Raxol.Auth.Plug.is_admin?/1","doc":"","ref":"Raxol.Auth.Plug.html#is_admin?/1"},{"type":"function","title":"Raxol.Auth.Plug.logout_user/1","doc":"Logs out the current user.","ref":"Raxol.Auth.Plug.html#logout_user/1"},{"type":"function","title":"Raxol.Auth.Plug.require_authenticated_user/2","doc":"Checks if the current user is logged in.","ref":"Raxol.Auth.Plug.html#require_authenticated_user/2"},{"type":"function","title":"Raxol.Auth.Plug.require_permission/3","doc":"","ref":"Raxol.Auth.Plug.html#require_permission/3"},{"type":"module","title":"Raxol.Auth.Role","doc":"Role schema for role-based access control.","ref":"Raxol.Auth.Role.html"},{"type":"function","title":"Raxol.Auth.Role.changeset/2","doc":"Creates a changeset for a role.","ref":"Raxol.Auth.Role.html#changeset/2"},{"type":"function","title":"Raxol.Auth.Role.system_changeset/2","doc":"Creates a changeset for a system role.","ref":"Raxol.Auth.Role.html#system_changeset/2"},{"type":"module","title":"Raxol.Auth.User","doc":"User schema for authentication and authorization.","ref":"Raxol.Auth.User.html"},{"type":"function","title":"Raxol.Auth.User.changeset/2","doc":"Creates a changeset for a user.","ref":"Raxol.Auth.User.html#changeset/2"},{"type":"function","title":"Raxol.Auth.User.password_reset_changeset/2","doc":"Creates a changeset for password reset.","ref":"Raxol.Auth.User.html#password_reset_changeset/2"},{"type":"function","title":"Raxol.Auth.User.registration_changeset/2","doc":"Creates a changeset for registration.","ref":"Raxol.Auth.User.html#registration_changeset/2"},{"type":"module","title":"Raxol.Benchmarks.Performance","doc":"Performance benchmarking and validation tools for Raxol.\n\nThis module provides utilities for measuring and validating performance metrics\nincluding rendering speed, memory usage, and event handling latency.","ref":"Raxol.Benchmarks.Performance.html"},{"type":"function","title":"Raxol.Benchmarks.Performance.run_all/1","doc":"Runs all performance benchmarks and returns the results.","ref":"Raxol.Benchmarks.Performance.html#run_all/1"},{"type":"function","title":"Options - Raxol.Benchmarks.Performance.run_all/1","doc":"* `:save_results` - Save results to file (default: `true`)\n* `:compare_with_baseline` - Compare with baseline metrics (default: `true`)\n* `:detailed` - Include detailed metrics (default: `false`)","ref":"Raxol.Benchmarks.Performance.html#run_all/1-options"},{"type":"function","title":"Returns - Raxol.Benchmarks.Performance.run_all/1","doc":"Map containing benchmark results with the following structure:\n\n```\n%{\n  render_performance: %{...},\n  event_latency: %{...},\n  memory_usage: %{...},\n  animation_fps: %{...},\n  metrics_validation: %{...}\n}\n```","ref":"Raxol.Benchmarks.Performance.html#run_all/1-returns"},{"type":"module","title":"Raxol.Benchmarks.Performance.Animation","doc":"Animation performance benchmark functions for Raxol.","ref":"Raxol.Benchmarks.Performance.Animation.html"},{"type":"function","title":"Raxol.Benchmarks.Performance.Animation.benchmark_animation_performance/0","doc":"Benchmarks animation performance and frame rate stability.\n\nTests:\n- Maximum achievable FPS\n- Frame time consistency\n- Animation smoothness\n- CPU usage during animation","ref":"Raxol.Benchmarks.Performance.Animation.html#benchmark_animation_performance/0"},{"type":"module","title":"Raxol.Benchmarks.Performance.EventHandling","doc":"Event handling performance benchmark functions for Raxol.","ref":"Raxol.Benchmarks.Performance.EventHandling.html"},{"type":"function","title":"Raxol.Benchmarks.Performance.EventHandling.benchmark_event_handling/0","doc":"Benchmarks event handling latency for different event types and volumes.\n\nTests event handling for:\n- Keyboard events\n- Mouse events\n- Window events\n- Custom events\n- High-volume event bursts","ref":"Raxol.Benchmarks.Performance.EventHandling.html#benchmark_event_handling/0"},{"type":"module","title":"Raxol.Benchmarks.Performance.MemoryUsage","doc":"Memory usage performance benchmark functions for Raxol.","ref":"Raxol.Benchmarks.Performance.MemoryUsage.html"},{"type":"function","title":"Raxol.Benchmarks.Performance.MemoryUsage.benchmark_memory_usage/0","doc":"Benchmarks memory usage patterns for components and rendering cycles.\n\nMeasures:\n- Memory consumption per component\n- Memory growth during rendering\n- GC impact on performance\n- Memory leaks in long-running scenarios","ref":"Raxol.Benchmarks.Performance.MemoryUsage.html#benchmark_memory_usage/0"},{"type":"module","title":"Raxol.Benchmarks.Performance.Rendering","doc":"Rendering performance benchmark functions for Raxol.","ref":"Raxol.Benchmarks.Performance.Rendering.html"},{"type":"function","title":"Raxol.Benchmarks.Performance.Rendering.benchmark_rendering/0","doc":"Benchmarks rendering performance for various component types and complexities.\n\nTests rendering performance for:\n- Simple components (text, buttons)\n- Medium complexity (tables, lists)\n- Complex components (dashboards, multi-panel layouts)","ref":"Raxol.Benchmarks.Performance.Rendering.html#benchmark_rendering/0"},{"type":"function","title":"Raxol.Benchmarks.Performance.Rendering.calculate_components_per_frame/1","doc":"","ref":"Raxol.Benchmarks.Performance.Rendering.html#calculate_components_per_frame/1"},{"type":"function","title":"Raxol.Benchmarks.Performance.Rendering.calculate_renders_per_second/1","doc":"","ref":"Raxol.Benchmarks.Performance.Rendering.html#calculate_renders_per_second/1"},{"type":"function","title":"Raxol.Benchmarks.Performance.Rendering.generate_test_component/1","doc":"","ref":"Raxol.Benchmarks.Performance.Rendering.html#generate_test_component/1"},{"type":"function","title":"Raxol.Benchmarks.Performance.Rendering.measure_full_screen_render/1","doc":"","ref":"Raxol.Benchmarks.Performance.Rendering.html#measure_full_screen_render/1"},{"type":"function","title":"Raxol.Benchmarks.Performance.Rendering.measure_render_time/2","doc":"","ref":"Raxol.Benchmarks.Performance.Rendering.html#measure_render_time/2"},{"type":"function","title":"Raxol.Benchmarks.Performance.Rendering.render_component/1","doc":"","ref":"Raxol.Benchmarks.Performance.Rendering.html#render_component/1"},{"type":"module","title":"Raxol.Benchmarks.Performance.Reporting","doc":"Reporting functions (saving, printing) for Raxol performance benchmarks.","ref":"Raxol.Benchmarks.Performance.Reporting.html"},{"type":"function","title":"Raxol.Benchmarks.Performance.Reporting.print_summary/2","doc":"","ref":"Raxol.Benchmarks.Performance.Reporting.html#print_summary/2"},{"type":"function","title":"Raxol.Benchmarks.Performance.Reporting.save_benchmark_results/2","doc":"Saves benchmark results to a file.","ref":"Raxol.Benchmarks.Performance.Reporting.html#save_benchmark_results/2"},{"type":"function","title":"Parameters - Raxol.Benchmarks.Performance.Reporting.save_benchmark_results/2","doc":"* `results` - Benchmark results map\n* `file_path` - Path to save results (default: auto-generated)","ref":"Raxol.Benchmarks.Performance.Reporting.html#save_benchmark_results/2-parameters"},{"type":"module","title":"Raxol.Benchmarks.Performance.Validation","doc":"Validation functions for Raxol performance benchmarks.","ref":"Raxol.Benchmarks.Performance.Validation.html"},{"type":"function","title":"Raxol.Benchmarks.Performance.Validation.get_baseline_metrics/0","doc":"Retrieves baseline performance metrics for the current platform.\n\nIf no platform-specific baseline exists, falls back to default baseline.","ref":"Raxol.Benchmarks.Performance.Validation.html#get_baseline_metrics/0"},{"type":"function","title":"Raxol.Benchmarks.Performance.Validation.validate_metrics/2","doc":"Validates performance against baseline requirements.","ref":"Raxol.Benchmarks.Performance.Validation.html#validate_metrics/2"},{"type":"function","title":"Parameters - Raxol.Benchmarks.Performance.Validation.validate_metrics/2","doc":"* `results` - Current benchmark results\n* `baseline` - Baseline metrics to compare against","ref":"Raxol.Benchmarks.Performance.Validation.html#validate_metrics/2-parameters"},{"type":"function","title":"Returns - Raxol.Benchmarks.Performance.Validation.validate_metrics/2","doc":"Map containing validation results and pass/fail status for each metric","ref":"Raxol.Benchmarks.Performance.Validation.html#validate_metrics/2-returns"},{"type":"module","title":"Raxol.Benchmarks.VisualizationBenchmark","doc":"Performance benchmarking tool for visualization components.\nProvides tools to measure rendering time, memory usage, and optimization effectiveness\nfor different data sizes and visualization types.","ref":"Raxol.Benchmarks.VisualizationBenchmark.html"},{"type":"function","title":"Raxol.Benchmarks.VisualizationBenchmark.benchmark_charts/4","doc":"Benchmark chart rendering performance.","ref":"Raxol.Benchmarks.VisualizationBenchmark.html#benchmark_charts/4"},{"type":"function","title":"Raxol.Benchmarks.VisualizationBenchmark.benchmark_treemaps/4","doc":"Benchmark treemap rendering performance.","ref":"Raxol.Benchmarks.VisualizationBenchmark.html#benchmark_treemaps/4"},{"type":"function","title":"Raxol.Benchmarks.VisualizationBenchmark.run_benchmark/1","doc":"Run a comprehensive benchmark suite for visualization components.\n\nThis test will:\n1. Generate test datasets of varying sizes\n2. Benchmark chart rendering performance\n3. Benchmark treemap rendering performance\n4. Test cache hit performance\n5. Measure memory usage\n6. Generate a summary report","ref":"Raxol.Benchmarks.VisualizationBenchmark.html#run_benchmark/1"},{"type":"function","title":"Options - Raxol.Benchmarks.VisualizationBenchmark.run_benchmark/1","doc":"* `:output_path` - Path to write the benchmark results (default: \"benchmark_results\")\n* `:datasets` - List of dataset sizes to test (default: [10, 100, 1000, 10000])\n* `:iterations` - Number of times to run each test (default: 5)\n* `:cache_test` - Whether to test cache performance (default: true)\n* `:memory_test` - Whether to track memory usage (default: true)","ref":"Raxol.Benchmarks.VisualizationBenchmark.html#run_benchmark/1-options"},{"type":"module","title":"Raxol.Benchmarks.VisualizationBenchmarkRealistic","doc":"A realistic benchmark tool for visualization components with progressive data sizes.\nTests the performance impact of our optimizations on various dataset sizes.","ref":"Raxol.Benchmarks.VisualizationBenchmarkRealistic.html"},{"type":"function","title":"Raxol.Benchmarks.VisualizationBenchmarkRealistic.run_benchmark/0","doc":"Run a benchmark test with realistic dataset sizes.\n\nThis function tests the caching system and data sampling optimizations\nwith progressively larger data sizes.\n\nReturns a map with the benchmark results.","ref":"Raxol.Benchmarks.VisualizationBenchmarkRealistic.html#run_benchmark/0"},{"type":"module","title":"Raxol.Benchmarks.VisualizationBenchmarkSimple","doc":"A simplified benchmark tool for visualization components, without external dependencies.\nThis is designed for direct testing during development without requiring the full application.","ref":"Raxol.Benchmarks.VisualizationBenchmarkSimple.html"},{"type":"function","title":"Raxol.Benchmarks.VisualizationBenchmarkSimple.run_simple_benchmark/0","doc":"Run a simple benchmark test of the visualization caching system.\n\nThis function directly tests the VisualizationPlugin's caching system\nwith small data samples and doesn't require the full application to be running.\n\nReturns a map with the benchmark results.","ref":"Raxol.Benchmarks.VisualizationBenchmarkSimple.html#run_simple_benchmark/0"},{"type":"module","title":"Raxol.CLI.Commands.UpdateCmd","doc":"CLI command for managing Raxol updates.\n\nThis module handles:\n- Checking for updates\n- Performing self-updates\n- Managing update settings","ref":"Raxol.CLI.Commands.UpdateCmd.html"},{"type":"function","title":"Raxol.CLI.Commands.UpdateCmd.execute/1","doc":"Executes the update command with the provided options and arguments.","ref":"Raxol.CLI.Commands.UpdateCmd.html#execute/1"},{"type":"function","title":"Options - Raxol.CLI.Commands.UpdateCmd.execute/1","doc":"- `--check` or `-c`: Check for updates without installing\n- `--force` or `-f`: Force update check, bypassing the check interval\n- `--auto` or `-a`: Enable or disable automatic update checks (value: on/off)\n- `--version` or `-v`: Update to a specific version\n- `--no-delta` or `-n`: Disable delta updates and use full updates only\n- `--delta-info` or `-d`: Show information about delta update availability","ref":"Raxol.CLI.Commands.UpdateCmd.html#execute/1-options"},{"type":"function","title":"Examples - Raxol.CLI.Commands.UpdateCmd.execute/1","doc":"Check for updates:\n```\nraxol update --check\n```\n\nPerform an update:\n```\nraxol update\n```\n\nUpdate to a specific version:\n```\nraxol update --version 0.2.0\n```\n\nUpdate without using delta updates:\n```\nraxol update --no-delta\n```\n\nDisable automatic update checks:\n```\nraxol update --auto off\n```","ref":"Raxol.CLI.Commands.UpdateCmd.html#execute/1-examples"},{"type":"module","title":"Raxol.Cloud","doc":"Cloud integration system for Raxol applications.","ref":"Raxol.Cloud.html"},{"type":"function","title":"Raxol.Cloud.config/3","doc":"","ref":"Raxol.Cloud.html#config/3"},{"type":"function","title":"Raxol.Cloud.connect/1","doc":"","ref":"Raxol.Cloud.html#connect/1"},{"type":"function","title":"Raxol.Cloud.deploy/1","doc":"","ref":"Raxol.Cloud.html#deploy/1"},{"type":"function","title":"Raxol.Cloud.discover/1","doc":"","ref":"Raxol.Cloud.html#discover/1"},{"type":"function","title":"Raxol.Cloud.execute/2","doc":"","ref":"Raxol.Cloud.html#execute/2"},{"type":"function","title":"Raxol.Cloud.init/1","doc":"","ref":"Raxol.Cloud.html#init/1"},{"type":"function","title":"Raxol.Cloud.monitor/3","doc":"","ref":"Raxol.Cloud.html#monitor/3"},{"type":"function","title":"Raxol.Cloud.register/1","doc":"","ref":"Raxol.Cloud.html#register/1"},{"type":"function","title":"Raxol.Cloud.scale/1","doc":"","ref":"Raxol.Cloud.html#scale/1"},{"type":"function","title":"Raxol.Cloud.start/0","doc":"","ref":"Raxol.Cloud.html#start/0"},{"type":"function","title":"Raxol.Cloud.status/0","doc":"","ref":"Raxol.Cloud.html#status/0"},{"type":"function","title":"Raxol.Cloud.stop/0","doc":"","ref":"Raxol.Cloud.html#stop/0"},{"type":"module","title":"Raxol.Cloud.Config","doc":"Configuration management for Raxol cloud integrations.\n\nProvides centralized configuration management with validation,\ndynamic updates, and multiple source support.","ref":"Raxol.Cloud.Config.html"},{"type":"function","title":"Raxol.Cloud.Config.get/1","doc":"Gets the current configuration.","ref":"Raxol.Cloud.Config.html#get/1"},{"type":"function","title":"Options - Raxol.Cloud.Config.get/1","doc":"* `:section` - Specific configuration section to get\n* `:flatten` - Whether to flatten nested maps","ref":"Raxol.Cloud.Config.html#get/1-options"},{"type":"function","title":"Raxol.Cloud.Config.get_default/1","doc":"Gets the default configuration value for a key.","ref":"Raxol.Cloud.Config.html#get_default/1"},{"type":"function","title":"Raxol.Cloud.Config.init/1","doc":"Initializes the configuration system.","ref":"Raxol.Cloud.Config.html#init/1"},{"type":"function","title":"Options - Raxol.Cloud.Config.init/1","doc":"* `:sources` - List of configuration sources [:env, :file]\n* `:environment` - Environment to use (:development, :test, :production)\n* `:config_file` - Path to configuration file\n* `:auto_apply` - Whether to automatically apply configuration","ref":"Raxol.Cloud.Config.html#init/1-options"},{"type":"function","title":"Raxol.Cloud.Config.reload/1","doc":"Reloads configuration from all sources.","ref":"Raxol.Cloud.Config.html#reload/1"},{"type":"function","title":"Options - Raxol.Cloud.Config.reload/1","doc":"* `:sources` - List of sources to reload from\n* `:apply` - Whether to apply the reloaded configuration","ref":"Raxol.Cloud.Config.html#reload/1-options"},{"type":"function","title":"Raxol.Cloud.Config.status/0","doc":"Gets the current status of the configuration system.","ref":"Raxol.Cloud.Config.html#status/0"},{"type":"function","title":"Raxol.Cloud.Config.update/2","doc":"Updates the configuration with new values.","ref":"Raxol.Cloud.Config.html#update/2"},{"type":"function","title":"Options - Raxol.Cloud.Config.update/2","doc":"* `:section` - Section to update\n* `:validate` - Whether to validate the configuration\n* `:persist` - Whether to persist changes\n* `:apply` - Whether to apply changes","ref":"Raxol.Cloud.Config.html#update/2-options"},{"type":"module","title":"Raxol.Cloud.Core","doc":"Core functionality for Raxol cloud integrations.\n\nThis module combines edge computing and monitoring capabilities,\nproviding a unified interface for cloud operations.","ref":"Raxol.Cloud.Core.html"},{"type":"function","title":"Raxol.Cloud.Core.deploy/1","doc":"Deploys an application component.","ref":"Raxol.Cloud.Core.html#deploy/1"},{"type":"function","title":"Raxol.Cloud.Core.discover_services/1","doc":"Discovers services available in the current environment.","ref":"Raxol.Cloud.Core.html#discover_services/1"},{"type":"function","title":"Raxol.Cloud.Core.execute/2","doc":"Executes a function in the optimal location (edge or cloud).","ref":"Raxol.Cloud.Core.html#execute/2"},{"type":"function","title":"Options - Raxol.Cloud.Core.execute/2","doc":"* `:priority` - Priority for execution (:speed, :reliability, :cost)\n* `:location` - Preferred location (:auto, :edge, :cloud)\n* `:timeout` - Timeout in milliseconds","ref":"Raxol.Cloud.Core.html#execute/2-options"},{"type":"function","title":"Raxol.Cloud.Core.get_service_connection/1","doc":"Gets a connection to a cloud service.","ref":"Raxol.Cloud.Core.html#get_service_connection/1"},{"type":"function","title":"Raxol.Cloud.Core.init/1","doc":"Initializes the cloud core components.","ref":"Raxol.Cloud.Core.html#init/1"},{"type":"function","title":"Options - Raxol.Cloud.Core.init/1","doc":"* `:edge` - Edge computing options\n* `:monitoring` - Monitoring options\n* `:providers` - List of cloud providers to enable","ref":"Raxol.Cloud.Core.html#init/1-options"},{"type":"function","title":"Raxol.Cloud.Core.record_error/2","doc":"Records an error or exception.","ref":"Raxol.Cloud.Core.html#record_error/2"},{"type":"function","title":"Raxol.Cloud.Core.record_metric/3","doc":"Records a metric with the given name and value.","ref":"Raxol.Cloud.Core.html#record_metric/3"},{"type":"function","title":"Raxol.Cloud.Core.register_service/1","doc":"Registers the current application as a service.","ref":"Raxol.Cloud.Core.html#register_service/1"},{"type":"function","title":"Raxol.Cloud.Core.run_health_check/1","doc":"Runs a health check on the system.","ref":"Raxol.Cloud.Core.html#run_health_check/1"},{"type":"function","title":"Raxol.Cloud.Core.scale/1","doc":"Scales a service based on current metrics and conditions.","ref":"Raxol.Cloud.Core.html#scale/1"},{"type":"function","title":"Raxol.Cloud.Core.start/0","doc":"Starts all cloud services.","ref":"Raxol.Cloud.Core.html#start/0"},{"type":"function","title":"Raxol.Cloud.Core.status/0","doc":"Returns the current status of all cloud services.","ref":"Raxol.Cloud.Core.html#status/0"},{"type":"function","title":"Raxol.Cloud.Core.stop/0","doc":"Stops all cloud services.","ref":"Raxol.Cloud.Core.html#stop/0"},{"type":"function","title":"Raxol.Cloud.Core.trigger_alert/3","doc":"Triggers an alert with the given type and data.","ref":"Raxol.Cloud.Core.html#trigger_alert/3"},{"type":"module","title":"Raxol.Cloud.EdgeComputing","doc":"Edge computing support for Raxol applications.\n\nThis module provides functionality for optimizing Raxol applications\nat the edge, allowing for improved performance, reduced latency,\nand offline capabilities.\n\nFeatures:\n* Edge processing configuration\n* Offline mode and data synchronization\n* Resource optimization for edge devices\n* Automatic failover between edge and cloud\n* Edge-specific monitoring and diagnostics\n* Edge-to-cloud data streaming","ref":"Raxol.Cloud.EdgeComputing.html"},{"type":"function","title":"Raxol.Cloud.EdgeComputing.check_connection/0","doc":"Manually checks the cloud connection status and updates the system state.","ref":"Raxol.Cloud.EdgeComputing.html#check_connection/0"},{"type":"function","title":"Raxol.Cloud.EdgeComputing.clear_cache/0","doc":"Clears the edge cache.","ref":"Raxol.Cloud.EdgeComputing.html#clear_cache/0"},{"type":"function","title":"Raxol.Cloud.EdgeComputing.execute/2","doc":"Executes a function at the edge or in the cloud based on current mode and conditions.","ref":"Raxol.Cloud.EdgeComputing.html#execute/2"},{"type":"function","title":"Options - Raxol.Cloud.EdgeComputing.execute/2","doc":"* `:force_edge` - Force execution at the edge even in hybrid mode (default: false)\n* `:force_cloud` - Force execution in the cloud even in hybrid mode (default: false)\n* `:fallback_fn` - Function to execute if primary execution fails (default: nil)\n* `:timeout` - Timeout in milliseconds for the operation (default: 5000)\n* `:retry` - Number of retry attempts (default: from config)","ref":"Raxol.Cloud.EdgeComputing.html#execute/2-options"},{"type":"function","title":"Examples - Raxol.Cloud.EdgeComputing.execute/2","doc":"iex> execute(fn -> process_data(data) end)\n    {:ok, result}","ref":"Raxol.Cloud.EdgeComputing.html#execute/2-examples"},{"type":"function","title":"Raxol.Cloud.EdgeComputing.force_mode/1","doc":"Forces the system into a specific mode.","ref":"Raxol.Cloud.EdgeComputing.html#force_mode/1"},{"type":"function","title":"Raxol.Cloud.EdgeComputing.get_metrics/0","doc":"Gets metrics for the edge computing system.","ref":"Raxol.Cloud.EdgeComputing.html#get_metrics/0"},{"type":"function","title":"Raxol.Cloud.EdgeComputing.init/1","doc":"Initializes the edge computing system.","ref":"Raxol.Cloud.EdgeComputing.html#init/1"},{"type":"function","title":"Options - Raxol.Cloud.EdgeComputing.init/1","doc":"* `:mode` - Operation mode (:edge_only, :cloud_only, :hybrid) (default: :hybrid)\n* `:connection_check_interval` - Time in ms between connection checks (default: 5000)\n* `:sync_interval` - Time in ms between cloud syncs (default: 30000)\n* `:retry_limit` - Number of retry attempts for operations (default: 5)\n* `:compression_enabled` - Whether to compress data for transfer (default: true)\n* `:offline_cache_size` - Maximum size in bytes for offline cache (default: 100MB)\n* `:priority_functions` - List of functions that should prioritize edge execution","ref":"Raxol.Cloud.EdgeComputing.html#init/1-options"},{"type":"function","title":"Examples - Raxol.Cloud.EdgeComputing.init/1","doc":"iex> init(mode: :hybrid)\n    :ok","ref":"Raxol.Cloud.EdgeComputing.html#init/1-examples"},{"type":"function","title":"Raxol.Cloud.EdgeComputing.offline?/0","doc":"Checks if the system is currently operating in offline mode.","ref":"Raxol.Cloud.EdgeComputing.html#offline?/0"},{"type":"function","title":"Raxol.Cloud.EdgeComputing.status/0","doc":"Gets the current status of the edge computing system.","ref":"Raxol.Cloud.EdgeComputing.html#status/0"},{"type":"function","title":"Raxol.Cloud.EdgeComputing.sync/1","doc":"Synchronizes data between edge and cloud.","ref":"Raxol.Cloud.EdgeComputing.html#sync/1"},{"type":"function","title":"Options - Raxol.Cloud.EdgeComputing.sync/1","doc":"* `:force` - Force immediate synchronization (default: false)\n* `:selective` - List of data types to synchronize (default: all)\n* `:direction` - Sync direction (:both, :to_cloud, :from_cloud) (default: :both)\n* `:conflict_resolution` - Strategy for resolving conflicts (default: :latest_wins)","ref":"Raxol.Cloud.EdgeComputing.html#sync/1-options"},{"type":"function","title":"Examples - Raxol.Cloud.EdgeComputing.sync/1","doc":"iex> sync(force: true)\n    {:ok, %{status: :completed, synced_items: 5}}","ref":"Raxol.Cloud.EdgeComputing.html#sync/1-examples"},{"type":"function","title":"Raxol.Cloud.EdgeComputing.update_config/2","doc":"Updates the edge computing configuration.","ref":"Raxol.Cloud.EdgeComputing.html#update_config/2"},{"type":"module","title":"Raxol.Cloud.Integrations","doc":"Cloud integration utilities for Raxol applications.\n\nThis module provides integration utilities for connecting various cloud services\nwith Raxol applications, focusing on edge computing, monitoring, and service discovery.\nIt serves as a central coordination point for cloud-related features.\n\nFeatures:\n* Edge-to-cloud integration helpers\n* Centralized configuration management\n* Service discovery and registration\n* Multi-cloud provider support\n* Deployment and scaling utilities","ref":"Raxol.Cloud.Integrations.html"},{"type":"function","title":"Raxol.Cloud.Integrations.deploy/1","doc":"Deploys an application component to the appropriate environment based on configuration.","ref":"Raxol.Cloud.Integrations.html#deploy/1"},{"type":"function","title":"Options - Raxol.Cloud.Integrations.deploy/1","doc":"* `:component` - Name of the component to deploy\n* `:version` - Version to deploy\n* `:environment` - Target environment (:production, :staging, :development)\n* `:strategy` - Deployment strategy (:blue_green, :canary, :rolling)","ref":"Raxol.Cloud.Integrations.html#deploy/1-options"},{"type":"function","title":"Examples - Raxol.Cloud.Integrations.deploy/1","doc":"iex> deploy(\n    ...>   component: :api_service,\n    ...>   version: \"1.2.3\",\n    ...>   environment: :production,\n    ...>   strategy: :blue_green\n    ...> )\n    {:ok, %{deployment_id: \"dep-12345\", status: :in_progress}}","ref":"Raxol.Cloud.Integrations.html#deploy/1-examples"},{"type":"function","title":"Raxol.Cloud.Integrations.discover_services/1","doc":"Discovers services available in the current environment.","ref":"Raxol.Cloud.Integrations.html#discover_services/1"},{"type":"function","title":"Options - Raxol.Cloud.Integrations.discover_services/1","doc":"* `:type` - Type of service to discover (:all, or a specific service type)\n* `:provider` - Cloud provider to query (:all, or a specific provider)\n* `:region` - Region to search in","ref":"Raxol.Cloud.Integrations.html#discover_services/1-options"},{"type":"function","title":"Examples - Raxol.Cloud.Integrations.discover_services/1","doc":"iex> discover_services(type: :database)\n    {:ok, [\n      %{name: \"main-db\", type: :database, endpoint: \"main-db.example.com:5432\"},\n      %{name: \"analytics-db\", type: :database, endpoint: \"analytics-db.example.com:5432\"}\n    ]}","ref":"Raxol.Cloud.Integrations.html#discover_services/1-examples"},{"type":"function","title":"Raxol.Cloud.Integrations.execute/2","doc":"Executes a function in the optimal location (edge or cloud) based on current conditions.\n\nThis is a wrapper around EdgeComputing.execute/2 that adds monitoring.","ref":"Raxol.Cloud.Integrations.html#execute/2"},{"type":"function","title":"Examples - Raxol.Cloud.Integrations.execute/2","doc":"iex> execute(fn -> perform_calculation(data) end, priority: :speed)\n    {:ok, result}","ref":"Raxol.Cloud.Integrations.html#execute/2-examples"},{"type":"function","title":"Raxol.Cloud.Integrations.get_service_connection/1","doc":"Gets a connection to a cloud service with the specified parameters.","ref":"Raxol.Cloud.Integrations.html#get_service_connection/1"},{"type":"function","title":"Options - Raxol.Cloud.Integrations.get_service_connection/1","doc":"* `:service` - Service name or type to connect to (required)\n* `:provider` - Cloud provider to use (:aws, :azure, :gcp, or :custom)\n* `:region` - Region to connect to\n* `:config` - Additional configuration for the connection","ref":"Raxol.Cloud.Integrations.html#get_service_connection/1-options"},{"type":"function","title":"Examples - Raxol.Cloud.Integrations.get_service_connection/1","doc":"iex> get_service_connection(\n    ...>   service: :storage,\n    ...>   provider: :aws,\n    ...>   region: \"us-west-2\"\n    ...> )\n    {:ok, %{\n    ...>   client: client,\n    ...>   endpoint: \"s3.us-west-2.amazonaws.com\",\n    ...>   service: :storage,\n    ...>   provider: :aws\n    ...> }}","ref":"Raxol.Cloud.Integrations.html#get_service_connection/1-examples"},{"type":"function","title":"Raxol.Cloud.Integrations.init/1","doc":"Initializes all cloud integrations with the provided configuration.","ref":"Raxol.Cloud.Integrations.html#init/1"},{"type":"function","title":"Options - Raxol.Cloud.Integrations.init/1","doc":"* `:edge` - Options for edge computing (passed to EdgeComputing.init/1)\n* `:monitoring` - Options for monitoring system (passed to Monitoring.init/1)\n* `:providers` - List of cloud providers to enable [:aws, :azure, :gcp, :custom]\n* `:service_discovery` - Service discovery configuration\n* `:deployment` - Deployment and scaling configuration","ref":"Raxol.Cloud.Integrations.html#init/1-options"},{"type":"function","title":"Examples - Raxol.Cloud.Integrations.init/1","doc":"iex> init(\n    ...>   edge: [mode: :auto, sync_interval: 30000],\n    ...>   monitoring: [backends: [:prometheus], active: true],\n    ...>   providers: [:aws]\n    ...> )\n    :ok","ref":"Raxol.Cloud.Integrations.html#init/1-examples"},{"type":"function","title":"Raxol.Cloud.Integrations.register_service/1","doc":"Registers the current application as a service in the service discovery system.","ref":"Raxol.Cloud.Integrations.html#register_service/1"},{"type":"function","title":"Options - Raxol.Cloud.Integrations.register_service/1","doc":"* `:name` - Service name (required)\n* `:type` - Service type (required)\n* `:endpoint` - Service endpoint (required)\n* `:metadata` - Additional metadata about the service\n* `:health_check_path` - Path for health checks","ref":"Raxol.Cloud.Integrations.html#register_service/1-options"},{"type":"function","title":"Examples - Raxol.Cloud.Integrations.register_service/1","doc":"iex> register_service(\n    ...>   name: \"user-api\",\n    ...>   type: :api,\n    ...>   endpoint: \"user-api.example.com:8080\",\n    ...>   health_check_path: \"/health\"\n    ...> )\n    {:ok, %{registration_id: \"reg-12345\", status: :registered}}","ref":"Raxol.Cloud.Integrations.html#register_service/1-examples"},{"type":"function","title":"Raxol.Cloud.Integrations.scale/1","doc":"Scales a service based on current metrics and conditions.","ref":"Raxol.Cloud.Integrations.html#scale/1"},{"type":"function","title":"Options - Raxol.Cloud.Integrations.scale/1","doc":"* `:service` - Service name to scale (required)\n* `:min` - Minimum number of instances\n* `:max` - Maximum number of instances\n* `:desired` - Desired number of instances (if specified, overrides automatic scaling)\n* `:metrics` - Metrics to use for scaling decisions","ref":"Raxol.Cloud.Integrations.html#scale/1-options"},{"type":"function","title":"Examples - Raxol.Cloud.Integrations.scale/1","doc":"iex> scale(\n    ...>   service: \"api-server\",\n    ...>   min: 2,\n    ...>   max: 10,\n    ...>   metrics: [\n    ...>     %{name: \"cpu\", target: 70},\n    ...>     %{name: \"requests\", target: 1000}\n    ...>   ]\n    ...> )\n    {:ok, %{service: \"api-server\", current: 2, target: 4, status: :scaling}}","ref":"Raxol.Cloud.Integrations.html#scale/1-examples"},{"type":"function","title":"Raxol.Cloud.Integrations.status/0","doc":"Returns the current status of all cloud integrations.","ref":"Raxol.Cloud.Integrations.html#status/0"},{"type":"function","title":"Examples - Raxol.Cloud.Integrations.status/0","doc":"iex> status()\n    %{\n      edge: %{mode: :auto, connected: true, ...},\n      monitoring: %{active: true, ...},\n      providers: %{aws: :connected, ...}\n    }","ref":"Raxol.Cloud.Integrations.html#status/0-examples"},{"type":"module","title":"Raxol.Cloud.Monitoring","doc":"Cloud monitoring system for Raxol applications.\n\nThis module provides comprehensive monitoring capabilities for Raxol\napplications, including performance metrics, error tracking, usage statistics,\nand health checks.\n\nFeatures:\n* Performance monitoring and metrics collection\n* Error and exception tracking\n* Resource usage tracking\n* Health checks and status monitoring\n* Alerting and notification system\n* Integration with popular monitoring services","ref":"Raxol.Cloud.Monitoring.html"},{"type":"function","title":"Raxol.Cloud.Monitoring.get_alerts/1","doc":"Gets recent alerts.","ref":"Raxol.Cloud.Monitoring.html#get_alerts/1"},{"type":"function","title":"Options - Raxol.Cloud.Monitoring.get_alerts/1","doc":"* `:limit` - Maximum number of alerts to return (default: 100)\n* `:since` - Only return alerts since this timestamp (default: 1 day ago)\n* `:until` - Only return alerts until this timestamp (default: now)\n* `:type` - Filter alerts by type\n* `:severity` - Filter alerts by severity","ref":"Raxol.Cloud.Monitoring.html#get_alerts/1-options"},{"type":"function","title":"Examples - Raxol.Cloud.Monitoring.get_alerts/1","doc":"iex> get_alerts(limit: 10, severity: :critical)\n    [%{type: :high_cpu_usage, severity: :critical, ...}]","ref":"Raxol.Cloud.Monitoring.html#get_alerts/1-examples"},{"type":"function","title":"Raxol.Cloud.Monitoring.get_errors/1","doc":"Gets recent errors.","ref":"Raxol.Cloud.Monitoring.html#get_errors/1"},{"type":"function","title":"Options - Raxol.Cloud.Monitoring.get_errors/1","doc":"* `:limit` - Maximum number of errors to return (default: 100)\n* `:since` - Only return errors since this timestamp (default: 1 day ago)\n* `:until` - Only return errors until this timestamp (default: now)\n* `:severity` - Filter errors by severity\n* `:tags` - Filter errors by tags","ref":"Raxol.Cloud.Monitoring.html#get_errors/1-options"},{"type":"function","title":"Examples - Raxol.Cloud.Monitoring.get_errors/1","doc":"iex> get_errors(limit: 10, severity: :critical)\n    [%{error: %RuntimeError{...}, severity: :critical, ...}]","ref":"Raxol.Cloud.Monitoring.html#get_errors/1-examples"},{"type":"function","title":"Raxol.Cloud.Monitoring.get_metrics/2","doc":"Gets recent metrics for the specified metric name.","ref":"Raxol.Cloud.Monitoring.html#get_metrics/2"},{"type":"function","title":"Options - Raxol.Cloud.Monitoring.get_metrics/2","doc":"* `:limit` - Maximum number of metrics to return (default: 100)\n* `:since` - Only return metrics since this timestamp (default: 1 hour ago)\n* `:until` - Only return metrics until this timestamp (default: now)\n* `:tags` - Filter metrics by tags","ref":"Raxol.Cloud.Monitoring.html#get_metrics/2-options"},{"type":"function","title":"Examples - Raxol.Cloud.Monitoring.get_metrics/2","doc":"iex> get_metrics(\"response_time\", limit: 10, tags: [\"api\"])\n    [%{name: \"response_time\", value: 123, timestamp: ~U[2023-01-01 12:00:00Z], tags: [\"api\"]}]","ref":"Raxol.Cloud.Monitoring.html#get_metrics/2-examples"},{"type":"function","title":"Raxol.Cloud.Monitoring.init/1","doc":"Initializes the monitoring system.","ref":"Raxol.Cloud.Monitoring.html#init/1"},{"type":"function","title":"Options - Raxol.Cloud.Monitoring.init/1","doc":"* `:active` - Whether monitoring should be active on start (default: true)\n* `:metrics_interval` - Interval in ms between metrics collection (default: 10000)\n* `:health_check_interval` - Interval in ms between health checks (default: 60000)\n* `:error_sample_rate` - Fraction of errors to track (0.0-1.0) (default: 1.0)\n* `:metrics_batch_size` - Number of metrics to batch before sending (default: 100)\n* `:backends` - List of monitoring service backends to use (default: [])\n* `:alert_thresholds` - Map of alert thresholds (default: see State.new)","ref":"Raxol.Cloud.Monitoring.html#init/1-options"},{"type":"function","title":"Examples - Raxol.Cloud.Monitoring.init/1","doc":"iex> init(metrics_interval: 5000, backends: [:datadog, :prometheus])\n    :ok","ref":"Raxol.Cloud.Monitoring.html#init/1-examples"},{"type":"function","title":"Raxol.Cloud.Monitoring.record_error/2","doc":"Records an error or exception.","ref":"Raxol.Cloud.Monitoring.html#record_error/2"},{"type":"function","title":"Options - Raxol.Cloud.Monitoring.record_error/2","doc":"* `:context` - Additional context information about the error\n* `:severity` - Severity level (:debug, :info, :warning, :error, :critical)\n* `:tags` - List of tags to associate with the error\n* `:timestamp` - Custom timestamp for the error (default: current time)","ref":"Raxol.Cloud.Monitoring.html#record_error/2-options"},{"type":"function","title":"Examples - Raxol.Cloud.Monitoring.record_error/2","doc":"iex> record_error(%RuntimeError{message: \"Connection failed\"},\n    ...>   context: %{user_id: 123}, severity: :error)\n    :ok","ref":"Raxol.Cloud.Monitoring.html#record_error/2-examples"},{"type":"function","title":"Raxol.Cloud.Monitoring.record_metric/3","doc":"Records a metric with the given name and value.","ref":"Raxol.Cloud.Monitoring.html#record_metric/3"},{"type":"function","title":"Options - Raxol.Cloud.Monitoring.record_metric/3","doc":"* `:tags` - List of tags to associate with the metric\n* `:timestamp` - Custom timestamp for the metric (default: current time)\n* `:source` - Source of the metric (default: :application)","ref":"Raxol.Cloud.Monitoring.html#record_metric/3-options"},{"type":"function","title":"Examples - Raxol.Cloud.Monitoring.record_metric/3","doc":"iex> record_metric(\"response_time\", 123, tags: [\"api\", \"users\"], source: :api)\n    :ok","ref":"Raxol.Cloud.Monitoring.html#record_metric/3-examples"},{"type":"function","title":"Raxol.Cloud.Monitoring.record_metrics/1","doc":"Records a batch of metrics.","ref":"Raxol.Cloud.Monitoring.html#record_metrics/1"},{"type":"function","title":"Examples - Raxol.Cloud.Monitoring.record_metrics/1","doc":"iex> record_metrics([\n    ...>   {\"cpu_usage\", 0.75, [source: :system]},\n    ...>   {\"memory_usage\", 0.5, [source: :system]}\n    ...> ])\n    :ok","ref":"Raxol.Cloud.Monitoring.html#record_metrics/1-examples"},{"type":"function","title":"Raxol.Cloud.Monitoring.run_health_check/1","doc":"Runs a health check on the system.","ref":"Raxol.Cloud.Monitoring.html#run_health_check/1"},{"type":"function","title":"Options - Raxol.Cloud.Monitoring.run_health_check/1","doc":"* `:components` - List of components to check (default: all)\n* `:timeout` - Timeout for health checks in milliseconds (default: 5000)","ref":"Raxol.Cloud.Monitoring.html#run_health_check/1-options"},{"type":"function","title":"Examples - Raxol.Cloud.Monitoring.run_health_check/1","doc":"iex> run_health_check(components: [:database, :api])\n    {:ok, %{status: :healthy, components: %{database: :healthy, api: :healthy}}}","ref":"Raxol.Cloud.Monitoring.html#run_health_check/1-examples"},{"type":"function","title":"Raxol.Cloud.Monitoring.start/0","doc":"Starts the monitoring system if it's not already active.","ref":"Raxol.Cloud.Monitoring.html#start/0"},{"type":"function","title":"Raxol.Cloud.Monitoring.status/0","doc":"Gets the current monitoring status.","ref":"Raxol.Cloud.Monitoring.html#status/0"},{"type":"function","title":"Raxol.Cloud.Monitoring.stop/0","doc":"Stops the monitoring system.","ref":"Raxol.Cloud.Monitoring.html#stop/0"},{"type":"function","title":"Raxol.Cloud.Monitoring.trigger_alert/3","doc":"Triggers an alert with the given type and data.","ref":"Raxol.Cloud.Monitoring.html#trigger_alert/3"},{"type":"function","title":"Options - Raxol.Cloud.Monitoring.trigger_alert/3","doc":"* `:severity` - Severity level of the alert (default: :warning)\n* `:notify` - Whether to send notifications (default: true)","ref":"Raxol.Cloud.Monitoring.html#trigger_alert/3-options"},{"type":"function","title":"Examples - Raxol.Cloud.Monitoring.trigger_alert/3","doc":"iex> trigger_alert(:high_cpu_usage, %{value: 0.95}, severity: :critical)\n    :ok","ref":"Raxol.Cloud.Monitoring.html#trigger_alert/3-examples"},{"type":"function","title":"Raxol.Cloud.Monitoring.update_config/2","doc":"Updates the monitoring configuration.","ref":"Raxol.Cloud.Monitoring.html#update_config/2"},{"type":"module","title":"Raxol.Cloud.StateManager","doc":"Centralized state management for Raxol cloud components.\n\nThis module provides a centralized way to store and retrieve state\nfor all cloud components, eliminating the need for Process.put/2\nand Process.get/1 in multiple modules.","ref":"Raxol.Cloud.StateManager.html"},{"type":"function","title":"Raxol.Cloud.StateManager.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Cloud.StateManager.html#child_spec/1"},{"type":"function","title":"Raxol.Cloud.StateManager.clear/1","doc":"Clears the state.","ref":"Raxol.Cloud.StateManager.html#clear/1"},{"type":"function","title":"Raxol.Cloud.StateManager.get/2","doc":"Gets a value from the state.","ref":"Raxol.Cloud.StateManager.html#get/2"},{"type":"function","title":"Raxol.Cloud.StateManager.get_all/1","doc":"Gets the entire state.","ref":"Raxol.Cloud.StateManager.html#get_all/1"},{"type":"function","title":"Raxol.Cloud.StateManager.put/3","doc":"Puts a value in the state.","ref":"Raxol.Cloud.StateManager.html#put/3"},{"type":"function","title":"Raxol.Cloud.StateManager.start_link/1","doc":"Starts the state manager.","ref":"Raxol.Cloud.StateManager.html#start_link/1"},{"type":"function","title":"Raxol.Cloud.StateManager.update/3","doc":"Updates a value in the state.","ref":"Raxol.Cloud.StateManager.html#update/3"},{"type":"module","title":"Raxol.Components.Base","doc":"Provides base functionality and utilities for Raxol components.\n\nThis module contains shared functionality used across different components,\nincluding common validation, styling, and event handling patterns.","ref":"Raxol.Components.Base.html"},{"type":"function","title":"Raxol.Components.Base.base_style/1","doc":"Creates a base style for components with common properties.","ref":"Raxol.Components.Base.html#base_style/1"},{"type":"function","title":"Raxol.Components.Base.handle_common_events/2","doc":"Handles common events like focus, blur, and keyboard navigation.\n\nShould be called from a component's handle_event callback.","ref":"Raxol.Components.Base.html#handle_common_events/2"},{"type":"type","title":"Raxol.Components.Base.state/0","doc":"","ref":"Raxol.Components.Base.html#t:state/0"},{"type":"function","title":"Raxol.Components.Base.validate_props/2","doc":"Validates component props against a schema.","ref":"Raxol.Components.Base.html#validate_props/2"},{"type":"function","title":"Example - Raxol.Components.Base.validate_props/2","doc":"def validate_props(props) do\n      Base.validate_props(props, %{\n        required: [:label],\n        optional: [:style, :disabled],\n        types: %{\n          label: :string,\n          style: {:one_of, [:primary, :secondary, :danger]},\n          disabled: :boolean\n        }\n      })\n    end","ref":"Raxol.Components.Base.html#validate_props/2-example"},{"type":"module","title":"Raxol.Components.Button","doc":"A customizable button component.\n\nThis module provides a more sophisticated button component than the basic\nbutton element, with support for various styles and behaviors.","ref":"Raxol.Components.Button.html"},{"type":"module","title":"Example - Raxol.Components.Button","doc":"```elixir\nalias Raxol.Components.Button\n\nButton.new(\"Save Changes\", on_click: :save_clicked, style: :primary)\n```","ref":"Raxol.Components.Button.html#module-example"},{"type":"function","title":"Raxol.Components.Button.new/2","doc":"Creates a new button with the given label and options.","ref":"Raxol.Components.Button.html#new/2"},{"type":"function","title":"Options - Raxol.Components.Button.new/2","doc":"* `:on_click` - Message to send when the button is clicked\n* `:style` - Button style (:primary, :secondary, :danger, :success, or a custom style map)\n* `:disabled` - Whether the button is disabled\n* `:icon` - Icon to display before the label\n* `:full_width` - Whether the button should take full width\n* `:size` - Button size (:small, :medium, :large)\n* `:tooltip` - Tooltip text to show on hover","ref":"Raxol.Components.Button.html#new/2-options"},{"type":"function","title":"Returns - Raxol.Components.Button.new/2","doc":"A button component that can be used in a Raxol view.","ref":"Raxol.Components.Button.html#new/2-returns"},{"type":"function","title":"Example - Raxol.Components.Button.new/2","doc":"```elixir\nButton.new(\"Delete\",\n  on_click: {:delete, item_id},\n  style: :danger,\n  icon: :trash\n)\n```","ref":"Raxol.Components.Button.html#new/2-example"},{"type":"function","title":"Raxol.Components.Button.render/1","doc":"Renders the button as a basic element.\n\nThis is typically called by the renderer, not directly by users.","ref":"Raxol.Components.Button.html#render/1"},{"type":"type","title":"Raxol.Components.Button.t/0","doc":"","ref":"Raxol.Components.Button.html#t:t/0"},{"type":"module","title":"Raxol.Components.Dashboard.Dashboard","doc":"A component responsible for rendering a grid-based dashboard layout.\nManages widget placement, drag/drop, and resizing.","ref":"Raxol.Components.Dashboard.Dashboard.html"},{"type":"function","title":"Raxol.Components.Dashboard.Dashboard.broadcast/1","doc":"","ref":"Raxol.Components.Dashboard.Dashboard.html#broadcast/1"},{"type":"function","title":"Raxol.Components.Dashboard.Dashboard.command/1","doc":"","ref":"Raxol.Components.Dashboard.Dashboard.html#command/1"},{"type":"function","title":"Raxol.Components.Dashboard.Dashboard.init_from_saved_layout/2","doc":"Initializes the Dashboard state from a saved layout.\nIf no saved layout exists, returns default widgets with the given grid configuration.\n\nThis function loads widget configurations using `LayoutPersistence.load_layout/0` and initializes\nthe dashboard model with those widgets and the provided grid_config.\n\nReturns {:ok, model} on success, or {:error, reason} on failure.","ref":"Raxol.Components.Dashboard.Dashboard.html#init_from_saved_layout/2"},{"type":"function","title":"Raxol.Components.Dashboard.Dashboard.mount/1","doc":"","ref":"Raxol.Components.Dashboard.Dashboard.html#mount/1"},{"type":"function","title":"Raxol.Components.Dashboard.Dashboard.schedule/2","doc":"","ref":"Raxol.Components.Dashboard.Dashboard.html#schedule/2"},{"type":"function","title":"Raxol.Components.Dashboard.Dashboard.unmount/1","doc":"","ref":"Raxol.Components.Dashboard.Dashboard.html#unmount/1"},{"type":"function","title":"Raxol.Components.Dashboard.Dashboard.validate_widgets/1","doc":"Validates a list of widget configurations to ensure they can be properly rendered.\nReturns true if widgets are valid, false otherwise.","ref":"Raxol.Components.Dashboard.Dashboard.html#validate_widgets/1"},{"type":"module","title":"Raxol.Components.Dashboard.Dashboard.Model","doc":"State for the Dashboard component.","ref":"Raxol.Components.Dashboard.Dashboard.Model.html"},{"type":"module","title":"Raxol.Components.Dashboard.GridContainer","doc":"Calculates layout bounds for widgets within a grid configuration.\nThis module provides functions to determine the position and size of widgets\nbased on a grid layout definition (columns, rows, gaps).","ref":"Raxol.Components.Dashboard.GridContainer.html"},{"type":"function","title":"Raxol.Components.Dashboard.GridContainer.calculate_widget_bounds/2","doc":"Calculates the absolute bounds for a widget within a grid layout.\n\nParameters:\n  - `widget_config`: Map containing at least `grid_spec: %{col: integer(), row: integer(), col_span: integer(), row_span: integer()}`.\n  - `grid_config`: Map containing `parent_bounds: %{x: integer(), y: integer(), width: integer(), height: integer()}`,\n    and optionally `cols: integer()`, `rows: integer()`, `gap: integer()`.\n\nReturns:\n  - `%{x: integer(), y: integer(), width: integer(), height: integer()}` representing the absolute bounds.","ref":"Raxol.Components.Dashboard.GridContainer.html#calculate_widget_bounds/2"},{"type":"function","title":"Raxol.Components.Dashboard.GridContainer.default_cols/0","doc":"","ref":"Raxol.Components.Dashboard.GridContainer.html#default_cols/0"},{"type":"function","title":"Raxol.Components.Dashboard.GridContainer.default_gap/0","doc":"","ref":"Raxol.Components.Dashboard.GridContainer.html#default_gap/0"},{"type":"function","title":"Raxol.Components.Dashboard.GridContainer.default_rows/0","doc":"","ref":"Raxol.Components.Dashboard.GridContainer.html#default_rows/0"},{"type":"function","title":"Raxol.Components.Dashboard.GridContainer.get_cell_dimensions/1","doc":"Calculates the dimensions of a single cell in the grid.\n\nParameters:\n  - `grid_config`: Map containing grid configuration including parent_bounds,\n    cols, rows, and gap.\n\nReturns:\n  - `{cell_width, cell_height}` tuple with the dimensions of a single cell.","ref":"Raxol.Components.Dashboard.GridContainer.html#get_cell_dimensions/1"},{"type":"function","title":"Raxol.Components.Dashboard.GridContainer.resolve_grid_params/1","doc":"Resolves the effective grid parameters (cols, rows) based on breakpoints\ndefined in the grid configuration and the current parent width.\n\nParameters:\n  - `grid_config`: Map containing `parent_bounds: %{width: _}` and `breakpoints: %{...}`.\n                 Breakpoints map should have keys like `:small`, `:medium`, `:large`,\n                 with values like `%{max_width: _, cols: _, rows: _}` or just `%{cols: _, rows: _}`\n                 for the largest/default breakpoint.\n\nReturns:\n  - `%{cols: integer(), rows: integer()}`","ref":"Raxol.Components.Dashboard.GridContainer.html#resolve_grid_params/1"},{"type":"module","title":"Raxol.Components.Dashboard.LayoutPersistence","doc":"Handles saving and loading dashboard widget layouts to disk.","ref":"Raxol.Components.Dashboard.LayoutPersistence.html"},{"type":"function","title":"Raxol.Components.Dashboard.LayoutPersistence.load_layout/0","doc":"Loads the widget layout from the file.\nReturns the list of widget configurations `[map()]` or `nil` if load fails or file doesn't exist.","ref":"Raxol.Components.Dashboard.LayoutPersistence.html#load_layout/0"},{"type":"function","title":"Raxol.Components.Dashboard.LayoutPersistence.save_layout/1","doc":"Saves the current widget layout (list of widget configs) to a file.\n\nOnly saves fields essential for reconstructing the layout and widget state:\n`:id`, `:type`, `:title`, `:grid_spec`, `:component_opts`, `:data`.","ref":"Raxol.Components.Dashboard.LayoutPersistence.html#save_layout/1"},{"type":"module","title":"Raxol.Components.Dashboard.WidgetContainer","doc":"A container component for dashboard widgets.\nProvides a frame, title bar (optional), and potentially drag/resize handles.\nRenders the actual widget content passed to it.","ref":"Raxol.Components.Dashboard.WidgetContainer.html"},{"type":"function","title":"Raxol.Components.Dashboard.WidgetContainer.broadcast/1","doc":"","ref":"Raxol.Components.Dashboard.WidgetContainer.html#broadcast/1"},{"type":"function","title":"Raxol.Components.Dashboard.WidgetContainer.command/1","doc":"","ref":"Raxol.Components.Dashboard.WidgetContainer.html#command/1"},{"type":"function","title":"Raxol.Components.Dashboard.WidgetContainer.mount/1","doc":"","ref":"Raxol.Components.Dashboard.WidgetContainer.html#mount/1"},{"type":"function","title":"Raxol.Components.Dashboard.WidgetContainer.render/2","doc":"Renders the widget container frame and its content.\n\nRequires props:\n- `bounds`: %{x, y, width, height} - The absolute bounds calculated by GridContainer.\n- `widget_config`: The configuration map for the widget being rendered.\n                   Used for title, etc. (%{id: _, type: _, title: _, ...}).\n- `content`: The actual View element(s) representing the widget's content.","ref":"Raxol.Components.Dashboard.WidgetContainer.html#render/2"},{"type":"function","title":"Raxol.Components.Dashboard.WidgetContainer.schedule/2","doc":"","ref":"Raxol.Components.Dashboard.WidgetContainer.html#schedule/2"},{"type":"function","title":"Raxol.Components.Dashboard.WidgetContainer.unmount/1","doc":"","ref":"Raxol.Components.Dashboard.WidgetContainer.html#unmount/1"},{"type":"module","title":"Raxol.Components.Dashboard.Widgets.ChartWidget","doc":"A dashboard widget that displays a chart using Raxol.Components.Visualization.Chart.\nThis module is responsible for holding the chart's state (data, config)\nand providing a data structure for rendering, rather than rendering directly.","ref":"Raxol.Components.Dashboard.Widgets.ChartWidget.html"},{"type":"function","title":"Raxol.Components.Dashboard.Widgets.ChartWidget.init/1","doc":"","ref":"Raxol.Components.Dashboard.Widgets.ChartWidget.html#init/1"},{"type":"function","title":"Raxol.Components.Dashboard.Widgets.ChartWidget.render_data_structure/1","doc":"","ref":"Raxol.Components.Dashboard.Widgets.ChartWidget.html#render_data_structure/1"},{"type":"module","title":"Raxol.Components.Dashboard.Widgets.InfoWidget","doc":"A dashboard widget that displays simple text information.","ref":"Raxol.Components.Dashboard.Widgets.InfoWidget.html"},{"type":"function","title":"Raxol.Components.Dashboard.Widgets.InfoWidget.broadcast/1","doc":"","ref":"Raxol.Components.Dashboard.Widgets.InfoWidget.html#broadcast/1"},{"type":"function","title":"Raxol.Components.Dashboard.Widgets.InfoWidget.command/1","doc":"","ref":"Raxol.Components.Dashboard.Widgets.InfoWidget.html#command/1"},{"type":"function","title":"Raxol.Components.Dashboard.Widgets.InfoWidget.mount/1","doc":"","ref":"Raxol.Components.Dashboard.Widgets.InfoWidget.html#mount/1"},{"type":"function","title":"Raxol.Components.Dashboard.Widgets.InfoWidget.schedule/2","doc":"","ref":"Raxol.Components.Dashboard.Widgets.InfoWidget.html#schedule/2"},{"type":"function","title":"Raxol.Components.Dashboard.Widgets.InfoWidget.unmount/1","doc":"","ref":"Raxol.Components.Dashboard.Widgets.InfoWidget.html#unmount/1"},{"type":"module","title":"Raxol.Components.Dashboard.Widgets.TreeMapWidget","doc":"A dashboard widget that displays a treemap using Raxol.Components.Visualization.TreeMap.\nThis module is responsible for holding the treemap's state (data, config)\nand providing a data structure for rendering, rather than rendering directly.","ref":"Raxol.Components.Dashboard.Widgets.TreeMapWidget.html"},{"type":"function","title":"Raxol.Components.Dashboard.Widgets.TreeMapWidget.init/1","doc":"","ref":"Raxol.Components.Dashboard.Widgets.TreeMapWidget.html#init/1"},{"type":"function","title":"Raxol.Components.Dashboard.Widgets.TreeMapWidget.render_data_structure/1","doc":"","ref":"Raxol.Components.Dashboard.Widgets.TreeMapWidget.html#render_data_structure/1"},{"type":"module","title":"Raxol.Components.FocusRing","doc":"Handles drawing the focus ring around focused components.","ref":"Raxol.Components.FocusRing.html"},{"type":"function","title":"Raxol.Components.FocusRing.broadcast/1","doc":"","ref":"Raxol.Components.FocusRing.html#broadcast/1"},{"type":"function","title":"Raxol.Components.FocusRing.command/1","doc":"","ref":"Raxol.Components.FocusRing.html#command/1"},{"type":"function","title":"Raxol.Components.FocusRing.mount/1","doc":"","ref":"Raxol.Components.FocusRing.html#mount/1"},{"type":"function","title":"Raxol.Components.FocusRing.schedule/2","doc":"","ref":"Raxol.Components.FocusRing.html#schedule/2"},{"type":"function","title":"Raxol.Components.FocusRing.unmount/1","doc":"","ref":"Raxol.Components.FocusRing.html#unmount/1"},{"type":"module","title":"Raxol.Components.HintDisplay","doc":"Displays contextual hints and keyboard shortcuts.","ref":"Raxol.Components.HintDisplay.html"},{"type":"function","title":"Raxol.Components.HintDisplay.broadcast/1","doc":"","ref":"Raxol.Components.HintDisplay.html#broadcast/1"},{"type":"function","title":"Raxol.Components.HintDisplay.command/1","doc":"","ref":"Raxol.Components.HintDisplay.html#command/1"},{"type":"function","title":"Raxol.Components.HintDisplay.mount/1","doc":"","ref":"Raxol.Components.HintDisplay.html#mount/1"},{"type":"function","title":"Raxol.Components.HintDisplay.schedule/2","doc":"","ref":"Raxol.Components.HintDisplay.html#schedule/2"},{"type":"function","title":"Raxol.Components.HintDisplay.unmount/1","doc":"","ref":"Raxol.Components.HintDisplay.html#unmount/1"},{"type":"module","title":"Raxol.Components.Input.MultiLineInput","doc":"A multi-line input component with line wrapping, vertical scrolling, and text manipulation.","ref":"Raxol.Components.Input.MultiLineInput.html"},{"type":"module","title":"Props - Raxol.Components.Input.MultiLineInput","doc":"* `:value` - Current text value (default: \"\")\n  * `:placeholder` - Placeholder text when empty (default: \"\")\n  * `:width` - Width of the input field (default: 40)\n  * `:height` - Height of the input field (default: 10)\n  * `:style` - Style map for customizing appearance\n    * `:text_color` - Color of the text (default: :white)\n    * `:placeholder_color` - Color of placeholder text (default: :gray)\n    * `:selection_color` - Color of selected text (default: :blue)\n    * `:cursor_color` - Color of the cursor (default: :white)\n    * `:line_numbers` - Whether to show line numbers (default: false)\n    * `:line_number_color` - Color of line numbers (default: :gray)\n  * `:wrap` - Line wrapping mode (default: :word)\n    * `:none` - No wrapping\n    * `:char` - Wrap at character boundaries\n    * `:word` - Wrap at word boundaries\n  * `:on_change` - Function called when text changes","ref":"Raxol.Components.Input.MultiLineInput.html#module-props"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.broadcast/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.html#broadcast/1"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.command/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.html#command/1"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.mount/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.html#mount/1"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.schedule/2","doc":"","ref":"Raxol.Components.Input.MultiLineInput.html#schedule/2"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.unmount/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.html#unmount/1"},{"type":"module","title":"Raxol.Components.Input.MultiLineInput.ClipboardHelper","doc":"Helper functions for clipboard interactions (copy/cut/paste) in MultiLineInput.","ref":"Raxol.Components.Input.MultiLineInput.ClipboardHelper.html"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.ClipboardHelper.copy_selection/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.ClipboardHelper.html#copy_selection/1"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.ClipboardHelper.cut_selection/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.ClipboardHelper.html#cut_selection/1"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.ClipboardHelper.paste/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.ClipboardHelper.html#paste/1"},{"type":"module","title":"Raxol.Components.Input.MultiLineInput.EventHandler","doc":"Handles key and mouse events for MultiLineInput, translating them into update messages.","ref":"Raxol.Components.Input.MultiLineInput.EventHandler.html"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.EventHandler.handle_event/2","doc":"","ref":"Raxol.Components.Input.MultiLineInput.EventHandler.html#handle_event/2"},{"type":"module","title":"Raxol.Components.Input.MultiLineInput.NavigationHelper","doc":"Helper functions for cursor navigation and text selection in MultiLineInput.","ref":"Raxol.Components.Input.MultiLineInput.NavigationHelper.html"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.NavigationHelper.clear_selection/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.NavigationHelper.html#clear_selection/1"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.NavigationHelper.is_line_in_selection?/3","doc":"","ref":"Raxol.Components.Input.MultiLineInput.NavigationHelper.html#is_line_in_selection?/3"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.NavigationHelper.move_cursor/2","doc":"","ref":"Raxol.Components.Input.MultiLineInput.NavigationHelper.html#move_cursor/2"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.NavigationHelper.move_cursor_doc_end/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.NavigationHelper.html#move_cursor_doc_end/1"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.NavigationHelper.move_cursor_doc_start/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.NavigationHelper.html#move_cursor_doc_start/1"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.NavigationHelper.move_cursor_line_end/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.NavigationHelper.html#move_cursor_line_end/1"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.NavigationHelper.move_cursor_line_start/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.NavigationHelper.html#move_cursor_line_start/1"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.NavigationHelper.move_cursor_page/2","doc":"","ref":"Raxol.Components.Input.MultiLineInput.NavigationHelper.html#move_cursor_page/2"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.NavigationHelper.move_cursor_word_left/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.NavigationHelper.html#move_cursor_word_left/1"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.NavigationHelper.move_cursor_word_right/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.NavigationHelper.html#move_cursor_word_right/1"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.NavigationHelper.normalize_selection/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.NavigationHelper.html#normalize_selection/1"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.NavigationHelper.select/2","doc":"","ref":"Raxol.Components.Input.MultiLineInput.NavigationHelper.html#select/2"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.NavigationHelper.select_all/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.NavigationHelper.html#select_all/1"},{"type":"module","title":"Raxol.Components.Input.MultiLineInput.RenderHelper","doc":"Helper functions for rendering lines, cursors, and selections in MultiLineInput.","ref":"Raxol.Components.Input.MultiLineInput.RenderHelper.html"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.RenderHelper.render_line/3","doc":"","ref":"Raxol.Components.Input.MultiLineInput.RenderHelper.html#render_line/3"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.RenderHelper.render_line_with_cursor/2","doc":"","ref":"Raxol.Components.Input.MultiLineInput.RenderHelper.html#render_line_with_cursor/2"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.RenderHelper.render_line_with_selection/3","doc":"","ref":"Raxol.Components.Input.MultiLineInput.RenderHelper.html#render_line_with_selection/3"},{"type":"module","title":"Raxol.Components.Input.MultiLineInput.TextHelper","doc":"Helper functions for text and line manipulation in MultiLineInput.","ref":"Raxol.Components.Input.MultiLineInput.TextHelper.html"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.TextHelper.calculate_new_position/3","doc":"","ref":"Raxol.Components.Input.MultiLineInput.TextHelper.html#calculate_new_position/3"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.TextHelper.clamp/3","doc":"","ref":"Raxol.Components.Input.MultiLineInput.TextHelper.html#clamp/3"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.TextHelper.delete_selection/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.TextHelper.html#delete_selection/1"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.TextHelper.handle_backspace_no_selection/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.TextHelper.html#handle_backspace_no_selection/1"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.TextHelper.handle_delete_no_selection/1","doc":"","ref":"Raxol.Components.Input.MultiLineInput.TextHelper.html#handle_delete_no_selection/1"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.TextHelper.insert_char/2","doc":"","ref":"Raxol.Components.Input.MultiLineInput.TextHelper.html#insert_char/2"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.TextHelper.pos_to_index/2","doc":"","ref":"Raxol.Components.Input.MultiLineInput.TextHelper.html#pos_to_index/2"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.TextHelper.replace_text_range/4","doc":"","ref":"Raxol.Components.Input.MultiLineInput.TextHelper.html#replace_text_range/4"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.TextHelper.split_and_wrap/3","doc":"","ref":"Raxol.Components.Input.MultiLineInput.TextHelper.html#split_and_wrap/3"},{"type":"function","title":"Raxol.Components.Input.MultiLineInput.TextHelper.split_into_lines/3","doc":"","ref":"Raxol.Components.Input.MultiLineInput.TextHelper.html#split_into_lines/3"},{"type":"module","title":"Raxol.Components.Input.SingleLineInput","doc":"A simple single-line text input component.","ref":"Raxol.Components.Input.SingleLineInput.html"},{"type":"function","title":"Raxol.Components.Input.SingleLineInput.broadcast/1","doc":"","ref":"Raxol.Components.Input.SingleLineInput.html#broadcast/1"},{"type":"function","title":"Raxol.Components.Input.SingleLineInput.command/1","doc":"","ref":"Raxol.Components.Input.SingleLineInput.html#command/1"},{"type":"function","title":"Raxol.Components.Input.SingleLineInput.mount/1","doc":"","ref":"Raxol.Components.Input.SingleLineInput.html#mount/1"},{"type":"function","title":"Raxol.Components.Input.SingleLineInput.schedule/2","doc":"","ref":"Raxol.Components.Input.SingleLineInput.html#schedule/2"},{"type":"function","title":"Raxol.Components.Input.SingleLineInput.unmount/1","doc":"","ref":"Raxol.Components.Input.SingleLineInput.html#unmount/1"},{"type":"module","title":"Raxol.Components.Input.TextInput","doc":"A text input component for single-line text entry.\n\nFeatures:\n* Cursor management\n* Text selection\n* Copy/paste support\n* Password masking\n* Placeholder text","ref":"Raxol.Components.Input.TextInput.html"},{"type":"function","title":"Raxol.Components.Input.TextInput.broadcast/1","doc":"","ref":"Raxol.Components.Input.TextInput.html#broadcast/1"},{"type":"function","title":"Raxol.Components.Input.TextInput.command/1","doc":"","ref":"Raxol.Components.Input.TextInput.html#command/1"},{"type":"function","title":"Raxol.Components.Input.TextInput.mount/1","doc":"","ref":"Raxol.Components.Input.TextInput.html#mount/1"},{"type":"function","title":"Raxol.Components.Input.TextInput.schedule/2","doc":"","ref":"Raxol.Components.Input.TextInput.html#schedule/2"},{"type":"type","title":"Raxol.Components.Input.TextInput.state/0","doc":"","ref":"Raxol.Components.Input.TextInput.html#t:state/0"},{"type":"function","title":"Raxol.Components.Input.TextInput.unmount/1","doc":"","ref":"Raxol.Components.Input.TextInput.html#unmount/1"},{"type":"module","title":"Raxol.Components.Input.TextWrapping","doc":"Utility functions for text wrapping.","ref":"Raxol.Components.Input.TextWrapping.html"},{"type":"function","title":"Raxol.Components.Input.TextWrapping.wrap_line_by_char/2","doc":"Wraps a single line of text by character count using recursion.\n\nHandles multi-byte characters correctly.","ref":"Raxol.Components.Input.TextWrapping.html#wrap_line_by_char/2"},{"type":"function","title":"Raxol.Components.Input.TextWrapping.wrap_line_by_word/2","doc":"Wraps a single line of text by word boundaries.","ref":"Raxol.Components.Input.TextWrapping.html#wrap_line_by_word/2"},{"type":"module","title":"Raxol.Components.Modal","doc":"A modal component for displaying overlay dialogs like alerts, prompts, confirmations.","ref":"Raxol.Components.Modal.html"},{"type":"function","title":"Raxol.Components.Modal.alert/4","doc":"Creates props for an alert modal.","ref":"Raxol.Components.Modal.html#alert/4"},{"type":"function","title":"Raxol.Components.Modal.broadcast/1","doc":"","ref":"Raxol.Components.Modal.html#broadcast/1"},{"type":"function","title":"Raxol.Components.Modal.command/1","doc":"","ref":"Raxol.Components.Modal.html#command/1"},{"type":"function","title":"Raxol.Components.Modal.confirm/6","doc":"Creates props for a confirmation modal.","ref":"Raxol.Components.Modal.html#confirm/6"},{"type":"function","title":"Raxol.Components.Modal.mount/1","doc":"","ref":"Raxol.Components.Modal.html#mount/1"},{"type":"function","title":"Raxol.Components.Modal.prompt/6","doc":"Creates props for a prompt modal.","ref":"Raxol.Components.Modal.html#prompt/6"},{"type":"function","title":"Raxol.Components.Modal.schedule/2","doc":"","ref":"Raxol.Components.Modal.html#schedule/2"},{"type":"function","title":"Raxol.Components.Modal.unmount/1","doc":"","ref":"Raxol.Components.Modal.html#unmount/1"},{"type":"module","title":"Raxol.Components.Progress","doc":"Provides components for displaying progress, like progress bars and spinners.","ref":"Raxol.Components.Progress.html"},{"type":"function","title":"Raxol.Components.Progress.bar/2","doc":"Renders a simple progress bar with configurable appearance.","ref":"Raxol.Components.Progress.html#bar/2"},{"type":"function","title":"Parameters - Raxol.Components.Progress.bar/2","doc":"* `value` - Current progress value (0.0 to 1.0)\n* `opts` - Options for customizing the progress bar","ref":"Raxol.Components.Progress.html#bar/2-parameters"},{"type":"function","title":"Options - Raxol.Components.Progress.bar/2","doc":"* `:id` - Unique identifier for the progress bar (default: \"progress_bar\")\n* `:width` - Width of the progress bar in characters (default: 20)\n* `:style` - Style for the progress bar container\n* `:filled_style` - Style for the filled portion of the bar (default: %{bg: :blue})\n* `:empty_style` - Style for the empty portion of the bar (default: %{bg: :black})\n* `:chars` - Characters to use for different parts of the bar\n  * `:filled` - Character for filled sections (default: \" \")\n  * `:empty` - Character for empty sections (default: \" \")","ref":"Raxol.Components.Progress.html#bar/2-options"},{"type":"function","title":"Returns - Raxol.Components.Progress.bar/2","doc":"A view element representing the progress bar.","ref":"Raxol.Components.Progress.html#bar/2-returns"},{"type":"function","title":"Example - Raxol.Components.Progress.bar/2","doc":"```elixir\nProgress.bar(\n  0.75,\n  width: 30,\n  filled_style: %{bg: :green},\n  chars: %{filled: \"█\", empty: \"░\"}\n)\n```","ref":"Raxol.Components.Progress.html#bar/2-example"},{"type":"function","title":"Raxol.Components.Progress.bar_with_label/3","doc":"Renders a progress bar with a label and optional percentage display.","ref":"Raxol.Components.Progress.html#bar_with_label/3"},{"type":"function","title":"Parameters - Raxol.Components.Progress.bar_with_label/3","doc":"* `value` - Current progress value (0.0 to 1.0)\n* `label` - Text label to display\n* `opts` - Options for customizing the progress bar","ref":"Raxol.Components.Progress.html#bar_with_label/3-parameters"},{"type":"function","title":"Options - Raxol.Components.Progress.bar_with_label/3","doc":"All options from `bar/2` plus:\n* `:show_percentage` - Whether to show percentage (default: true)\n* `:percentage_style` - Style for the percentage text (default: %{})\n* `:label_style` - Style for the label text (default: %{})\n* `:position` - Position of the label/percentage (:above, :below, :right, default: :above)","ref":"Raxol.Components.Progress.html#bar_with_label/3-options"},{"type":"function","title":"Returns - Raxol.Components.Progress.bar_with_label/3","doc":"A view element representing the progress bar with label.","ref":"Raxol.Components.Progress.html#bar_with_label/3-returns"},{"type":"function","title":"Example - Raxol.Components.Progress.bar_with_label/3","doc":"```elixir\nProgress.bar_with_label(\n  0.35,\n  \"Loading assets...\",\n  show_percentage: true,\n  position: :below,\n  filled_style: %{bg: :cyan}\n)\n```","ref":"Raxol.Components.Progress.html#bar_with_label/3-example"},{"type":"function","title":"Raxol.Components.Progress.broadcast/1","doc":"","ref":"Raxol.Components.Progress.html#broadcast/1"},{"type":"function","title":"Raxol.Components.Progress.circular/2","doc":"Renders a circular progress indicator.","ref":"Raxol.Components.Progress.html#circular/2"},{"type":"function","title":"Parameters - Raxol.Components.Progress.circular/2","doc":"* `value` - Current progress value (0.0 to 1.0)\n* `opts` - Options for customizing the progress indicator","ref":"Raxol.Components.Progress.html#circular/2-parameters"},{"type":"function","title":"Options - Raxol.Components.Progress.circular/2","doc":"* `:id` - Unique identifier for the indicator (default: \"circular_progress\")\n* `:style` - Style for the indicator\n* `:show_percentage` - Whether to show percentage inside (default: true)\n* `:percentage_style` - Style for the percentage text","ref":"Raxol.Components.Progress.html#circular/2-options"},{"type":"function","title":"Returns - Raxol.Components.Progress.circular/2","doc":"A view element representing the circular progress indicator.","ref":"Raxol.Components.Progress.html#circular/2-returns"},{"type":"function","title":"Example - Raxol.Components.Progress.circular/2","doc":"```elixir\nProgress.circular(\n  0.65,\n  style: %{fg: :green}\n)\n```","ref":"Raxol.Components.Progress.html#circular/2-example"},{"type":"function","title":"Raxol.Components.Progress.command/1","doc":"","ref":"Raxol.Components.Progress.html#command/1"},{"type":"function","title":"Raxol.Components.Progress.indeterminate/2","doc":"Renders an indeterminate progress bar (animated).","ref":"Raxol.Components.Progress.html#indeterminate/2"},{"type":"function","title":"Parameters - Raxol.Components.Progress.indeterminate/2","doc":"* `frame` - Current animation frame (integer, typically incremented on each render)\n* `opts` - Options for customizing the indeterminate progress bar","ref":"Raxol.Components.Progress.html#indeterminate/2-parameters"},{"type":"function","title":"Options - Raxol.Components.Progress.indeterminate/2","doc":"* `:id` - Unique identifier for the progress bar (default: \"indeterminate_progress\")\n* `:width` - Width of the progress bar in characters (default: 20)\n* `:style` - Style for the progress bar container\n* `:bar_style` - Style for the animated bar (default: %{bg: :blue})\n* `:background_style` - Style for the background (default: %{bg: :black})\n* `:segment_size` - Size of the animated segment (default: 5)","ref":"Raxol.Components.Progress.html#indeterminate/2-options"},{"type":"function","title":"Returns - Raxol.Components.Progress.indeterminate/2","doc":"A view element representing the indeterminate progress bar.","ref":"Raxol.Components.Progress.html#indeterminate/2-returns"},{"type":"function","title":"Example - Raxol.Components.Progress.indeterminate/2","doc":"```elixir\nProgress.indeterminate(\n  model.animation_frame,\n  width: 30,\n  bar_style: %{bg: :purple},\n  segment_size: 8\n)\n```","ref":"Raxol.Components.Progress.html#indeterminate/2-example"},{"type":"function","title":"Raxol.Components.Progress.mount/1","doc":"","ref":"Raxol.Components.Progress.html#mount/1"},{"type":"function","title":"Raxol.Components.Progress.schedule/2","doc":"","ref":"Raxol.Components.Progress.html#schedule/2"},{"type":"function","title":"Raxol.Components.Progress.spinner/3","doc":"Renders a spinner animation for indicating loading or processing.","ref":"Raxol.Components.Progress.html#spinner/3"},{"type":"function","title":"Parameters - Raxol.Components.Progress.spinner/3","doc":"* `message` - Optional message to display next to the spinner\n* `frame` - Current animation frame (integer, typically incremented on each render)\n* `opts` - Options for customizing the spinner","ref":"Raxol.Components.Progress.html#spinner/3-parameters"},{"type":"function","title":"Options - Raxol.Components.Progress.spinner/3","doc":"* `:id` - Unique identifier for the spinner (default: \"spinner\")\n* `:style` - Style for the spinner container\n* `:spinner_style` - Style for the spinner character\n* `:message_style` - Style for the message text\n* `:type` - Type of spinner animation (default: :dots)","ref":"Raxol.Components.Progress.html#spinner/3-options"},{"type":"function","title":"Returns - Raxol.Components.Progress.spinner/3","doc":"A view element representing the spinner.","ref":"Raxol.Components.Progress.html#spinner/3-returns"},{"type":"function","title":"Example - Raxol.Components.Progress.spinner/3","doc":"```elixir\n# In your update function, increment the frame on each update\ndef update(model, :tick) do\n  %{model | spinner_frame: model.spinner_frame + 1}\nend\n\n# In your view function\nProgress.spinner(\n  \"Processing data...\",\n  model.spinner_frame,\n  type: :braille,\n  spinner_style: %{fg: :cyan}\n)\n```","ref":"Raxol.Components.Progress.html#spinner/3-example"},{"type":"function","title":"Raxol.Components.Progress.spinner_types/0","doc":"Returns the available spinner types.","ref":"Raxol.Components.Progress.html#spinner_types/0"},{"type":"function","title":"Returns - Raxol.Components.Progress.spinner_types/0","doc":"A map of spinner types to their frame sequences.","ref":"Raxol.Components.Progress.html#spinner_types/0-returns"},{"type":"function","title":"Example - Raxol.Components.Progress.spinner_types/0","doc":"```elixir\nspinner_types = Progress.spinner_types()\n```","ref":"Raxol.Components.Progress.html#spinner_types/0-example"},{"type":"function","title":"Raxol.Components.Progress.unmount/1","doc":"","ref":"Raxol.Components.Progress.html#unmount/1"},{"type":"module","title":"Raxol.Components.Progress.ProgressBar","doc":"A component to display a progress bar.","ref":"Raxol.Components.Progress.ProgressBar.html"},{"type":"function","title":"Raxol.Components.Progress.ProgressBar.broadcast/1","doc":"","ref":"Raxol.Components.Progress.ProgressBar.html#broadcast/1"},{"type":"function","title":"Raxol.Components.Progress.ProgressBar.command/1","doc":"","ref":"Raxol.Components.Progress.ProgressBar.html#command/1"},{"type":"function","title":"Raxol.Components.Progress.ProgressBar.mount/1","doc":"","ref":"Raxol.Components.Progress.ProgressBar.html#mount/1"},{"type":"function","title":"Raxol.Components.Progress.ProgressBar.schedule/2","doc":"","ref":"Raxol.Components.Progress.ProgressBar.html#schedule/2"},{"type":"function","title":"Raxol.Components.Progress.ProgressBar.unmount/1","doc":"","ref":"Raxol.Components.Progress.ProgressBar.html#unmount/1"},{"type":"module","title":"Raxol.Components.Progress.Spinner","doc":"A spinner component that provides animated loading indicators.","ref":"Raxol.Components.Progress.Spinner.html"},{"type":"module","title":"Props - Raxol.Components.Progress.Spinner","doc":"* `:style` - The animation style to use (default: :dots)\n  * `:dots` - Rotating dots (⠋⠙⠹⠸⠼⠴⠦⠧⠇⠏)\n  * `:line` - Rotating line (|/-\\)\n  * `:bounce` - Bouncing ball (⠁⠂⠄⠂)\n  * `:pulse` - Pulsing circle (●○)\n  * `:custom` - Custom animation using `:frames`\n  * `:frames` - List of characters to use for custom animation\n  * `:colors` - List of colors to transition between\n  * `:speed` - Animation speed in milliseconds (default: 80)\n  * `:text` - Optional text to display next to the spinner\n  * `:text_position` - Position of text relative to spinner (:left or :right, default: :right)","ref":"Raxol.Components.Progress.Spinner.html#module-props"},{"type":"function","title":"Raxol.Components.Progress.Spinner.broadcast/1","doc":"","ref":"Raxol.Components.Progress.Spinner.html#broadcast/1"},{"type":"function","title":"Raxol.Components.Progress.Spinner.command/1","doc":"","ref":"Raxol.Components.Progress.Spinner.html#command/1"},{"type":"function","title":"Raxol.Components.Progress.Spinner.error/1","doc":"","ref":"Raxol.Components.Progress.Spinner.html#error/1"},{"type":"function","title":"Raxol.Components.Progress.Spinner.loading/1","doc":"","ref":"Raxol.Components.Progress.Spinner.html#loading/1"},{"type":"function","title":"Raxol.Components.Progress.Spinner.mount/1","doc":"","ref":"Raxol.Components.Progress.Spinner.html#mount/1"},{"type":"function","title":"Raxol.Components.Progress.Spinner.processing/1","doc":"","ref":"Raxol.Components.Progress.Spinner.html#processing/1"},{"type":"function","title":"Raxol.Components.Progress.Spinner.saving/1","doc":"","ref":"Raxol.Components.Progress.Spinner.html#saving/1"},{"type":"function","title":"Raxol.Components.Progress.Spinner.schedule/2","doc":"","ref":"Raxol.Components.Progress.Spinner.html#schedule/2"},{"type":"function","title":"Raxol.Components.Progress.Spinner.unmount/1","doc":"","ref":"Raxol.Components.Progress.Spinner.html#unmount/1"},{"type":"module","title":"Raxol.Components.Selection.Dropdown","doc":"A dropdown component that allows selecting one option from a list.","ref":"Raxol.Components.Selection.Dropdown.html"},{"type":"function","title":"Raxol.Components.Selection.Dropdown.broadcast/1","doc":"","ref":"Raxol.Components.Selection.Dropdown.html#broadcast/1"},{"type":"function","title":"Raxol.Components.Selection.Dropdown.command/1","doc":"","ref":"Raxol.Components.Selection.Dropdown.html#command/1"},{"type":"function","title":"Raxol.Components.Selection.Dropdown.mount/1","doc":"","ref":"Raxol.Components.Selection.Dropdown.html#mount/1"},{"type":"function","title":"Raxol.Components.Selection.Dropdown.schedule/2","doc":"","ref":"Raxol.Components.Selection.Dropdown.html#schedule/2"},{"type":"function","title":"Raxol.Components.Selection.Dropdown.unmount/1","doc":"","ref":"Raxol.Components.Selection.Dropdown.html#unmount/1"},{"type":"module","title":"Raxol.Components.Selection.List","doc":"A component for displaying a selectable list of items.","ref":"Raxol.Components.Selection.List.html"},{"type":"function","title":"Raxol.Components.Selection.List.broadcast/1","doc":"","ref":"Raxol.Components.Selection.List.html#broadcast/1"},{"type":"function","title":"Raxol.Components.Selection.List.command/1","doc":"","ref":"Raxol.Components.Selection.List.html#command/1"},{"type":"function","title":"Raxol.Components.Selection.List.mount/1","doc":"","ref":"Raxol.Components.Selection.List.html#mount/1"},{"type":"function","title":"Raxol.Components.Selection.List.schedule/2","doc":"","ref":"Raxol.Components.Selection.List.html#schedule/2"},{"type":"function","title":"Raxol.Components.Selection.List.unmount/1","doc":"","ref":"Raxol.Components.Selection.List.html#unmount/1"},{"type":"module","title":"Raxol.Components.TabBar","doc":"A tab bar component for Raxol.\n\nA tab bar component for navigating between different sections of a UI.","ref":"Raxol.Components.TabBar.html"},{"type":"module","title":"Examples - Raxol.Components.TabBar","doc":"```elixir\nalias Raxol.Components.TabBar\n\n# In your view function\ndef view(model) do\n  tabs = [\n    %{id: :dashboard, label: \"Dashboard\"},\n    %{id: :settings, label: \"Settings\"},\n    %{id: :help, label: \"Help\"}\n  ]\n\n  view do\n    panel do\n      TabBar.render(tabs, model.active_tab, &handle_tab_change/2)\n\n      # Content based on active tab\n      case model.active_tab do\n        :dashboard -> dashboard_view(model)\n        :settings -> settings_view(model)\n        :help -> help_view(model)\n      end\n    end\n  end\nend\n\n# Handler function\ndef handle_tab_change(model, tab_id) do\n  %{model | active_tab: tab_id}\nend\n\n@behaviour Raxol.ComponentBehaviour\n\n@doc \"\"\"\nRenders a tab bar with the given tabs, highlighting the active tab.","ref":"Raxol.Components.TabBar.html#module-examples"},{"type":"module","title":"Parameters - Raxol.Components.TabBar","doc":"* `tabs` - A list of tab maps, each containing `:id` and `:label` keys\n* `active_tab` - The ID of the currently active tab\n* `on_change` - A function that takes the model and a tab ID and returns an updated model\n* `opts` - Options for customizing the tab bar appearance","ref":"Raxol.Components.TabBar.html#module-parameters"},{"type":"module","title":"Options - Raxol.Components.TabBar","doc":"* `:focus_key` - Key for focusing the tab bar (default: \"tab_bar\")\n* `:style` - Style for the tab bar (default: %{})\n* `:tab_style` - Style for individual tabs (default: %{})\n* `:active_tab_style` - Style for the active tab (default: %{fg: :white, bg: :blue})","ref":"Raxol.Components.TabBar.html#module-options"},{"type":"module","title":"Returns - Raxol.Components.TabBar","doc":"A view element representing the tab bar.","ref":"Raxol.Components.TabBar.html#module-returns"},{"type":"module","title":"Example - Raxol.Components.TabBar","doc":"```elixir\nTabBar.render(\n  [\n    %{id: :tab1, label: \"First Tab\"},\n    %{id: :tab2, label: \"Second Tab\"}\n  ],\n  :tab1,\n  &handle_tab_change/2,\n  active_tab_style: %{fg: :white, bg: :green}\n)\n```","ref":"Raxol.Components.TabBar.html#module-example"},{"type":"function","title":"Raxol.Components.TabBar.render/4","doc":"","ref":"Raxol.Components.TabBar.html#render/4"},{"type":"function","title":"Raxol.Components.TabBar.tabbed_view/4","doc":"Creates a tabbed interface with content.\n\nThis is a higher-level component that combines the tab bar with\ncontent areas for each tab.","ref":"Raxol.Components.TabBar.html#tabbed_view/4"},{"type":"function","title":"Parameters - Raxol.Components.TabBar.tabbed_view/4","doc":"* `tabs` - A list of tab maps, each containing `:id`, `:label`, and `:content` keys\n* `active_tab` - The ID of the currently active tab\n* `on_change` - A function that takes the model and a tab ID and returns an updated model\n* `opts` - Options for customizing the tabbed interface","ref":"Raxol.Components.TabBar.html#tabbed_view/4-parameters"},{"type":"function","title":"Options - Raxol.Components.TabBar.tabbed_view/4","doc":"* `:focus_key` - Key for focusing the tabbed interface (default: \"tabbed_view\")\n* `:style` - Style for the container (default: %{})\n* `:tab_bar_style` - Style for the tab bar (default: %{})\n* `:tab_style` - Style for individual tabs (default: %{})\n* `:active_tab_style` - Style for the active tab (default: %{fg: :white, bg: :blue})\n* `:content_style` - Style for the content area (default: %{})","ref":"Raxol.Components.TabBar.html#tabbed_view/4-options"},{"type":"function","title":"Returns - Raxol.Components.TabBar.tabbed_view/4","doc":"A view element representing the complete tabbed interface.","ref":"Raxol.Components.TabBar.html#tabbed_view/4-returns"},{"type":"function","title":"Example - Raxol.Components.TabBar.tabbed_view/4","doc":"```elixir\nTabBar.tabbed_view(\n  [\n    %{id: :tab1, label: \"First Tab\", content: fn -> View.text(\"First tab content\") end},\n    %{id: :tab2, label: \"Second Tab\", content: fn -> View.text(\"Second tab content\") end}\n  ],\n  :tab1,\n  &handle_tab_change/2\n)\n```","ref":"Raxol.Components.TabBar.html#tabbed_view/4-example"},{"type":"module","title":"Raxol.Components.Table","doc":"Renders data in a tabular format with optional headers, sorting, and pagination.","ref":"Raxol.Components.Table.html"},{"type":"function","title":"Raxol.Components.Table.broadcast/1","doc":"","ref":"Raxol.Components.Table.html#broadcast/1"},{"type":"function","title":"Raxol.Components.Table.command/1","doc":"","ref":"Raxol.Components.Table.html#command/1"},{"type":"function","title":"Raxol.Components.Table.mount/1","doc":"","ref":"Raxol.Components.Table.html#mount/1"},{"type":"function","title":"Raxol.Components.Table.schedule/2","doc":"","ref":"Raxol.Components.Table.html#schedule/2"},{"type":"function","title":"Raxol.Components.Table.unmount/1","doc":"","ref":"Raxol.Components.Table.html#unmount/1"},{"type":"module","title":"Raxol.Components.Terminal","doc":"A terminal component that emulates a standard terminal within the UI.","ref":"Raxol.Components.Terminal.html"},{"type":"function","title":"Raxol.Components.Terminal.broadcast/1","doc":"","ref":"Raxol.Components.Terminal.html#broadcast/1"},{"type":"function","title":"Raxol.Components.Terminal.command/1","doc":"","ref":"Raxol.Components.Terminal.html#command/1"},{"type":"function","title":"Raxol.Components.Terminal.mount/1","doc":"","ref":"Raxol.Components.Terminal.html#mount/1"},{"type":"function","title":"Raxol.Components.Terminal.schedule/2","doc":"","ref":"Raxol.Components.Terminal.html#schedule/2"},{"type":"function","title":"Raxol.Components.Terminal.unmount/1","doc":"","ref":"Raxol.Components.Terminal.html#unmount/1"},{"type":"module","title":"Raxol.Components.Terminal.Emulator","doc":"Terminal emulator component wrapping the core emulator logic.","ref":"Raxol.Components.Terminal.Emulator.html"},{"type":"type","title":"Raxol.Components.Terminal.Emulator.emulator_state/0","doc":"","ref":"Raxol.Components.Terminal.Emulator.html#t:emulator_state/0"},{"type":"function","title":"Raxol.Components.Terminal.Emulator.get_visible_content/1","doc":"Gets the visible content from the UI component's state.","ref":"Raxol.Components.Terminal.Emulator.html#get_visible_content/1"},{"type":"function","title":"Raxol.Components.Terminal.Emulator.handle_resize/2","doc":"Handles terminal resize events.\nTODO: Implement proper resizing by delegating to CoreEmulator or ScreenBuffer","ref":"Raxol.Components.Terminal.Emulator.html#handle_resize/2"},{"type":"function","title":"Raxol.Components.Terminal.Emulator.init/0","doc":"Initializes a new terminal emulator component state.","ref":"Raxol.Components.Terminal.Emulator.html#init/0"},{"type":"function","title":"Raxol.Components.Terminal.Emulator.process_input/2","doc":"Processes input and updates terminal state by delegating to the core emulator.","ref":"Raxol.Components.Terminal.Emulator.html#process_input/2"},{"type":"module","title":"Raxol.Components.TextInput","doc":"A text input component with editing capabilities.\n\nThis module provides a text input field that allows users to enter\nand edit text with cursor positioning, selection, and validation.","ref":"Raxol.Components.TextInput.html"},{"type":"module","title":"Example - Raxol.Components.TextInput","doc":"```elixir\nalias Raxol.Components.TextInput\n\nTextInput.new(\n  value: model.name,\n  placeholder: \"Enter your name\",\n  on_change: fn value -> {:update_name, value} end\n)\n```","ref":"Raxol.Components.TextInput.html#module-example"},{"type":"function","title":"Raxol.Components.TextInput.handle_key_event/2","doc":"Updates the text input based on keyboard input.","ref":"Raxol.Components.TextInput.html#handle_key_event/2"},{"type":"function","title":"Parameters - Raxol.Components.TextInput.handle_key_event/2","doc":"* `input` - The text input component\n* `key_event` - Keyboard event as `{meta, key}`","ref":"Raxol.Components.TextInput.html#handle_key_event/2-parameters"},{"type":"function","title":"Returns - Raxol.Components.TextInput.handle_key_event/2","doc":"Updated text input component.","ref":"Raxol.Components.TextInput.html#handle_key_event/2-returns"},{"type":"function","title":"Example - Raxol.Components.TextInput.handle_key_event/2","doc":"```elixir\nupdated_input = TextInput.handle_key_event(input, {:none, ?a})\n```","ref":"Raxol.Components.TextInput.html#handle_key_event/2-example"},{"type":"function","title":"Raxol.Components.TextInput.new/1","doc":"Creates a new text input with the given options.","ref":"Raxol.Components.TextInput.html#new/1"},{"type":"function","title":"Options - Raxol.Components.TextInput.new/1","doc":"* `:value` - Current input value\n* `:placeholder` - Placeholder text when empty\n* `:on_change` - Function to call when value changes\n* `:password` - Whether to mask input as password\n* `:max_length` - Maximum input length\n* `:style` - Custom style for the input\n* `:disabled` - Whether the input is disabled\n* `:validation` - Validation function\n* `:invalid_message` - Message to show when validation fails","ref":"Raxol.Components.TextInput.html#new/1-options"},{"type":"function","title":"Returns - Raxol.Components.TextInput.new/1","doc":"A text input component that can be used in a Raxol view.","ref":"Raxol.Components.TextInput.html#new/1-returns"},{"type":"function","title":"Example - Raxol.Components.TextInput.new/1","doc":"```elixir\nTextInput.new(\n  value: model.email,\n  placeholder: \"example@example.com\",\n  validation: &String.contains?(&1, \"@\"),\n  invalid_message: \"Must be a valid email\"\n)\n```","ref":"Raxol.Components.TextInput.html#new/1-example"},{"type":"function","title":"Raxol.Components.TextInput.render/1","doc":"Renders the text input as a basic element.\n\nThis is typically called by the renderer, not directly by users.","ref":"Raxol.Components.TextInput.html#render/1"},{"type":"type","title":"Raxol.Components.TextInput.t/0","doc":"","ref":"Raxol.Components.TextInput.html#t:t/0"},{"type":"module","title":"Raxol.Core.Accessibility","doc":"Accessibility module for Raxol terminal UI applications.\n\nThis module provides accessibility features including:\n- Screen reader announcements\n- Keyboard navigation enhancements\n- High contrast mode\n- Reduced motion support\n- Focus management\n- Large text support","ref":"Raxol.Core.Accessibility.html"},{"type":"module","title":"Usage - Raxol.Core.Accessibility","doc":"```elixir\n# Enable accessibility features\nAccessibility.enable()\n\n# Make an announcement for screen readers\nAccessibility.announce(\"You have selected the search button\")\n\n# Enable high contrast mode\nAccessibility.set_high_contrast(true)\n\n# Enable reduced motion mode\nAccessibility.set_reduced_motion(true)\n\n# Enable large text mode\nAccessibility.set_large_text(true)\n```","ref":"Raxol.Core.Accessibility.html#module-usage"},{"type":"function","title":"Raxol.Core.Accessibility.announce/2","doc":"Make an announcement for screen readers.\n\nThis function adds a message to the announcement queue that will be\nread by screen readers.","ref":"Raxol.Core.Accessibility.html#announce/2"},{"type":"function","title":"Parameters - Raxol.Core.Accessibility.announce/2","doc":"* `message` - The message to announce\n* `opts` - Options for the announcement","ref":"Raxol.Core.Accessibility.html#announce/2-parameters"},{"type":"function","title":"Options - Raxol.Core.Accessibility.announce/2","doc":"* `:priority` - Priority level (`:low`, `:medium`, `:high`) (default: `:medium`)\n* `:interrupt` - Whether to interrupt current announcements (default: `false`)","ref":"Raxol.Core.Accessibility.html#announce/2-options"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.announce/2","doc":"iex> Accessibility.announce(\"Button clicked\")\n    :ok\n\n    iex> Accessibility.announce(\"Error occurred\", priority: :high, interrupt: true)\n    :ok","ref":"Raxol.Core.Accessibility.html#announce/2-examples"},{"type":"function","title":"Raxol.Core.Accessibility.clear_announcements/0","doc":"Clear all pending announcements.","ref":"Raxol.Core.Accessibility.html#clear_announcements/0"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.clear_announcements/0","doc":"iex> Accessibility.clear_announcements()\n    :ok","ref":"Raxol.Core.Accessibility.html#clear_announcements/0-examples"},{"type":"function","title":"Raxol.Core.Accessibility.disable/0","doc":"Disable accessibility features.","ref":"Raxol.Core.Accessibility.html#disable/0"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.disable/0","doc":"iex> Accessibility.disable()\n    :ok","ref":"Raxol.Core.Accessibility.html#disable/0-examples"},{"type":"function","title":"Raxol.Core.Accessibility.enable/1","doc":"Enable accessibility features.","ref":"Raxol.Core.Accessibility.html#enable/1"},{"type":"function","title":"Options - Raxol.Core.Accessibility.enable/1","doc":"* `:screen_reader` - Enable screen reader support (default: `true`)\n* `:high_contrast` - Enable high contrast mode (default: `false`)\n* `:reduced_motion` - Reduce or disable animations (default: `false`)\n* `:keyboard_focus` - Enhanced keyboard focus indicators (default: `true`)\n* `:large_text` - Use larger text for better readability (default: `false`)","ref":"Raxol.Core.Accessibility.html#enable/1-options"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.enable/1","doc":"iex> Accessibility.enable()\n    :ok\n\n    iex> Accessibility.enable(high_contrast: true, reduced_motion: true)\n    :ok","ref":"Raxol.Core.Accessibility.html#enable/1-examples"},{"type":"function","title":"Raxol.Core.Accessibility.get_color_scheme/0","doc":"Get the current color scheme based on accessibility settings.","ref":"Raxol.Core.Accessibility.html#get_color_scheme/0"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.get_color_scheme/0","doc":"iex> Accessibility.get_color_scheme()\n    %{background: ...}  # Returns the current color scheme","ref":"Raxol.Core.Accessibility.html#get_color_scheme/0-examples"},{"type":"function","title":"Raxol.Core.Accessibility.get_next_announcement/0","doc":"Get the next announcement to be read by screen readers.\n\nThis function is typically called by the screen reader integration.","ref":"Raxol.Core.Accessibility.html#get_next_announcement/0"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.get_next_announcement/0","doc":"iex> Accessibility.get_next_announcement()\n    \"Button clicked\"","ref":"Raxol.Core.Accessibility.html#get_next_announcement/0-examples"},{"type":"function","title":"Raxol.Core.Accessibility.get_option/1","doc":"Get an accessibility option value.","ref":"Raxol.Core.Accessibility.html#get_option/1"},{"type":"function","title":"Parameters - Raxol.Core.Accessibility.get_option/1","doc":"* `key` - The option key to get","ref":"Raxol.Core.Accessibility.html#get_option/1-parameters"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.get_option/1","doc":"iex> Accessibility.get_option(:high_contrast)\n    false","ref":"Raxol.Core.Accessibility.html#get_option/1-examples"},{"type":"function","title":"Raxol.Core.Accessibility.get_text_scale/0","doc":"Get the current text scale factor.","ref":"Raxol.Core.Accessibility.html#get_text_scale/0"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.get_text_scale/0","doc":"iex> Accessibility.get_text_scale()\n    1.0  # Default scale\n\n    iex> Accessibility.set_large_text(true)\n    iex> Accessibility.get_text_scale()\n    1.5  # Large text scale","ref":"Raxol.Core.Accessibility.html#get_text_scale/0-examples"},{"type":"function","title":"Raxol.Core.Accessibility.handle_focus_change/2","doc":"Handle focus change events for accessibility announcements.","ref":"Raxol.Core.Accessibility.html#handle_focus_change/2"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.handle_focus_change/2","doc":"iex> Accessibility.handle_focus_change(nil, \"search_button\")\n    :ok","ref":"Raxol.Core.Accessibility.html#handle_focus_change/2-examples"},{"type":"function","title":"Raxol.Core.Accessibility.register_metadata/2","doc":"Register metadata for an element to be used for accessibility features.","ref":"Raxol.Core.Accessibility.html#register_metadata/2"},{"type":"function","title":"Parameters - Raxol.Core.Accessibility.register_metadata/2","doc":"* `element_id` - Unique identifier for the element\n* `metadata` - Metadata to associate with the element","ref":"Raxol.Core.Accessibility.html#register_metadata/2-parameters"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.register_metadata/2","doc":"iex> Accessibility.register_metadata(\"search_button\", %{label: \"Search\"})\n    :ok","ref":"Raxol.Core.Accessibility.html#register_metadata/2-examples"},{"type":"function","title":"Raxol.Core.Accessibility.set_high_contrast/1","doc":"Enable or disable high contrast mode.","ref":"Raxol.Core.Accessibility.html#set_high_contrast/1"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.set_high_contrast/1","doc":"iex> Accessibility.set_high_contrast(true)\n    :ok","ref":"Raxol.Core.Accessibility.html#set_high_contrast/1-examples"},{"type":"function","title":"Raxol.Core.Accessibility.set_large_text/1","doc":"Enable or disable large text mode.","ref":"Raxol.Core.Accessibility.html#set_large_text/1"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.set_large_text/1","doc":"iex> Accessibility.set_large_text(true)\n    :ok","ref":"Raxol.Core.Accessibility.html#set_large_text/1-examples"},{"type":"function","title":"Raxol.Core.Accessibility.set_option/2","doc":"Set an accessibility option value.","ref":"Raxol.Core.Accessibility.html#set_option/2"},{"type":"function","title":"Parameters - Raxol.Core.Accessibility.set_option/2","doc":"* `key` - The option key to set\n* `value` - The value to set","ref":"Raxol.Core.Accessibility.html#set_option/2-parameters"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.set_option/2","doc":"iex> Accessibility.set_option(:high_contrast, true)\n    :ok","ref":"Raxol.Core.Accessibility.html#set_option/2-examples"},{"type":"function","title":"Raxol.Core.Accessibility.set_reduced_motion/1","doc":"Enable or disable reduced motion.","ref":"Raxol.Core.Accessibility.html#set_reduced_motion/1"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.set_reduced_motion/1","doc":"iex> Accessibility.set_reduced_motion(true)\n    :ok","ref":"Raxol.Core.Accessibility.html#set_reduced_motion/1-examples"},{"type":"module","title":"Raxol.Core.Accessibility.Mock","doc":"Mock implementation for Raxol.Core.Accessibility.\n\nThis module provides manual definitions for functions expected to be\ncalled during tests when Raxol.Core.Accessibility is replaced\nusing Mox.stub_with/2.","ref":"Raxol.Core.Accessibility.Mock.html"},{"type":"function","title":"Raxol.Core.Accessibility.Mock.announce/2","doc":"","ref":"Raxol.Core.Accessibility.Mock.html#announce/2"},{"type":"module","title":"Raxol.Core.Accessibility.ThemeIntegration","doc":"Manages the integration between accessibility settings and the active theme.\n\nListens for accessibility changes (e.g., high contrast toggle) and\nupdates the active theme variant accordingly.","ref":"Raxol.Core.Accessibility.ThemeIntegration.html"},{"type":"function","title":"Raxol.Core.Accessibility.ThemeIntegration.apply_current_settings/0","doc":"Apply the current accessibility settings to components.\nThis function is typically called during initialization to ensure components\nreflect the persisted preferences.","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#apply_current_settings/0"},{"type":"function","title":"Raxol.Core.Accessibility.ThemeIntegration.cleanup/0","doc":"Clean up the theme integration.\n\nUnregisters event handlers.","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#cleanup/0"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.ThemeIntegration.cleanup/0","doc":"iex> ThemeIntegration.cleanup()\n    :ok","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#cleanup/0-examples"},{"type":"function","title":"Raxol.Core.Accessibility.ThemeIntegration.get_active_variant/0","doc":"Returns the currently active theme variant based on accessibility settings.\nDefaults to `:default` if high contrast is off.","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#get_active_variant/0"},{"type":"function","title":"Raxol.Core.Accessibility.ThemeIntegration.handle_high_contrast/1","doc":"Handle high contrast mode changes.\nStores the active variant (:high_contrast or nil) in the process dictionary.\nComponents should then use a central function (e.g., ColorSystem.get) to query colors.","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#handle_high_contrast/1"},{"type":"function","title":"Raxol.Core.Accessibility.ThemeIntegration.handle_large_text/1","doc":"Handle large text setting changes.","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#handle_large_text/1"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.ThemeIntegration.handle_large_text/1","doc":"iex> ThemeIntegration.handle_large_text({:accessibility_large_text, true})\n    :ok","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#handle_large_text/1-examples"},{"type":"function","title":"Raxol.Core.Accessibility.ThemeIntegration.handle_reduced_motion/1","doc":"Handle reduced motion setting changes.","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#handle_reduced_motion/1"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.ThemeIntegration.handle_reduced_motion/1","doc":"iex> ThemeIntegration.handle_reduced_motion({:accessibility_reduced_motion, true})\n    :ok","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#handle_reduced_motion/1-examples"},{"type":"function","title":"Raxol.Core.Accessibility.ThemeIntegration.init/0","doc":"Initialize the theme integration.\n\nRegisters event handlers for accessibility setting changes.","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#init/0"},{"type":"function","title":"Examples - Raxol.Core.Accessibility.ThemeIntegration.init/0","doc":"iex> ThemeIntegration.init()\n    :ok","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#init/0-examples"},{"type":"module","title":"Raxol.Core.ColorSystem","doc":"Provides access to the application's color palette, considering the current theme\nand accessibility settings (like high contrast mode).\n\nComponents should use `ColorSystem.get/2` to retrieve semantic colors.","ref":"Raxol.Core.ColorSystem.html"},{"type":"function","title":"Raxol.Core.ColorSystem.get/2","doc":"Gets the effective color value for a given semantic color name.\n\nIt retrieves the color from the specified theme (by ID), automatically considering\nwhether a high contrast variant is active based on accessibility settings.\n\nArgs:\n  - `theme_id`: The atom ID of the theme to use (e.g., :default, :dark).\n  - `color_name`: The semantic name of the color (e.g., :primary, :background).\n\nReturns the color value (e.g., :red, {:rgb, r, g, b}) or nil if not found.","ref":"Raxol.Core.ColorSystem.html#get/2"},{"type":"function","title":"Raxol.Core.ColorSystem.get_as/3","doc":"Gets a color value and ensures it's returned in a specific format (e.g., RGB tuple).\nUseful when a specific color representation is required for rendering.\n\nArgs:\n  - `theme_id`: The atom ID of the theme to use.\n  - `color_name`: The semantic name of the color.\n  - `format`: The desired output format (:rgb_tuple, :hex_string, :term).\n\nSupported formats: :rgb_tuple, :hex_string, :term","ref":"Raxol.Core.ColorSystem.html#get_as/3"},{"type":"module","title":"Raxol.Core.Events.Clipboard","doc":"Handles clipboard operations for the Raxol application.\n\nNote: On Linux, this module requires the `xclip` utility to be installed\nfor accessing the X11 clipboard. Wayland is not currently supported directly.","ref":"Raxol.Core.Events.Clipboard.html"},{"type":"function","title":"Raxol.Core.Events.Clipboard.copy/1","doc":"Copies text to the system clipboard.","ref":"Raxol.Core.Events.Clipboard.html#copy/1"},{"type":"function","title":"Raxol.Core.Events.Clipboard.paste/0","doc":"Retrieves text from the system clipboard.","ref":"Raxol.Core.Events.Clipboard.html#paste/0"},{"type":"module","title":"Raxol.Core.Events.Event","doc":"Defines the structure for events in the Raxol system, providing a standardized format\nfor key presses, mouse actions, and other UI events that components need to process.\n\nEvents are structs with a :type and :data field, where :type indicates the event category\n(e.g., :key, :mouse, :resize) and :data contains the event-specific details.","ref":"Raxol.Core.Events.Event.html"},{"type":"type","title":"Raxol.Core.Events.Event.cursor_event/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:cursor_event/0"},{"type":"function","title":"Raxol.Core.Events.Event.cursor_event/4","doc":"Creates a cursor event.","ref":"Raxol.Core.Events.Event.html#cursor_event/4"},{"type":"function","title":"Parameters - Raxol.Core.Events.Event.cursor_event/4","doc":"* `visible` - Whether cursor is visible\n  * `style` - Cursor style\n  * `blink` - Whether cursor should blink\n  * `position` - Cursor position","ref":"Raxol.Core.Events.Event.html#cursor_event/4-parameters"},{"type":"function","title":"Raxol.Core.Events.Event.custom/1","doc":"Creates a simple custom event.","ref":"Raxol.Core.Events.Event.html#custom/1"},{"type":"function","title":"Raxol.Core.Events.Event.custom_event/1","doc":"Creates a custom event.","ref":"Raxol.Core.Events.Event.html#custom_event/1"},{"type":"function","title":"Parameters - Raxol.Core.Events.Event.custom_event/1","doc":"* `data` - Custom event data","ref":"Raxol.Core.Events.Event.html#custom_event/1-parameters"},{"type":"type","title":"Raxol.Core.Events.Event.event_data/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:event_data/0"},{"type":"type","title":"Raxol.Core.Events.Event.event_type/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:event_type/0"},{"type":"type","title":"Raxol.Core.Events.Event.focus_event/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:focus_event/0"},{"type":"function","title":"Raxol.Core.Events.Event.focus_event/2","doc":"Creates a focus event.","ref":"Raxol.Core.Events.Event.html#focus_event/2"},{"type":"function","title":"Parameters - Raxol.Core.Events.Event.focus_event/2","doc":"* `target` - What received/lost focus\n  * `focused` - Whether focus was gained (true) or lost (false)","ref":"Raxol.Core.Events.Event.html#focus_event/2-parameters"},{"type":"type","title":"Raxol.Core.Events.Event.focus_target/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:focus_target/0"},{"type":"type","title":"Raxol.Core.Events.Event.key/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:key/0"},{"type":"function","title":"Raxol.Core.Events.Event.key/1","doc":"Creates a simple key event with pressed state and no modifiers.","ref":"Raxol.Core.Events.Event.html#key/1"},{"type":"type","title":"Raxol.Core.Events.Event.key_event/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:key_event/0"},{"type":"function","title":"Raxol.Core.Events.Event.key_event/3","doc":"Creates a keyboard event.","ref":"Raxol.Core.Events.Event.html#key_event/3"},{"type":"function","title":"Parameters - Raxol.Core.Events.Event.key_event/3","doc":"* `key` - The key that was pressed/released (e.g. :enter, :backspace, \"a\")\n  * `state` - The state of the key (:pressed, :released, :repeat)\n  * `modifiers` - List of active modifiers (e.g. [:shift, :ctrl])","ref":"Raxol.Core.Events.Event.html#key_event/3-parameters"},{"type":"type","title":"Raxol.Core.Events.Event.key_state/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:key_state/0"},{"type":"type","title":"Raxol.Core.Events.Event.modifiers/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:modifiers/0"},{"type":"function","title":"Raxol.Core.Events.Event.mouse/2","doc":"Creates a simple mouse event with pressed state and no modifiers.","ref":"Raxol.Core.Events.Event.html#mouse/2"},{"type":"function","title":"Raxol.Core.Events.Event.mouse/3","doc":"Creates a mouse event with drag state.","ref":"Raxol.Core.Events.Event.html#mouse/3"},{"type":"type","title":"Raxol.Core.Events.Event.mouse_button/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:mouse_button/0"},{"type":"type","title":"Raxol.Core.Events.Event.mouse_event/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:mouse_event/0"},{"type":"function","title":"Raxol.Core.Events.Event.mouse_event/4","doc":"Creates a mouse event.","ref":"Raxol.Core.Events.Event.html#mouse_event/4"},{"type":"function","title":"Parameters - Raxol.Core.Events.Event.mouse_event/4","doc":"* `button` - The mouse button (:left, :right, :middle)\n  * `position` - The mouse position as {x, y}\n  * `state` - The button state (:pressed, :released, :double_click)\n  * `modifiers` - List of active modifiers (e.g. [:shift, :ctrl])","ref":"Raxol.Core.Events.Event.html#mouse_event/4-parameters"},{"type":"type","title":"Raxol.Core.Events.Event.mouse_position/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:mouse_position/0"},{"type":"type","title":"Raxol.Core.Events.Event.mouse_state/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:mouse_state/0"},{"type":"function","title":"Raxol.Core.Events.Event.new/2","doc":"Creates a new event with the given type and data.","ref":"Raxol.Core.Events.Event.html#new/2"},{"type":"type","title":"Raxol.Core.Events.Event.paste_event/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:paste_event/0"},{"type":"function","title":"Raxol.Core.Events.Event.paste_event/2","doc":"Creates a paste event.","ref":"Raxol.Core.Events.Event.html#paste_event/2"},{"type":"function","title":"Parameters - Raxol.Core.Events.Event.paste_event/2","doc":"* `text` - Pasted text\n  * `position` - Paste position","ref":"Raxol.Core.Events.Event.html#paste_event/2-parameters"},{"type":"type","title":"Raxol.Core.Events.Event.scroll_direction/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:scroll_direction/0"},{"type":"type","title":"Raxol.Core.Events.Event.scroll_event/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:scroll_event/0"},{"type":"function","title":"Raxol.Core.Events.Event.scroll_event/3","doc":"Creates a scroll event.","ref":"Raxol.Core.Events.Event.html#scroll_event/3"},{"type":"function","title":"Parameters - Raxol.Core.Events.Event.scroll_event/3","doc":"* `direction` - Scroll direction\n  * `delta` - Amount scrolled (positive or negative)\n  * `position` - Current scroll position","ref":"Raxol.Core.Events.Event.html#scroll_event/3-parameters"},{"type":"type","title":"Raxol.Core.Events.Event.selection_event/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:selection_event/0"},{"type":"function","title":"Raxol.Core.Events.Event.selection_event/3","doc":"Creates a selection event.","ref":"Raxol.Core.Events.Event.html#selection_event/3"},{"type":"function","title":"Parameters - Raxol.Core.Events.Event.selection_event/3","doc":"* `start_pos` - Selection start position\n  * `end_pos` - Selection end position\n  * `text` - Selected text","ref":"Raxol.Core.Events.Event.html#selection_event/3-parameters"},{"type":"type","title":"Raxol.Core.Events.Event.t/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:t/0"},{"type":"function","title":"Raxol.Core.Events.Event.timer/1","doc":"Creates a simple timer event.","ref":"Raxol.Core.Events.Event.html#timer/1"},{"type":"function","title":"Raxol.Core.Events.Event.timer_event/1","doc":"Creates a timer event.","ref":"Raxol.Core.Events.Event.html#timer_event/1"},{"type":"function","title":"Parameters - Raxol.Core.Events.Event.timer_event/1","doc":"* `data` - Timer-specific data","ref":"Raxol.Core.Events.Event.html#timer_event/1-parameters"},{"type":"function","title":"Raxol.Core.Events.Event.window/3","doc":"Creates a simple window event.","ref":"Raxol.Core.Events.Event.html#window/3"},{"type":"type","title":"Raxol.Core.Events.Event.window_event/0","doc":"","ref":"Raxol.Core.Events.Event.html#t:window_event/0"},{"type":"function","title":"Raxol.Core.Events.Event.window_event/3","doc":"Creates a window event.","ref":"Raxol.Core.Events.Event.html#window_event/3"},{"type":"function","title":"Parameters - Raxol.Core.Events.Event.window_event/3","doc":"* `width` - The window width\n  * `height` - The window height\n  * `action` - The window action (:resize, :focus, :blur)","ref":"Raxol.Core.Events.Event.html#window_event/3-parameters"},{"type":"module","title":"Raxol.Core.Events.Manager","doc":"Event manager for handling and dispatching events in Raxol applications.\n\nThis module provides a simple event system that allows:\n- Registering event handlers\n- Dispatching events\n- Handling events\n- Managing subscriptions","ref":"Raxol.Core.Events.Manager.html"},{"type":"module","title":"Usage - Raxol.Core.Events.Manager","doc":"```elixir\n# Initialize the event manager\nEventManager.init()\n\n# Register an event handler\nEventManager.register_handler(:click, MyModule, :handle_click)\n\n# Subscribe to events\n{:ok, ref} = EventManager.subscribe([:click, :key_press])\n\n# Dispatch an event\nEventManager.dispatch({:click, %{x: 10, y: 20}})\n\n# Unsubscribe\nEventManager.unsubscribe(ref)\n```","ref":"Raxol.Core.Events.Manager.html#module-usage"},{"type":"function","title":"Raxol.Core.Events.Manager.broadcast/1","doc":"Broadcast an event to all subscribers.","ref":"Raxol.Core.Events.Manager.html#broadcast/1"},{"type":"function","title":"Examples - Raxol.Core.Events.Manager.broadcast/1","doc":"iex> EventManager.broadcast({:system_event, :shutdown})\n    :ok","ref":"Raxol.Core.Events.Manager.html#broadcast/1-examples"},{"type":"function","title":"Raxol.Core.Events.Manager.cleanup/0","doc":"Cleans up the event manager state.","ref":"Raxol.Core.Events.Manager.html#cleanup/0"},{"type":"function","title":"Raxol.Core.Events.Manager.clear_handlers/0","doc":"Clear all event handlers.","ref":"Raxol.Core.Events.Manager.html#clear_handlers/0"},{"type":"function","title":"Examples - Raxol.Core.Events.Manager.clear_handlers/0","doc":"iex> EventManager.clear_handlers()\n    :ok","ref":"Raxol.Core.Events.Manager.html#clear_handlers/0-examples"},{"type":"function","title":"Raxol.Core.Events.Manager.dispatch/1","doc":"Dispatch an event to all registered handlers and subscribers.","ref":"Raxol.Core.Events.Manager.html#dispatch/1"},{"type":"function","title":"Parameters - Raxol.Core.Events.Manager.dispatch/1","doc":"* `event` - The event to dispatch","ref":"Raxol.Core.Events.Manager.html#dispatch/1-parameters"},{"type":"function","title":"Examples - Raxol.Core.Events.Manager.dispatch/1","doc":"iex> EventManager.dispatch({:click, %{x: 10, y: 20}})\n    :ok\n\n    iex> EventManager.dispatch(:accessibility_high_contrast)\n    :ok","ref":"Raxol.Core.Events.Manager.html#dispatch/1-examples"},{"type":"function","title":"Raxol.Core.Events.Manager.get_handlers/0","doc":"Get all registered event handlers.","ref":"Raxol.Core.Events.Manager.html#get_handlers/0"},{"type":"function","title":"Examples - Raxol.Core.Events.Manager.get_handlers/0","doc":"iex> EventManager.get_handlers()\n    %{click: [{MyModule, :handle_click}]}","ref":"Raxol.Core.Events.Manager.html#get_handlers/0-examples"},{"type":"function","title":"Raxol.Core.Events.Manager.init/0","doc":"Initialize the event manager.","ref":"Raxol.Core.Events.Manager.html#init/0"},{"type":"function","title":"Examples - Raxol.Core.Events.Manager.init/0","doc":"iex> EventManager.init()\n    :ok","ref":"Raxol.Core.Events.Manager.html#init/0-examples"},{"type":"function","title":"Raxol.Core.Events.Manager.register_handler/3","doc":"Register an event handler.","ref":"Raxol.Core.Events.Manager.html#register_handler/3"},{"type":"function","title":"Parameters - Raxol.Core.Events.Manager.register_handler/3","doc":"* `event_type` - The type of event to handle\n* `module` - The module containing the handler function\n* `function` - The function to call when the event occurs","ref":"Raxol.Core.Events.Manager.html#register_handler/3-parameters"},{"type":"function","title":"Examples - Raxol.Core.Events.Manager.register_handler/3","doc":"iex> EventManager.register_handler(:click, MyModule, :handle_click)\n    :ok","ref":"Raxol.Core.Events.Manager.html#register_handler/3-examples"},{"type":"function","title":"Raxol.Core.Events.Manager.subscribe/2","doc":"Subscribe to events with optional filters.","ref":"Raxol.Core.Events.Manager.html#subscribe/2"},{"type":"function","title":"Parameters - Raxol.Core.Events.Manager.subscribe/2","doc":"* `event_types` - List of event types to subscribe to\n* `opts` - Optional filters and options","ref":"Raxol.Core.Events.Manager.html#subscribe/2-parameters"},{"type":"function","title":"Examples - Raxol.Core.Events.Manager.subscribe/2","doc":"iex> EventManager.subscribe([:click, :key_press])\n    {:ok, ref}\n\n    iex> EventManager.subscribe([:mouse], button: :left)\n    {:ok, ref}","ref":"Raxol.Core.Events.Manager.html#subscribe/2-examples"},{"type":"function","title":"Raxol.Core.Events.Manager.unregister_handler/3","doc":"Unregister an event handler.","ref":"Raxol.Core.Events.Manager.html#unregister_handler/3"},{"type":"function","title":"Parameters - Raxol.Core.Events.Manager.unregister_handler/3","doc":"* `event_type` - The type of event\n* `module` - The module containing the handler function\n* `function` - The function that was registered","ref":"Raxol.Core.Events.Manager.html#unregister_handler/3-parameters"},{"type":"function","title":"Examples - Raxol.Core.Events.Manager.unregister_handler/3","doc":"iex> EventManager.unregister_handler(:click, MyModule, :handle_click)\n    :ok","ref":"Raxol.Core.Events.Manager.html#unregister_handler/3-examples"},{"type":"function","title":"Raxol.Core.Events.Manager.unsubscribe/1","doc":"Unsubscribe from events using the subscription reference.","ref":"Raxol.Core.Events.Manager.html#unsubscribe/1"},{"type":"function","title":"Examples - Raxol.Core.Events.Manager.unsubscribe/1","doc":"iex> EventManager.unsubscribe(ref)\n    :ok","ref":"Raxol.Core.Events.Manager.html#unsubscribe/1-examples"},{"type":"module","title":"Raxol.Core.Events.Subscription","doc":"Provides helpers for managing event subscriptions.\n\nThis module makes it easy to:\n* Subscribe to specific event types\n* Filter events based on criteria\n* Handle event cleanup\n* Manage multiple subscriptions","ref":"Raxol.Core.Events.Subscription.html"},{"type":"function","title":"Raxol.Core.Events.Subscription.events/1","doc":"Subscribes to a list of event types.","ref":"Raxol.Core.Events.Subscription.html#events/1"},{"type":"function","title":"Parameters - Raxol.Core.Events.Subscription.events/1","doc":"- `event_types` - A list of event type atoms (e.g., `[:key, :mouse, :window]`).\n                   Can also include tuples like `{:key, opts}` or `{:mouse, opts}`\n                   to pass specific options to the individual subscription functions.","ref":"Raxol.Core.Events.Subscription.html#events/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Events.Subscription.events/1","doc":"- `{:ok, list(subscription_ref())}` on success, containing a list of references for each subscription.\n- `{:error, reason}` if any subscription fails. Successfully created subscriptions before the failure will be automatically unsubscribed.","ref":"Raxol.Core.Events.Subscription.html#events/1-returns"},{"type":"function","title":"Raxol.Core.Events.Subscription.subscribe_custom/1","doc":"Subscribes to custom events with data matching.","ref":"Raxol.Core.Events.Subscription.html#subscribe_custom/1"},{"type":"function","title":"Options - Raxol.Core.Events.Subscription.subscribe_custom/1","doc":"* `:match` - Pattern to match against custom event data","ref":"Raxol.Core.Events.Subscription.html#subscribe_custom/1-options"},{"type":"function","title":"Example - Raxol.Core.Events.Subscription.subscribe_custom/1","doc":"subscribe_custom(match: {:user_action, _})","ref":"Raxol.Core.Events.Subscription.html#subscribe_custom/1-example"},{"type":"function","title":"Raxol.Core.Events.Subscription.subscribe_keyboard/1","doc":"Subscribes to keyboard events with optional key filters.","ref":"Raxol.Core.Events.Subscription.html#subscribe_keyboard/1"},{"type":"function","title":"Options - Raxol.Core.Events.Subscription.subscribe_keyboard/1","doc":"* `:keys` - List of specific keys to match\n* `:exclude_keys` - List of keys to ignore","ref":"Raxol.Core.Events.Subscription.html#subscribe_keyboard/1-options"},{"type":"function","title":"Example - Raxol.Core.Events.Subscription.subscribe_keyboard/1","doc":"subscribe_keyboard(keys: [:enter, :esc])\n    subscribe_keyboard(exclude_keys: [:tab])","ref":"Raxol.Core.Events.Subscription.html#subscribe_keyboard/1-example"},{"type":"function","title":"Raxol.Core.Events.Subscription.subscribe_mouse/1","doc":"Subscribes to mouse events with optional button and position filters.","ref":"Raxol.Core.Events.Subscription.html#subscribe_mouse/1"},{"type":"function","title":"Options - Raxol.Core.Events.Subscription.subscribe_mouse/1","doc":"* `:buttons` - List of mouse buttons to match\n* `:drag_only` - Only match drag events\n* `:click_only` - Only match click events\n* `:area` - Tuple of {x, y, width, height} to match position","ref":"Raxol.Core.Events.Subscription.html#subscribe_mouse/1-options"},{"type":"function","title":"Example - Raxol.Core.Events.Subscription.subscribe_mouse/1","doc":"subscribe_mouse(buttons: [:left, :right])\n    subscribe_mouse(area: {0, 0, 10, 10})","ref":"Raxol.Core.Events.Subscription.html#subscribe_mouse/1-example"},{"type":"function","title":"Raxol.Core.Events.Subscription.subscribe_timer/1","doc":"Subscribes to timer events with optional data matching.","ref":"Raxol.Core.Events.Subscription.html#subscribe_timer/1"},{"type":"function","title":"Options - Raxol.Core.Events.Subscription.subscribe_timer/1","doc":"* `:match` - Pattern to match against timer data","ref":"Raxol.Core.Events.Subscription.html#subscribe_timer/1-options"},{"type":"function","title":"Example - Raxol.Core.Events.Subscription.subscribe_timer/1","doc":"subscribe_timer(match: :tick)","ref":"Raxol.Core.Events.Subscription.html#subscribe_timer/1-example"},{"type":"function","title":"Raxol.Core.Events.Subscription.subscribe_window/1","doc":"Subscribes to window events with optional action filters.","ref":"Raxol.Core.Events.Subscription.html#subscribe_window/1"},{"type":"function","title":"Options - Raxol.Core.Events.Subscription.subscribe_window/1","doc":"* `:actions` - List of window actions to match (:resize, :focus, :blur)","ref":"Raxol.Core.Events.Subscription.html#subscribe_window/1-options"},{"type":"function","title":"Example - Raxol.Core.Events.Subscription.subscribe_window/1","doc":"subscribe_window(actions: [:resize])","ref":"Raxol.Core.Events.Subscription.html#subscribe_window/1-example"},{"type":"type","title":"Raxol.Core.Events.Subscription.subscription_opts/0","doc":"","ref":"Raxol.Core.Events.Subscription.html#t:subscription_opts/0"},{"type":"type","title":"Raxol.Core.Events.Subscription.subscription_ref/0","doc":"","ref":"Raxol.Core.Events.Subscription.html#t:subscription_ref/0"},{"type":"function","title":"Raxol.Core.Events.Subscription.unsubscribe/1","doc":"Unsubscribes from events using the subscription reference.","ref":"Raxol.Core.Events.Subscription.html#unsubscribe/1"},{"type":"function","title":"Raxol.Core.Events.Subscription.unsubscribe_all/1","doc":"Unsubscribes from multiple subscriptions.","ref":"Raxol.Core.Events.Subscription.html#unsubscribe_all/1"},{"type":"module","title":"Raxol.Core.Events.TermboxConverter","doc":"Converts rrex_termbox v2.0.1 NIF events to Raxol.Core.Events.Event structs.\n\nThis module handles the translation from the low-level rrex_termbox event format\nto the Raxol event system format.","ref":"Raxol.Core.Events.TermboxConverter.html"},{"type":"function","title":"Raxol.Core.Events.TermboxConverter.convert/1","doc":"Converts a rrex_termbox v2.0.1 event map to a Raxol Event struct.","ref":"Raxol.Core.Events.TermboxConverter.html#convert/1"},{"type":"function","title":"Parameters - Raxol.Core.Events.TermboxConverter.convert/1","doc":"- event_map: The event map from rrex_termbox","ref":"Raxol.Core.Events.TermboxConverter.html#convert/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Events.TermboxConverter.convert/1","doc":"- `{:ok, %Event{}}` if the conversion was successful\n- `:ignore` if the event should be ignored\n- `{:error, reason}` if the conversion failed","ref":"Raxol.Core.Events.TermboxConverter.html#convert/1-returns"},{"type":"module","title":"Raxol.Core.FocusManager","doc":"Focus management system for Raxol terminal UI applications.\n\nThis module provides utilities for managing focus between interactive components:\n- Tab-based keyboard navigation\n- Focus history tracking\n- Focus ring rendering\n- Screen reader announcements","ref":"Raxol.Core.FocusManager.html"},{"type":"module","title":"Usage - Raxol.Core.FocusManager","doc":"```elixir\n# Register focusable components in your view\nFocusManager.register_focusable(\"search_input\", 1)\nFocusManager.register_focusable(\"submit_button\", 2)\n\n# Initialize the focus manager with the first focusable element\nFocusManager.set_initial_focus(\"search_input\")\n```","ref":"Raxol.Core.FocusManager.html#module-usage"},{"type":"function","title":"Raxol.Core.FocusManager.disable_component/1","doc":"Disable a focusable component, preventing it from receiving focus.","ref":"Raxol.Core.FocusManager.html#disable_component/1"},{"type":"function","title":"Examples - Raxol.Core.FocusManager.disable_component/1","doc":"iex> FocusManager.disable_component(\"submit_button\")\n    :ok","ref":"Raxol.Core.FocusManager.html#disable_component/1-examples"},{"type":"function","title":"Raxol.Core.FocusManager.enable_component/1","doc":"Enable a previously disabled focusable component.","ref":"Raxol.Core.FocusManager.html#enable_component/1"},{"type":"function","title":"Examples - Raxol.Core.FocusManager.enable_component/1","doc":"iex> FocusManager.enable_component(\"submit_button\")\n    :ok","ref":"Raxol.Core.FocusManager.html#enable_component/1-examples"},{"type":"function","title":"Raxol.Core.FocusManager.focus_next/1","doc":"Move focus to the next focusable element.","ref":"Raxol.Core.FocusManager.html#focus_next/1"},{"type":"function","title":"Options - Raxol.Core.FocusManager.focus_next/1","doc":"* `:group` - Only navigate within this group (default: `nil` - use current group)\n* `:wrap` - Wrap around to first element when at the end (default: `true`)","ref":"Raxol.Core.FocusManager.html#focus_next/1-options"},{"type":"function","title":"Examples - Raxol.Core.FocusManager.focus_next/1","doc":"iex> FocusManager.focus_next()\n    :ok\n\n    iex> FocusManager.focus_next(group: :form_actions)\n    :ok","ref":"Raxol.Core.FocusManager.html#focus_next/1-examples"},{"type":"function","title":"Raxol.Core.FocusManager.focus_previous/1","doc":"Move focus to the previous focusable element.","ref":"Raxol.Core.FocusManager.html#focus_previous/1"},{"type":"function","title":"Options - Raxol.Core.FocusManager.focus_previous/1","doc":"* `:group` - Only navigate within this group (default: `nil` - use current group)\n* `:wrap` - Wrap around to last element when at the beginning (default: `true`)","ref":"Raxol.Core.FocusManager.html#focus_previous/1-options"},{"type":"function","title":"Examples - Raxol.Core.FocusManager.focus_previous/1","doc":"iex> FocusManager.focus_previous()\n    :ok","ref":"Raxol.Core.FocusManager.html#focus_previous/1-examples"},{"type":"function","title":"Raxol.Core.FocusManager.get_current_focus/0","doc":"Alias for get_focused_element/0.","ref":"Raxol.Core.FocusManager.html#get_current_focus/0"},{"type":"function","title":"Raxol.Core.FocusManager.get_focused_element/0","doc":"Get the ID of the currently focused element.","ref":"Raxol.Core.FocusManager.html#get_focused_element/0"},{"type":"function","title":"Examples - Raxol.Core.FocusManager.get_focused_element/0","doc":"iex> FocusManager.set_initial_focus(\"my_button\")\n    iex> FocusManager.get_focused_element()\n    \"my_button\"","ref":"Raxol.Core.FocusManager.html#get_focused_element/0-examples"},{"type":"function","title":"Raxol.Core.FocusManager.get_next_focusable/1","doc":"Get the next focusable element after the given one.\n(Placeholder implementation - mirrors focus_next logic)","ref":"Raxol.Core.FocusManager.html#get_next_focusable/1"},{"type":"function","title":"Raxol.Core.FocusManager.get_previous_focusable/1","doc":"Get the previous focusable element before the given one.\nMirrors the logic of `get_next_focusable/1` but searches backwards.","ref":"Raxol.Core.FocusManager.html#get_previous_focusable/1"},{"type":"function","title":"Raxol.Core.FocusManager.has_focus?/1","doc":"Check if a component has focus.","ref":"Raxol.Core.FocusManager.html#has_focus?/1"},{"type":"function","title":"Examples - Raxol.Core.FocusManager.has_focus?/1","doc":"iex> FocusManager.has_focus?(\"search_input\")\n    true","ref":"Raxol.Core.FocusManager.html#has_focus?/1-examples"},{"type":"function","title":"Raxol.Core.FocusManager.register_focus_change_handler/1","doc":"Register a handler function to be called when focus changes.\n\nThe handler function should accept two arguments: `old_focus` and `new_focus`.\n(Placeholder implementation)","ref":"Raxol.Core.FocusManager.html#register_focus_change_handler/1"},{"type":"function","title":"Raxol.Core.FocusManager.register_focusable/3","doc":"Register a focusable component with the focus manager.","ref":"Raxol.Core.FocusManager.html#register_focusable/3"},{"type":"function","title":"Parameters - Raxol.Core.FocusManager.register_focusable/3","doc":"* `component_id` - Unique identifier for the component\n* `tab_index` - Tab order index (lower numbers are focused first)\n* `opts` - Additional options","ref":"Raxol.Core.FocusManager.html#register_focusable/3-parameters"},{"type":"function","title":"Options - Raxol.Core.FocusManager.register_focusable/3","doc":"* `:group` - Focus group name for grouped navigation (default: `:default`)\n* `:disabled` - Whether the component is initially disabled (default: `false`)\n* `:announce` - Announcement text for screen readers when focused (default: `nil`)","ref":"Raxol.Core.FocusManager.html#register_focusable/3-options"},{"type":"function","title":"Examples - Raxol.Core.FocusManager.register_focusable/3","doc":"iex> FocusManager.register_focusable(\"search_input\", 1)\n    :ok\n\n    iex> FocusManager.register_focusable(\"submit_button\", 2, group: :form_actions)\n    :ok","ref":"Raxol.Core.FocusManager.html#register_focusable/3-examples"},{"type":"function","title":"Raxol.Core.FocusManager.return_to_previous/0","doc":"Return to the previously focused element.","ref":"Raxol.Core.FocusManager.html#return_to_previous/0"},{"type":"function","title":"Examples - Raxol.Core.FocusManager.return_to_previous/0","doc":"iex> FocusManager.return_to_previous()\n    :ok","ref":"Raxol.Core.FocusManager.html#return_to_previous/0-examples"},{"type":"function","title":"Raxol.Core.FocusManager.set_focus/1","doc":"Set focus to a specific component.","ref":"Raxol.Core.FocusManager.html#set_focus/1"},{"type":"function","title":"Examples - Raxol.Core.FocusManager.set_focus/1","doc":"iex> FocusManager.set_focus(\"submit_button\")\n    :ok","ref":"Raxol.Core.FocusManager.html#set_focus/1-examples"},{"type":"function","title":"Raxol.Core.FocusManager.set_initial_focus/1","doc":"Set the initial focus to a specific component.","ref":"Raxol.Core.FocusManager.html#set_initial_focus/1"},{"type":"function","title":"Examples - Raxol.Core.FocusManager.set_initial_focus/1","doc":"iex> FocusManager.set_initial_focus(\"search_input\")\n    :ok","ref":"Raxol.Core.FocusManager.html#set_initial_focus/1-examples"},{"type":"function","title":"Raxol.Core.FocusManager.unregister_focus_change_handler/1","doc":"Unregister a focus change handler function.\n(Placeholder implementation)","ref":"Raxol.Core.FocusManager.html#unregister_focus_change_handler/1"},{"type":"function","title":"Raxol.Core.FocusManager.unregister_focusable/1","doc":"Unregister a focusable component.","ref":"Raxol.Core.FocusManager.html#unregister_focusable/1"},{"type":"function","title":"Examples - Raxol.Core.FocusManager.unregister_focusable/1","doc":"iex> FocusManager.unregister_focusable(\"search_input\")\n    :ok","ref":"Raxol.Core.FocusManager.html#unregister_focusable/1-examples"},{"type":"module","title":"Raxol.Core.I18n","doc":"Internationalization framework for Raxol terminal UI applications.\n\nThis module provides comprehensive internationalization (i18n) support:\n- Translation of UI text to multiple languages\n- Right-to-left (RTL) language support\n- Integration with accessibility features\n- Language detection and selection\n- Translation fallbacks\n- Dynamic language switching\n\nThe framework works seamlessly with the accessibility module to provide\nscreen reader announcements in the user's preferred language.","ref":"Raxol.Core.I18n.html"},{"type":"module","title":"Usage - Raxol.Core.I18n","doc":"```elixir\n# Initialize with default locale\nI18n.init(default_locale: \"en\")\n\n# Get a translated string\nmessage = I18n.t(\"welcome_message\")\n\n# Get a translated string with variables\ngreeting = I18n.t(\"hello_name\", %{name: \"John\"})\n\n# Switch to a different locale\nI18n.set_locale(\"fr\")\n\n# Check if the current locale is RTL\nis_rtl = I18n.rtl?()\n```","ref":"Raxol.Core.I18n.html#module-usage"},{"type":"function","title":"Raxol.Core.I18n.announce/3","doc":"Format a screen reader announcement in the current locale.\n\nThis integrates with the accessibility module to provide\nscreen reader announcements in the user's preferred language.","ref":"Raxol.Core.I18n.html#announce/3"},{"type":"function","title":"Parameters - Raxol.Core.I18n.announce/3","doc":"* `key` - The translation key for the announcement\n* `bindings` - Map of variable bindings (default: %{})\n* `opts` - Additional options","ref":"Raxol.Core.I18n.html#announce/3-parameters"},{"type":"function","title":"Examples - Raxol.Core.I18n.announce/3","doc":"iex> I18n.announce(\"file_saved\")\n    :ok\n\n    iex> I18n.announce(\"item_selected\", %{item: \"Document\"})\n    :ok","ref":"Raxol.Core.I18n.html#announce/3-examples"},{"type":"function","title":"Raxol.Core.I18n.available_locales/0","doc":"Get a list of available locales.","ref":"Raxol.Core.I18n.html#available_locales/0"},{"type":"function","title":"Examples - Raxol.Core.I18n.available_locales/0","doc":"iex> I18n.available_locales()\n    [\"en\", \"fr\", \"es\"]","ref":"Raxol.Core.I18n.html#available_locales/0-examples"},{"type":"function","title":"Raxol.Core.I18n.get_locale/0","doc":"Get the current locale.","ref":"Raxol.Core.I18n.html#get_locale/0"},{"type":"function","title":"Examples - Raxol.Core.I18n.get_locale/0","doc":"iex> I18n.get_locale()\n    \"en\"","ref":"Raxol.Core.I18n.html#get_locale/0-examples"},{"type":"function","title":"Raxol.Core.I18n.handle_locale_changed/1","doc":"Handle locale changed events.","ref":"Raxol.Core.I18n.html#handle_locale_changed/1"},{"type":"function","title":"Raxol.Core.I18n.init/1","doc":"Initialize the internationalization system.","ref":"Raxol.Core.I18n.html#init/1"},{"type":"function","title":"Options - Raxol.Core.I18n.init/1","doc":"* `:default_locale` - The default locale to use (default: \"en\")\n* `:available_locales` - List of available locales (default: [\"en\"])\n* `:fallback_locale` - Fallback locale when translation is missing (default: \"en\")\n* `:translations_dir` - Directory containing translation files (default: \"./priv/locales\")","ref":"Raxol.Core.I18n.html#init/1-options"},{"type":"function","title":"Examples - Raxol.Core.I18n.init/1","doc":"iex> I18n.init()\n    :ok\n\n    iex> I18n.init(default_locale: \"fr\", available_locales: [\"en\", \"fr\", \"es\"])\n    :ok","ref":"Raxol.Core.I18n.html#init/1-examples"},{"type":"function","title":"Raxol.Core.I18n.register_translations/2","doc":"Register translations for a specific locale.","ref":"Raxol.Core.I18n.html#register_translations/2"},{"type":"function","title":"Parameters - Raxol.Core.I18n.register_translations/2","doc":"* `locale` - The locale for these translations\n* `translations` - Map of translation keys to translated strings","ref":"Raxol.Core.I18n.html#register_translations/2-parameters"},{"type":"function","title":"Examples - Raxol.Core.I18n.register_translations/2","doc":"iex> I18n.register_translations(\"fr\", %{\n    ...>   \"welcome_message\" => \"Bienvenue dans l'application\",\n    ...>   \"hello_name\" => \"Bonjour, {{name}}!\"\n    ...> })\n    :ok","ref":"Raxol.Core.I18n.html#register_translations/2-examples"},{"type":"function","title":"Raxol.Core.I18n.rtl?/1","doc":"Check if the current locale is right-to-left (RTL).","ref":"Raxol.Core.I18n.html#rtl?/1"},{"type":"function","title":"Options - Raxol.Core.I18n.rtl?/1","doc":"* `:locale` - Check a specific locale instead of the current one","ref":"Raxol.Core.I18n.html#rtl?/1-options"},{"type":"function","title":"Examples - Raxol.Core.I18n.rtl?/1","doc":"iex> I18n.rtl?()\n    false\n\n    iex> I18n.rtl?(locale: \"ar\")\n    true","ref":"Raxol.Core.I18n.html#rtl?/1-examples"},{"type":"function","title":"Raxol.Core.I18n.set_locale/1","doc":"Set the current locale.","ref":"Raxol.Core.I18n.html#set_locale/1"},{"type":"function","title":"Parameters - Raxol.Core.I18n.set_locale/1","doc":"* `locale` - The locale to set as current","ref":"Raxol.Core.I18n.html#set_locale/1-parameters"},{"type":"function","title":"Examples - Raxol.Core.I18n.set_locale/1","doc":"iex> I18n.set_locale(\"fr\")\n    :ok\n\n    iex> I18n.set_locale(\"invalid\")\n    {:error, :invalid_locale}","ref":"Raxol.Core.I18n.html#set_locale/1-examples"},{"type":"function","title":"Raxol.Core.I18n.t/3","doc":"Get a translated string for the current locale.","ref":"Raxol.Core.I18n.html#t/3"},{"type":"function","title":"Parameters - Raxol.Core.I18n.t/3","doc":"* `key` - The translation key\n* `bindings` - Map of variable bindings (default: %{})\n* `opts` - Additional options","ref":"Raxol.Core.I18n.html#t/3-parameters"},{"type":"function","title":"Options - Raxol.Core.I18n.t/3","doc":"* `:locale` - Override the current locale\n* `:default` - Default text if translation is missing","ref":"Raxol.Core.I18n.html#t/3-options"},{"type":"function","title":"Examples - Raxol.Core.I18n.t/3","doc":"iex> I18n.t(\"welcome_message\")\n    \"Welcome to the application\"\n\n    iex> I18n.t(\"hello_name\", %{name: \"John\"})\n    \"Hello, John!\"\n\n    iex> I18n.t(\"missing_key\", %{}, default: \"Missing translation\")\n    \"Missing translation\"","ref":"Raxol.Core.I18n.html#t/3-examples"},{"type":"module","title":"Raxol.Core.ID","doc":"Provides functions for generating unique identifiers.","ref":"Raxol.Core.ID.html"},{"type":"function","title":"Raxol.Core.ID.generate/0","doc":"Generates a unique string identifier.\n\nUses Erlang's `make_ref` and converts it to a string representation.\nWhile unique within the runtime, refs are not guaranteed universally unique\nlike UUIDs.","ref":"Raxol.Core.ID.html#generate/0"},{"type":"module","title":"Raxol.Core.KeyboardNavigator","doc":"Keyboard navigation handler for Raxol terminal UI applications.\n\nThis module integrates with the FocusManager to provide keyboard navigation between\ninteractive components using standard key bindings:\n\n- Tab: Move to next focusable element\n- Shift+Tab: Move to previous focusable element\n- Arrow keys: Navigate between elements in a component group\n- Escape: Return to previous focus or dismiss dialogs\n- Enter/Space: Activate currently focused element","ref":"Raxol.Core.KeyboardNavigator.html"},{"type":"module","title":"Usage - Raxol.Core.KeyboardNavigator","doc":"```elixir\n# Initialize keyboard navigation in your application\nKeyboardNavigator.init()\n\n# Customize keybindings\nKeyboardNavigator.configure(next_key: :right, previous_key: :left)\n```","ref":"Raxol.Core.KeyboardNavigator.html#module-usage"},{"type":"function","title":"Raxol.Core.KeyboardNavigator.configure/1","doc":"Configure keyboard navigation behavior.","ref":"Raxol.Core.KeyboardNavigator.html#configure/1"},{"type":"function","title":"Options - Raxol.Core.KeyboardNavigator.configure/1","doc":"* `:next_key` - Key to move to next element (default: `:tab`)\n* `:previous_key` - Key to move to previous element (default: `:tab` with shift)\n* `:activate_keys` - Keys to activate elements (default: `[:enter, :space]`)\n* `:dismiss_key` - Key to dismiss or go back (default: `:escape`)\n* `:arrow_navigation` - Enable arrow key navigation (default: `true`)\n* `:vim_keys` - Enable vim-style navigation with h,j,k,l (default: `false`)\n* `:group_navigation` - Enable group-based navigation (default: `true`)\n* `:spatial_navigation` - Enable spatial navigation for grid layouts (default: `false`)\n* `:tab_navigation` - Enable tab-based navigation (default: `true`)","ref":"Raxol.Core.KeyboardNavigator.html#configure/1-options"},{"type":"function","title":"Examples - Raxol.Core.KeyboardNavigator.configure/1","doc":"iex> KeyboardNavigator.configure(vim_keys: true)\n    :ok","ref":"Raxol.Core.KeyboardNavigator.html#configure/1-examples"},{"type":"function","title":"Raxol.Core.KeyboardNavigator.define_navigation_path/3","doc":"Define explicit navigation paths between components.\n\nThis allows customizing navigation beyond spatial or tab order.","ref":"Raxol.Core.KeyboardNavigator.html#define_navigation_path/3"},{"type":"function","title":"Parameters - Raxol.Core.KeyboardNavigator.define_navigation_path/3","doc":"* `from_id` - Component ID to navigate from\n* `direction` - Navigation direction (`:up`, `:down`, `:left`, `:right`)\n* `to_id` - Component ID to navigate to","ref":"Raxol.Core.KeyboardNavigator.html#define_navigation_path/3-parameters"},{"type":"function","title":"Examples - Raxol.Core.KeyboardNavigator.define_navigation_path/3","doc":"iex> KeyboardNavigator.define_navigation_path(\"search_input\", :down, \"submit_button\")\n    :ok","ref":"Raxol.Core.KeyboardNavigator.html#define_navigation_path/3-examples"},{"type":"function","title":"Raxol.Core.KeyboardNavigator.handle_keyboard_event/1","doc":"Handle keyboard events for navigation.\n\nThis function is called by the EventManager when keyboard events occur.","ref":"Raxol.Core.KeyboardNavigator.html#handle_keyboard_event/1"},{"type":"function","title":"Parameters - Raxol.Core.KeyboardNavigator.handle_keyboard_event/1","doc":"* `event` - The keyboard event to handle","ref":"Raxol.Core.KeyboardNavigator.html#handle_keyboard_event/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.KeyboardNavigator.handle_keyboard_event/1","doc":"* `:handled` - If the event was handled by the navigator\n* `:unhandled` - If the event was not handled","ref":"Raxol.Core.KeyboardNavigator.html#handle_keyboard_event/1-returns"},{"type":"function","title":"Raxol.Core.KeyboardNavigator.init/0","doc":"Initialize the keyboard navigator.\n\nThis registers event handlers for keyboard navigation.","ref":"Raxol.Core.KeyboardNavigator.html#init/0"},{"type":"function","title":"Examples - Raxol.Core.KeyboardNavigator.init/0","doc":"iex> KeyboardNavigator.init()\n    :ok","ref":"Raxol.Core.KeyboardNavigator.html#init/0-examples"},{"type":"function","title":"Raxol.Core.KeyboardNavigator.register_component_position/5","doc":"Register component positions for spatial navigation.\n\nThis allows arrow keys to navigate components based on their physical layout.","ref":"Raxol.Core.KeyboardNavigator.html#register_component_position/5"},{"type":"function","title":"Parameters - Raxol.Core.KeyboardNavigator.register_component_position/5","doc":"* `component_id` - Unique identifier for the component\n* `x` - X coordinate\n* `y` - Y coordinate\n* `width` - Width of the component\n* `height` - Height of the component","ref":"Raxol.Core.KeyboardNavigator.html#register_component_position/5-parameters"},{"type":"function","title":"Examples - Raxol.Core.KeyboardNavigator.register_component_position/5","doc":"iex> KeyboardNavigator.register_component_position(\"search_input\", 10, 5, 30, 3)\n    :ok","ref":"Raxol.Core.KeyboardNavigator.html#register_component_position/5-examples"},{"type":"function","title":"Raxol.Core.KeyboardNavigator.register_shortcut/3","doc":"Register a custom shortcut handler.","ref":"Raxol.Core.KeyboardNavigator.html#register_shortcut/3"},{"type":"function","title":"Parameters - Raxol.Core.KeyboardNavigator.register_shortcut/3","doc":"* `key` - The key to handle\n* `modifiers` - List of modifier keys (e.g., [:ctrl, :shift])\n* `handler` - Function to call when shortcut is pressed","ref":"Raxol.Core.KeyboardNavigator.html#register_shortcut/3-parameters"},{"type":"function","title":"Examples - Raxol.Core.KeyboardNavigator.register_shortcut/3","doc":"iex> KeyboardNavigator.register_shortcut(:f1, [], &show_help/0)\n    :ok","ref":"Raxol.Core.KeyboardNavigator.html#register_shortcut/3-examples"},{"type":"module","title":"Raxol.Core.KeyboardShortcuts","doc":"Keyboard shortcuts manager for Raxol applications.\n\nThis module provides functionality to register, manage, and handle keyboard shortcuts\nthroughout the application. It integrates with the accessibility features to provide\nbetter keyboard navigation and interaction.","ref":"Raxol.Core.KeyboardShortcuts.html"},{"type":"module","title":"Features - Raxol.Core.KeyboardShortcuts","doc":"* Register global and context-specific shortcuts\n* Handle keyboard shortcuts with custom callbacks\n* Display available shortcuts based on current context\n* Integration with accessibility features\n* Support for shortcut combinations (Ctrl, Alt, Shift modifiers)","ref":"Raxol.Core.KeyboardShortcuts.html#module-features"},{"type":"module","title":"Examples - Raxol.Core.KeyboardShortcuts","doc":"# Initialize the keyboard shortcuts manager\n    KeyboardShortcuts.init()\n\n    # Register a global shortcut\n    KeyboardShortcuts.register_shortcut(\"Ctrl+F\", :search, fn ->\n      # Search functionality\n      search_content()\n    end)\n\n    # Register a context-specific shortcut\n    KeyboardShortcuts.register_shortcut(\"Alt+S\", :save, fn ->\n      # Save functionality\n      save_document()\n    end, context: :editor)\n\n    # Get all available shortcuts for current context\n    shortcuts = KeyboardShortcuts.get_shortcuts_for_context(:editor)\n\n    # Display help for available shortcuts\n    KeyboardShortcuts.show_shortcuts_help()","ref":"Raxol.Core.KeyboardShortcuts.html#module-examples"},{"type":"function","title":"Raxol.Core.KeyboardShortcuts.cleanup/0","doc":"Clean up the keyboard shortcuts manager.\n\nThis function cleans up any resources used by the keyboard shortcuts manager\nand unregisters event handlers.","ref":"Raxol.Core.KeyboardShortcuts.html#cleanup/0"},{"type":"function","title":"Examples - Raxol.Core.KeyboardShortcuts.cleanup/0","doc":"iex> KeyboardShortcuts.cleanup()\n    :ok","ref":"Raxol.Core.KeyboardShortcuts.html#cleanup/0-examples"},{"type":"function","title":"Raxol.Core.KeyboardShortcuts.get_current_context/0","doc":"Get the current active context for shortcuts.","ref":"Raxol.Core.KeyboardShortcuts.html#get_current_context/0"},{"type":"function","title":"Examples - Raxol.Core.KeyboardShortcuts.get_current_context/0","doc":"iex> KeyboardShortcuts.get_current_context()\n    :editor","ref":"Raxol.Core.KeyboardShortcuts.html#get_current_context/0-examples"},{"type":"function","title":"Raxol.Core.KeyboardShortcuts.get_shortcuts_for_context/1","doc":"Get all shortcuts for a specific context.","ref":"Raxol.Core.KeyboardShortcuts.html#get_shortcuts_for_context/1"},{"type":"function","title":"Parameters - Raxol.Core.KeyboardShortcuts.get_shortcuts_for_context/1","doc":"* `context` - The context to get shortcuts for (default: current context)","ref":"Raxol.Core.KeyboardShortcuts.html#get_shortcuts_for_context/1-parameters"},{"type":"function","title":"Examples - Raxol.Core.KeyboardShortcuts.get_shortcuts_for_context/1","doc":"iex> KeyboardShortcuts.get_shortcuts_for_context(:editor)\n    [\n      %{name: :save, key_combo: \"Ctrl+S\", description: \"Save document\"},\n      %{name: :find, key_combo: \"Ctrl+F\", description: \"Find in document\"}\n    ]","ref":"Raxol.Core.KeyboardShortcuts.html#get_shortcuts_for_context/1-examples"},{"type":"function","title":"Raxol.Core.KeyboardShortcuts.handle_keyboard_event/1","doc":"","ref":"Raxol.Core.KeyboardShortcuts.html#handle_keyboard_event/1"},{"type":"function","title":"Raxol.Core.KeyboardShortcuts.init/0","doc":"Initialize the keyboard shortcuts manager.\n\nThis function sets up the necessary state for managing keyboard shortcuts\nand registers event handlers for keyboard events.","ref":"Raxol.Core.KeyboardShortcuts.html#init/0"},{"type":"function","title":"Examples - Raxol.Core.KeyboardShortcuts.init/0","doc":"iex> KeyboardShortcuts.init()\n    :ok","ref":"Raxol.Core.KeyboardShortcuts.html#init/0-examples"},{"type":"function","title":"Raxol.Core.KeyboardShortcuts.register_shortcut/4","doc":"Register a keyboard shortcut with a callback function.","ref":"Raxol.Core.KeyboardShortcuts.html#register_shortcut/4"},{"type":"function","title":"Parameters - Raxol.Core.KeyboardShortcuts.register_shortcut/4","doc":"* `shortcut` - The keyboard shortcut string (e.g., \"Ctrl+S\", \"Alt+F4\")\n* `name` - A unique identifier for the shortcut (atom or string)\n* `callback` - A function to be called when the shortcut is triggered\n* `opts` - Options for the shortcut","ref":"Raxol.Core.KeyboardShortcuts.html#register_shortcut/4-parameters"},{"type":"function","title":"Options - Raxol.Core.KeyboardShortcuts.register_shortcut/4","doc":"* `:context` - The context in which this shortcut is active (default: `:global`)\n* `:description` - A description of what the shortcut does\n* `:priority` - Priority level (`:high`, `:medium`, `:low`), affects precedence","ref":"Raxol.Core.KeyboardShortcuts.html#register_shortcut/4-options"},{"type":"function","title":"Examples - Raxol.Core.KeyboardShortcuts.register_shortcut/4","doc":"iex> KeyboardShortcuts.register_shortcut(\"Ctrl+S\", :save, fn -> save_document() end)\n    :ok\n\n    iex> KeyboardShortcuts.register_shortcut(\"Alt+F\", :file_menu, fn -> open_file_menu() end,\n    ...>   context: :main_menu, description: \"Open File menu\")\n    :ok","ref":"Raxol.Core.KeyboardShortcuts.html#register_shortcut/4-examples"},{"type":"function","title":"Raxol.Core.KeyboardShortcuts.set_context/1","doc":"Set the current context for shortcuts.\n\nThis affects which shortcuts are active and will be triggered by keyboard events.","ref":"Raxol.Core.KeyboardShortcuts.html#set_context/1"},{"type":"function","title":"Parameters - Raxol.Core.KeyboardShortcuts.set_context/1","doc":"* `context` - The context to set as active","ref":"Raxol.Core.KeyboardShortcuts.html#set_context/1-parameters"},{"type":"function","title":"Examples - Raxol.Core.KeyboardShortcuts.set_context/1","doc":"iex> KeyboardShortcuts.set_context(:editor)\n    :ok\n\n    iex> KeyboardShortcuts.set_context(:file_browser)\n    :ok","ref":"Raxol.Core.KeyboardShortcuts.html#set_context/1-examples"},{"type":"function","title":"Raxol.Core.KeyboardShortcuts.show_shortcuts_help/0","doc":"Display help for available shortcuts.\n\nThis function generates a help message for all shortcuts available in the current context\nand announces it through the accessibility system if enabled.","ref":"Raxol.Core.KeyboardShortcuts.html#show_shortcuts_help/0"},{"type":"function","title":"Examples - Raxol.Core.KeyboardShortcuts.show_shortcuts_help/0","doc":"iex> KeyboardShortcuts.show_shortcuts_help()\n    :ok","ref":"Raxol.Core.KeyboardShortcuts.html#show_shortcuts_help/0-examples"},{"type":"function","title":"Raxol.Core.KeyboardShortcuts.trigger_shortcut/2","doc":"Trigger a shortcut programmatically.","ref":"Raxol.Core.KeyboardShortcuts.html#trigger_shortcut/2"},{"type":"function","title":"Parameters - Raxol.Core.KeyboardShortcuts.trigger_shortcut/2","doc":"* `name` - The unique identifier for the shortcut\n* `context` - The context in which the shortcut was registered (default: current context)","ref":"Raxol.Core.KeyboardShortcuts.html#trigger_shortcut/2-parameters"},{"type":"function","title":"Examples - Raxol.Core.KeyboardShortcuts.trigger_shortcut/2","doc":"iex> KeyboardShortcuts.trigger_shortcut(:save)\n    :ok\n\n    iex> KeyboardShortcuts.trigger_shortcut(:file_menu, :main_menu)\n    :ok","ref":"Raxol.Core.KeyboardShortcuts.html#trigger_shortcut/2-examples"},{"type":"function","title":"Raxol.Core.KeyboardShortcuts.unregister_shortcut/2","doc":"Unregister a keyboard shortcut.","ref":"Raxol.Core.KeyboardShortcuts.html#unregister_shortcut/2"},{"type":"function","title":"Parameters - Raxol.Core.KeyboardShortcuts.unregister_shortcut/2","doc":"* `name` - The unique identifier for the shortcut\n* `context` - The context in which the shortcut was registered (default: `:global`)","ref":"Raxol.Core.KeyboardShortcuts.html#unregister_shortcut/2-parameters"},{"type":"function","title":"Examples - Raxol.Core.KeyboardShortcuts.unregister_shortcut/2","doc":"iex> KeyboardShortcuts.unregister_shortcut(:save)\n    :ok\n\n    iex> KeyboardShortcuts.unregister_shortcut(:file_menu, :main_menu)\n    :ok","ref":"Raxol.Core.KeyboardShortcuts.html#unregister_shortcut/2-examples"},{"type":"module","title":"Raxol.Core.Performance.AIAnalyzer","doc":"Handles AI-based analysis of performance metrics and generates optimization recommendations.\nThis module integrates with an AI agent to provide deep insights and actionable suggestions.","ref":"Raxol.Core.Performance.AIAnalyzer.html"},{"type":"function","title":"Raxol.Core.Performance.AIAnalyzer.analyze/2","doc":"Analyzes performance metrics using AI and returns detailed insights and recommendations.","ref":"Raxol.Core.Performance.AIAnalyzer.html#analyze/2"},{"type":"function","title":"Parameters - Raxol.Core.Performance.AIAnalyzer.analyze/2","doc":"- metrics: Map containing performance metrics from the monitor\n  - options: Map of analysis options\n    - :depth (atom) - Analysis depth (:basic, :detailed, :comprehensive)\n    - :focus (list) - Areas to focus on ([:fps, :memory, :jank, :gc])\n    - :historical_data (list) - Optional historical metrics for trend analysis","ref":"Raxol.Core.Performance.AIAnalyzer.html#analyze/2-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.AIAnalyzer.analyze/2","doc":"- Map containing:\n    - :insights - Detailed performance insights\n    - :recommendations - Prioritized optimization suggestions\n    - :risk_assessment - Performance risk analysis\n    - :optimization_impact - Expected impact of suggested optimizations\n    - :ai_confidence - AI's confidence in the analysis","ref":"Raxol.Core.Performance.AIAnalyzer.html#analyze/2-returns"},{"type":"function","title":"Raxol.Core.Performance.AIAnalyzer.generate_report/2","doc":"Generates a performance report with AI insights and recommendations.","ref":"Raxol.Core.Performance.AIAnalyzer.html#generate_report/2"},{"type":"function","title":"Parameters - Raxol.Core.Performance.AIAnalyzer.generate_report/2","doc":"- metrics: Map containing performance metrics\n  - options: Map of report options\n    - :format (atom) - Report format (:text, :json, :html)\n    - :include_graphs (boolean) - Whether to include performance graphs\n    - :include_code_samples (boolean) - Whether to include code optimization examples","ref":"Raxol.Core.Performance.AIAnalyzer.html#generate_report/2-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.AIAnalyzer.generate_report/2","doc":"- Map containing the formatted report and additional data","ref":"Raxol.Core.Performance.AIAnalyzer.html#generate_report/2-returns"},{"type":"module","title":"Raxol.Core.Performance.Analyzer","doc":"Analyzes performance metrics and generates insights for AI analysis.\n\nThis module:\n- Processes performance metrics\n- Identifies performance patterns\n- Generates optimization suggestions\n- Formats data for AI analysis","ref":"Raxol.Core.Performance.Analyzer.html"},{"type":"module","title":"Usage - Raxol.Core.Performance.Analyzer","doc":"```elixir\n# Get metrics from monitor\nmetrics = Monitor.get_metrics(monitor)\n\n# Analyze metrics\nanalysis = Analyzer.analyze(metrics)\n\n# Get AI-ready data\nai_data = Analyzer.prepare_ai_data(analysis)\n```","ref":"Raxol.Core.Performance.Analyzer.html#module-usage"},{"type":"function","title":"Raxol.Core.Performance.Analyzer.analyze/1","doc":"Analyzes performance metrics and generates insights.","ref":"Raxol.Core.Performance.Analyzer.html#analyze/1"},{"type":"function","title":"Parameters - Raxol.Core.Performance.Analyzer.analyze/1","doc":"* `metrics` - Map of performance metrics from Monitor","ref":"Raxol.Core.Performance.Analyzer.html#analyze/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.Analyzer.analyze/1","doc":"Map containing analysis results:\n* `:performance_score` - Overall performance score (0-100)\n* `:issues` - List of identified performance issues\n* `:suggestions` - List of optimization suggestions\n* `:patterns` - Identified performance patterns\n* `:trends` - Performance trends over time","ref":"Raxol.Core.Performance.Analyzer.html#analyze/1-returns"},{"type":"function","title":"Examples - Raxol.Core.Performance.Analyzer.analyze/1","doc":"iex> metrics = %{\n      fps: 60,\n      avg_frame_time: 16.5,\n      jank_count: 2,\n      memory_usage: 1234567,\n      gc_stats: %{...}\n    }\n    iex> Analyzer.analyze(metrics)\n    %{\n      performance_score: 85,\n      issues: [\"High memory usage\", \"Occasional jank\"],\n      suggestions: [\"Optimize memory allocation\", \"Profile render loop\"],\n      patterns: %{...},\n      trends: %{...}\n    }","ref":"Raxol.Core.Performance.Analyzer.html#analyze/1-examples"},{"type":"function","title":"Raxol.Core.Performance.Analyzer.prepare_ai_data/1","doc":"Prepares performance data for AI analysis.","ref":"Raxol.Core.Performance.Analyzer.html#prepare_ai_data/1"},{"type":"function","title":"Parameters - Raxol.Core.Performance.Analyzer.prepare_ai_data/1","doc":"* `analysis` - Analysis results from analyze/1","ref":"Raxol.Core.Performance.Analyzer.html#prepare_ai_data/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.Analyzer.prepare_ai_data/1","doc":"Map containing AI-ready data:\n* `:metrics` - Raw performance metrics\n* `:analysis` - Analysis results\n* `:context` - Additional context for AI\n* `:format` - Data format specification","ref":"Raxol.Core.Performance.Analyzer.html#prepare_ai_data/1-returns"},{"type":"function","title":"Examples - Raxol.Core.Performance.Analyzer.prepare_ai_data/1","doc":"iex> metrics = %{fps: 60, ...}\n    iex> analysis = Analyzer.analyze(metrics)\n    iex> ai_data = Analyzer.prepare_ai_data(analysis)\n    iex> Map.has_key?(ai_data, :metrics)\n    true","ref":"Raxol.Core.Performance.Analyzer.html#prepare_ai_data/1-examples"},{"type":"module","title":"Raxol.Core.Performance.JankDetector","doc":"Detects UI jank by analyzing frame timing.\n\nA frame is considered janky if it takes longer than the jank threshold\nto render. The detector maintains a rolling window of frame times to\nidentify patterns of jank.","ref":"Raxol.Core.Performance.JankDetector.html"},{"type":"module","title":"Usage - Raxol.Core.Performance.JankDetector","doc":"```elixir\n# Create a new detector\ndetector = JankDetector.new(16, 60)  # 16ms threshold, 60 frame window\n\n# Record a frame\ndetector = JankDetector.record_frame(detector, 20)\n\n# Check for jank\nif JankDetector.detect_jank?(detector) do\n  Logger.warning(\"Jank detected\")\nend\n```","ref":"Raxol.Core.Performance.JankDetector.html#module-usage"},{"type":"function","title":"Raxol.Core.Performance.JankDetector.detect_jank?/1","doc":"Checks if jank was detected in the last frame.","ref":"Raxol.Core.Performance.JankDetector.html#detect_jank?/1"},{"type":"function","title":"Parameters - Raxol.Core.Performance.JankDetector.detect_jank?/1","doc":"* `detector` - The jank detector","ref":"Raxol.Core.Performance.JankDetector.html#detect_jank?/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.JankDetector.detect_jank?/1","doc":"* `true` if the last frame was janky\n* `false` otherwise","ref":"Raxol.Core.Performance.JankDetector.html#detect_jank?/1-returns"},{"type":"function","title":"Examples - Raxol.Core.Performance.JankDetector.detect_jank?/1","doc":"iex> detector = JankDetector.new(16, 60)\n    iex> detector = JankDetector.record_frame(detector, 20)\n    iex> JankDetector.detect_jank?(detector)\n    true","ref":"Raxol.Core.Performance.JankDetector.html#detect_jank?/1-examples"},{"type":"function","title":"Raxol.Core.Performance.JankDetector.get_avg_frame_time/1","doc":"Gets the average frame time in the current window.","ref":"Raxol.Core.Performance.JankDetector.html#get_avg_frame_time/1"},{"type":"function","title":"Parameters - Raxol.Core.Performance.JankDetector.get_avg_frame_time/1","doc":"* `detector` - The jank detector","ref":"Raxol.Core.Performance.JankDetector.html#get_avg_frame_time/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.JankDetector.get_avg_frame_time/1","doc":"Average frame time in milliseconds.","ref":"Raxol.Core.Performance.JankDetector.html#get_avg_frame_time/1-returns"},{"type":"function","title":"Examples - Raxol.Core.Performance.JankDetector.get_avg_frame_time/1","doc":"iex> detector = JankDetector.new(16, 60)\n    iex> detector = JankDetector.record_frame(detector, 20)\n    iex> JankDetector.get_avg_frame_time(detector)\n    20.0","ref":"Raxol.Core.Performance.JankDetector.html#get_avg_frame_time/1-examples"},{"type":"function","title":"Raxol.Core.Performance.JankDetector.get_jank_count/1","doc":"Gets the number of janky frames in the current window.","ref":"Raxol.Core.Performance.JankDetector.html#get_jank_count/1"},{"type":"function","title":"Parameters - Raxol.Core.Performance.JankDetector.get_jank_count/1","doc":"* `detector` - The jank detector","ref":"Raxol.Core.Performance.JankDetector.html#get_jank_count/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.JankDetector.get_jank_count/1","doc":"Number of janky frames.","ref":"Raxol.Core.Performance.JankDetector.html#get_jank_count/1-returns"},{"type":"function","title":"Examples - Raxol.Core.Performance.JankDetector.get_jank_count/1","doc":"iex> detector = JankDetector.new(16, 60)\n    iex> detector = JankDetector.record_frame(detector, 20)\n    iex> JankDetector.get_jank_count(detector)\n    1","ref":"Raxol.Core.Performance.JankDetector.html#get_jank_count/1-examples"},{"type":"function","title":"Raxol.Core.Performance.JankDetector.get_max_frame_time/1","doc":"Gets the maximum frame time in the current window.","ref":"Raxol.Core.Performance.JankDetector.html#get_max_frame_time/1"},{"type":"function","title":"Parameters - Raxol.Core.Performance.JankDetector.get_max_frame_time/1","doc":"* `detector` - The jank detector","ref":"Raxol.Core.Performance.JankDetector.html#get_max_frame_time/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.JankDetector.get_max_frame_time/1","doc":"Maximum frame time in milliseconds.","ref":"Raxol.Core.Performance.JankDetector.html#get_max_frame_time/1-returns"},{"type":"function","title":"Examples - Raxol.Core.Performance.JankDetector.get_max_frame_time/1","doc":"iex> detector = JankDetector.new(16, 60)\n    iex> detector = JankDetector.record_frame(detector, 20)\n    iex> JankDetector.get_max_frame_time(detector)\n    20","ref":"Raxol.Core.Performance.JankDetector.html#get_max_frame_time/1-examples"},{"type":"function","title":"Raxol.Core.Performance.JankDetector.new/2","doc":"Creates a new jank detector.","ref":"Raxol.Core.Performance.JankDetector.html#new/2"},{"type":"function","title":"Parameters - Raxol.Core.Performance.JankDetector.new/2","doc":"* `threshold` - Time in milliseconds above which a frame is considered janky\n* `window_size` - Number of frames to keep in the rolling window","ref":"Raxol.Core.Performance.JankDetector.html#new/2-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.JankDetector.new/2","doc":"A new jank detector struct.","ref":"Raxol.Core.Performance.JankDetector.html#new/2-returns"},{"type":"function","title":"Examples - Raxol.Core.Performance.JankDetector.new/2","doc":"iex> JankDetector.new(16, 60)\n    %JankDetector{\n      threshold: 16,\n      window_size: 60,\n      frame_times: [],\n      jank_count: 0\n    }","ref":"Raxol.Core.Performance.JankDetector.html#new/2-examples"},{"type":"function","title":"Raxol.Core.Performance.JankDetector.record_frame/2","doc":"Records a frame's timing.","ref":"Raxol.Core.Performance.JankDetector.html#record_frame/2"},{"type":"function","title":"Parameters - Raxol.Core.Performance.JankDetector.record_frame/2","doc":"* `detector` - The jank detector\n* `frame_time` - Time taken to render the frame in milliseconds","ref":"Raxol.Core.Performance.JankDetector.html#record_frame/2-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.JankDetector.record_frame/2","doc":"Updated jank detector.","ref":"Raxol.Core.Performance.JankDetector.html#record_frame/2-returns"},{"type":"function","title":"Examples - Raxol.Core.Performance.JankDetector.record_frame/2","doc":"iex> detector = JankDetector.new(16, 60)\n    iex> detector = JankDetector.record_frame(detector, 20)\n    iex> detector.jank_count\n    1","ref":"Raxol.Core.Performance.JankDetector.html#record_frame/2-examples"},{"type":"module","title":"Raxol.Core.Performance.MetricsCollector","doc":"Collects and calculates performance metrics.\n\nThis module tracks:\n- Frame rate (FPS)\n- Frame timing statistics\n- Memory usage\n- Garbage collection statistics","ref":"Raxol.Core.Performance.MetricsCollector.html"},{"type":"module","title":"Usage - Raxol.Core.Performance.MetricsCollector","doc":"```elixir\n# Create a new collector\ncollector = MetricsCollector.new()\n\n# Record a frame\ncollector = MetricsCollector.record_frame(collector, 16)\n\n# Get current FPS\nfps = MetricsCollector.get_fps(collector)\n\n# Update memory metrics\ncollector = MetricsCollector.update_memory_usage(collector)\n```","ref":"Raxol.Core.Performance.MetricsCollector.html#module-usage"},{"type":"function","title":"Raxol.Core.Performance.MetricsCollector.get_avg_frame_time/1","doc":"Gets the average frame time.","ref":"Raxol.Core.Performance.MetricsCollector.html#get_avg_frame_time/1"},{"type":"function","title":"Parameters - Raxol.Core.Performance.MetricsCollector.get_avg_frame_time/1","doc":"* `collector` - The metrics collector","ref":"Raxol.Core.Performance.MetricsCollector.html#get_avg_frame_time/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.MetricsCollector.get_avg_frame_time/1","doc":"Average frame time in milliseconds.","ref":"Raxol.Core.Performance.MetricsCollector.html#get_avg_frame_time/1-returns"},{"type":"function","title":"Examples - Raxol.Core.Performance.MetricsCollector.get_avg_frame_time/1","doc":"iex> collector = MetricsCollector.new()\n    iex> collector = MetricsCollector.record_frame(collector, 16)\n    iex> MetricsCollector.get_avg_frame_time(collector)\n    16.0","ref":"Raxol.Core.Performance.MetricsCollector.html#get_avg_frame_time/1-examples"},{"type":"function","title":"Raxol.Core.Performance.MetricsCollector.get_fps/1","doc":"Gets the current frames per second.","ref":"Raxol.Core.Performance.MetricsCollector.html#get_fps/1"},{"type":"function","title":"Parameters - Raxol.Core.Performance.MetricsCollector.get_fps/1","doc":"* `collector` - The metrics collector","ref":"Raxol.Core.Performance.MetricsCollector.html#get_fps/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.MetricsCollector.get_fps/1","doc":"Current FPS as a float.","ref":"Raxol.Core.Performance.MetricsCollector.html#get_fps/1-returns"},{"type":"function","title":"Examples - Raxol.Core.Performance.MetricsCollector.get_fps/1","doc":"iex> collector = MetricsCollector.new()\n    iex> collector = MetricsCollector.record_frame(collector, 16)\n    iex> MetricsCollector.get_fps(collector)\n    62.5","ref":"Raxol.Core.Performance.MetricsCollector.html#get_fps/1-examples"},{"type":"function","title":"Raxol.Core.Performance.MetricsCollector.get_gc_stats/1","doc":"Gets garbage collection statistics.","ref":"Raxol.Core.Performance.MetricsCollector.html#get_gc_stats/1"},{"type":"function","title":"Parameters - Raxol.Core.Performance.MetricsCollector.get_gc_stats/1","doc":"* `collector` - The metrics collector","ref":"Raxol.Core.Performance.MetricsCollector.html#get_gc_stats/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.MetricsCollector.get_gc_stats/1","doc":"Map containing GC statistics:\n* `:number_of_gcs` - Total number of garbage collections\n* `:words_reclaimed` - Total words reclaimed\n* `:heap_size` - Current heap size\n* `:heap_limit` - Maximum heap size","ref":"Raxol.Core.Performance.MetricsCollector.html#get_gc_stats/1-returns"},{"type":"function","title":"Examples - Raxol.Core.Performance.MetricsCollector.get_gc_stats/1","doc":"iex> collector = MetricsCollector.new()\n    iex> collector = MetricsCollector.update_memory_usage(collector)\n    iex> gc_stats = MetricsCollector.get_gc_stats(collector)\n    iex> Map.has_key?(gc_stats, :number_of_gcs)\n    true","ref":"Raxol.Core.Performance.MetricsCollector.html#get_gc_stats/1-examples"},{"type":"function","title":"Raxol.Core.Performance.MetricsCollector.get_memory_trend/1","doc":"Gets the memory usage trend.","ref":"Raxol.Core.Performance.MetricsCollector.html#get_memory_trend/1"},{"type":"function","title":"Parameters - Raxol.Core.Performance.MetricsCollector.get_memory_trend/1","doc":"* `collector` - The metrics collector","ref":"Raxol.Core.Performance.MetricsCollector.html#get_memory_trend/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.MetricsCollector.get_memory_trend/1","doc":"Memory usage trend as a percentage change.","ref":"Raxol.Core.Performance.MetricsCollector.html#get_memory_trend/1-returns"},{"type":"function","title":"Examples - Raxol.Core.Performance.MetricsCollector.get_memory_trend/1","doc":"iex> collector = MetricsCollector.new()\n    iex> collector = MetricsCollector.update_memory_usage(collector)\n    iex> collector = MetricsCollector.update_memory_usage(collector)\n    iex> MetricsCollector.get_memory_trend(collector)\n    0.0","ref":"Raxol.Core.Performance.MetricsCollector.html#get_memory_trend/1-examples"},{"type":"function","title":"Raxol.Core.Performance.MetricsCollector.new/0","doc":"Creates a new metrics collector.","ref":"Raxol.Core.Performance.MetricsCollector.html#new/0"},{"type":"function","title":"Returns - Raxol.Core.Performance.MetricsCollector.new/0","doc":"A new metrics collector struct.","ref":"Raxol.Core.Performance.MetricsCollector.html#new/0-returns"},{"type":"function","title":"Examples - Raxol.Core.Performance.MetricsCollector.new/0","doc":"iex> MetricsCollector.new()\n    %MetricsCollector{\n      frame_times: [],\n      memory_usage: 0,\n      gc_stats: %{},\n      last_gc_time: 0\n    }","ref":"Raxol.Core.Performance.MetricsCollector.html#new/0-examples"},{"type":"function","title":"Raxol.Core.Performance.MetricsCollector.record_frame/2","doc":"Records a frame's timing.","ref":"Raxol.Core.Performance.MetricsCollector.html#record_frame/2"},{"type":"function","title":"Parameters - Raxol.Core.Performance.MetricsCollector.record_frame/2","doc":"* `collector` - The metrics collector\n* `frame_time` - Time taken to render the frame in milliseconds","ref":"Raxol.Core.Performance.MetricsCollector.html#record_frame/2-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.MetricsCollector.record_frame/2","doc":"Updated metrics collector.","ref":"Raxol.Core.Performance.MetricsCollector.html#record_frame/2-returns"},{"type":"function","title":"Examples - Raxol.Core.Performance.MetricsCollector.record_frame/2","doc":"iex> collector = MetricsCollector.new()\n    iex> collector = MetricsCollector.record_frame(collector, 16)\n    iex> length(collector.frame_times)\n    1","ref":"Raxol.Core.Performance.MetricsCollector.html#record_frame/2-examples"},{"type":"function","title":"Raxol.Core.Performance.MetricsCollector.update_memory_usage/1","doc":"Updates memory usage metrics.","ref":"Raxol.Core.Performance.MetricsCollector.html#update_memory_usage/1"},{"type":"function","title":"Parameters - Raxol.Core.Performance.MetricsCollector.update_memory_usage/1","doc":"* `collector` - The metrics collector","ref":"Raxol.Core.Performance.MetricsCollector.html#update_memory_usage/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.MetricsCollector.update_memory_usage/1","doc":"Updated metrics collector with current memory usage and GC stats.","ref":"Raxol.Core.Performance.MetricsCollector.html#update_memory_usage/1-returns"},{"type":"function","title":"Examples - Raxol.Core.Performance.MetricsCollector.update_memory_usage/1","doc":"iex> collector = MetricsCollector.new()\n    iex> collector = MetricsCollector.update_memory_usage(collector)\n    iex> collector.memory_usage > 0\n    true","ref":"Raxol.Core.Performance.MetricsCollector.html#update_memory_usage/1-examples"},{"type":"module","title":"Raxol.Core.Performance.Monitor","doc":"Performance monitoring system for Raxol applications.\n\nThis module provides tools for:\n- Frame rate monitoring\n- Memory usage tracking\n- UI jank detection\n- Performance metrics collection\n- Performance visualization","ref":"Raxol.Core.Performance.Monitor.html"},{"type":"module","title":"Usage - Raxol.Core.Performance.Monitor","doc":"```elixir\n# Start monitoring\n{:ok, monitor} = Monitor.start_link()\n\n# Record frame timing\nMonitor.record_frame(monitor, 16)  # 16ms frame time\n\n# Check for jank\nif Monitor.detect_jank?(monitor) do\n  Logger.warning(\"UI jank detected\")\nend\n\n# Get performance metrics\nmetrics = Monitor.get_metrics(monitor)\n```","ref":"Raxol.Core.Performance.Monitor.html#module-usage"},{"type":"function","title":"Raxol.Core.Performance.Monitor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Core.Performance.Monitor.html#child_spec/1"},{"type":"function","title":"Raxol.Core.Performance.Monitor.detect_jank?/1","doc":"Checks if jank was detected in the last frame.","ref":"Raxol.Core.Performance.Monitor.html#detect_jank?/1"},{"type":"function","title":"Parameters - Raxol.Core.Performance.Monitor.detect_jank?/1","doc":"* `monitor` - The monitor process","ref":"Raxol.Core.Performance.Monitor.html#detect_jank?/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.Monitor.detect_jank?/1","doc":"* `true` if jank was detected\n* `false` otherwise","ref":"Raxol.Core.Performance.Monitor.html#detect_jank?/1-returns"},{"type":"function","title":"Examples - Raxol.Core.Performance.Monitor.detect_jank?/1","doc":"iex> Monitor.detect_jank?(monitor)\n    false","ref":"Raxol.Core.Performance.Monitor.html#detect_jank?/1-examples"},{"type":"function","title":"Raxol.Core.Performance.Monitor.get_metrics/1","doc":"Gets current performance metrics.","ref":"Raxol.Core.Performance.Monitor.html#get_metrics/1"},{"type":"function","title":"Parameters - Raxol.Core.Performance.Monitor.get_metrics/1","doc":"* `monitor` - The monitor process","ref":"Raxol.Core.Performance.Monitor.html#get_metrics/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Performance.Monitor.get_metrics/1","doc":"Map containing performance metrics:\n* `:fps` - Current frames per second\n* `:avg_frame_time` - Average frame time in milliseconds\n* `:jank_count` - Number of janky frames in the sample window\n* `:memory_usage` - Current memory usage in bytes\n* `:gc_stats` - Garbage collection statistics","ref":"Raxol.Core.Performance.Monitor.html#get_metrics/1-returns"},{"type":"function","title":"Examples - Raxol.Core.Performance.Monitor.get_metrics/1","doc":"iex> Monitor.get_metrics(monitor)\n    %{\n      fps: 60,\n      avg_frame_time: 16.5,\n      jank_count: 2,\n      memory_usage: 1234567,\n      gc_stats: %{...}\n    }","ref":"Raxol.Core.Performance.Monitor.html#get_metrics/1-examples"},{"type":"function","title":"Raxol.Core.Performance.Monitor.record_frame/2","doc":"Records a frame's timing.","ref":"Raxol.Core.Performance.Monitor.html#record_frame/2"},{"type":"function","title":"Parameters - Raxol.Core.Performance.Monitor.record_frame/2","doc":"* `monitor` - The monitor process\n* `frame_time` - Time taken to render the frame in milliseconds","ref":"Raxol.Core.Performance.Monitor.html#record_frame/2-parameters"},{"type":"function","title":"Examples - Raxol.Core.Performance.Monitor.record_frame/2","doc":"iex> Monitor.record_frame(monitor, 16)\n    :ok","ref":"Raxol.Core.Performance.Monitor.html#record_frame/2-examples"},{"type":"function","title":"Raxol.Core.Performance.Monitor.start_link/1","doc":"Starts a new performance monitor.","ref":"Raxol.Core.Performance.Monitor.html#start_link/1"},{"type":"function","title":"Options - Raxol.Core.Performance.Monitor.start_link/1","doc":"* `:jank_threshold` - Time in milliseconds above which a frame is considered janky (default: 16)\n* `:sample_size` - Number of frames to keep in the rolling window (default: 60)\n* `:memory_check_interval` - How often to check memory usage in milliseconds (default: 5000)","ref":"Raxol.Core.Performance.Monitor.html#start_link/1-options"},{"type":"function","title":"Examples - Raxol.Core.Performance.Monitor.start_link/1","doc":"iex> {:ok, monitor} = Monitor.start_link()\n    {:ok, #PID<0.123.0>}\n\n    iex> {:ok, monitor} = Monitor.start_link(jank_threshold: 20)\n    {:ok, #PID<0.124.0>}","ref":"Raxol.Core.Performance.Monitor.html#start_link/1-examples"},{"type":"module","title":"Raxol.Core.Plugins.Core.ClipboardPlugin","doc":"Core plugin responsible for handling clipboard operations (:clipboard_write, :clipboard_read).","ref":"Raxol.Core.Plugins.Core.ClipboardPlugin.html"},{"type":"function","title":"Raxol.Core.Plugins.Core.ClipboardPlugin.terminate/1","doc":"","ref":"Raxol.Core.Plugins.Core.ClipboardPlugin.html#terminate/1"},{"type":"module","title":"Raxol.Core.Plugins.Core.NotificationPlugin","doc":"Core plugin responsible for handling notifications (:notify).","ref":"Raxol.Core.Plugins.Core.NotificationPlugin.html"},{"type":"function","title":"Raxol.Core.Plugins.Core.NotificationPlugin.terminate/1","doc":"","ref":"Raxol.Core.Plugins.Core.NotificationPlugin.html#terminate/1"},{"type":"module","title":"Raxol.Core.Preferences.Persistence","doc":"Handles persistence (loading/saving) of user preferences to a file.","ref":"Raxol.Core.Preferences.Persistence.html"},{"type":"function","title":"Raxol.Core.Preferences.Persistence.load/0","doc":"Loads user preferences from the designated file.\n\nReturns:\n  - `{:ok, preferences_map}` if successful.\n  - `{:error, :file_not_found}` if the file doesn't exist.\n  - `{:error, reason}` for other file or decoding errors.","ref":"Raxol.Core.Preferences.Persistence.html#load/0"},{"type":"function","title":"Raxol.Core.Preferences.Persistence.preferences_path/0","doc":"Returns the full path to the user preferences file.\nUses an application-specific directory.","ref":"Raxol.Core.Preferences.Persistence.html#preferences_path/0"},{"type":"function","title":"Raxol.Core.Preferences.Persistence.save/1","doc":"Saves the given preferences map to the designated file.\n\nSerializes the map using `:erlang.term_to_binary`.\n\nReturns:\n  - `:ok` on success.\n  - `{:error, reason}` on failure.","ref":"Raxol.Core.Preferences.Persistence.html#save/1"},{"type":"module","title":"Raxol.Core.Preferences.Store","doc":"Handles storage and retrieval of user preferences.","ref":"Raxol.Core.Preferences.Store.html"},{"type":"function","title":"Raxol.Core.Preferences.Store.save_to_preferences/1","doc":"","ref":"Raxol.Core.Preferences.Store.html#save_to_preferences/1"},{"type":"module","title":"Raxol.Core.Renderer.Buffer","doc":"Manages terminal buffer rendering with double buffering and damage tracking.\n\nThis module provides efficient terminal rendering by:\n* Using double buffering to prevent screen flicker\n* Tracking damaged regions to minimize updates\n* Supporting partial screen updates\n* Managing frame timing","ref":"Raxol.Core.Renderer.Buffer.html"},{"type":"type","title":"Raxol.Core.Renderer.Buffer.buffer/0","doc":"","ref":"Raxol.Core.Renderer.Buffer.html#t:buffer/0"},{"type":"type","title":"Raxol.Core.Renderer.Buffer.cell/0","doc":"","ref":"Raxol.Core.Renderer.Buffer.html#t:cell/0"},{"type":"function","title":"Raxol.Core.Renderer.Buffer.clear/1","doc":"Clears the entire buffer and marks all cells as damaged.","ref":"Raxol.Core.Renderer.Buffer.html#clear/1"},{"type":"function","title":"Raxol.Core.Renderer.Buffer.get_damage/1","doc":"Gets the damaged regions that need to be redrawn.\nReturns a list of {position, cell} tuples.","ref":"Raxol.Core.Renderer.Buffer.html#get_damage/1"},{"type":"function","title":"Raxol.Core.Renderer.Buffer.new/3","doc":"Creates a new buffer manager with the given size and FPS.","ref":"Raxol.Core.Renderer.Buffer.html#new/3"},{"type":"type","title":"Raxol.Core.Renderer.Buffer.position/0","doc":"","ref":"Raxol.Core.Renderer.Buffer.html#t:position/0"},{"type":"function","title":"Raxol.Core.Renderer.Buffer.put_cell/4","doc":"Updates a cell in the back buffer and marks it as damaged.","ref":"Raxol.Core.Renderer.Buffer.html#put_cell/4"},{"type":"function","title":"Raxol.Core.Renderer.Buffer.resize/3","doc":"Resizes the buffer to the new dimensions.\nPreserves content where possible and marks all changed cells as damaged.","ref":"Raxol.Core.Renderer.Buffer.html#resize/3"},{"type":"type","title":"Raxol.Core.Renderer.Buffer.size/0","doc":"","ref":"Raxol.Core.Renderer.Buffer.html#t:size/0"},{"type":"function","title":"Raxol.Core.Renderer.Buffer.swap_buffers/1","doc":"Swaps the front and back buffers if enough time has passed since the last frame.\nReturns {buffer, should_render}, where should_render indicates if a new frame should be drawn.","ref":"Raxol.Core.Renderer.Buffer.html#swap_buffers/1"},{"type":"module","title":"Raxol.Core.Renderer.Color","doc":"Provides comprehensive color support for terminal rendering.\n\nSupports:\n* ANSI 16 colors (4-bit)\n* ANSI 256 colors (8-bit)\n* True Color (24-bit)\n* Color themes\n* Terminal background detection","ref":"Raxol.Core.Renderer.Color.html"},{"type":"type","title":"Raxol.Core.Renderer.Color.ansi_16/0","doc":"","ref":"Raxol.Core.Renderer.Color.html#t:ansi_16/0"},{"type":"type","title":"Raxol.Core.Renderer.Color.ansi_256/0","doc":"","ref":"Raxol.Core.Renderer.Color.html#t:ansi_256/0"},{"type":"type","title":"Raxol.Core.Renderer.Color.color/0","doc":"","ref":"Raxol.Core.Renderer.Color.html#t:color/0"},{"type":"function","title":"Raxol.Core.Renderer.Color.create_theme/1","doc":"Creates a color theme map.","ref":"Raxol.Core.Renderer.Color.html#create_theme/1"},{"type":"function","title":"Raxol.Core.Renderer.Color.default_theme/0","doc":"Returns the default color theme.","ref":"Raxol.Core.Renderer.Color.html#default_theme/0"},{"type":"function","title":"Raxol.Core.Renderer.Color.detect_background/0","doc":"Detects the terminal's background color.\nReturns :light or :dark.","ref":"Raxol.Core.Renderer.Color.html#detect_background/0"},{"type":"function","title":"Raxol.Core.Renderer.Color.hex_to_rgb/1","doc":"Converts a hex color string to RGB.","ref":"Raxol.Core.Renderer.Color.html#hex_to_rgb/1"},{"type":"function","title":"Raxol.Core.Renderer.Color.rgb_to_ansi256/1","doc":"Converts RGB values to the nearest ANSI 256 color code.","ref":"Raxol.Core.Renderer.Color.html#rgb_to_ansi256/1"},{"type":"function","title":"Raxol.Core.Renderer.Color.to_ansi/1","doc":"Converts a color representation to its ANSI foreground escape code.","ref":"Raxol.Core.Renderer.Color.html#to_ansi/1"},{"type":"function","title":"Raxol.Core.Renderer.Color.to_bg_ansi/1","doc":"Converts a color representation to its ANSI background escape code.","ref":"Raxol.Core.Renderer.Color.html#to_bg_ansi/1"},{"type":"type","title":"Raxol.Core.Renderer.Color.true_color/0","doc":"","ref":"Raxol.Core.Renderer.Color.html#t:true_color/0"},{"type":"module","title":"Raxol.Core.Renderer.Element","doc":"Defines the core element structure for the rendering system.\n\nElements are the building blocks of Raxol's UI system. Each element\nrepresents a renderable component with:\n* A tag identifying its type\n* Attributes controlling its appearance and behavior\n* Optional children forming a tree structure","ref":"Raxol.Core.Renderer.Element.html"},{"type":"function","title":"Raxol.Core.Renderer.Element.add_children/2","doc":"Adds children to an existing element.","ref":"Raxol.Core.Renderer.Element.html#add_children/2"},{"type":"function","title":"Raxol.Core.Renderer.Element.new/3","doc":"Creates a new element with the given tag and attributes.","ref":"Raxol.Core.Renderer.Element.html#new/3"},{"type":"type","title":"Raxol.Core.Renderer.Element.t/0","doc":"","ref":"Raxol.Core.Renderer.Element.html#t:t/0"},{"type":"function","title":"Raxol.Core.Renderer.Element.update_attrs/2","doc":"Updates an element's attributes while preserving its structure.","ref":"Raxol.Core.Renderer.Element.html#update_attrs/2"},{"type":"function","title":"Raxol.Core.Renderer.Element.validate/1","doc":"Validates that an element tree follows the component rules.","ref":"Raxol.Core.Renderer.Element.html#validate/1"},{"type":"module","title":"Raxol.Core.Renderer.Manager","doc":"Manages the rendering system for Raxol applications.\n\nThis module coordinates:\n* Frame-based rendering\n* Terminal buffer management\n* Component rendering\n* Screen updates","ref":"Raxol.Core.Renderer.Manager.html"},{"type":"function","title":"Raxol.Core.Renderer.Manager.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Core.Renderer.Manager.html#child_spec/1"},{"type":"function","title":"Raxol.Core.Renderer.Manager.cleanup/0","doc":"","ref":"Raxol.Core.Renderer.Manager.html#cleanup/0"},{"type":"function","title":"Raxol.Core.Renderer.Manager.initialize/1","doc":"","ref":"Raxol.Core.Renderer.Manager.html#initialize/1"},{"type":"function","title":"Raxol.Core.Renderer.Manager.render/0","doc":"","ref":"Raxol.Core.Renderer.Manager.html#render/0"},{"type":"function","title":"Raxol.Core.Renderer.Manager.start_link/1","doc":"","ref":"Raxol.Core.Renderer.Manager.html#start_link/1"},{"type":"module","title":"Raxol.Core.Renderer.View","doc":"Defines the view system for Raxol components.\n\nProvides:\n* Box model layout (content, padding, border, margin)\n* Flexible layouts (grid, flex)\n* Rich text rendering\n* Borders and shadows","ref":"Raxol.Core.Renderer.View.html"},{"type":"function","title":"Raxol.Core.Renderer.View.absolute/2","doc":"Creates an absolutely positioned view.","ref":"Raxol.Core.Renderer.View.html#absolute/2"},{"type":"function","title":"Raxol.Core.Renderer.View.border/3","doc":"Creates a border around a view.","ref":"Raxol.Core.Renderer.View.html#border/3"},{"type":"type","title":"Raxol.Core.Renderer.View.border_style/0","doc":"","ref":"Raxol.Core.Renderer.View.html#t:border_style/0"},{"type":"function","title":"Raxol.Core.Renderer.View.box/1","doc":"Creates a box view for layout.","ref":"Raxol.Core.Renderer.View.html#box/1"},{"type":"type","title":"Raxol.Core.Renderer.View.color/0","doc":"","ref":"Raxol.Core.Renderer.View.html#t:color/0"},{"type":"function","title":"Raxol.Core.Renderer.View.fixed/2","doc":"Creates a fixed position view (relative to viewport).","ref":"Raxol.Core.Renderer.View.html#fixed/2"},{"type":"function","title":"Raxol.Core.Renderer.View.flex/2","doc":"Creates a flex container.","ref":"Raxol.Core.Renderer.View.html#flex/2"},{"type":"function","title":"Raxol.Core.Renderer.View.grid/2","doc":"Creates a grid container.","ref":"Raxol.Core.Renderer.View.html#grid/2"},{"type":"function","title":"Raxol.Core.Renderer.View.layout/2","doc":"Calculates the layout for a view tree.\nReturns a list of positioned views ready for rendering.","ref":"Raxol.Core.Renderer.View.html#layout/2"},{"type":"type","title":"Raxol.Core.Renderer.View.layout_type/0","doc":"","ref":"Raxol.Core.Renderer.View.html#t:layout_type/0"},{"type":"type","title":"Raxol.Core.Renderer.View.margin/0","doc":"","ref":"Raxol.Core.Renderer.View.html#t:margin/0"},{"type":"function","title":"Raxol.Core.Renderer.View.new/2","doc":"Creates a new view with the given type and options.","ref":"Raxol.Core.Renderer.View.html#new/2"},{"type":"type","title":"Raxol.Core.Renderer.View.padding/0","doc":"","ref":"Raxol.Core.Renderer.View.html#t:padding/0"},{"type":"type","title":"Raxol.Core.Renderer.View.position/0","doc":"","ref":"Raxol.Core.Renderer.View.html#t:position/0"},{"type":"type","title":"Raxol.Core.Renderer.View.position_type/0","doc":"","ref":"Raxol.Core.Renderer.View.html#t:position_type/0"},{"type":"function","title":"Raxol.Core.Renderer.View.scroll/2","doc":"Creates a scrollable view.","ref":"Raxol.Core.Renderer.View.html#scroll/2"},{"type":"function","title":"Raxol.Core.Renderer.View.shadow/2","doc":"Creates a shadow effect.","ref":"Raxol.Core.Renderer.View.html#shadow/2"},{"type":"type","title":"Raxol.Core.Renderer.View.size/0","doc":"","ref":"Raxol.Core.Renderer.View.html#t:size/0"},{"type":"type","title":"Raxol.Core.Renderer.View.style/0","doc":"","ref":"Raxol.Core.Renderer.View.html#t:style/0"},{"type":"function","title":"Raxol.Core.Renderer.View.text/2","doc":"Creates a text view.","ref":"Raxol.Core.Renderer.View.html#text/2"},{"type":"type","title":"Raxol.Core.Renderer.View.view/0","doc":"","ref":"Raxol.Core.Renderer.View.html#t:view/0"},{"type":"type","title":"Raxol.Core.Renderer.View.z_index/0","doc":"","ref":"Raxol.Core.Renderer.View.html#t:z_index/0"},{"type":"module","title":"Raxol.Core.Renderer.Views.Chart","doc":"Chart view component for data visualization.\n\nSupports:\n* Bar charts (vertical and horizontal)\n* Line charts\n* Sparklines\n* Axes and labels\n* Multiple series\n* Custom styling","ref":"Raxol.Core.Renderer.Views.Chart.html"},{"type":"type","title":"Raxol.Core.Renderer.Views.Chart.chart_type/0","doc":"","ref":"Raxol.Core.Renderer.Views.Chart.html#t:chart_type/0"},{"type":"function","title":"Raxol.Core.Renderer.Views.Chart.new/1","doc":"Creates a new chart view.","ref":"Raxol.Core.Renderer.Views.Chart.html#new/1"},{"type":"type","title":"Raxol.Core.Renderer.Views.Chart.options/0","doc":"","ref":"Raxol.Core.Renderer.Views.Chart.html#t:options/0"},{"type":"type","title":"Raxol.Core.Renderer.Views.Chart.orientation/0","doc":"","ref":"Raxol.Core.Renderer.Views.Chart.html#t:orientation/0"},{"type":"type","title":"Raxol.Core.Renderer.Views.Chart.series/0","doc":"","ref":"Raxol.Core.Renderer.Views.Chart.html#t:series/0"},{"type":"module","title":"Raxol.Core.Renderer.Views.Table","doc":"Table view component for displaying tabular data.\n\nFeatures:\n* Column headers\n* Row striping\n* Column alignment\n* Border styles\n* Column resizing\n* Row selection","ref":"Raxol.Core.Renderer.Views.Table.html"},{"type":"type","title":"Raxol.Core.Renderer.Views.Table.column/0","doc":"","ref":"Raxol.Core.Renderer.Views.Table.html#t:column/0"},{"type":"function","title":"Raxol.Core.Renderer.Views.Table.new/1","doc":"Creates a new table view.","ref":"Raxol.Core.Renderer.Views.Table.html#new/1"},{"type":"type","title":"Raxol.Core.Renderer.Views.Table.options/0","doc":"","ref":"Raxol.Core.Renderer.Views.Table.html#t:options/0"},{"type":"behaviour","title":"Raxol.Core.Runtime.Application","doc":"Defines the behaviour for Raxol applications following The Elm Architecture (TEA).\n\nThis module provides the core structure for building terminal applications using\na pure functional approach with unidirectional data flow. The architecture is\ncomposed of three main parts:\n\n1. **Model** - The complete state of your application\n2. **Update** - A way to update your state\n3. **View** - A way to view your state as UI elements","ref":"Raxol.Core.Runtime.Application.html"},{"type":"behaviour","title":"Example - Raxol.Core.Runtime.Application","doc":"defmodule MyApp do\n      use Raxol.Core.Runtime.Application\n\n      def init(_context) do\n        %{count: 0}\n      end\n\n      def update(msg, model) do\n        case msg do\n          :increment ->\n            {%{model | count: model.count + 1}, []}\n          :decrement ->\n            {%{model | count: model.count - 1}, []}\n          _ ->\n            {model, []}\n        end\n      end\n\n      def view(model) do\n        view do\n          panel title: \"Counter\" do\n            row do\n              button(label: \"-\", on_click: :decrement)\n              text(content: \"Count: #{model.count}\")\n              button(label: \"+\", on_click: :increment)\n            end\n          end\n        end\n      end\n\n      def subscribe(_model) do\n        # Optional subscriptions to time-based or external events\n        []\n      end\n    end","ref":"Raxol.Core.Runtime.Application.html#module-example"},{"type":"behaviour","title":"Lifecycle - Raxol.Core.Runtime.Application","doc":"1. The application starts with `init/1`, which sets up the initial state\n2. Events or messages trigger `update/2`, which computes the new state\n3. State changes cause `view/1` to re-render the UI\n4. `subscribe/1` can set up recurring updates or external event subscriptions","ref":"Raxol.Core.Runtime.Application.html#module-lifecycle"},{"type":"behaviour","title":"Commands and Effects - Raxol.Core.Runtime.Application","doc":"The update function returns a tuple of `{new_state, commands}`, where commands\nare used to handle side effects like:\n- API calls\n- File operations\n- Timer operations\n- Inter-process communication\n\nCommands are executed by the runtime system, keeping the update function pure.","ref":"Raxol.Core.Runtime.Application.html#module-commands-and-effects"},{"type":"behaviour","title":"Subscriptions - Raxol.Core.Runtime.Application","doc":"Subscriptions allow your application to receive messages over time, such as:\n- Timer-based updates\n- System events\n- External data streams\n\nDefine subscriptions in the `subscribe/1` callback, which is called after\ninitialization and after each state update.","ref":"Raxol.Core.Runtime.Application.html#module-subscriptions"},{"type":"type","title":"Raxol.Core.Runtime.Application.command/0","doc":"","ref":"Raxol.Core.Runtime.Application.html#t:command/0"},{"type":"type","title":"Raxol.Core.Runtime.Application.context/0","doc":"","ref":"Raxol.Core.Runtime.Application.html#t:context/0"},{"type":"function","title":"Raxol.Core.Runtime.Application.delegate_init/2","doc":"","ref":"Raxol.Core.Runtime.Application.html#delegate_init/2"},{"type":"function","title":"Raxol.Core.Runtime.Application.delegate_update/3","doc":"","ref":"Raxol.Core.Runtime.Application.html#delegate_update/3"},{"type":"type","title":"Raxol.Core.Runtime.Application.element/0","doc":"","ref":"Raxol.Core.Runtime.Application.html#t:element/0"},{"type":"function","title":"Raxol.Core.Runtime.Application.get_env/3","doc":"Placeholder for getting environment configuration.","ref":"Raxol.Core.Runtime.Application.html#get_env/3"},{"type":"callback","title":"Raxol.Core.Runtime.Application.handle_event/1","doc":"","ref":"Raxol.Core.Runtime.Application.html#c:handle_event/1"},{"type":"callback","title":"Raxol.Core.Runtime.Application.handle_message/2","doc":"","ref":"Raxol.Core.Runtime.Application.html#c:handle_message/2"},{"type":"callback","title":"Raxol.Core.Runtime.Application.handle_tick/1","doc":"","ref":"Raxol.Core.Runtime.Application.html#c:handle_tick/1"},{"type":"callback","title":"Raxol.Core.Runtime.Application.init/1","doc":"Initializes the application state.\n\nCalled once when the application starts. The context map contains runtime\ninformation such as terminal dimensions, environment variables, and startup\narguments.\n\nReturns either:\n- Initial state: `state()`\n- State and commands: `{state(), [command()]}`","ref":"Raxol.Core.Runtime.Application.html#c:init/1"},{"type":"function","title":"Raxol.Core.Runtime.Application.init/2","doc":"Initializes the application state.\n\nCalled once when the application starts. The context map contains runtime\ninformation such as terminal dimensions, environment variables, and startup\narguments.\n\nReturns either:\n- Initial state: `state()`\n- State and commands: `{state(), [command()]}`","ref":"Raxol.Core.Runtime.Application.html#init/2"},{"type":"type","title":"Raxol.Core.Runtime.Application.message/0","doc":"","ref":"Raxol.Core.Runtime.Application.html#t:message/0"},{"type":"type","title":"Raxol.Core.Runtime.Application.model/0","doc":"","ref":"Raxol.Core.Runtime.Application.html#t:model/0"},{"type":"type","title":"Raxol.Core.Runtime.Application.state/0","doc":"","ref":"Raxol.Core.Runtime.Application.html#t:state/0"},{"type":"callback","title":"Raxol.Core.Runtime.Application.subscribe/1","doc":"Sets up subscriptions based on the current state.\n\nCalled after initialization and after each state update. Use this to\nset up recurring updates or subscribe to external events.\n\nReturns a list of subscription specifications.","ref":"Raxol.Core.Runtime.Application.html#c:subscribe/1"},{"type":"type","title":"Raxol.Core.Runtime.Application.subscription/0","doc":"","ref":"Raxol.Core.Runtime.Application.html#t:subscription/0"},{"type":"callback","title":"Raxol.Core.Runtime.Application.subscriptions/1","doc":"","ref":"Raxol.Core.Runtime.Application.html#c:subscriptions/1"},{"type":"callback","title":"Raxol.Core.Runtime.Application.terminate/2","doc":"","ref":"Raxol.Core.Runtime.Application.html#c:terminate/2"},{"type":"callback","title":"Raxol.Core.Runtime.Application.update/2","doc":"Updates the application state in response to messages.\n\nCalled whenever a message is received, either from events, commands, or\nsubscriptions. Should be a pure function that computes the new state\nbased on the current state and message.\n\nReturns a tuple of the new state and any commands to be executed:\n`{state(), [command()]}`","ref":"Raxol.Core.Runtime.Application.html#c:update/2"},{"type":"function","title":"Raxol.Core.Runtime.Application.update/3","doc":"Handles incoming events or messages and updates the application state.\n\nReturns the updated model and optional commands to execute.","ref":"Raxol.Core.Runtime.Application.html#update/3"},{"type":"callback","title":"Raxol.Core.Runtime.Application.view/1","doc":"Renders the current state as UI elements.\n\nCalled after every state update to generate the new view. Should be a\npure function that converts the state into UI elements.\n\nReturns an element tree that will be rendered to the terminal.","ref":"Raxol.Core.Runtime.Application.html#c:view/1"},{"type":"module","title":"Raxol.Core.Runtime.Command","doc":"Provides a way to handle side effects in a pure functional way.\n\nCommands are used to describe side effects that should be performed by the\nruntime system. This keeps the application's update function pure while still\nallowing necessary side effects to occur.","ref":"Raxol.Core.Runtime.Command.html"},{"type":"module","title":"Types of Commands - Raxol.Core.Runtime.Command","doc":"* `:none` - No side effect\n* `:task` - Asynchronous task that will send a message when complete\n* `:batch` - Multiple commands to be executed in sequence\n* `:delay` - Delayed message delivery\n* `:broadcast` - Send a message to all components\n* `:system` - System-level operations (file, network, etc.)\n* `:quit` - Signals the runtime to quit\n* `:clipboard_write` - Write text to the system clipboard\n* `:clipboard_read` - Request text from the system clipboard (will result in a message)\n* `:notify` - Send a system notification","ref":"Raxol.Core.Runtime.Command.html#module-types-of-commands"},{"type":"module","title":"Examples - Raxol.Core.Runtime.Command","doc":"# No side effect\n    Command.none()\n\n    # Run an async task\n    Command.task(fn ->\n      # Do something expensive\n      result = expensive_operation()\n      {:operation_complete, result}\n    end)\n\n    # Multiple commands\n    Command.batch([\n      Command.task(fn -> {:fetch_data, api_call()} end),\n      Command.delay(:refresh, 1000)\n    ])\n\n    # Delayed message\n    Command.delay(:timeout, 5000)\n\n    # Broadcast to all components\n    Command.broadcast(:data_updated)\n\n    # System operation\n    Command.system(:file_write, path: \"data.txt\", content: \"Hello\")\n\n    # Signal the runtime to quit\n    Command.quit()\n\n    # Write to clipboard\n    Command.clipboard_write(\"Copied text\")\n\n    # Read from clipboard (expects a {:clipboard_content, text} message later)\n    Command.clipboard_read()\n\n    # Send notification\n    Command.notify(\"Task Complete\", \"Your background job finished.\")","ref":"Raxol.Core.Runtime.Command.html#module-examples"},{"type":"function","title":"Raxol.Core.Runtime.Command.batch/1","doc":"Creates a command that will execute multiple commands in sequence.","ref":"Raxol.Core.Runtime.Command.html#batch/1"},{"type":"function","title":"Raxol.Core.Runtime.Command.broadcast/1","doc":"Creates a command that will broadcast a message to all components.","ref":"Raxol.Core.Runtime.Command.html#broadcast/1"},{"type":"function","title":"Raxol.Core.Runtime.Command.clipboard_read/0","doc":"Creates a command to read text from the system clipboard.\nThis will eventually result in a `{:command_result, {:clipboard_content, content}}`\nmessage being sent back to the application's update function.","ref":"Raxol.Core.Runtime.Command.html#clipboard_read/0"},{"type":"function","title":"Raxol.Core.Runtime.Command.clipboard_write/1","doc":"Creates a command to write text to the system clipboard.","ref":"Raxol.Core.Runtime.Command.html#clipboard_write/1"},{"type":"function","title":"Raxol.Core.Runtime.Command.delay/2","doc":"Creates a command that will send a message after the specified delay\nin milliseconds.","ref":"Raxol.Core.Runtime.Command.html#delay/2"},{"type":"function","title":"Raxol.Core.Runtime.Command.execute/2","doc":"Executes a command within the given context. This is used by the runtime\nsystem and should not be called directly by applications.","ref":"Raxol.Core.Runtime.Command.html#execute/2"},{"type":"function","title":"Raxol.Core.Runtime.Command.map/2","doc":"Maps a function over a command's result message. This is useful for\nnamespacing messages or transforming them before they reach the update\nfunction.","ref":"Raxol.Core.Runtime.Command.html#map/2"},{"type":"function","title":"Example - Raxol.Core.Runtime.Command.map/2","doc":"# Transform the task's result message\n    Command.task(fn -> {:data, fetch_data()} end)\n    |> Command.map(fn {:data, result} -> {:processed_data, process(result)} end)","ref":"Raxol.Core.Runtime.Command.html#map/2-example"},{"type":"function","title":"Raxol.Core.Runtime.Command.new/2","doc":"Creates a new command. This is the low-level constructor, prefer using\nthe specific command constructors unless you need custom behavior.","ref":"Raxol.Core.Runtime.Command.html#new/2"},{"type":"function","title":"Raxol.Core.Runtime.Command.none/0","doc":"Returns a command that does nothing.","ref":"Raxol.Core.Runtime.Command.html#none/0"},{"type":"function","title":"Raxol.Core.Runtime.Command.notify/2","doc":"Creates a command to send a system notification.","ref":"Raxol.Core.Runtime.Command.html#notify/2"},{"type":"function","title":"Raxol.Core.Runtime.Command.quit/0","doc":"Returns a command that signals the runtime to quit.","ref":"Raxol.Core.Runtime.Command.html#quit/0"},{"type":"function","title":"Raxol.Core.Runtime.Command.system/2","doc":"Creates a command for system-level operations like file I/O or network\nrequests. The operation type and options specify what should be done.","ref":"Raxol.Core.Runtime.Command.html#system/2"},{"type":"type","title":"Raxol.Core.Runtime.Command.t/0","doc":"","ref":"Raxol.Core.Runtime.Command.html#t:t/0"},{"type":"function","title":"Raxol.Core.Runtime.Command.task/1","doc":"Creates a command that will execute the given function asynchronously.\nThe function should return a message that will be sent back to the update\nfunction when the task completes.","ref":"Raxol.Core.Runtime.Command.html#task/1"},{"type":"module","title":"Raxol.Core.Runtime.ComponentManager","doc":"Manages component lifecycle and state in the Raxol runtime system.\n\nThis module is responsible for:\n* Mounting and unmounting components\n* Managing component state\n* Handling event dispatch to components\n* Managing component subscriptions\n* Coordinating updates and renders","ref":"Raxol.Core.Runtime.ComponentManager.html"},{"type":"function","title":"Raxol.Core.Runtime.ComponentManager.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Core.Runtime.ComponentManager.html#child_spec/1"},{"type":"function","title":"Raxol.Core.Runtime.ComponentManager.dispatch_event/1","doc":"","ref":"Raxol.Core.Runtime.ComponentManager.html#dispatch_event/1"},{"type":"function","title":"Raxol.Core.Runtime.ComponentManager.get_component/1","doc":"Retrieves a specific component's data by its ID.","ref":"Raxol.Core.Runtime.ComponentManager.html#get_component/1"},{"type":"function","title":"Raxol.Core.Runtime.ComponentManager.get_render_queue/0","doc":"Retrieves the current render queue and clears it.","ref":"Raxol.Core.Runtime.ComponentManager.html#get_render_queue/0"},{"type":"function","title":"Raxol.Core.Runtime.ComponentManager.mount/2","doc":"","ref":"Raxol.Core.Runtime.ComponentManager.html#mount/2"},{"type":"function","title":"Raxol.Core.Runtime.ComponentManager.start_link/1","doc":"","ref":"Raxol.Core.Runtime.ComponentManager.html#start_link/1"},{"type":"function","title":"Raxol.Core.Runtime.ComponentManager.unmount/1","doc":"","ref":"Raxol.Core.Runtime.ComponentManager.html#unmount/1"},{"type":"function","title":"Raxol.Core.Runtime.ComponentManager.update/2","doc":"","ref":"Raxol.Core.Runtime.ComponentManager.html#update/2"},{"type":"module","title":"Raxol.Core.Runtime.Debug","doc":"Simple logging wrapper for the runtime.","ref":"Raxol.Core.Runtime.Debug.html"},{"type":"function","title":"Raxol.Core.Runtime.Debug.debug/1","doc":"","ref":"Raxol.Core.Runtime.Debug.html#debug/1"},{"type":"function","title":"Raxol.Core.Runtime.Debug.error/1","doc":"","ref":"Raxol.Core.Runtime.Debug.html#error/1"},{"type":"function","title":"Raxol.Core.Runtime.Debug.info/1","doc":"","ref":"Raxol.Core.Runtime.Debug.html#info/1"},{"type":"function","title":"Raxol.Core.Runtime.Debug.warn/1","doc":"","ref":"Raxol.Core.Runtime.Debug.html#warn/1"},{"type":"behaviour","title":"Raxol.Core.Runtime.EventSource","doc":"Behaviour for implementing custom event sources for subscriptions.\n\nEvent sources are processes that can generate events over time and send them\nto subscribers. This behaviour defines the contract that custom event sources\nmust implement.","ref":"Raxol.Core.Runtime.EventSource.html"},{"type":"behaviour","title":"Example - Raxol.Core.Runtime.EventSource","doc":"defmodule MyEventSource do\n      use Raxol.Core.Runtime.EventSource\n\n      @impl true\n      def init(args, context) do\n        # Set up initial state\n        {:ok, %{args: args, context: context}}\n      end\n\n      @impl true\n      def handle_info(:tick, state) do\n        # Send an event to the subscriber\n        send_event(state.context, {:my_event, :data})\n        {:noreply, state}\n      end\n    end","ref":"Raxol.Core.Runtime.EventSource.html#module-example"},{"type":"callback","title":"Raxol.Core.Runtime.EventSource.handle_info/2","doc":"Called when the event source receives a message. Should handle the message\nand optionally send events to the subscriber.","ref":"Raxol.Core.Runtime.EventSource.html#c:handle_info/2"},{"type":"callback","title":"Parameters - Raxol.Core.Runtime.EventSource.handle_info/2","doc":"* `msg` - The received message\n  * `state` - The current state","ref":"Raxol.Core.Runtime.EventSource.html#c:handle_info/2-parameters"},{"type":"callback","title":"Returns - Raxol.Core.Runtime.EventSource.handle_info/2","doc":"* `{:noreply, new_state}` - Continue with new state\n  * `{:stop, reason, new_state}` - Stop the event source","ref":"Raxol.Core.Runtime.EventSource.html#c:handle_info/2-returns"},{"type":"callback","title":"Raxol.Core.Runtime.EventSource.init/2","doc":"Called when the event source is started. Should return the initial state.","ref":"Raxol.Core.Runtime.EventSource.html#c:init/2"},{"type":"callback","title":"Parameters - Raxol.Core.Runtime.EventSource.init/2","doc":"* `args` - The arguments passed to `Subscription.custom/2`\n  * `context` - The runtime context containing the subscriber pid","ref":"Raxol.Core.Runtime.EventSource.html#c:init/2-parameters"},{"type":"callback","title":"Returns - Raxol.Core.Runtime.EventSource.init/2","doc":"* `{:ok, state}` - Successfully initialized with state\n  * `{:error, reason}` - Failed to initialize","ref":"Raxol.Core.Runtime.EventSource.html#c:init/2-returns"},{"type":"callback","title":"Raxol.Core.Runtime.EventSource.terminate/2","doc":"Called when the event source is stopping. Can be used to clean up resources.","ref":"Raxol.Core.Runtime.EventSource.html#c:terminate/2"},{"type":"callback","title":"Parameters - Raxol.Core.Runtime.EventSource.terminate/2","doc":"* `reason` - The reason for stopping\n  * `state` - The current state","ref":"Raxol.Core.Runtime.EventSource.html#c:terminate/2-parameters"},{"type":"callback","title":"Returns - Raxol.Core.Runtime.EventSource.terminate/2","doc":"* `:ok`","ref":"Raxol.Core.Runtime.EventSource.html#c:terminate/2-returns"},{"type":"module","title":"Raxol.Core.Runtime.Events.Converter","doc":"Handles conversion between different event formats in the Raxol system.\n\nThis module is responsible for:\n* Converting Termbox events to the Raxol event format\n* Converting VS Code events to the Raxol event format\n* Normalizing events into a consistent format","ref":"Raxol.Core.Runtime.Events.Converter.html"},{"type":"function","title":"Raxol.Core.Runtime.Events.Converter.convert_termbox_event/6","doc":"Converts a Termbox event to the standardized Raxol event format.","ref":"Raxol.Core.Runtime.Events.Converter.html#convert_termbox_event/6"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Events.Converter.convert_termbox_event/6","doc":"- `type`: The Termbox event type (e.g., :key, :resize)\n- `mod`: Key modifiers (if applicable)\n- `key`: The key code (for key events)\n- `ch`: The character (for character events)\n- `w`, `h`: Width and height (for resize events)","ref":"Raxol.Core.Runtime.Events.Converter.html#convert_termbox_event/6-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Events.Converter.convert_termbox_event/6","doc":"A structured `%Event{}` struct.","ref":"Raxol.Core.Runtime.Events.Converter.html#convert_termbox_event/6-returns"},{"type":"function","title":"Raxol.Core.Runtime.Events.Converter.convert_vscode_event/1","doc":"Converts a VS Code extension event to the standardized Raxol event format.","ref":"Raxol.Core.Runtime.Events.Converter.html#convert_vscode_event/1"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Events.Converter.convert_vscode_event/1","doc":"- `event`: The VS Code event map","ref":"Raxol.Core.Runtime.Events.Converter.html#convert_vscode_event/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Events.Converter.convert_vscode_event/1","doc":"A structured `%Event{}` struct.","ref":"Raxol.Core.Runtime.Events.Converter.html#convert_vscode_event/1-returns"},{"type":"function","title":"Raxol.Core.Runtime.Events.Converter.normalize_event/1","doc":"Normalizes events from various sources into a consistent format.\n\nThis is useful when handling events from multiple backends to ensure\nthey all follow the same structure before processing.","ref":"Raxol.Core.Runtime.Events.Converter.html#normalize_event/1"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Events.Converter.normalize_event/1","doc":"- `event`: The event to normalize","ref":"Raxol.Core.Runtime.Events.Converter.html#normalize_event/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Events.Converter.normalize_event/1","doc":"A normalized `%Event{}` struct.","ref":"Raxol.Core.Runtime.Events.Converter.html#normalize_event/1-returns"},{"type":"module","title":"Raxol.Core.Runtime.Events.Dispatcher","doc":"Manages the application state (model) and dispatches events to the application's\n`update/2` function. It also handles commands returned by `update/2`.","ref":"Raxol.Core.Runtime.Events.Dispatcher.html"},{"type":"function","title":"Raxol.Core.Runtime.Events.Dispatcher.broadcast/2","doc":"Broadcasts an event payload to all subscribers of a topic.","ref":"Raxol.Core.Runtime.Events.Dispatcher.html#broadcast/2"},{"type":"function","title":"Raxol.Core.Runtime.Events.Dispatcher.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Core.Runtime.Events.Dispatcher.html#child_spec/1"},{"type":"function","title":"Raxol.Core.Runtime.Events.Dispatcher.dispatch_event/2","doc":"Dispatches an event to the appropriate handler based on event type and target.\n\nReturns `{:ok, updated_state}` if the event was successfully handled,\nor `{:error, reason, state}` if something went wrong.","ref":"Raxol.Core.Runtime.Events.Dispatcher.html#dispatch_event/2"},{"type":"function","title":"Raxol.Core.Runtime.Events.Dispatcher.handle_event/2","doc":"Handles an application-level event and updates the application state.\n\nThis is typically used for user interaction events like keyboard or mouse input.","ref":"Raxol.Core.Runtime.Events.Dispatcher.html#handle_event/2"},{"type":"function","title":"Raxol.Core.Runtime.Events.Dispatcher.process_system_event/2","doc":"Processes a system-level event that affects the runtime itself rather than\nthe application logic.\n\nExamples include terminal resize events, focus events, or quit requests.","ref":"Raxol.Core.Runtime.Events.Dispatcher.html#process_system_event/2"},{"type":"function","title":"Raxol.Core.Runtime.Events.Dispatcher.start_link/2","doc":"","ref":"Raxol.Core.Runtime.Events.Dispatcher.html#start_link/2"},{"type":"function","title":"Raxol.Core.Runtime.Events.Dispatcher.subscribe/1","doc":"Subscribes the calling process to a specific event topic.","ref":"Raxol.Core.Runtime.Events.Dispatcher.html#subscribe/1"},{"type":"function","title":"Raxol.Core.Runtime.Events.Dispatcher.unsubscribe/1","doc":"Unsubscribes the calling process from a specific event topic.","ref":"Raxol.Core.Runtime.Events.Dispatcher.html#unsubscribe/1"},{"type":"module","title":"Raxol.Core.Runtime.Events.Handlers","doc":"Manages event handlers registration and execution in the Raxol system.\n\nThis module is responsible for:\n* Registering event handlers for specific event types\n* Executing handlers when events occur\n* Managing the priority and order of handlers","ref":"Raxol.Core.Runtime.Events.Handlers.html"},{"type":"function","title":"Raxol.Core.Runtime.Events.Handlers.execute_handlers/2","doc":"Executes all registered handlers for the given event.\n\nHandlers are executed in priority order (lowest to highest).\nEach handler can transform the event for the next handler.","ref":"Raxol.Core.Runtime.Events.Handlers.html#execute_handlers/2"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Events.Handlers.execute_handlers/2","doc":"- `event`: The event to handle\n- `state`: The current application state","ref":"Raxol.Core.Runtime.Events.Handlers.html#execute_handlers/2-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Events.Handlers.execute_handlers/2","doc":"`{:ok, updated_event, updated_state}` if all handlers executed successfully,\n`{:error, reason, state}` if a handler failed.","ref":"Raxol.Core.Runtime.Events.Handlers.html#execute_handlers/2-returns"},{"type":"function","title":"Raxol.Core.Runtime.Events.Handlers.register_handler/4","doc":"Registers a new event handler for the specified event types.","ref":"Raxol.Core.Runtime.Events.Handlers.html#register_handler/4"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Events.Handlers.register_handler/4","doc":"- `handler_id`: Unique identifier for the handler\n- `event_types`: List of event types the handler should receive\n- `handler_fun`: Function to call when an event occurs\n- `options`: Additional options for handler registration\n  - `:priority` - Handler priority (default: 100, lower numbers run first)\n  - `:filter` - Optional filter function to determine if events should be handled","ref":"Raxol.Core.Runtime.Events.Handlers.html#register_handler/4-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Events.Handlers.register_handler/4","doc":"`{:ok, handler_id}` if registration succeeded,\n`{:error, reason}` otherwise.","ref":"Raxol.Core.Runtime.Events.Handlers.html#register_handler/4-returns"},{"type":"function","title":"Raxol.Core.Runtime.Events.Handlers.unregister_handler/1","doc":"Unregisters an event handler.","ref":"Raxol.Core.Runtime.Events.Handlers.html#unregister_handler/1"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Events.Handlers.unregister_handler/1","doc":"- `handler_id`: ID of the handler to remove","ref":"Raxol.Core.Runtime.Events.Handlers.html#unregister_handler/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Events.Handlers.unregister_handler/1","doc":"`:ok` if the handler was removed,\n`{:error, :not_found}` if the handler wasn't registered.","ref":"Raxol.Core.Runtime.Events.Handlers.html#unregister_handler/1-returns"},{"type":"module","title":"Raxol.Core.Runtime.Events.Keyboard","doc":"Handles keyboard event processing in the Raxol system.\n\nThis module is responsible for:\n* Processing keyboard events\n* Handling special key combinations\n* Converting keyboard events to application messages","ref":"Raxol.Core.Runtime.Events.Keyboard.html"},{"type":"function","title":"Raxol.Core.Runtime.Events.Keyboard.check_shortcuts/2","doc":"Checks if a key combination matches any of the application's registered shortcuts.","ref":"Raxol.Core.Runtime.Events.Keyboard.html#check_shortcuts/2"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Events.Keyboard.check_shortcuts/2","doc":"- `event`: The keyboard event to check\n- `shortcuts`: Map of registered shortcuts","ref":"Raxol.Core.Runtime.Events.Keyboard.html#check_shortcuts/2-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Events.Keyboard.check_shortcuts/2","doc":"`{:ok, action}` if a match is found, `:none` otherwise.","ref":"Raxol.Core.Runtime.Events.Keyboard.html#check_shortcuts/2-returns"},{"type":"function","title":"Raxol.Core.Runtime.Events.Keyboard.convert_to_message/1","doc":"Converts a keyboard event to an application message.","ref":"Raxol.Core.Runtime.Events.Keyboard.html#convert_to_message/1"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Events.Keyboard.convert_to_message/1","doc":"- `event`: The keyboard event to convert","ref":"Raxol.Core.Runtime.Events.Keyboard.html#convert_to_message/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Events.Keyboard.convert_to_message/1","doc":"A message that can be understood by the application's update function.","ref":"Raxol.Core.Runtime.Events.Keyboard.html#convert_to_message/1-returns"},{"type":"function","title":"Raxol.Core.Runtime.Events.Keyboard.process_keyboard_event/2","doc":"Processes a keyboard event and determines if it should be handled by the application\nor if it's a system-level command.","ref":"Raxol.Core.Runtime.Events.Keyboard.html#process_keyboard_event/2"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Events.Keyboard.process_keyboard_event/2","doc":"- `event`: The keyboard event to process\n- `state`: The current application state","ref":"Raxol.Core.Runtime.Events.Keyboard.html#process_keyboard_event/2-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Events.Keyboard.process_keyboard_event/2","doc":"`{:system, command, state}` if it's a system command,\n`{:application, event, state}` if it should be handled by the application,\n`{:ignore, state}` if the event should be ignored.","ref":"Raxol.Core.Runtime.Events.Keyboard.html#process_keyboard_event/2-returns"},{"type":"module","title":"Raxol.Core.Runtime.Lifecycle","doc":"Manages the application lifecycle, including startup, shutdown, and terminal interaction.","ref":"Raxol.Core.Runtime.Lifecycle.html"},{"type":"function","title":"Raxol.Core.Runtime.Lifecycle.handle_cleanup/1","doc":"Cleans up resources when an application is shutting down.","ref":"Raxol.Core.Runtime.Lifecycle.html#handle_cleanup/1"},{"type":"function","title":"Raxol.Core.Runtime.Lifecycle.handle_error/2","doc":"Handles errors during application execution.\n\nLogs the error and attempts to recover if possible.","ref":"Raxol.Core.Runtime.Lifecycle.html#handle_error/2"},{"type":"function","title":"Raxol.Core.Runtime.Lifecycle.init/1","doc":"","ref":"Raxol.Core.Runtime.Lifecycle.html#init/1"},{"type":"function","title":"Raxol.Core.Runtime.Lifecycle.initialize_environment/1","doc":"Initializes the appropriate environment (TTY or VS Code) based on the runtime options.","ref":"Raxol.Core.Runtime.Lifecycle.html#initialize_environment/1"},{"type":"function","title":"Raxol.Core.Runtime.Lifecycle.lookup_app/1","doc":"Looks up an application by name.\n\nReturns `{:ok, pid}` if the application is found, `:error` otherwise.","ref":"Raxol.Core.Runtime.Lifecycle.html#lookup_app/1"},{"type":"function","title":"Raxol.Core.Runtime.Lifecycle.register_application/2","doc":"Registers an application with the registry.","ref":"Raxol.Core.Runtime.Lifecycle.html#register_application/2"},{"type":"function","title":"Raxol.Core.Runtime.Lifecycle.start_application/2","doc":"Starts a Raxol application with the given module and options.","ref":"Raxol.Core.Runtime.Lifecycle.html#start_application/2"},{"type":"function","title":"Options - Raxol.Core.Runtime.Lifecycle.start_application/2","doc":"* `:title` - The window title (default: \"Raxol Application\")\n  * `:fps` - Frames per second (default: 60)\n  * `:quit_keys` - List of keys that will quit the application (default: [:ctrl_c])\n  * `:debug` - Enable debug mode (default: false)\n  * `:width` - Terminal width (default: 80)\n  * `:height` - Terminal height (default: 24)","ref":"Raxol.Core.Runtime.Lifecycle.html#start_application/2-options"},{"type":"function","title":"Raxol.Core.Runtime.Lifecycle.stop_application/1","doc":"Stops a running application.\n\nReturns `:ok` if the application was stopped successfully,\n`{:error, :app_not_running}` if the application is not running.","ref":"Raxol.Core.Runtime.Lifecycle.html#stop_application/1"},{"type":"module","title":"Raxol.Core.Runtime.Plugins.API","doc":"Public API for Raxol plugins to interact with the core system.\n\nThis module provides standardized interfaces for plugins to:\n- Register event handlers\n- Access runtime services\n- Register commands\n- Access rendering capabilities\n- Modify application state in approved ways\n\nPlugin developers should only use these API functions for interacting with\nthe Raxol system to ensure forward compatibility when the internal system changes.","ref":"Raxol.Core.Runtime.Plugins.API.html"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.API.broadcast/2","doc":"Broadcast an event to all subscribers.","ref":"Raxol.Core.Runtime.Plugins.API.html#broadcast/2"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Plugins.API.broadcast/2","doc":"- `event_type` - The type of event to broadcast\n- `payload` - Data to include with the event","ref":"Raxol.Core.Runtime.Plugins.API.html#broadcast/2-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Plugins.API.broadcast/2","doc":"- `:ok` if broadcast was successful","ref":"Raxol.Core.Runtime.Plugins.API.html#broadcast/2-returns"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.API.get_config/2","doc":"Get the current application configuration.","ref":"Raxol.Core.Runtime.Plugins.API.html#get_config/2"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Plugins.API.get_config/2","doc":"- `key` - The configuration key to retrieve\n- `default` - Default value if the key is not found","ref":"Raxol.Core.Runtime.Plugins.API.html#get_config/2-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Plugins.API.get_config/2","doc":"The configuration value or default","ref":"Raxol.Core.Runtime.Plugins.API.html#get_config/2-returns"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.API.log/3","doc":"Log a message from a plugin.","ref":"Raxol.Core.Runtime.Plugins.API.html#log/3"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Plugins.API.log/3","doc":"- `plugin_id` - The ID of the plugin\n- `level` - Log level (:debug, :info, :warn, :error)\n- `message` - The message to log","ref":"Raxol.Core.Runtime.Plugins.API.html#log/3-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Plugins.API.log/3","doc":"`:ok`","ref":"Raxol.Core.Runtime.Plugins.API.html#log/3-returns"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.API.plugin_data_dir/1","doc":"Get the path to the plugin data directory.","ref":"Raxol.Core.Runtime.Plugins.API.html#plugin_data_dir/1"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Plugins.API.plugin_data_dir/1","doc":"- `plugin_id` - The ID of the plugin","ref":"Raxol.Core.Runtime.Plugins.API.html#plugin_data_dir/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Plugins.API.plugin_data_dir/1","doc":"String path to the plugin's data directory","ref":"Raxol.Core.Runtime.Plugins.API.html#plugin_data_dir/1-returns"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.API.register_command/4","doc":"Register a command that can be executed from the terminal.","ref":"Raxol.Core.Runtime.Plugins.API.html#register_command/4"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Plugins.API.register_command/4","doc":"- `command_name` - String name of the command\n- `handler` - Module that will handle the command\n- `help_text` - Description of the command for help documentation\n- `options` - Additional options for the command","ref":"Raxol.Core.Runtime.Plugins.API.html#register_command/4-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Plugins.API.register_command/4","doc":"- `:ok` if command was registered\n- `{:error, reason}` if registration failed","ref":"Raxol.Core.Runtime.Plugins.API.html#register_command/4-returns"},{"type":"function","title":"Example - Raxol.Core.Runtime.Plugins.API.register_command/4","doc":"```elixir\nAPI.register_command(\"myplugin:hello\", MyPlugin.Commands,\n  \"Displays a hello message from myplugin\")\n```","ref":"Raxol.Core.Runtime.Plugins.API.html#register_command/4-example"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.API.subscribe/3","doc":"Subscribe to runtime events.","ref":"Raxol.Core.Runtime.Plugins.API.html#subscribe/3"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Plugins.API.subscribe/3","doc":"- `event_type` - The type of event to subscribe to\n- `handler` - Module that will handle the event\n- `function` - Function in the handler module that will be called (default: :handle_event)","ref":"Raxol.Core.Runtime.Plugins.API.html#subscribe/3-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Plugins.API.subscribe/3","doc":"- `:ok` if successful\n- `{:error, reason}` if subscription failed","ref":"Raxol.Core.Runtime.Plugins.API.html#subscribe/3-returns"},{"type":"function","title":"Example - Raxol.Core.Runtime.Plugins.API.subscribe/3","doc":"```elixir\nAPI.subscribe(:key_press, MyPluginHandlers)\n```","ref":"Raxol.Core.Runtime.Plugins.API.html#subscribe/3-example"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.API.unregister_command/1","doc":"Unregister a previously registered command.","ref":"Raxol.Core.Runtime.Plugins.API.html#unregister_command/1"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Plugins.API.unregister_command/1","doc":"- `command_name` - String name of the command to unregister","ref":"Raxol.Core.Runtime.Plugins.API.html#unregister_command/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Plugins.API.unregister_command/1","doc":"- `:ok` if command was unregistered\n- `{:error, reason}` if unregistration failed","ref":"Raxol.Core.Runtime.Plugins.API.html#unregister_command/1-returns"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.API.unsubscribe/2","doc":"Unsubscribe from runtime events.","ref":"Raxol.Core.Runtime.Plugins.API.html#unsubscribe/2"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Plugins.API.unsubscribe/2","doc":"- `event_type` - The type of event to unsubscribe from\n- `handler` - Module to unsubscribe","ref":"Raxol.Core.Runtime.Plugins.API.html#unsubscribe/2-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Plugins.API.unsubscribe/2","doc":"- `:ok` if successful\n- `{:error, reason}` if unsubscription failed","ref":"Raxol.Core.Runtime.Plugins.API.html#unsubscribe/2-returns"},{"type":"module","title":"Raxol.Core.Runtime.Plugins.CommandHelper","doc":"Handles plugin command registration and dispatch for the Plugin Manager.","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.html"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.CommandHelper.find_plugin_for_command/4","doc":"Finds the plugin responsible for handling a command.\n\nUses the CommandRegistry to look up the command by name and optional namespace.\nReturns `{:ok, module, function, arity} | :not_found`.","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.html#find_plugin_for_command/4"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.CommandHelper.handle_command/5","doc":"Handles the dispatching of a command to the appropriate plugin.\n\nThis function is called by the Manager's `handle_cast`.\nIt finds the plugin, calls its command handler, and returns an updated\nplugin state map or an error indicator.\n\nReturns `{:ok, updated_plugin_states_map} | :not_found | {:error, reason}`.\nReplies are sent directly via `send/2` within this function.","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.html#handle_command/5"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.CommandHelper.register_plugin_commands/3","doc":"Registers the commands exposed by a plugin.\n\nCalls the plugin's `get_commands/1` or `get_commands/0` callback\nand registers them in the command table.","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.html#register_plugin_commands/3"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.CommandHelper.unregister_plugin_commands/2","doc":"Unregisters all commands associated with a specific plugin module.","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.html#unregister_plugin_commands/2"},{"type":"module","title":"Raxol.Core.Runtime.Plugins.CommandRegistry","doc":"Manages commands registered by plugins using an ETS table.\n\nProvides functions to register, unregister, and look up commands.","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html"},{"type":"type","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.command_entry/0","doc":"","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#t:command_entry/0"},{"type":"type","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.command_key/0","doc":"","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#t:command_key/0"},{"type":"type","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.command_name/0","doc":"","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#t:command_name/0"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.lookup_command/3","doc":"Looks up the handler {module, function, arity} for a command name and namespace.","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#lookup_command/3"},{"type":"type","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.namespace/0","doc":"","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#t:namespace/0"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.new/0","doc":"Creates a new ETS table for the command registry.\n\nReturns the name of the created table.","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#new/0"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.register_command/6","doc":"Registers a command provided by a plugin.\n\nArgs:\n  - `table`: The ETS table name.\n  - `command_name`: The name the command will be invoked by.\n  - `module`: The plugin module implementing the command.\n  - `function`: The function within the module to call.\n  - `arity`: The arity of the function.\n\nReturns `:ok` or `{:error, :already_registered}`.","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#register_command/6"},{"type":"type","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.table_name/0","doc":"","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#t:table_name/0"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.unregister_command/3","doc":"Unregisters a command.","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#unregister_command/3"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.unregister_commands_by_module/2","doc":"Unregisters all commands associated with a specific module.\n\nUseful when a plugin is unloaded.","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#unregister_commands_by_module/2"},{"type":"module","title":"Raxol.Core.Runtime.Plugins.Commands","doc":"Handles registration and execution of commands provided by plugins.\n\nThis module maintains a registry of commands provided by plugins and\nintegrates them with the main command execution system. It ensures that\nplugin commands are properly isolated and cannot interfere with core\nsystem functionality.","ref":"Raxol.Core.Runtime.Plugins.Commands.html"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Commands.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Core.Runtime.Plugins.Commands.html#child_spec/1"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Commands.execute/3","doc":"Execute a plugin command with the given arguments.","ref":"Raxol.Core.Runtime.Plugins.Commands.html#execute/3"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Plugins.Commands.execute/3","doc":"- `command_name` - The name of the command to execute\n- `args` - Arguments to pass to the command\n- `context` - Execution context for the command","ref":"Raxol.Core.Runtime.Plugins.Commands.html#execute/3-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Plugins.Commands.execute/3","doc":"- `{:ok, result}` if execution was successful\n- `{:error, reason}` if execution failed","ref":"Raxol.Core.Runtime.Plugins.Commands.html#execute/3-returns"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Commands.get_help/1","doc":"Get help text for a specific command.","ref":"Raxol.Core.Runtime.Plugins.Commands.html#get_help/1"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Plugins.Commands.get_help/1","doc":"- `command_name` - The name of the command","ref":"Raxol.Core.Runtime.Plugins.Commands.html#get_help/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Plugins.Commands.get_help/1","doc":"- `{:ok, help_text}` if command exists\n- `{:error, :not_found}` if command does not exist","ref":"Raxol.Core.Runtime.Plugins.Commands.html#get_help/1-returns"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Commands.handle_shutdown/2","doc":"","ref":"Raxol.Core.Runtime.Plugins.Commands.html#handle_shutdown/2"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Commands.list_commands/0","doc":"List all registered plugin commands.","ref":"Raxol.Core.Runtime.Plugins.Commands.html#list_commands/0"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Plugins.Commands.list_commands/0","doc":"Map with command names as keys and metadata as values","ref":"Raxol.Core.Runtime.Plugins.Commands.html#list_commands/0-returns"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Commands.register/4","doc":"Register a new command provided by a plugin.","ref":"Raxol.Core.Runtime.Plugins.Commands.html#register/4"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Plugins.Commands.register/4","doc":"- `command_name` - The name of the command (should be prefixed with plugin namespace)\n- `handler` - Module that will handle the command\n- `help_text` - Help text to display for the command\n- `options` - Additional options for command registration","ref":"Raxol.Core.Runtime.Plugins.Commands.html#register/4-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Plugins.Commands.register/4","doc":"- `:ok` if command was registered\n- `{:error, :already_registered}` if command name is already in use\n- `{:error, reason}` for other errors","ref":"Raxol.Core.Runtime.Plugins.Commands.html#register/4-returns"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Commands.start_link/1","doc":"Start the plugin commands registry.","ref":"Raxol.Core.Runtime.Plugins.Commands.html#start_link/1"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Commands.unregister/1","doc":"Unregister a previously registered command.","ref":"Raxol.Core.Runtime.Plugins.Commands.html#unregister/1"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Plugins.Commands.unregister/1","doc":"- `command_name` - The name of the command to unregister","ref":"Raxol.Core.Runtime.Plugins.Commands.html#unregister/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Plugins.Commands.unregister/1","doc":"- `:ok` if command was unregistered\n- `{:error, :not_found}` if command was not registered","ref":"Raxol.Core.Runtime.Plugins.Commands.html#unregister/1-returns"},{"type":"module","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper","doc":"Handles plugin lifecycle operations (loading, unloading, reloading) for the Plugin Manager.","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.html"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.check_dependencies/3","doc":"Checks if all dependencies for a plugin are met by the currently loaded plugins.\nReturns `:ok` or `{:error, :missing_dependencies, missing_list}`.","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.html#check_dependencies/3"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.find_plugin_id_by_module/2","doc":"","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.html#find_plugin_id_by_module/2"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.initialize_plugins/6","doc":"Discovers, sorts, and loads all plugins from the default directory.\n\nAccepts the initial Manager state maps and returns the updated maps (including `plugin_paths`) after loading,\nor an error tuple if discovery, sorting, or loading fails.\n\nReturns `{:ok, %{...updated_maps..., plugin_paths: map()}} | {:error, reason}`","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.html#initialize_plugins/6"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.load_plugin/8","doc":"Loads a plugin by its ID (string) or module (atom).\n\nAccepts the current plugin state maps and config, returns updated maps or an error.\nReturns `{:ok, %{plugins: map(), metadata: map(), plugin_states: map(), load_order: list(), plugin_config: map()}} | {:error, reason}`.","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.html#load_plugin/8"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.load_plugin_config/0","doc":"Loads plugin configuration (placeholder).","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.html#load_plugin_config/0"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.reload_plugin_from_disk/8","doc":"Reloads a plugin identified by its ID.\n\nHandles unloading and then loading again, potentially with code reloading.\nAccepts the current plugin state maps and config, returns updated maps or an error.\nRequires the `plugin_paths` map to find the source file.\nReturns `{:ok, %{...updated_maps...}} | {:error, reason}`.","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.html#reload_plugin_from_disk/8"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.sort_plugins/1","doc":"Sorts a list of plugin modules based on their declared dependencies.\n\nAccepts a list of `{plugin_module, plugin_metadata}` tuples.\nReturns `{:ok, sorted_plugin_modules}` or `{:error, :circular_dependency, cycle}`.\nUses a topological sort algorithm.","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.html#sort_plugins/1"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.unload_plugin/6","doc":"Unloads a plugin identified by its ID.\n\nAccepts the current plugin state maps, returns updated maps or an error.\nReturns `{:ok, %{plugins: map(), metadata: map(), plugin_states: map(), load_order: list()}} | {:error, reason}`.","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.html#unload_plugin/6"},{"type":"module","title":"Raxol.Core.Runtime.Plugins.Loader","doc":"Placeholder for the plugin loader.\nHandles loading plugin code and dependencies.","ref":"Raxol.Core.Runtime.Plugins.Loader.html"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Loader.discover_plugins/1","doc":"Discovers potential plugin modules in a given directory.\n\nScans for `.ex` files and attempts to derive module names.\nReturns a list of `{potential_module_atom, file_path}` tuples.","ref":"Raxol.Core.Runtime.Plugins.Loader.html#discover_plugins/1"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Loader.extract_metadata/1","doc":"Extracts metadata for a given plugin module.\n\nChecks if the plugin implements `Raxol.Core.Runtime.Plugins.PluginMetadataProvider`.\nIf so, it calls `get_metadata/0` on the module.\nOtherwise, it returns a default metadata map derived from the module name.","ref":"Raxol.Core.Runtime.Plugins.Loader.html#extract_metadata/1"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Loader.load_code/1","doc":"Ensures the code for a given plugin module is loaded.\nReturns `:ok` or `{:error, :module_not_found}`.","ref":"Raxol.Core.Runtime.Plugins.Loader.html#load_code/1"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Loader.load_plugin/2","doc":"Loads a plugin module based on its ID.\n\nAssumes the plugin ID corresponds to an existing module atom.\nReturns the module atom, placeholder metadata, and config.","ref":"Raxol.Core.Runtime.Plugins.Loader.html#load_plugin/2"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Loader.module_to_default_id/1","doc":"","ref":"Raxol.Core.Runtime.Plugins.Loader.html#module_to_default_id/1"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Loader.sort_plugins/1","doc":"Sorts plugins based on dependencies (Placeholder).\n\nCurrently returns the input list unsorted.\nRequires metadata extraction to be implemented first for actual sorting.\nReturns `{:ok, sorted_plugin_ids}` or `{:error, reason}`.","ref":"Raxol.Core.Runtime.Plugins.Loader.html#sort_plugins/1"},{"type":"module","title":"Raxol.Core.Runtime.Plugins.Manager","doc":"Manages the loading, initialization, and lifecycle of plugins in the Raxol runtime.\n\nThis module is responsible for:\n- Discovering available plugins\n- Loading and initializing plugins\n- Managing plugin lifecycle events\n- Providing access to loaded plugins\n- Handling plugin dependencies and conflicts","ref":"Raxol.Core.Runtime.Plugins.Manager.html"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Manager.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Core.Runtime.Plugins.Manager.html#child_spec/1"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Manager.disable_plugin/1","doc":"Disable a plugin temporarily without unloading it.","ref":"Raxol.Core.Runtime.Plugins.Manager.html#disable_plugin/1"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Manager.enable_plugin/1","doc":"Enable a plugin that was previously disabled.","ref":"Raxol.Core.Runtime.Plugins.Manager.html#enable_plugin/1"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Manager.filter_event/2","doc":"Placeholder for allowing plugins to filter events.","ref":"Raxol.Core.Runtime.Plugins.Manager.html#filter_event/2"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Manager.get_plugin/1","doc":"Get a specific plugin by its ID.","ref":"Raxol.Core.Runtime.Plugins.Manager.html#get_plugin/1"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Manager.initialize/0","doc":"Initialize the plugin system and load all available plugins.","ref":"Raxol.Core.Runtime.Plugins.Manager.html#initialize/0"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Manager.list_plugins/0","doc":"Get a list of all loaded plugins with their metadata.","ref":"Raxol.Core.Runtime.Plugins.Manager.html#list_plugins/0"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Manager.load_plugin/2","doc":"Load a plugin with a given configuration.","ref":"Raxol.Core.Runtime.Plugins.Manager.html#load_plugin/2"},{"type":"type","title":"Raxol.Core.Runtime.Plugins.Manager.plugin_id/0","doc":"","ref":"Raxol.Core.Runtime.Plugins.Manager.html#t:plugin_id/0"},{"type":"type","title":"Raxol.Core.Runtime.Plugins.Manager.plugin_metadata/0","doc":"","ref":"Raxol.Core.Runtime.Plugins.Manager.html#t:plugin_metadata/0"},{"type":"type","title":"Raxol.Core.Runtime.Plugins.Manager.plugin_state/0","doc":"","ref":"Raxol.Core.Runtime.Plugins.Manager.html#t:plugin_state/0"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Manager.reload_plugin/1","doc":"Reload a plugin by unloading and then loading it again.","ref":"Raxol.Core.Runtime.Plugins.Manager.html#reload_plugin/1"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Manager.start_link/1","doc":"Starts the plugin manager process.","ref":"Raxol.Core.Runtime.Plugins.Manager.html#start_link/1"},{"type":"behaviour","title":"Raxol.Core.Runtime.Plugins.Plugin","doc":"Defines the behaviour for Raxol plugins.\n\nPlugins must implement this behaviour to be loaded and managed by the PluginManager.","ref":"Raxol.Core.Runtime.Plugins.Plugin.html"},{"type":"type","title":"Raxol.Core.Runtime.Plugins.Plugin.command/0","doc":"","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#t:command/0"},{"type":"type","title":"Raxol.Core.Runtime.Plugins.Plugin.config/0","doc":"","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#t:config/0"},{"type":"callback","title":"Raxol.Core.Runtime.Plugins.Plugin.disable/1","doc":"Called when the plugin is disabled.\n\nShould return `{:ok, new_state}` or `{:error, reason}`.","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#c:disable/1"},{"type":"callback","title":"Raxol.Core.Runtime.Plugins.Plugin.enable/1","doc":"Called when the plugin is enabled after being disabled.\n\nShould return `{:ok, new_state}` or `{:error, reason}`.","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#c:enable/1"},{"type":"type","title":"Raxol.Core.Runtime.Plugins.Plugin.event/0","doc":"","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#t:event/0"},{"type":"callback","title":"Raxol.Core.Runtime.Plugins.Plugin.filter_event/2","doc":"Optional callback to filter or react to system events before they reach the application.\n\nReturn `{:ok, event}` to pass the event through (potentially modified).\nReturn `:halt` to stop the event from propagating further.\nReturn any other value to indicate an error.","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#c:filter_event/2"},{"type":"callback","title":"Raxol.Core.Runtime.Plugins.Plugin.get_commands/0","doc":"Optional callback to declare commands provided by the plugin.\n\nShould return a list of `{namespace, command_name, function_name, arity}` tuples.\nExample: `[{:my_plugin, :do_something, :handle_do_something_command, 2}]`\nThese will be registered in the CommandRegistry.","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#c:get_commands/0"},{"type":"callback","title":"Raxol.Core.Runtime.Plugins.Plugin.handle_command/3","doc":"Optional callback to handle commands delegated by the PluginManager.\n\nShould return `{:ok, new_state, result}` or `{:error, reason, new_state}`.\nThe `result` can be sent back to the original command requester if needed.","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#c:handle_command/3"},{"type":"callback","title":"Raxol.Core.Runtime.Plugins.Plugin.init/1","doc":"Called when the plugin is first initialized.\n\nShould return `{:ok, initial_state}` or `{:error, reason}`.\nThe `initial_state` will be managed by the PluginManager.","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#c:init/1"},{"type":"type","title":"Raxol.Core.Runtime.Plugins.Plugin.state/0","doc":"","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#t:state/0"},{"type":"callback","title":"Raxol.Core.Runtime.Plugins.Plugin.terminate/2","doc":"Called when the plugin is terminated (e.g., during shutdown or unload).\n\nAllows the plugin to perform cleanup. The return value is ignored.","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#c:terminate/2"},{"type":"behaviour","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider","doc":"Defines the behaviour for plugins that provide metadata like ID, version, and dependencies.\n\nPlugins can optionally implement this behaviour to declare their metadata,\nwhich the `PluginManager` uses for dependency resolution and management.","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.html"},{"type":"callback","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.get_metadata/0","doc":"Callback invoked by the `PluginManager` to retrieve the plugin's metadata.","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.html#c:get_metadata/0"},{"type":"type","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.metadata/0","doc":"Represents the metadata for a plugin.\n- `id`: A unique atom identifying the plugin (e.g., `:my_plugin`).\n- `version`: A string representing the plugin version (e.g., \"0.1.0\").\n- `dependencies`: A list of plugin IDs (atoms) that this plugin depends on.","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.html#t:metadata/0"},{"type":"module","title":"Raxol.Core.Runtime.Plugins.Registry","doc":"Placeholder for the plugin registry.\nManages information about loaded plugins.","ref":"Raxol.Core.Runtime.Plugins.Registry.html"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Registry.list_plugins/1","doc":"Placeholder for listing plugins.","ref":"Raxol.Core.Runtime.Plugins.Registry.html#list_plugins/1"},{"type":"function","title":"Raxol.Core.Runtime.Plugins.Registry.new/0","doc":"Creates a new, empty registry state.","ref":"Raxol.Core.Runtime.Plugins.Registry.html#new/0"},{"type":"module","title":"Raxol.Core.Runtime.Rendering.Buffer","doc":"Provides a screen buffer implementation for efficient rendering in Raxol applications.\n\nThis module is responsible for:\n* Maintaining the screen buffer state\n* Calculating diffs between buffer states\n* Optimizing rendering by only updating changed cells","ref":"Raxol.Core.Runtime.Rendering.Buffer.html"},{"type":"type","title":"Raxol.Core.Runtime.Rendering.Buffer.cell/0","doc":"A cell represents a single character position on the screen.\n\nIt is represented as a tuple with the following elements:\n- `x`: X coordinate (column)\n- `y`: Y coordinate (row)\n- `ch`: Character to display\n- `fg`: Foreground color\n- `bg`: Background color\n- `attrs`: List of attributes (e.g., :bold, :underline)","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#t:cell/0"},{"type":"function","title":"Raxol.Core.Runtime.Rendering.Buffer.clear/1","doc":"Clears the buffer by removing all cells.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#clear/1"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.clear/1","doc":"- `buffer`: The buffer to clear","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#clear/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.clear/1","doc":"Cleared buffer.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#clear/1-returns"},{"type":"function","title":"Raxol.Core.Runtime.Rendering.Buffer.diff/2","doc":"Computes the diff between two buffers.\n\nThe diff contains only the cells that need to be updated.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#diff/2"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.diff/2","doc":"- `old_buffer`: Previous buffer state\n- `new_buffer`: Current buffer state","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#diff/2-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.diff/2","doc":"List of changed cells.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#diff/2-returns"},{"type":"function","title":"Raxol.Core.Runtime.Rendering.Buffer.from_cells/3","doc":"Builds a buffer from a list of cells.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#from_cells/3"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.from_cells/3","doc":"- `cells`: List of cells\n- `width`: Width of the buffer in columns\n- `height`: Height of the buffer in rows","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#from_cells/3-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.from_cells/3","doc":"A new buffer containing the cells.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#from_cells/3-returns"},{"type":"function","title":"Raxol.Core.Runtime.Rendering.Buffer.get_cell/3","doc":"Gets the cell at the specified position.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#get_cell/3"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.get_cell/3","doc":"- `buffer`: The buffer to query\n- `x`: X coordinate\n- `y`: Y coordinate","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#get_cell/3-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.get_cell/3","doc":"The cell tuple if found, nil otherwise.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#get_cell/3-returns"},{"type":"function","title":"Raxol.Core.Runtime.Rendering.Buffer.merge/4","doc":"Merges another buffer's cells into this buffer.\n\nCells from the other buffer overwrite cells in this buffer.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#merge/4"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.merge/4","doc":"- `buffer`: The destination buffer\n- `other`: The source buffer\n- `offset_x`: X offset to apply when merging\n- `offset_y`: Y offset to apply when merging","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#merge/4-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.merge/4","doc":"Updated buffer.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#merge/4-returns"},{"type":"function","title":"Raxol.Core.Runtime.Rendering.Buffer.new/2","doc":"Creates a new empty buffer with the given dimensions.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#new/2"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.new/2","doc":"- `width`: Width of the buffer in columns\n- `height`: Height of the buffer in rows","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#new/2-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.new/2","doc":"A new buffer struct.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#new/2-returns"},{"type":"function","title":"Raxol.Core.Runtime.Rendering.Buffer.resize/3","doc":"Resizes the buffer to new dimensions.\n\nCells outside the new dimensions are discarded.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#resize/3"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.resize/3","doc":"- `buffer`: The buffer to resize\n- `width`: New width\n- `height`: New height","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#resize/3-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.resize/3","doc":"Resized buffer.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#resize/3-returns"},{"type":"function","title":"Raxol.Core.Runtime.Rendering.Buffer.set_cell/7","doc":"Sets a cell in the buffer.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#set_cell/7"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.set_cell/7","doc":"- `buffer`: The buffer to modify\n- `x`: X coordinate\n- `y`: Y coordinate\n- `ch`: Character\n- `fg`: Foreground color\n- `bg`: Background color\n- `attrs`: Attributes list","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#set_cell/7-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.set_cell/7","doc":"Updated buffer.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#set_cell/7-returns"},{"type":"type","title":"Raxol.Core.Runtime.Rendering.Buffer.t/0","doc":"A buffer is a map containing cells indexed by their position.\n\nThe buffer also contains metadata about its dimensions.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#t:t/0"},{"type":"function","title":"Raxol.Core.Runtime.Rendering.Buffer.to_cells/1","doc":"Converts the buffer to a flat list of cells.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#to_cells/1"},{"type":"function","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.to_cells/1","doc":"- `buffer`: The buffer to convert","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#to_cells/1-parameters"},{"type":"function","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.to_cells/1","doc":"List of cells.","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#to_cells/1-returns"},{"type":"module","title":"Raxol.Core.Runtime.Rendering.Engine","doc":"Provides the core rendering functionality for Raxol applications.\n\nThis module is responsible for:\n* Rendering application views into screen buffers\n* Managing the rendering lifecycle\n* Coordinating with the output backends","ref":"Raxol.Core.Runtime.Rendering.Engine.html"},{"type":"function","title":"Raxol.Core.Runtime.Rendering.Engine.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Core.Runtime.Rendering.Engine.html#child_spec/1"},{"type":"function","title":"Raxol.Core.Runtime.Rendering.Engine.start_link/1","doc":"Starts the Rendering Engine process.","ref":"Raxol.Core.Runtime.Rendering.Engine.html#start_link/1"},{"type":"module","title":"Raxol.Core.Runtime.Rendering.Scheduler","doc":"Manages the rendering schedule based on frame rate.","ref":"Raxol.Core.Runtime.Rendering.Scheduler.html"},{"type":"function","title":"Raxol.Core.Runtime.Rendering.Scheduler.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Core.Runtime.Rendering.Scheduler.html#child_spec/1"},{"type":"function","title":"Raxol.Core.Runtime.Rendering.Scheduler.disable/0","doc":"","ref":"Raxol.Core.Runtime.Rendering.Scheduler.html#disable/0"},{"type":"function","title":"Raxol.Core.Runtime.Rendering.Scheduler.enable/0","doc":"","ref":"Raxol.Core.Runtime.Rendering.Scheduler.html#enable/0"},{"type":"function","title":"Raxol.Core.Runtime.Rendering.Scheduler.set_interval/1","doc":"","ref":"Raxol.Core.Runtime.Rendering.Scheduler.html#set_interval/1"},{"type":"function","title":"Raxol.Core.Runtime.Rendering.Scheduler.start_link/1","doc":"","ref":"Raxol.Core.Runtime.Rendering.Scheduler.html#start_link/1"},{"type":"module","title":"Raxol.Core.Runtime.Subscription","doc":"Provides a way to subscribe to recurring updates and external events.\n\nSubscriptions allow applications to receive messages over time without\nexplicitly requesting them. This is useful for:\n* Timer-based updates (animation, polling)\n* System events (window resize, focus change)\n* External data streams (file changes, network events)","ref":"Raxol.Core.Runtime.Subscription.html"},{"type":"module","title":"Types of Subscriptions - Raxol.Core.Runtime.Subscription","doc":"* `:interval` - Regular time-based updates\n* `:events` - System or component events\n* `:file_watch` - File system changes\n* `:custom` - Custom event sources","ref":"Raxol.Core.Runtime.Subscription.html#module-types-of-subscriptions"},{"type":"module","title":"Examples - Raxol.Core.Runtime.Subscription","doc":"# Update every second\n    Subscription.interval(1000, :tick)\n\n    # Listen for specific events\n    Subscription.events([:key_press, :mouse_click])\n\n    # Watch a file for changes\n    Subscription.file_watch(\"config.json\", [:modify, :delete])\n\n    # Custom subscription\n    Subscription.custom(MyEventSource, :start_listening)","ref":"Raxol.Core.Runtime.Subscription.html#module-examples"},{"type":"function","title":"Raxol.Core.Runtime.Subscription.custom/2","doc":"Creates a custom subscription using a provided event source.\nThe event source should implement the `Raxol.Core.Runtime.EventSource`\nbehaviour.","ref":"Raxol.Core.Runtime.Subscription.html#custom/2"},{"type":"function","title":"Raxol.Core.Runtime.Subscription.events/1","doc":"Creates a subscription for system or component events.","ref":"Raxol.Core.Runtime.Subscription.html#events/1"},{"type":"function","title":"Event Types - Raxol.Core.Runtime.Subscription.events/1","doc":"* `:key_press` - Keyboard events\n  * `:mouse_click` - Mouse click events\n  * `:mouse_move` - Mouse movement events\n  * `:window_resize` - Terminal window resize\n  * `:focus_change` - Terminal focus change\n  * `:component` - Component-specific events","ref":"Raxol.Core.Runtime.Subscription.html#events/1-event-types"},{"type":"function","title":"Raxol.Core.Runtime.Subscription.file_watch/2","doc":"Creates a subscription that watches for file system changes.","ref":"Raxol.Core.Runtime.Subscription.html#file_watch/2"},{"type":"function","title":"Event Types - Raxol.Core.Runtime.Subscription.file_watch/2","doc":"* `:modify` - File content changes\n  * `:delete` - File deletion\n  * `:create` - File creation\n  * `:rename` - File rename\n  * `:attrib` - Attribute changes","ref":"Raxol.Core.Runtime.Subscription.html#file_watch/2-event-types"},{"type":"function","title":"Raxol.Core.Runtime.Subscription.interval/3","doc":"Creates a subscription that will send a message at regular intervals.","ref":"Raxol.Core.Runtime.Subscription.html#interval/3"},{"type":"function","title":"Options - Raxol.Core.Runtime.Subscription.interval/3","doc":"* `:start_immediately` - Send first message immediately (default: false)\n  * `:jitter` - Add random jitter to interval (default: 0)","ref":"Raxol.Core.Runtime.Subscription.html#interval/3-options"},{"type":"function","title":"Raxol.Core.Runtime.Subscription.new/2","doc":"Creates a new subscription. This is the low-level constructor, prefer using\nthe specific subscription constructors unless you need custom behavior.","ref":"Raxol.Core.Runtime.Subscription.html#new/2"},{"type":"function","title":"Raxol.Core.Runtime.Subscription.start/2","doc":"Starts a subscription within the given context. This is used by the runtime\nsystem and should not be called directly by applications.\n\nReturns `{:ok, subscription_id}` or `{:error, reason}`.","ref":"Raxol.Core.Runtime.Subscription.html#start/2"},{"type":"function","title":"Raxol.Core.Runtime.Subscription.stop/1","doc":"Stops a subscription. This is used by the runtime system and should not\nbe called directly by applications.","ref":"Raxol.Core.Runtime.Subscription.html#stop/1"},{"type":"type","title":"Raxol.Core.Runtime.Subscription.t/0","doc":"","ref":"Raxol.Core.Runtime.Subscription.html#t:t/0"},{"type":"module","title":"Raxol.Core.Runtime.Supervisor","doc":"Supervises the core runtime processes of a Raxol application.\n\nThis supervisor manages:\n* Application runtime\n* Event handlers\n* Render processes\n* State management\n* Plugin system","ref":"Raxol.Core.Runtime.Supervisor.html"},{"type":"function","title":"Raxol.Core.Runtime.Supervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Core.Runtime.Supervisor.html#child_spec/1"},{"type":"function","title":"Raxol.Core.Runtime.Supervisor.start_link/1","doc":"","ref":"Raxol.Core.Runtime.Supervisor.html#start_link/1"},{"type":"module","title":"Raxol.Core.UXRefinement","doc":"User experience refinement module for the Raxol terminal UI.\n\nThis module provides comprehensive UX features to enhance the terminal UI experience:\n\n* Focus Management - Track and manage focus across UI components\n* Keyboard Navigation - Enable intuitive keyboard navigation\n* Contextual Hints - Display helpful hints based on current context\n* Focus Indicators - Visual indicators for focused elements\n* Multi-level Hints - Basic, detailed, and examples for different help levels\n* Keyboard Shortcuts - Global and context-specific keyboard shortcuts\n* Accessibility Features - Screen reader support, high contrast, reduced motion, etc.\n\nAll features can be enabled or disabled individually to customize the UX to your needs.","ref":"Raxol.Core.UXRefinement.html"},{"type":"function","title":"Raxol.Core.UXRefinement.disable_feature/1","doc":"Disable a previously enabled UX refinement feature.","ref":"Raxol.Core.UXRefinement.html#disable_feature/1"},{"type":"function","title":"Parameters - Raxol.Core.UXRefinement.disable_feature/1","doc":"* `feature` - The feature to disable","ref":"Raxol.Core.UXRefinement.html#disable_feature/1-parameters"},{"type":"function","title":"Examples - Raxol.Core.UXRefinement.disable_feature/1","doc":"iex> UXRefinement.disable_feature(:hints)\n    :ok","ref":"Raxol.Core.UXRefinement.html#disable_feature/1-examples"},{"type":"function","title":"Raxol.Core.UXRefinement.enable_feature/2","doc":"Enable a UX refinement feature.\n\nAvailable features:\n\n* `:focus_management` - Enable focus tracking and management\n* `:keyboard_navigation` - Enable keyboard navigation\n* `:hints` - Enable contextual hints\n* `:focus_ring` - Enable visual focus indicators\n* `:accessibility` - Enable accessibility features\n* `:keyboard_shortcuts` - Enable keyboard shortcuts\n* `:events` - Enable event management system","ref":"Raxol.Core.UXRefinement.html#enable_feature/2"},{"type":"function","title":"Parameters - Raxol.Core.UXRefinement.enable_feature/2","doc":"* `feature` - The feature to enable\n* `opts` - Options for the feature","ref":"Raxol.Core.UXRefinement.html#enable_feature/2-parameters"},{"type":"function","title":"Examples - Raxol.Core.UXRefinement.enable_feature/2","doc":"iex> UXRefinement.enable_feature(:focus_management)\n    :ok\n\n    iex> UXRefinement.enable_feature(:accessibility, high_contrast: true)\n    :ok","ref":"Raxol.Core.UXRefinement.html#enable_feature/2-examples"},{"type":"function","title":"Raxol.Core.UXRefinement.feature_enabled?/1","doc":"Check if a UX refinement feature is enabled.","ref":"Raxol.Core.UXRefinement.html#feature_enabled?/1"},{"type":"function","title":"Parameters - Raxol.Core.UXRefinement.feature_enabled?/1","doc":"* `feature` - The feature to check","ref":"Raxol.Core.UXRefinement.html#feature_enabled?/1-parameters"},{"type":"function","title":"Examples - Raxol.Core.UXRefinement.feature_enabled?/1","doc":"iex> UXRefinement.feature_enabled?(:focus_management)\n    true","ref":"Raxol.Core.UXRefinement.html#feature_enabled?/1-examples"},{"type":"function","title":"Raxol.Core.UXRefinement.get_accessibility_metadata/1","doc":"Get accessibility metadata for a component.","ref":"Raxol.Core.UXRefinement.html#get_accessibility_metadata/1"},{"type":"function","title":"Raxol.Core.UXRefinement.get_component_hint/2","doc":"Get a specific hint level for a component.","ref":"Raxol.Core.UXRefinement.html#get_component_hint/2"},{"type":"function","title":"Parameters - Raxol.Core.UXRefinement.get_component_hint/2","doc":"* `component_id` - The ID of the component\n* `level` - The hint level to retrieve (`:basic`, `:detailed`, `:examples`)","ref":"Raxol.Core.UXRefinement.html#get_component_hint/2-parameters"},{"type":"function","title":"Examples - Raxol.Core.UXRefinement.get_component_hint/2","doc":"iex> UXRefinement.get_component_hint(\"search_button\", :detailed)\n    \"Search for content in the application using keywords\"","ref":"Raxol.Core.UXRefinement.html#get_component_hint/2-examples"},{"type":"function","title":"Raxol.Core.UXRefinement.get_component_shortcuts/1","doc":"Get shortcuts for a component.","ref":"Raxol.Core.UXRefinement.html#get_component_shortcuts/1"},{"type":"function","title":"Parameters - Raxol.Core.UXRefinement.get_component_shortcuts/1","doc":"* `component_id` - The ID of the component","ref":"Raxol.Core.UXRefinement.html#get_component_shortcuts/1-parameters"},{"type":"function","title":"Examples - Raxol.Core.UXRefinement.get_component_shortcuts/1","doc":"iex> UXRefinement.get_component_shortcuts(\"search_button\")\n    [{\"Enter\", \"Execute search\"}, {\"Alt+S\", \"Focus search\"}]","ref":"Raxol.Core.UXRefinement.html#get_component_shortcuts/1-examples"},{"type":"function","title":"Raxol.Core.UXRefinement.get_hint/1","doc":"Get the hint for a component.\n\nThis returns the basic hint by default. Use `get_component_hint/2` for\nmore detailed hints.","ref":"Raxol.Core.UXRefinement.html#get_hint/1"},{"type":"function","title":"Parameters - Raxol.Core.UXRefinement.get_hint/1","doc":"* `component_id` - The ID of the component","ref":"Raxol.Core.UXRefinement.html#get_hint/1-parameters"},{"type":"function","title":"Examples - Raxol.Core.UXRefinement.get_hint/1","doc":"iex> UXRefinement.get_hint(\"search_button\")\n    \"Search for content\"","ref":"Raxol.Core.UXRefinement.html#get_hint/1-examples"},{"type":"function","title":"Raxol.Core.UXRefinement.init/0","doc":"Initialize the UX refinement system.\n\nThis function sets up the basic infrastructure for UX refinement features.\nIt should be called before enabling any specific features.","ref":"Raxol.Core.UXRefinement.html#init/0"},{"type":"function","title":"Examples - Raxol.Core.UXRefinement.init/0","doc":"iex> UXRefinement.init()\n    :ok","ref":"Raxol.Core.UXRefinement.html#init/0-examples"},{"type":"function","title":"Raxol.Core.UXRefinement.register_component_hint/2","doc":"Register comprehensive hints for a component with multiple detail levels.","ref":"Raxol.Core.UXRefinement.html#register_component_hint/2"},{"type":"function","title":"Parameters - Raxol.Core.UXRefinement.register_component_hint/2","doc":"* `component_id` - The ID of the component\n* `hint_info` - Map containing different levels of hints and shortcuts","ref":"Raxol.Core.UXRefinement.html#register_component_hint/2-parameters"},{"type":"function","title":"Hint Info Structure - Raxol.Core.UXRefinement.register_component_hint/2","doc":"* `:basic` - Basic hint (shown by default)\n* `:detailed` - More detailed explanation\n* `:examples` - Examples of usage\n* `:shortcuts` - List of keyboard shortcuts for the component: `[{\"Ctrl+S\", \"Save\"}, ...]`","ref":"Raxol.Core.UXRefinement.html#register_component_hint/2-hint-info-structure"},{"type":"function","title":"Examples - Raxol.Core.UXRefinement.register_component_hint/2","doc":"iex> UXRefinement.register_component_hint(\"search_button\", %{\n    ...>   basic: \"Search for content\",\n    ...>   detailed: \"Search for content in the application using keywords\",\n    ...>   examples: \"Type keywords like 'settings' or 'help'\",\n    ...>   shortcuts: [\n    ...>     {\"Enter\", \"Execute search\"},\n    ...>     {\"Alt+S\", \"Focus search\"}\n    ...>   ]\n    ...> })\n    :ok","ref":"Raxol.Core.UXRefinement.html#register_component_hint/2-examples"},{"type":"function","title":"Raxol.Core.UXRefinement.register_hint/2","doc":"Register a hint for a component.","ref":"Raxol.Core.UXRefinement.html#register_hint/2"},{"type":"function","title":"Parameters - Raxol.Core.UXRefinement.register_hint/2","doc":"* `component_id` - The ID of the component\n* `hint` - The hint text","ref":"Raxol.Core.UXRefinement.html#register_hint/2-parameters"},{"type":"function","title":"Examples - Raxol.Core.UXRefinement.register_hint/2","doc":"iex> UXRefinement.register_hint(\"search_button\", \"Search for content\")\n    :ok","ref":"Raxol.Core.UXRefinement.html#register_hint/2-examples"},{"type":"module","title":"Raxol.Core.UserPreferences","doc":"Manages user preferences for the Raxol application.\n\nActs as a GenServer holding the preferences state and handles persistence.","ref":"Raxol.Core.UserPreferences.html"},{"type":"function","title":"Raxol.Core.UserPreferences.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Core.UserPreferences.html#child_spec/1"},{"type":"function","title":"Raxol.Core.UserPreferences.get/1","doc":"Gets a user preference value by key path.\n\nAccepts a single key or a list of keys for nested access.","ref":"Raxol.Core.UserPreferences.html#get/1"},{"type":"function","title":"Examples - Raxol.Core.UserPreferences.get/1","doc":"UserPreferences.get(:theme) #=> \"dark\"\n    UserPreferences.get([:accessibility, :high_contrast]) #=> true","ref":"Raxol.Core.UserPreferences.html#get/1-examples"},{"type":"function","title":"Raxol.Core.UserPreferences.get_all/0","doc":"Retrieves the entire preferences map.","ref":"Raxol.Core.UserPreferences.html#get_all/0"},{"type":"function","title":"Raxol.Core.UserPreferences.save!/0","doc":"Forces an immediate save of the current preferences.","ref":"Raxol.Core.UserPreferences.html#save!/0"},{"type":"function","title":"Raxol.Core.UserPreferences.set/2","doc":"Sets a user preference value by key path.\n\nAccepts a single key or a list of keys for nested access.\nTriggers an automatic save after a short delay.","ref":"Raxol.Core.UserPreferences.html#set/2"},{"type":"function","title":"Examples - Raxol.Core.UserPreferences.set/2","doc":"UserPreferences.set(:theme, \"light\")\n    UserPreferences.set([:accessibility, :high_contrast], false)","ref":"Raxol.Core.UserPreferences.html#set/2-examples"},{"type":"function","title":"Raxol.Core.UserPreferences.start_link/1","doc":"","ref":"Raxol.Core.UserPreferences.html#start_link/1"},{"type":"module","title":"Raxol.Core.UserPreferences.State","doc":"Internal state for the UserPreferences GenServer.","ref":"Raxol.Core.UserPreferences.State.html"},{"type":"module","title":"Raxol.Database","doc":"Provides a safe interface for database operations.\n\nThis module:\n- Wraps all database operations with retry logic\n- Provides convenience functions for common database operations\n- Handles database errors gracefully","ref":"Raxol.Database.html"},{"type":"function","title":"Raxol.Database.all/2","doc":"Gets all records of a schema with retry logic.","ref":"Raxol.Database.html#all/2"},{"type":"function","title":"Parameters - Raxol.Database.all/2","doc":"- `schema` - The schema module\n- `clauses` - Optional where clauses","ref":"Raxol.Database.html#all/2-parameters"},{"type":"function","title":"Returns - Raxol.Database.all/2","doc":"- `{:ok, records}` - Records found\n- `{:error, reason}` - Query failed","ref":"Raxol.Database.html#all/2-returns"},{"type":"function","title":"Raxol.Database.create/2","doc":"Creates a record with retry logic.","ref":"Raxol.Database.html#create/2"},{"type":"function","title":"Parameters - Raxol.Database.create/2","doc":"- `schema` - The schema module\n- `attrs` - The attributes for the new record","ref":"Raxol.Database.html#create/2-parameters"},{"type":"function","title":"Returns - Raxol.Database.create/2","doc":"- `{:ok, record}` - Record created\n- `{:error, changeset}` - Validation failed\n- `{:error, reason}` - Query failed","ref":"Raxol.Database.html#create/2-returns"},{"type":"function","title":"Raxol.Database.delete/1","doc":"Deletes a record with retry logic.","ref":"Raxol.Database.html#delete/1"},{"type":"function","title":"Parameters - Raxol.Database.delete/1","doc":"- `record` - The record to delete","ref":"Raxol.Database.html#delete/1-parameters"},{"type":"function","title":"Returns - Raxol.Database.delete/1","doc":"- `{:ok, record}` - Record deleted\n- `{:error, changeset}` - Deletion validation failed\n- `{:error, reason}` - Query failed","ref":"Raxol.Database.html#delete/1-returns"},{"type":"function","title":"Raxol.Database.get/2","doc":"Gets a record by ID with retry logic.","ref":"Raxol.Database.html#get/2"},{"type":"function","title":"Parameters - Raxol.Database.get/2","doc":"- `schema` - The schema module\n- `id` - The record ID","ref":"Raxol.Database.html#get/2-parameters"},{"type":"function","title":"Returns - Raxol.Database.get/2","doc":"- `{:ok, record}` - Record found\n- `{:error, :not_found}` - Record not found\n- `{:error, reason}` - Query failed","ref":"Raxol.Database.html#get/2-returns"},{"type":"function","title":"Raxol.Database.healthy?/0","doc":"Checks if the database connection is healthy.","ref":"Raxol.Database.html#healthy?/0"},{"type":"function","title":"Returns - Raxol.Database.healthy?/0","doc":"- `true` - Connection is healthy\n- `false` - Connection is unhealthy","ref":"Raxol.Database.html#healthy?/0-returns"},{"type":"function","title":"Raxol.Database.restart_connection/0","doc":"Restarts the database connection if it becomes unhealthy.","ref":"Raxol.Database.html#restart_connection/0"},{"type":"function","title":"Returns - Raxol.Database.restart_connection/0","doc":"- `:ok` - Connection restart attempted","ref":"Raxol.Database.html#restart_connection/0-returns"},{"type":"function","title":"Raxol.Database.safe_query/1","doc":"Safely executes a database query with retry logic.","ref":"Raxol.Database.html#safe_query/1"},{"type":"function","title":"Parameters - Raxol.Database.safe_query/1","doc":"- `fun` - Function containing database operations","ref":"Raxol.Database.html#safe_query/1-parameters"},{"type":"function","title":"Returns - Raxol.Database.safe_query/1","doc":"- `{:ok, result}` - Operation succeeded\n- `{:error, reason}` - Operation failed after retries","ref":"Raxol.Database.html#safe_query/1-returns"},{"type":"function","title":"Raxol.Database.transaction/1","doc":"Executes a transaction with retry logic.","ref":"Raxol.Database.html#transaction/1"},{"type":"function","title":"Parameters - Raxol.Database.transaction/1","doc":"- `fun` - Function containing transaction operations","ref":"Raxol.Database.html#transaction/1-parameters"},{"type":"function","title":"Returns - Raxol.Database.transaction/1","doc":"- `{:ok, result}` - Transaction succeeded\n- `{:error, reason}` - Transaction failed","ref":"Raxol.Database.html#transaction/1-returns"},{"type":"function","title":"Raxol.Database.update/3","doc":"Updates a record with retry logic.","ref":"Raxol.Database.html#update/3"},{"type":"function","title":"Parameters - Raxol.Database.update/3","doc":"- `schema` - The schema module\n- `record` - The record to update\n- `attrs` - The new attributes","ref":"Raxol.Database.html#update/3-parameters"},{"type":"function","title":"Returns - Raxol.Database.update/3","doc":"- `{:ok, record}` - Record updated\n- `{:error, changeset}` - Validation failed\n- `{:error, reason}` - Query failed","ref":"Raxol.Database.html#update/3-returns"},{"type":"module","title":"Raxol.Database.ConnectionManager","doc":"Manages database connections and provides retry logic for Postgres errors.\n\nThis module:\n- Handles graceful connection retries\n- Monitors database connection health\n- Provides tools for debugging connection issues","ref":"Raxol.Database.ConnectionManager.html"},{"type":"function","title":"Raxol.Database.ConnectionManager.ensure_connection/0","doc":"Ensures the database connection is reset after application crash.\n\nThis function should be called during application startup.","ref":"Raxol.Database.ConnectionManager.html#ensure_connection/0"},{"type":"function","title":"Raxol.Database.ConnectionManager.healthy?/0","doc":"Checks if the database connection is healthy.","ref":"Raxol.Database.ConnectionManager.html#healthy?/0"},{"type":"function","title":"Returns - Raxol.Database.ConnectionManager.healthy?/0","doc":"- `true` - Connection is healthy\n- `false` - Connection is unhealthy","ref":"Raxol.Database.ConnectionManager.html#healthy?/0-returns"},{"type":"function","title":"Raxol.Database.ConnectionManager.restart_connection/0","doc":"Forcibly restarts the database connection.","ref":"Raxol.Database.ConnectionManager.html#restart_connection/0"},{"type":"function","title":"Raxol.Database.ConnectionManager.with_retries/3","doc":"Attempts a database operation with retry logic.","ref":"Raxol.Database.ConnectionManager.html#with_retries/3"},{"type":"function","title":"Parameters - Raxol.Database.ConnectionManager.with_retries/3","doc":"- `operation` - A function that performs a database operation\n- `max_retries` - Maximum number of retry attempts (default: 5)\n- `retry_delay_ms` - Delay between retries in milliseconds (default: 1000)","ref":"Raxol.Database.ConnectionManager.html#with_retries/3-parameters"},{"type":"function","title":"Returns - Raxol.Database.ConnectionManager.with_retries/3","doc":"- `{:ok, result}` - Operation succeeded\n- `{:error, error}` - Operation failed after retries","ref":"Raxol.Database.ConnectionManager.html#with_retries/3-returns"},{"type":"module","title":"Raxol.Docs.ComponentCatalog","doc":"Visual component catalog for Raxol documentation.\n\nThis module provides a comprehensive catalog of all UI components\navailable in Raxol, with visual examples, code snippets, and interactive\ncustomization capabilities.\n\nFeatures:\n* Categorized components listing\n* Live examples with code snippets\n* Interactive property customization\n* Accessibility information\n* Related components suggestions\n* Search functionality","ref":"Raxol.Docs.ComponentCatalog.html"},{"type":"function","title":"Raxol.Docs.ComponentCatalog.generate_code_snippet/2","doc":"Generates code snippets for a component with the given properties.","ref":"Raxol.Docs.ComponentCatalog.html#generate_code_snippet/2"},{"type":"function","title":"Raxol.Docs.ComponentCatalog.get_accessibility_info/1","doc":"Gets accessibility information for a component.","ref":"Raxol.Docs.ComponentCatalog.html#get_accessibility_info/1"},{"type":"function","title":"Raxol.Docs.ComponentCatalog.get_category/1","doc":"Gets a specific category by ID.","ref":"Raxol.Docs.ComponentCatalog.html#get_category/1"},{"type":"function","title":"Raxol.Docs.ComponentCatalog.get_component/1","doc":"Gets a specific component by ID.","ref":"Raxol.Docs.ComponentCatalog.html#get_component/1"},{"type":"function","title":"Raxol.Docs.ComponentCatalog.get_usage_stats/0","doc":"Gets usage statistics for components.","ref":"Raxol.Docs.ComponentCatalog.html#get_usage_stats/0"},{"type":"function","title":"Raxol.Docs.ComponentCatalog.init/0","doc":"Initializes the component catalog.","ref":"Raxol.Docs.ComponentCatalog.html#init/0"},{"type":"function","title":"Raxol.Docs.ComponentCatalog.list_categories/0","doc":"Lists all component categories.","ref":"Raxol.Docs.ComponentCatalog.html#list_categories/0"},{"type":"function","title":"Raxol.Docs.ComponentCatalog.list_components/1","doc":"Lists all components in a specific category.","ref":"Raxol.Docs.ComponentCatalog.html#list_components/1"},{"type":"function","title":"Raxol.Docs.ComponentCatalog.render_example/3","doc":"Renders a component example.","ref":"Raxol.Docs.ComponentCatalog.html#render_example/3"},{"type":"function","title":"Raxol.Docs.ComponentCatalog.search/1","doc":"Searches for components based on a query.","ref":"Raxol.Docs.ComponentCatalog.html#search/1"},{"type":"function","title":"Raxol.Docs.ComponentCatalog.suggest_related_components/1","doc":"Suggests related components.","ref":"Raxol.Docs.ComponentCatalog.html#suggest_related_components/1"},{"type":"module","title":"Raxol.Docs.InteractiveTutorial","doc":"Interactive tutorial system for Raxol documentation.\n\nThis module provides a framework for creating and displaying interactive\ntutorials that guide users through Raxol features with hands-on examples\nand step-by-step instructions.\n\nFeatures:\n* Step-by-step guides with interactive examples\n* Progress tracking and bookmarking\n* Exercise validation\n* Contextual hints and help\n* Integration with documentation","ref":"Raxol.Docs.InteractiveTutorial.html"},{"type":"function","title":"Raxol.Docs.InteractiveTutorial.bookmark/1","doc":"Bookmarks the current position in a tutorial.","ref":"Raxol.Docs.InteractiveTutorial.html#bookmark/1"},{"type":"function","title":"Raxol.Docs.InteractiveTutorial.export_progress/0","doc":"Exports a user's progress for saving.","ref":"Raxol.Docs.InteractiveTutorial.html#export_progress/0"},{"type":"function","title":"Raxol.Docs.InteractiveTutorial.get_current_position/0","doc":"Gets the current tutorial and step.","ref":"Raxol.Docs.InteractiveTutorial.html#get_current_position/0"},{"type":"function","title":"Raxol.Docs.InteractiveTutorial.get_hint/1","doc":"Gets a hint for the current exercise.","ref":"Raxol.Docs.InteractiveTutorial.html#get_hint/1"},{"type":"function","title":"Raxol.Docs.InteractiveTutorial.goto_bookmark/1","doc":"Returns to a bookmarked position.","ref":"Raxol.Docs.InteractiveTutorial.html#goto_bookmark/1"},{"type":"function","title":"Raxol.Docs.InteractiveTutorial.import_progress/1","doc":"Imports saved progress.","ref":"Raxol.Docs.InteractiveTutorial.html#import_progress/1"},{"type":"function","title":"Raxol.Docs.InteractiveTutorial.init/0","doc":"Initializes the tutorial system.","ref":"Raxol.Docs.InteractiveTutorial.html#init/0"},{"type":"function","title":"Raxol.Docs.InteractiveTutorial.list_bookmarks/0","doc":"Lists all bookmarks.","ref":"Raxol.Docs.InteractiveTutorial.html#list_bookmarks/0"},{"type":"function","title":"Raxol.Docs.InteractiveTutorial.list_tutorials/0","doc":"Returns a list of all available tutorials.","ref":"Raxol.Docs.InteractiveTutorial.html#list_tutorials/0"},{"type":"function","title":"Raxol.Docs.InteractiveTutorial.next_step/0","doc":"Goes to the next step in the current tutorial.","ref":"Raxol.Docs.InteractiveTutorial.html#next_step/0"},{"type":"function","title":"Raxol.Docs.InteractiveTutorial.previous_step/0","doc":"Goes to the previous step in the current tutorial.","ref":"Raxol.Docs.InteractiveTutorial.html#previous_step/0"},{"type":"function","title":"Raxol.Docs.InteractiveTutorial.register_tutorial/2","doc":"Registers a new tutorial.","ref":"Raxol.Docs.InteractiveTutorial.html#register_tutorial/2"},{"type":"function","title":"Raxol.Docs.InteractiveTutorial.start_tutorial/1","doc":"Starts a tutorial by ID.","ref":"Raxol.Docs.InteractiveTutorial.html#start_tutorial/1"},{"type":"type","title":"Raxol.Docs.InteractiveTutorial.step_id/0","doc":"","ref":"Raxol.Docs.InteractiveTutorial.html#t:step_id/0"},{"type":"type","title":"Raxol.Docs.InteractiveTutorial.tutorial_id/0","doc":"","ref":"Raxol.Docs.InteractiveTutorial.html#t:tutorial_id/0"},{"type":"function","title":"Raxol.Docs.InteractiveTutorial.validate_exercise/1","doc":"Validates the current exercise.","ref":"Raxol.Docs.InteractiveTutorial.html#validate_exercise/1"},{"type":"module","title":"Raxol.DynamicSupervisor","doc":"A dynamic supervisor for dynamically starting Raxol application processes.","ref":"Raxol.DynamicSupervisor.html"},{"type":"function","title":"Raxol.DynamicSupervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.DynamicSupervisor.html#child_spec/1"},{"type":"function","title":"Raxol.DynamicSupervisor.start_link/1","doc":"","ref":"Raxol.DynamicSupervisor.html#start_link/1"},{"type":"module","title":"Raxol.Examples.AccessibilityDemo","doc":"Demo of accessibility features in Raxol. (Refactored to use Application behaviour)\n\nThis example demonstrates:\n- Screen reader announcements\n- High contrast mode\n- Keyboard navigation with focus management\n- Reduced motion\n- Comprehensive hints\n- Large text support\n- Theme integration","ref":"Raxol.Examples.AccessibilityDemo.html"},{"type":"function","title":"Raxol.Examples.AccessibilityDemo.batch/1","doc":"","ref":"Raxol.Examples.AccessibilityDemo.html#batch/1"},{"type":"function","title":"Raxol.Examples.AccessibilityDemo.command/1","doc":"","ref":"Raxol.Examples.AccessibilityDemo.html#command/1"},{"type":"function","title":"Raxol.Examples.AccessibilityDemo.handle_event/2","doc":"","ref":"Raxol.Examples.AccessibilityDemo.html#handle_event/2"},{"type":"function","title":"Raxol.Examples.AccessibilityDemo.subscribe/1","doc":"","ref":"Raxol.Examples.AccessibilityDemo.html#subscribe/1"},{"type":"function","title":"Raxol.Examples.AccessibilityDemo.subscribe_interval/2","doc":"","ref":"Raxol.Examples.AccessibilityDemo.html#subscribe_interval/2"},{"type":"function","title":"Raxol.Examples.AccessibilityDemo.subscribe_to_events/1","doc":"","ref":"Raxol.Examples.AccessibilityDemo.html#subscribe_to_events/1"},{"type":"module","title":"Raxol.Examples.Button","doc":"A sample button component that demonstrates various testable features.\n\nThis component includes:\n- Click handling\n- Disabled state\n- Visual styling\n- Responsive layout\n- Theme support","ref":"Raxol.Examples.Button.html"},{"type":"function","title":"Raxol.Examples.Button.broadcast/1","doc":"","ref":"Raxol.Examples.Button.html#broadcast/1"},{"type":"function","title":"Raxol.Examples.Button.command/1","doc":"","ref":"Raxol.Examples.Button.html#command/1"},{"type":"function","title":"Raxol.Examples.Button.mount/1","doc":"","ref":"Raxol.Examples.Button.html#mount/1"},{"type":"function","title":"Raxol.Examples.Button.schedule/2","doc":"","ref":"Raxol.Examples.Button.html#schedule/2"},{"type":"type","title":"Raxol.Examples.Button.state/0","doc":"","ref":"Raxol.Examples.Button.html#t:state/0"},{"type":"function","title":"Raxol.Examples.Button.unmount/1","doc":"","ref":"Raxol.Examples.Button.html#unmount/1"},{"type":"module","title":"Raxol.Examples.ColorSystemDemo","doc":"Demonstrates the color system capabilities using the Application behaviour.","ref":"Raxol.Examples.ColorSystemDemo.html"},{"type":"function","title":"Raxol.Examples.ColorSystemDemo.batch/1","doc":"","ref":"Raxol.Examples.ColorSystemDemo.html#batch/1"},{"type":"function","title":"Raxol.Examples.ColorSystemDemo.command/1","doc":"","ref":"Raxol.Examples.ColorSystemDemo.html#command/1"},{"type":"function","title":"Raxol.Examples.ColorSystemDemo.handle_event/2","doc":"","ref":"Raxol.Examples.ColorSystemDemo.html#handle_event/2"},{"type":"function","title":"Raxol.Examples.ColorSystemDemo.run/0","doc":"Starts the Color System Demo application.","ref":"Raxol.Examples.ColorSystemDemo.html#run/0"},{"type":"function","title":"Raxol.Examples.ColorSystemDemo.subscribe/1","doc":"","ref":"Raxol.Examples.ColorSystemDemo.html#subscribe/1"},{"type":"function","title":"Raxol.Examples.ColorSystemDemo.subscribe_interval/2","doc":"","ref":"Raxol.Examples.ColorSystemDemo.html#subscribe_interval/2"},{"type":"function","title":"Raxol.Examples.ColorSystemDemo.subscribe_to_events/1","doc":"","ref":"Raxol.Examples.ColorSystemDemo.html#subscribe_to_events/1"},{"type":"module","title":"Raxol.Examples.Form","doc":"A sample form component that demonstrates parent-child interactions.\n\nThis component includes:\n- Child component management\n- Event bubbling\n- State synchronization\n- Error boundaries","ref":"Raxol.Examples.Form.html"},{"type":"function","title":"Raxol.Examples.Form.batch/1","doc":"","ref":"Raxol.Examples.Form.html#batch/1"},{"type":"function","title":"Raxol.Examples.Form.command/1","doc":"","ref":"Raxol.Examples.Form.html#command/1"},{"type":"function","title":"Raxol.Examples.Form.subscribe/1","doc":"","ref":"Raxol.Examples.Form.html#subscribe/1"},{"type":"function","title":"Raxol.Examples.Form.subscribe_interval/2","doc":"","ref":"Raxol.Examples.Form.html#subscribe_interval/2"},{"type":"function","title":"Raxol.Examples.Form.subscribe_to_events/1","doc":"","ref":"Raxol.Examples.Form.html#subscribe_to_events/1"},{"type":"module","title":"Raxol.Examples.IntegratedAccessibilityDemo","doc":"An integrated demo showcasing Raxol's accessibility features working together\nwith color system, animation framework, and internationalization.","ref":"Raxol.Examples.IntegratedAccessibilityDemo.html"},{"type":"module","title":"Raxol.Examples.KeyboardShortcutsDemo","doc":"","ref":"Raxol.Examples.KeyboardShortcutsDemo.html"},{"type":"function","title":"Raxol.Examples.KeyboardShortcutsDemo.batch/1","doc":"","ref":"Raxol.Examples.KeyboardShortcutsDemo.html#batch/1"},{"type":"function","title":"Raxol.Examples.KeyboardShortcutsDemo.command/1","doc":"","ref":"Raxol.Examples.KeyboardShortcutsDemo.html#command/1"},{"type":"function","title":"Raxol.Examples.KeyboardShortcutsDemo.subscribe/1","doc":"","ref":"Raxol.Examples.KeyboardShortcutsDemo.html#subscribe/1"},{"type":"function","title":"Raxol.Examples.KeyboardShortcutsDemo.subscribe_interval/2","doc":"","ref":"Raxol.Examples.KeyboardShortcutsDemo.html#subscribe_interval/2"},{"type":"function","title":"Raxol.Examples.KeyboardShortcutsDemo.subscribe_to_events/1","doc":"","ref":"Raxol.Examples.KeyboardShortcutsDemo.html#subscribe_to_events/1"},{"type":"module","title":"Raxol.Examples.TableDemo","doc":"Demonstrates the Table component using the Application behaviour.","ref":"Raxol.Examples.TableDemo.html"},{"type":"function","title":"Raxol.Examples.TableDemo.batch/1","doc":"","ref":"Raxol.Examples.TableDemo.html#batch/1"},{"type":"function","title":"Raxol.Examples.TableDemo.command/1","doc":"","ref":"Raxol.Examples.TableDemo.html#command/1"},{"type":"function","title":"Raxol.Examples.TableDemo.handle_event/2","doc":"","ref":"Raxol.Examples.TableDemo.html#handle_event/2"},{"type":"function","title":"Raxol.Examples.TableDemo.run/0","doc":"Starts the Table Demo application.","ref":"Raxol.Examples.TableDemo.html#run/0"},{"type":"function","title":"Raxol.Examples.TableDemo.subscribe/1","doc":"","ref":"Raxol.Examples.TableDemo.html#subscribe/1"},{"type":"function","title":"Raxol.Examples.TableDemo.subscribe_interval/2","doc":"","ref":"Raxol.Examples.TableDemo.html#subscribe_interval/2"},{"type":"function","title":"Raxol.Examples.TableDemo.subscribe_to_events/1","doc":"","ref":"Raxol.Examples.TableDemo.html#subscribe_to_events/1"},{"type":"module","title":"Raxol.Examples.UXRefinementDemo","doc":"Demo example showcasing the User Experience Refinement components.\n\nThis example demonstrates:\n1. Focus management with keyboard navigation\n2. Contextual hints for different components\n3. Visual focus indication\n4. Accessibility support\n\nRun this example with:\n```\n$ mix run -e \"Raxol.Examples.UXRefinementDemo.run()\"\n```","ref":"Raxol.Examples.UXRefinementDemo.html"},{"type":"function","title":"Raxol.Examples.UXRefinementDemo.batch/1","doc":"","ref":"Raxol.Examples.UXRefinementDemo.html#batch/1"},{"type":"function","title":"Raxol.Examples.UXRefinementDemo.command/1","doc":"","ref":"Raxol.Examples.UXRefinementDemo.html#command/1"},{"type":"function","title":"Raxol.Examples.UXRefinementDemo.init/1","doc":"Initialize the application state and perform setup.","ref":"Raxol.Examples.UXRefinementDemo.html#init/1"},{"type":"function","title":"Raxol.Examples.UXRefinementDemo.run/0","doc":"Run the UX Refinement demo application.","ref":"Raxol.Examples.UXRefinementDemo.html#run/0"},{"type":"function","title":"Raxol.Examples.UXRefinementDemo.subscribe/1","doc":"","ref":"Raxol.Examples.UXRefinementDemo.html#subscribe/1"},{"type":"function","title":"Raxol.Examples.UXRefinementDemo.subscribe_interval/2","doc":"","ref":"Raxol.Examples.UXRefinementDemo.html#subscribe_interval/2"},{"type":"function","title":"Raxol.Examples.UXRefinementDemo.subscribe_to_events/1","doc":"","ref":"Raxol.Examples.UXRefinementDemo.html#subscribe_to_events/1"},{"type":"function","title":"Raxol.Examples.UXRefinementDemo.update/2","doc":"Update the application state based on events.","ref":"Raxol.Examples.UXRefinementDemo.html#update/2"},{"type":"function","title":"Raxol.Examples.UXRefinementDemo.view/1","doc":"Render the application UI.","ref":"Raxol.Examples.UXRefinementDemo.html#view/1"},{"type":"module","title":"Raxol.Metrics","doc":"Handles collection and management of system metrics.\n\nThis module is responsible for collecting and managing various system metrics\nincluding:\n- CPU usage\n- Memory usage\n- Active sessions\n- Database connections\n- Response times\n- Error rates","ref":"Raxol.Metrics.html"},{"type":"function","title":"Raxol.Metrics.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Metrics.html#child_spec/1"},{"type":"function","title":"Raxol.Metrics.gauge/2","doc":"Records a gauge metric value.","ref":"Raxol.Metrics.html#gauge/2"},{"type":"function","title":"Parameters - Raxol.Metrics.gauge/2","doc":"- name: The name of the metric\n- value: The value to record for the metric","ref":"Raxol.Metrics.html#gauge/2-parameters"},{"type":"function","title":"Examples - Raxol.Metrics.gauge/2","doc":"Raxol.Metrics.gauge(\"raxol.chart_render_time\", 42.5)","ref":"Raxol.Metrics.html#gauge/2-examples"},{"type":"function","title":"Raxol.Metrics.get_active_sessions/0","doc":"","ref":"Raxol.Metrics.html#get_active_sessions/0"},{"type":"function","title":"Raxol.Metrics.get_cpu_usage/0","doc":"","ref":"Raxol.Metrics.html#get_cpu_usage/0"},{"type":"function","title":"Raxol.Metrics.get_current_metrics/0","doc":"Returns the current metrics.\n\nReturns a map containing the current system metrics.","ref":"Raxol.Metrics.html#get_current_metrics/0"},{"type":"function","title":"Raxol.Metrics.get_memory_usage/0","doc":"","ref":"Raxol.Metrics.html#get_memory_usage/0"},{"type":"function","title":"Raxol.Metrics.increment/1","doc":"Increments a counter metric.","ref":"Raxol.Metrics.html#increment/1"},{"type":"function","title":"Parameters - Raxol.Metrics.increment/1","doc":"- name: The name of the metric to increment","ref":"Raxol.Metrics.html#increment/1-parameters"},{"type":"function","title":"Examples - Raxol.Metrics.increment/1","doc":"Raxol.Metrics.increment(\"raxol.chart_cache_hits\")","ref":"Raxol.Metrics.html#increment/1-examples"},{"type":"function","title":"Raxol.Metrics.init/1","doc":"","ref":"Raxol.Metrics.html#init/1"},{"type":"function","title":"Raxol.Metrics.start_link/1","doc":"","ref":"Raxol.Metrics.html#start_link/1"},{"type":"module","title":"Raxol.Metrics.Collector","doc":"Collects and stores performance metrics for the Raxol event system.\nWorks in conjunction with the Visualizer module to provide insights into system performance.","ref":"Raxol.Metrics.Collector.html"},{"type":"function","title":"Raxol.Metrics.Collector.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Metrics.Collector.html#child_spec/1"},{"type":"function","title":"Raxol.Metrics.Collector.get_metrics/0","doc":"","ref":"Raxol.Metrics.Collector.html#get_metrics/0"},{"type":"function","title":"Raxol.Metrics.Collector.record_event_timing/2","doc":"","ref":"Raxol.Metrics.Collector.html#record_event_timing/2"},{"type":"function","title":"Raxol.Metrics.Collector.record_memory_usage/0","doc":"","ref":"Raxol.Metrics.Collector.html#record_memory_usage/0"},{"type":"function","title":"Raxol.Metrics.Collector.record_throughput/1","doc":"","ref":"Raxol.Metrics.Collector.html#record_throughput/1"},{"type":"function","title":"Raxol.Metrics.Collector.start_link/1","doc":"","ref":"Raxol.Metrics.Collector.html#start_link/1"},{"type":"module","title":"Raxol.Metrics.Visualizer","doc":"Provides visualization capabilities for Raxol performance metrics.\nUses Contex to generate charts and graphs for various performance indicators.","ref":"Raxol.Metrics.Visualizer.html"},{"type":"function","title":"Raxol.Metrics.Visualizer.create_event_timing_chart/2","doc":"Creates a bar chart visualization for event processing times.","ref":"Raxol.Metrics.Visualizer.html#create_event_timing_chart/2"},{"type":"function","title":"Parameters - Raxol.Metrics.Visualizer.create_event_timing_chart/2","doc":"* data - List of {event_type, processing_time} tuples\n  * options - Optional configuration for the chart","ref":"Raxol.Metrics.Visualizer.html#create_event_timing_chart/2-parameters"},{"type":"function","title":"Raxol.Metrics.Visualizer.create_memory_usage_chart/2","doc":"Creates a line chart for memory usage trends.","ref":"Raxol.Metrics.Visualizer.html#create_memory_usage_chart/2"},{"type":"function","title":"Parameters - Raxol.Metrics.Visualizer.create_memory_usage_chart/2","doc":"* data - List of {timestamp, memory_usage} tuples\n  * options - Optional configuration for the chart","ref":"Raxol.Metrics.Visualizer.html#create_memory_usage_chart/2-parameters"},{"type":"function","title":"Raxol.Metrics.Visualizer.create_throughput_plot/2","doc":"Creates a scatter plot for event throughput over time.","ref":"Raxol.Metrics.Visualizer.html#create_throughput_plot/2"},{"type":"function","title":"Parameters - Raxol.Metrics.Visualizer.create_throughput_plot/2","doc":"* data - List of {timestamp, events_per_second} tuples\n  * options - Optional configuration for the chart","ref":"Raxol.Metrics.Visualizer.html#create_throughput_plot/2-parameters"},{"type":"module","title":"Raxol.Plugins.ClipboardPlugin","doc":"Plugin for clipboard operations in Raxol.","ref":"Raxol.Plugins.ClipboardPlugin.html"},{"type":"type","title":"Raxol.Plugins.ClipboardPlugin.t/0","doc":"","ref":"Raxol.Plugins.ClipboardPlugin.html#t:t/0"},{"type":"module","title":"Raxol.Plugins.HyperlinkPlugin","doc":"Plugin that detects URLs in terminal output and makes them clickable.","ref":"Raxol.Plugins.HyperlinkPlugin.html"},{"type":"type","title":"Raxol.Plugins.HyperlinkPlugin.t/0","doc":"","ref":"Raxol.Plugins.HyperlinkPlugin.html#t:t/0"},{"type":"module","title":"Raxol.Plugins.ImagePlugin","doc":"Plugin that enables displaying images in the terminal using the iTerm2 image protocol.\nSupports various image formats and provides options for image display.","ref":"Raxol.Plugins.ImagePlugin.html"},{"type":"type","title":"Raxol.Plugins.ImagePlugin.t/0","doc":"","ref":"Raxol.Plugins.ImagePlugin.html#t:t/0"},{"type":"module","title":"Raxol.Plugins.NotificationPlugin","doc":"Plugin that provides terminal notifications with configurable styles and behaviors.","ref":"Raxol.Plugins.NotificationPlugin.html"},{"type":"behaviour","title":"Raxol.Plugins.Plugin","doc":"Defines the behavior for Raxol terminal emulator plugins.\nPlugins can extend the terminal's functionality by implementing this behavior.","ref":"Raxol.Plugins.Plugin.html"},{"type":"callback","title":"Raxol.Plugins.Plugin.cleanup/1","doc":"","ref":"Raxol.Plugins.Plugin.html#c:cleanup/1"},{"type":"callback","title":"Raxol.Plugins.Plugin.get_api_version/0","doc":"Returns the plugin's API version.\nThis is used to check compatibility with the plugin manager.","ref":"Raxol.Plugins.Plugin.html#c:get_api_version/0"},{"type":"callback","title":"Raxol.Plugins.Plugin.get_dependencies/0","doc":"Returns the plugin's dependencies.\nEach dependency is a map with the following keys:\n- name: The name of the plugin\n- version: The version constraint (e.g., \">= 1.0.0\")\n- optional: Whether the dependency is optional (default: false)","ref":"Raxol.Plugins.Plugin.html#c:get_dependencies/0"},{"type":"callback","title":"Raxol.Plugins.Plugin.handle_cells/3","doc":"(Optional) Processes a cell, potentially a placeholder, before drawing.\n\nAllows plugins to identify specific cells (like placeholders) and replace them\nwith actual content (a list of cells) or generate commands (like escape sequences).","ref":"Raxol.Plugins.Plugin.html#c:handle_cells/3"},{"type":"callback","title":"Parameters - Raxol.Plugins.Plugin.handle_cells/3","doc":"- `cell` - The specific cell being processed. Can be a regular cell map\n           `%{x: _, y: _, char: _, ...}` or a special map like\n           `%{type: :placeholder, value: :image, bounds: ...}`.\n- `emulator_state` - The current state map of the `Runtime` GenServer.\n- `plugin_state` - The current internal state of the plugin itself.","ref":"Raxol.Plugins.Plugin.html#c:handle_cells/3-parameters"},{"type":"callback","title":"Returns - Raxol.Plugins.Plugin.handle_cells/3","doc":"- `{:ok, updated_plugin_state, replacement_cells, commands}`:\n  The plugin handled the cell. `replacement_cells` (a list of `{x,y,map}` tuples)\n  will replace the original `cell` in the render list. `commands` are executed.\n  `updated_plugin_state` is stored.\n- `{:cont, updated_plugin_state}`:\n  The plugin declined to handle this cell or handled it internally without replacing it.\n  The original cell is kept. `updated_plugin_state` is stored.\n  Allows other plugins to potentially process the same cell.","ref":"Raxol.Plugins.Plugin.html#c:handle_cells/3-returns"},{"type":"callback","title":"Raxol.Plugins.Plugin.handle_input/2","doc":"","ref":"Raxol.Plugins.Plugin.html#c:handle_input/2"},{"type":"callback","title":"Raxol.Plugins.Plugin.handle_mouse/3","doc":"","ref":"Raxol.Plugins.Plugin.html#c:handle_mouse/3"},{"type":"callback","title":"Raxol.Plugins.Plugin.handle_output/2","doc":"","ref":"Raxol.Plugins.Plugin.html#c:handle_output/2"},{"type":"callback","title":"Raxol.Plugins.Plugin.handle_render/1","doc":"Optional callback executed just before the terminal buffer is presented.\nAllows plugins to inject direct output commands (e.g., escape sequences).\n\nShould return:\n- `{:ok, updated_plugin_state, command_to_write}` - If state changes and command is output.\n- `{:ok, updated_plugin_state}` - If state changes but no command is output.\n- `command_to_write` - If only a command is output (state unchanged).\n- `:ok` - If nothing needs to be done.","ref":"Raxol.Plugins.Plugin.html#c:handle_render/1"},{"type":"callback","title":"Raxol.Plugins.Plugin.handle_resize/3","doc":"","ref":"Raxol.Plugins.Plugin.html#c:handle_resize/3"},{"type":"callback","title":"Raxol.Plugins.Plugin.init/1","doc":"","ref":"Raxol.Plugins.Plugin.html#c:init/1"},{"type":"type","title":"Raxol.Plugins.Plugin.t/0","doc":"","ref":"Raxol.Plugins.Plugin.html#t:t/0"},{"type":"module","title":"Raxol.Plugins.PluginConfig","doc":"Handles persistence of plugin configurations.\nStores and loads plugin configurations from disk.","ref":"Raxol.Plugins.PluginConfig.html"},{"type":"function","title":"Raxol.Plugins.PluginConfig.disable_plugin/2","doc":"Disables a plugin.","ref":"Raxol.Plugins.PluginConfig.html#disable_plugin/2"},{"type":"function","title":"Raxol.Plugins.PluginConfig.enable_plugin/2","doc":"Enables a plugin.","ref":"Raxol.Plugins.PluginConfig.html#enable_plugin/2"},{"type":"function","title":"Raxol.Plugins.PluginConfig.get_plugin_config/2","doc":"Gets the configuration for a specific plugin.","ref":"Raxol.Plugins.PluginConfig.html#get_plugin_config/2"},{"type":"function","title":"Raxol.Plugins.PluginConfig.is_plugin_enabled?/2","doc":"Checks if a plugin is enabled.","ref":"Raxol.Plugins.PluginConfig.html#is_plugin_enabled?/2"},{"type":"function","title":"Raxol.Plugins.PluginConfig.load/0","doc":"Loads plugin configurations from disk.","ref":"Raxol.Plugins.PluginConfig.html#load/0"},{"type":"function","title":"Raxol.Plugins.PluginConfig.new/0","doc":"Creates a new plugin configuration manager.","ref":"Raxol.Plugins.PluginConfig.html#new/0"},{"type":"function","title":"Raxol.Plugins.PluginConfig.save/1","doc":"Saves plugin configurations to disk.","ref":"Raxol.Plugins.PluginConfig.html#save/1"},{"type":"type","title":"Raxol.Plugins.PluginConfig.t/0","doc":"","ref":"Raxol.Plugins.PluginConfig.html#t:t/0"},{"type":"function","title":"Raxol.Plugins.PluginConfig.update_plugin_config/3","doc":"Updates the configuration for a specific plugin.","ref":"Raxol.Plugins.PluginConfig.html#update_plugin_config/3"},{"type":"module","title":"Raxol.Plugins.PluginDependency","doc":"Handles plugin dependency resolution and version compatibility checks.","ref":"Raxol.Plugins.PluginDependency.html"},{"type":"function","title":"Raxol.Plugins.PluginDependency.check_api_compatibility/2","doc":"Checks if a plugin's API version is compatible with the plugin manager.","ref":"Raxol.Plugins.PluginDependency.html#check_api_compatibility/2"},{"type":"function","title":"Raxol.Plugins.PluginDependency.check_dependencies/2","doc":"Checks if a plugin's dependencies are satisfied by the currently loaded plugins.","ref":"Raxol.Plugins.PluginDependency.html#check_dependencies/2"},{"type":"function","title":"Raxol.Plugins.PluginDependency.resolve_dependencies/1","doc":"Resolves plugin dependencies and returns a sorted list of plugins to load.\nThe list is sorted so that dependencies are loaded before the plugins that depend on them.","ref":"Raxol.Plugins.PluginDependency.html#resolve_dependencies/1"},{"type":"module","title":"Raxol.Plugins.PluginManager","doc":"Manages plugins for the Raxol terminal emulator.\nHandles plugin loading, lifecycle management, and event dispatching.","ref":"Raxol.Plugins.PluginManager.html"},{"type":"function","title":"Raxol.Plugins.PluginManager.disable_plugin/2","doc":"Disables a plugin by name.","ref":"Raxol.Plugins.PluginManager.html#disable_plugin/2"},{"type":"function","title":"Raxol.Plugins.PluginManager.enable_plugin/2","doc":"Enables a plugin by name.","ref":"Raxol.Plugins.PluginManager.html#enable_plugin/2"},{"type":"function","title":"Raxol.Plugins.PluginManager.get_api_version/1","doc":"Gets the current API version of the plugin manager.","ref":"Raxol.Plugins.PluginManager.html#get_api_version/1"},{"type":"function","title":"Raxol.Plugins.PluginManager.get_plugin/2","doc":"Gets a plugin by name.","ref":"Raxol.Plugins.PluginManager.html#get_plugin/2"},{"type":"function","title":"Raxol.Plugins.PluginManager.handle_cells/3","doc":"Allows plugins to process or replace cells generated by the renderer.\nIterates through enabled plugins that implement `handle_cells/3`.\nThe callback should return `{:ok, updated_plugin_state, cells_to_render, commands}`.\n\nReturns `{:ok, updated_manager, processed_cells, collected_commands}`.","ref":"Raxol.Plugins.PluginManager.html#handle_cells/3"},{"type":"function","title":"Raxol.Plugins.PluginManager.handle_key_event/3","doc":"Processes a keyboard event through all enabled plugins.\nPlugins can return commands and choose to halt propagation.\nReturns {:ok, updated_manager, list_of_commands, :propagate | :halt} or {:error, reason}.","ref":"Raxol.Plugins.PluginManager.html#handle_key_event/3"},{"type":"function","title":"Raxol.Plugins.PluginManager.handle_mouse_event/3","doc":"Processes a mouse event through all enabled plugins, providing cell context.\nPlugins can choose to halt propagation if they handle the event.\nReturns {:ok, updated_manager, :propagate | :halt} or {:error, reason}.","ref":"Raxol.Plugins.PluginManager.html#handle_mouse_event/3"},{"type":"function","title":"Raxol.Plugins.PluginManager.handle_resize/3","doc":"Notifies all enabled plugins of a terminal resize event.","ref":"Raxol.Plugins.PluginManager.html#handle_resize/3"},{"type":"function","title":"Raxol.Plugins.PluginManager.list_plugins/1","doc":"Gets a list of all loaded plugins.","ref":"Raxol.Plugins.PluginManager.html#list_plugins/1"},{"type":"function","title":"Raxol.Plugins.PluginManager.load_plugin/3","doc":"Loads a plugin module and initializes it with the given configuration.","ref":"Raxol.Plugins.PluginManager.html#load_plugin/3"},{"type":"function","title":"Raxol.Plugins.PluginManager.load_plugins/2","doc":"Loads multiple plugins in the correct dependency order.","ref":"Raxol.Plugins.PluginManager.html#load_plugins/2"},{"type":"function","title":"Raxol.Plugins.PluginManager.new/1","doc":"Creates a new plugin manager with default configuration.","ref":"Raxol.Plugins.PluginManager.html#new/1"},{"type":"function","title":"Raxol.Plugins.PluginManager.process_input/2","doc":"Processes input through all enabled plugins.","ref":"Raxol.Plugins.PluginManager.html#process_input/2"},{"type":"function","title":"Raxol.Plugins.PluginManager.process_mouse/3","doc":"Processes mouse events through all enabled plugins.","ref":"Raxol.Plugins.PluginManager.html#process_mouse/3"},{"type":"function","title":"Raxol.Plugins.PluginManager.process_output/2","doc":"Processes output through all enabled plugins.\nReturns {:ok, manager, transformed_output} if a plugin transforms the output,\nor {:ok, manager} if no transformation is needed.","ref":"Raxol.Plugins.PluginManager.html#process_output/2"},{"type":"function","title":"Raxol.Plugins.PluginManager.run_render_hooks/1","doc":"Runs render-related hooks for all enabled plugins.\nCollects any direct output commands (e.g., escape sequences) returned by plugins.\nReturns {:ok, updated_manager, list_of_output_commands}","ref":"Raxol.Plugins.PluginManager.html#run_render_hooks/1"},{"type":"type","title":"Raxol.Plugins.PluginManager.t/0","doc":"","ref":"Raxol.Plugins.PluginManager.html#t:t/0"},{"type":"function","title":"Raxol.Plugins.PluginManager.unload_plugin/2","doc":"Unloads a plugin by name.","ref":"Raxol.Plugins.PluginManager.html#unload_plugin/2"},{"type":"function","title":"Raxol.Plugins.PluginManager.update_plugin/3","doc":"Updates the state of a specific plugin within the manager.\nThe `update_fun` receives the current plugin state and should return the new state.","ref":"Raxol.Plugins.PluginManager.html#update_plugin/3"},{"type":"module","title":"Raxol.Plugins.SearchPlugin","doc":"Plugin for text search functionality.","ref":"Raxol.Plugins.SearchPlugin.html"},{"type":"function","title":"Raxol.Plugins.SearchPlugin.get_current_result/1","doc":"Gets the current search result.","ref":"Raxol.Plugins.SearchPlugin.html#get_current_result/1"},{"type":"function","title":"Raxol.Plugins.SearchPlugin.get_current_result_index/1","doc":"Gets the current result index.","ref":"Raxol.Plugins.SearchPlugin.html#get_current_result_index/1"},{"type":"function","title":"Raxol.Plugins.SearchPlugin.get_search_results/1","doc":"Gets the current search results.","ref":"Raxol.Plugins.SearchPlugin.html#get_search_results/1"},{"type":"function","title":"Raxol.Plugins.SearchPlugin.get_search_term/1","doc":"Gets the current search term.","ref":"Raxol.Plugins.SearchPlugin.html#get_search_term/1"},{"type":"function","title":"Raxol.Plugins.SearchPlugin.highlight_search_term/2","doc":"Highlights the search term in the given text.","ref":"Raxol.Plugins.SearchPlugin.html#highlight_search_term/2"},{"type":"type","title":"Raxol.Plugins.SearchPlugin.t/0","doc":"","ref":"Raxol.Plugins.SearchPlugin.html#t:t/0"},{"type":"module","title":"Raxol.Plugins.ThemePlugin","doc":"Plugin that manages terminal themes and color schemes.\nAllows users to apply predefined themes or create custom color schemes.","ref":"Raxol.Plugins.ThemePlugin.html"},{"type":"function","title":"Raxol.Plugins.ThemePlugin.change_theme/2","doc":"Changes the current theme to the specified theme name.","ref":"Raxol.Plugins.ThemePlugin.html#change_theme/2"},{"type":"function","title":"Raxol.Plugins.ThemePlugin.create_custom_theme/3","doc":"Creates a custom theme with the specified colors.","ref":"Raxol.Plugins.ThemePlugin.html#create_custom_theme/3"},{"type":"function","title":"Raxol.Plugins.ThemePlugin.disable/1","doc":"","ref":"Raxol.Plugins.ThemePlugin.html#disable/1"},{"type":"function","title":"Raxol.Plugins.ThemePlugin.enable/1","doc":"","ref":"Raxol.Plugins.ThemePlugin.html#enable/1"},{"type":"function","title":"Raxol.Plugins.ThemePlugin.get_name/1","doc":"","ref":"Raxol.Plugins.ThemePlugin.html#get_name/1"},{"type":"function","title":"Raxol.Plugins.ThemePlugin.get_theme/1","doc":"Gets the current theme.","ref":"Raxol.Plugins.ThemePlugin.html#get_theme/1"},{"type":"function","title":"Raxol.Plugins.ThemePlugin.is_enabled?/1","doc":"","ref":"Raxol.Plugins.ThemePlugin.html#is_enabled?/1"},{"type":"function","title":"Raxol.Plugins.ThemePlugin.list_themes/0","doc":"Gets a list of available themes.","ref":"Raxol.Plugins.ThemePlugin.html#list_themes/0"},{"type":"module","title":"Raxol.Plugins.Visualization.ChartRenderer","doc":"Handles rendering logic for chart visualizations within the VisualizationPlugin.","ref":"Raxol.Plugins.Visualization.ChartRenderer.html"},{"type":"function","title":"Raxol.Plugins.Visualization.ChartRenderer.render_chart_content/4","doc":"Public entry point for rendering chart content.\nHandles bounds checking, error handling, and calls the internal drawing logic.\nExpects bounds to be a map like %{width: w, height: h}.","ref":"Raxol.Plugins.Visualization.ChartRenderer.html#render_chart_content/4"},{"type":"module","title":"Raxol.Plugins.Visualization.DrawingUtils","doc":"Utility functions for drawing basic shapes and text onto a cell grid.\nUsed by visualization renderers.","ref":"Raxol.Plugins.Visualization.DrawingUtils.html"},{"type":"function","title":"Raxol.Plugins.Visualization.DrawingUtils.draw_box_borders/6","doc":"Draws box borders onto an existing grid.","ref":"Raxol.Plugins.Visualization.DrawingUtils.html#draw_box_borders/6"},{"type":"function","title":"Raxol.Plugins.Visualization.DrawingUtils.draw_box_with_text/2","doc":"Draws a simple box with optional text centered inside.\nReturns a grid of cells.\nExpects bounds map: %{width: w, height: h}.","ref":"Raxol.Plugins.Visualization.DrawingUtils.html#draw_box_with_text/2"},{"type":"function","title":"Raxol.Plugins.Visualization.DrawingUtils.draw_text/5","doc":"Draws text onto a grid at a specific coordinate.\nTruncates if text exceeds grid width.\nUses optional style.","ref":"Raxol.Plugins.Visualization.DrawingUtils.html#draw_text/5"},{"type":"function","title":"Raxol.Plugins.Visualization.DrawingUtils.draw_text_centered/3","doc":"Draws text centered horizontally on a specific row in the grid.\nTruncates text if it exceeds grid width.","ref":"Raxol.Plugins.Visualization.DrawingUtils.html#draw_text_centered/3"},{"type":"function","title":"Raxol.Plugins.Visualization.DrawingUtils.get_cell/3","doc":"Safely gets a cell from the grid.\nReturns nil if coordinates are out of bounds.","ref":"Raxol.Plugins.Visualization.DrawingUtils.html#get_cell/3"},{"type":"function","title":"Raxol.Plugins.Visualization.DrawingUtils.put_cell/4","doc":"Safely puts a cell into the grid (list of lists).\nHandles out-of-bounds coordinates gracefully (no-op).","ref":"Raxol.Plugins.Visualization.DrawingUtils.html#put_cell/4"},{"type":"module","title":"Raxol.Plugins.Visualization.ImageRenderer","doc":"Handles rendering logic for image placeholders within the VisualizationPlugin.\nCurrently provides a text placeholder, but intended for protocols like sixel or kitty.","ref":"Raxol.Plugins.Visualization.ImageRenderer.html"},{"type":"function","title":"Raxol.Plugins.Visualization.ImageRenderer.render_image_content/4","doc":"Public entry point for rendering image content.\nHandles bounds checking and calls the internal drawing logic.\nExpects bounds map: %{width: w, height: h}.","ref":"Raxol.Plugins.Visualization.ImageRenderer.html#render_image_content/4"},{"type":"module","title":"Raxol.Plugins.Visualization.TreemapRenderer","doc":"Handles rendering logic for treemap visualizations within the VisualizationPlugin.\nUses a squarified layout algorithm.","ref":"Raxol.Plugins.Visualization.TreemapRenderer.html"},{"type":"function","title":"Raxol.Plugins.Visualization.TreemapRenderer.render_treemap_content/4","doc":"Public entry point for rendering treemap content.\nHandles bounds checking, error handling, and calls the internal layout/drawing logic.\nExpects bounds map: %{width: w, height: h}.","ref":"Raxol.Plugins.Visualization.TreemapRenderer.html#render_treemap_content/4"},{"type":"module","title":"Raxol.Plugins.VisualizationPlugin","doc":"Plugin responsible for rendering visualization components like charts and treemaps.\nIt receives data structures from the view rendering pipeline and outputs\nactual terminal cells.","ref":"Raxol.Plugins.VisualizationPlugin.html"},{"type":"function","title":"Raxol.Plugins.VisualizationPlugin.get_commands/0","doc":"","ref":"Raxol.Plugins.VisualizationPlugin.html#get_commands/0"},{"type":"function","title":"Raxol.Plugins.VisualizationPlugin.handle_command/4","doc":"","ref":"Raxol.Plugins.VisualizationPlugin.html#handle_command/4"},{"type":"function","title":"Raxol.Plugins.VisualizationPlugin.handle_event/3","doc":"","ref":"Raxol.Plugins.VisualizationPlugin.html#handle_event/3"},{"type":"function","title":"Raxol.Plugins.VisualizationPlugin.handle_placeholder/3","doc":"","ref":"Raxol.Plugins.VisualizationPlugin.html#handle_placeholder/3"},{"type":"function","title":"Raxol.Plugins.VisualizationPlugin.terminate/3","doc":"","ref":"Raxol.Plugins.VisualizationPlugin.html#terminate/3"},{"type":"module","title":"Raxol.Renderer.Layout","doc":"Handles layout calculations for UI elements.\n\nThis module translates the logical layout (panels, rows, columns)\ninto absolute positions for rendering.","ref":"Raxol.Renderer.Layout.html"},{"type":"function","title":"Raxol.Renderer.Layout.apply_layout/2","doc":"Applies layout to a view, calculating absolute positions for all elements.","ref":"Raxol.Renderer.Layout.html#apply_layout/2"},{"type":"function","title":"Parameters - Raxol.Renderer.Layout.apply_layout/2","doc":"* `view` - The view to calculate layout for\n* `dimensions` - Terminal dimensions `%{width: w, height: h}`","ref":"Raxol.Renderer.Layout.html#apply_layout/2-parameters"},{"type":"function","title":"Returns - Raxol.Renderer.Layout.apply_layout/2","doc":"A list of positioned elements with absolute coordinates.","ref":"Raxol.Renderer.Layout.html#apply_layout/2-returns"},{"type":"module","title":"Raxol.Repo","doc":"","ref":"Raxol.Repo.html"},{"type":"function","title":"Raxol.Repo.aggregate/3","doc":"","ref":"Raxol.Repo.html#aggregate/3"},{"type":"function","title":"Raxol.Repo.aggregate/4","doc":"","ref":"Raxol.Repo.html#aggregate/4"},{"type":"function","title":"Raxol.Repo.all/2","doc":"","ref":"Raxol.Repo.html#all/2"},{"type":"function","title":"Raxol.Repo.checked_out?/0","doc":"","ref":"Raxol.Repo.html#checked_out?/0"},{"type":"function","title":"Raxol.Repo.checkout/2","doc":"","ref":"Raxol.Repo.html#checkout/2"},{"type":"function","title":"Raxol.Repo.child_spec/1","doc":"","ref":"Raxol.Repo.html#child_spec/1"},{"type":"function","title":"Raxol.Repo.config/0","doc":"","ref":"Raxol.Repo.html#config/0"},{"type":"function","title":"Raxol.Repo.custom_query/3","doc":"Executes raw SQL query with logging.\n\nThis adds better error handling and logging around raw SQL queries.","ref":"Raxol.Repo.html#custom_query/3"},{"type":"function","title":"Returns - Raxol.Repo.custom_query/3","doc":"* `{:ok, result}` - on success\n* `{:error, exception}` - on failure","ref":"Raxol.Repo.html#custom_query/3-returns"},{"type":"function","title":"Raxol.Repo.custom_query!/3","doc":"Executes raw SQL query with logging, raising on errors.\n\nThis adds better error handling and logging around raw SQL queries.","ref":"Raxol.Repo.html#custom_query!/3"},{"type":"function","title":"Raxol.Repo.default_options/1","doc":"","ref":"Raxol.Repo.html#default_options/1"},{"type":"function","title":"Raxol.Repo.delete/2","doc":"","ref":"Raxol.Repo.html#delete/2"},{"type":"function","title":"Raxol.Repo.delete!/2","doc":"","ref":"Raxol.Repo.html#delete!/2"},{"type":"function","title":"Raxol.Repo.delete_all/2","doc":"","ref":"Raxol.Repo.html#delete_all/2"},{"type":"function","title":"Raxol.Repo.disconnect_all/2","doc":"A convenience function for SQL-based repositories that forces all connections in the\npool to disconnect within the given interval.\n\nSee `Ecto.Adapters.SQL.disconnect_all/3` for more information.","ref":"Raxol.Repo.html#disconnect_all/2"},{"type":"function","title":"Raxol.Repo.exists?/2","doc":"","ref":"Raxol.Repo.html#exists?/2"},{"type":"function","title":"Raxol.Repo.explain/3","doc":"A convenience function for SQL-based repositories that executes an EXPLAIN statement or similar\ndepending on the adapter to obtain statistics for the given query.\n\nSee `Ecto.Adapters.SQL.explain/4` for more information.","ref":"Raxol.Repo.html#explain/3"},{"type":"function","title":"Raxol.Repo.get/3","doc":"","ref":"Raxol.Repo.html#get/3"},{"type":"function","title":"Raxol.Repo.get!/3","doc":"","ref":"Raxol.Repo.html#get!/3"},{"type":"function","title":"Raxol.Repo.get_by/3","doc":"","ref":"Raxol.Repo.html#get_by/3"},{"type":"function","title":"Raxol.Repo.get_by!/3","doc":"","ref":"Raxol.Repo.html#get_by!/3"},{"type":"function","title":"Raxol.Repo.get_dynamic_repo/0","doc":"","ref":"Raxol.Repo.html#get_dynamic_repo/0"},{"type":"function","title":"Raxol.Repo.in_transaction?/0","doc":"","ref":"Raxol.Repo.html#in_transaction?/0"},{"type":"function","title":"Raxol.Repo.init/2","doc":"Initializes the repository.","ref":"Raxol.Repo.html#init/2"},{"type":"function","title":"Overrides - Raxol.Repo.init/2","doc":"This function is called when the repo is started. It adds improved logging\naround database connection events.","ref":"Raxol.Repo.html#init/2-overrides"},{"type":"function","title":"Raxol.Repo.insert/2","doc":"","ref":"Raxol.Repo.html#insert/2"},{"type":"function","title":"Raxol.Repo.insert!/2","doc":"","ref":"Raxol.Repo.html#insert!/2"},{"type":"function","title":"Raxol.Repo.insert_all/3","doc":"","ref":"Raxol.Repo.html#insert_all/3"},{"type":"function","title":"Raxol.Repo.insert_or_update/2","doc":"","ref":"Raxol.Repo.html#insert_or_update/2"},{"type":"function","title":"Raxol.Repo.insert_or_update!/2","doc":"","ref":"Raxol.Repo.html#insert_or_update!/2"},{"type":"function","title":"Raxol.Repo.load/2","doc":"","ref":"Raxol.Repo.html#load/2"},{"type":"function","title":"Raxol.Repo.one/2","doc":"","ref":"Raxol.Repo.html#one/2"},{"type":"function","title":"Raxol.Repo.one!/2","doc":"","ref":"Raxol.Repo.html#one!/2"},{"type":"function","title":"Raxol.Repo.preload/3","doc":"","ref":"Raxol.Repo.html#preload/3"},{"type":"function","title":"Raxol.Repo.prepare_query/3","doc":"","ref":"Raxol.Repo.html#prepare_query/3"},{"type":"function","title":"Raxol.Repo.put_dynamic_repo/1","doc":"","ref":"Raxol.Repo.html#put_dynamic_repo/1"},{"type":"function","title":"Raxol.Repo.query/3","doc":"A convenience function for SQL-based repositories that executes the given query.\n\nSee `Ecto.Adapters.SQL.query/4` for more information.","ref":"Raxol.Repo.html#query/3"},{"type":"function","title":"Raxol.Repo.query!/3","doc":"A convenience function for SQL-based repositories that executes the given query.\n\nSee `Ecto.Adapters.SQL.query!/4` for more information.","ref":"Raxol.Repo.html#query!/3"},{"type":"function","title":"Raxol.Repo.query_many/3","doc":"A convenience function for SQL-based repositories that executes the given multi-result query.\n\nSee `Ecto.Adapters.SQL.query_many/4` for more information.","ref":"Raxol.Repo.html#query_many/3"},{"type":"function","title":"Raxol.Repo.query_many!/3","doc":"A convenience function for SQL-based repositories that executes the given multi-result query.\n\nSee `Ecto.Adapters.SQL.query_many!/4` for more information.","ref":"Raxol.Repo.html#query_many!/3"},{"type":"function","title":"Raxol.Repo.reload/2","doc":"","ref":"Raxol.Repo.html#reload/2"},{"type":"function","title":"Raxol.Repo.reload!/2","doc":"","ref":"Raxol.Repo.html#reload!/2"},{"type":"function","title":"Raxol.Repo.rollback/1","doc":"","ref":"Raxol.Repo.html#rollback/1"},{"type":"function","title":"Raxol.Repo.start_link/1","doc":"","ref":"Raxol.Repo.html#start_link/1"},{"type":"function","title":"Raxol.Repo.stop/1","doc":"","ref":"Raxol.Repo.html#stop/1"},{"type":"function","title":"Raxol.Repo.stream/2","doc":"","ref":"Raxol.Repo.html#stream/2"},{"type":"function","title":"Raxol.Repo.to_sql/2","doc":"A convenience function for SQL-based repositories that translates the given query to SQL.\n\nSee `Ecto.Adapters.SQL.to_sql/3` for more information.","ref":"Raxol.Repo.html#to_sql/2"},{"type":"function","title":"Raxol.Repo.transaction/2","doc":"","ref":"Raxol.Repo.html#transaction/2"},{"type":"function","title":"Raxol.Repo.update/2","doc":"","ref":"Raxol.Repo.html#update/2"},{"type":"function","title":"Raxol.Repo.update!/2","doc":"","ref":"Raxol.Repo.html#update!/2"},{"type":"function","title":"Raxol.Repo.update_all/3","doc":"","ref":"Raxol.Repo.html#update_all/3"},{"type":"module","title":"Raxol.Runtime.Supervisor","doc":"The main supervisor for the Raxol application runtime.\nManages core processes like Dispatcher, PluginManager, etc.","ref":"Raxol.Runtime.Supervisor.html"},{"type":"function","title":"Raxol.Runtime.Supervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Runtime.Supervisor.html#child_spec/1"},{"type":"function","title":"Raxol.Runtime.Supervisor.start_link/1","doc":"","ref":"Raxol.Runtime.Supervisor.html#start_link/1"},{"type":"module","title":"Raxol.Session","doc":"Session management module for handling terminal sessions.\n\nThis module provides functionality for:\n- Session creation and management\n- Session authentication\n- Session state tracking\n- Session cleanup","ref":"Raxol.Session.html"},{"type":"function","title":"Raxol.Session.authenticate_session/2","doc":"","ref":"Raxol.Session.html#authenticate_session/2"},{"type":"function","title":"Raxol.Session.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Session.html#child_spec/1"},{"type":"function","title":"Raxol.Session.cleanup_session/1","doc":"","ref":"Raxol.Session.html#cleanup_session/1"},{"type":"function","title":"Raxol.Session.create_session/1","doc":"","ref":"Raxol.Session.html#create_session/1"},{"type":"function","title":"Raxol.Session.get_session/1","doc":"","ref":"Raxol.Session.html#get_session/1"},{"type":"function","title":"Raxol.Session.start_link/1","doc":"","ref":"Raxol.Session.html#start_link/1"},{"type":"module","title":"Raxol.Style","doc":"Defines style properties for terminal UI elements.","ref":"Raxol.Style.html"},{"type":"function","title":"Raxol.Style.apply_component_specific/2","doc":"Apply component-specific styling.","ref":"Raxol.Style.html#apply_component_specific/2"},{"type":"function","title":"Raxol.Style.apply_responsive/3","doc":"Apply responsive styling based on terminal dimensions.","ref":"Raxol.Style.html#apply_responsive/3"},{"type":"function","title":"Raxol.Style.merge/2","doc":"Merges two styles, with the second overriding the first.","ref":"Raxol.Style.html#merge/2"},{"type":"function","title":"Raxol.Style.new/0","doc":"Creates a new style with default values.","ref":"Raxol.Style.html#new/0"},{"type":"function","title":"Raxol.Style.new/1","doc":"Creates a new style from a keyword list or map of attributes.","ref":"Raxol.Style.html#new/1"},{"type":"function","title":"Raxol.Style.resolve/2","doc":"Resolves a style definition against the current theme.","ref":"Raxol.Style.html#resolve/2"},{"type":"type","title":"Raxol.Style.t/0","doc":"","ref":"Raxol.Style.html#t:t/0"},{"type":"function","title":"Raxol.Style.to_ansi/1","doc":"Converts style properties to ANSI escape sequences (currently just numeric codes).","ref":"Raxol.Style.html#to_ansi/1"},{"type":"module","title":"Raxol.Style.Borders","doc":"Defines border properties for terminal UI elements.","ref":"Raxol.Style.Borders.html"},{"type":"function","title":"Raxol.Style.Borders.merge/2","doc":"Merges two border structs, with the second overriding the first.","ref":"Raxol.Style.Borders.html#merge/2"},{"type":"function","title":"Raxol.Style.Borders.new/0","doc":"Creates a new border with default values.","ref":"Raxol.Style.Borders.html#new/0"},{"type":"function","title":"Raxol.Style.Borders.new/1","doc":"Creates a new border with the specified values.","ref":"Raxol.Style.Borders.html#new/1"},{"type":"type","title":"Raxol.Style.Borders.t/0","doc":"","ref":"Raxol.Style.Borders.html#t:t/0"},{"type":"module","title":"Raxol.Style.Colors.Accessibility","doc":"Provides utilities for color accessibility, focusing on WCAG contrast.","ref":"Raxol.Style.Colors.Accessibility.html"},{"type":"function","title":"Raxol.Style.Colors.Accessibility.accessible_color_pair/2","doc":"Finds an accessible color pair (foreground/background) based on a base color and WCAG level.\n\nTries to find a contrasting color (black or white first) that meets the desired level.\n\nParameters:\n  - `base_color`: The Color struct or hex string to find a contrasting pair for.\n  - `level`: The minimum WCAG contrast ratio level (:aa or :aaa, defaults to :aa).\n\nReturns:\n  A tuple `{foreground_color, background_color}` where one is the `base_color`\n  and the other is a contrasting color (typically black or white) that meets the\n  specified `level`. Returns `nil` if no suitable pair is found immediately\n  (further logic might be needed for complex cases).","ref":"Raxol.Style.Colors.Accessibility.html#accessible_color_pair/2"},{"type":"function","title":"Raxol.Style.Colors.Accessibility.contrast_ratio/2","doc":"Calculates the contrast ratio between two colors according to WCAG guidelines.","ref":"Raxol.Style.Colors.Accessibility.html#contrast_ratio/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Accessibility.contrast_ratio/2","doc":"- `color1` - The first color (hex string or Color struct)\n- `color2` - The second color (hex string or Color struct)","ref":"Raxol.Style.Colors.Accessibility.html#contrast_ratio/2-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Accessibility.contrast_ratio/2","doc":"- A float representing the contrast ratio (1:1 to 21:1)","ref":"Raxol.Style.Colors.Accessibility.html#contrast_ratio/2-returns"},{"type":"function","title":"Examples - Raxol.Style.Colors.Accessibility.contrast_ratio/2","doc":"iex> Raxol.Style.Colors.Accessibility.contrast_ratio(\"#000000\", \"#FFFFFF\")\n    21.0\n\n    iex> Raxol.Style.Colors.Accessibility.contrast_ratio(\"#777777\", \"#999999\")\n    1.3","ref":"Raxol.Style.Colors.Accessibility.html#contrast_ratio/2-examples"},{"type":"function","title":"Raxol.Style.Colors.Accessibility.darken_until_contrast/3","doc":"Darkens a color until it meets the specified contrast ratio with a background color.\n\nRequires HSL module for `darken` function.","ref":"Raxol.Style.Colors.Accessibility.html#darken_until_contrast/3"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Accessibility.darken_until_contrast/3","doc":"- `color` - The color to darken (Color struct)\n- `background` - The background color (Color struct)\n- `target_ratio` - The target contrast ratio to achieve","ref":"Raxol.Style.Colors.Accessibility.html#darken_until_contrast/3-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Accessibility.darken_until_contrast/3","doc":"- A Color struct representing the darkened color","ref":"Raxol.Style.Colors.Accessibility.html#darken_until_contrast/3-returns"},{"type":"function","title":"Raxol.Style.Colors.Accessibility.lighten_until_contrast/3","doc":"","ref":"Raxol.Style.Colors.Accessibility.html#lighten_until_contrast/3"},{"type":"function","title":"Raxol.Style.Colors.Accessibility.readable?/3","doc":"Checks if a foreground color is readable on a background color.","ref":"Raxol.Style.Colors.Accessibility.html#readable?/3"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Accessibility.readable?/3","doc":"- `background` - Background color\n- `foreground` - Text color\n- `level` - Accessibility level (`:aa`, `:aaa`, `:aa_large`, `:aaa_large`)","ref":"Raxol.Style.Colors.Accessibility.html#readable?/3-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Accessibility.readable?/3","doc":"iex> bg = Raxol.Style.Colors.Color.from_hex(\"#333333\")\n    iex> fg = Raxol.Style.Colors.Color.from_hex(\"#FFFFFF\")\n    iex> Raxol.Style.Colors.Accessibility.readable?(bg, fg)\n    true\n\n    iex> bg = Raxol.Style.Colors.Color.from_hex(\"#CCCCCC\")\n    iex> fg = Raxol.Style.Colors.Color.from_hex(\"#999999\")\n    iex> Raxol.Style.Colors.Accessibility.readable?(bg, fg, :aaa)\n    false","ref":"Raxol.Style.Colors.Accessibility.html#readable?/3-examples"},{"type":"function","title":"Raxol.Style.Colors.Accessibility.relative_luminance/1","doc":"Calculates the relative luminance of a color according to WCAG guidelines.","ref":"Raxol.Style.Colors.Accessibility.html#relative_luminance/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Accessibility.relative_luminance/1","doc":"- `color` - The color to calculate luminance for (hex string or Color struct)","ref":"Raxol.Style.Colors.Accessibility.html#relative_luminance/1-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Accessibility.relative_luminance/1","doc":"- A float between 0 and 1 representing the relative luminance","ref":"Raxol.Style.Colors.Accessibility.html#relative_luminance/1-returns"},{"type":"function","title":"Examples - Raxol.Style.Colors.Accessibility.relative_luminance/1","doc":"iex> Raxol.Style.Colors.Accessibility.relative_luminance(\"#000000\")\n    0.0\n\n    iex> Raxol.Style.Colors.Accessibility.relative_luminance(\"#FFFFFF\")\n    1.0","ref":"Raxol.Style.Colors.Accessibility.html#relative_luminance/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Accessibility.suggest_contrast_color/1","doc":"Suggests a color with good contrast (at least AA) to the base color.\n\nPrioritizes complementary color, then black/white.","ref":"Raxol.Style.Colors.Accessibility.html#suggest_contrast_color/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Accessibility.suggest_contrast_color/1","doc":"- `color` - The base color (hex string or Color struct)","ref":"Raxol.Style.Colors.Accessibility.html#suggest_contrast_color/1-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Accessibility.suggest_contrast_color/1","doc":"iex> color = Raxol.Style.Colors.Color.from_hex(\"#3366CC\")\n    iex> contrast_color = Raxol.Style.Colors.Accessibility.suggest_contrast_color(color)\n    iex> Raxol.Style.Colors.Accessibility.readable?(color, contrast_color)\n    true","ref":"Raxol.Style.Colors.Accessibility.html#suggest_contrast_color/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Accessibility.suggest_text_color/1","doc":"Suggests an appropriate text color (black or white) for a given background.\n\nEnsures minimum AA contrast.","ref":"Raxol.Style.Colors.Accessibility.html#suggest_text_color/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Accessibility.suggest_text_color/1","doc":"- `background` - The background color (hex string or Color struct)","ref":"Raxol.Style.Colors.Accessibility.html#suggest_text_color/1-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Accessibility.suggest_text_color/1","doc":"iex> Raxol.Style.Colors.Accessibility.suggest_text_color(\"#333333\").hex\n    \"#FFFFFF\"\n\n    iex> Raxol.Style.Colors.Accessibility.suggest_text_color(\"#EEEEEE\").hex\n    \"#000000\"","ref":"Raxol.Style.Colors.Accessibility.html#suggest_text_color/1-examples"},{"type":"module","title":"Raxol.Style.Colors.Adaptive","doc":"Detects terminal capabilities and adapts color schemes accordingly.\n\nThis module provides functionality to detect what color capabilities are\nsupported by the current terminal and adapt colors and themes to work\noptimally with the detected capabilities.","ref":"Raxol.Style.Colors.Adaptive.html"},{"type":"module","title":"Examples - Raxol.Style.Colors.Adaptive","doc":"```elixir\n# Check if the terminal supports true color\nif Raxol.Style.Colors.Adaptive.supports_true_color?() do\n  # Use true color features\nelse\n  # Fall back to 256 colors or 16 colors\nend\n\n# Adapt a color to the current terminal capabilities\ncolor = Raxol.Style.Colors.Color.from_hex(\"#FF5500\")\nadapted_color = Raxol.Style.Colors.Adaptive.adapt_color(color)\n\n# Check if we're in a dark terminal\nif Raxol.Style.Colors.Adaptive.is_dark_terminal?() do\n  # Use light text on dark background\nelse\n  # Use dark text on light background\nend\n```","ref":"Raxol.Style.Colors.Adaptive.html#module-examples"},{"type":"function","title":"Raxol.Style.Colors.Adaptive.adapt_color/1","doc":"Adapts a color to the current terminal capabilities.\n\nIf the terminal does not support the full color range, this will\nconvert the color to the best available representation.","ref":"Raxol.Style.Colors.Adaptive.html#adapt_color/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Adaptive.adapt_color/1","doc":"- `color` - The color to adapt","ref":"Raxol.Style.Colors.Adaptive.html#adapt_color/1-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Adaptive.adapt_color/1","doc":"iex> color = Raxol.Style.Colors.Color.from_hex(\"#FF5500\")\n    iex> adapted = Raxol.Style.Colors.Adaptive.adapt_color(color)\n    iex> adapted.hex\n    \"#FF5500\"  # If terminal supports true color, otherwise closest supported color","ref":"Raxol.Style.Colors.Adaptive.html#adapt_color/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Adaptive.adapt_palette/1","doc":"Adapts a palette to the current terminal capabilities.","ref":"Raxol.Style.Colors.Adaptive.html#adapt_palette/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Adaptive.adapt_palette/1","doc":"- `palette` - The palette to adapt","ref":"Raxol.Style.Colors.Adaptive.html#adapt_palette/1-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Adaptive.adapt_palette/1","doc":"iex> palette = Raxol.Style.Colors.Palette.nord()\n    iex> adapted = Raxol.Style.Colors.Adaptive.adapt_palette(palette)\n    iex> adapted.name\n    \"Nord (Adapted)\"  # Adapted to terminal capabilities","ref":"Raxol.Style.Colors.Adaptive.html#adapt_palette/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Adaptive.adapt_theme/1","doc":"Adapts a theme to the current terminal capabilities.","ref":"Raxol.Style.Colors.Adaptive.html#adapt_theme/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Adaptive.adapt_theme/1","doc":"- `theme` - The theme to adapt","ref":"Raxol.Style.Colors.Adaptive.html#adapt_theme/1-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Adaptive.adapt_theme/1","doc":"iex> theme = Raxol.Style.Colors.Theme.from_palette(Raxol.Style.Colors.Palette.nord())\n    iex> adapted = Raxol.Style.Colors.Adaptive.adapt_theme(theme)\n    iex> adapted.name\n    \"Nord (Adapted)\"  # Adapted to terminal capabilities","ref":"Raxol.Style.Colors.Adaptive.html#adapt_theme/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Adaptive.detect_color_support/0","doc":"Detects the color support level of the current terminal.\n\nReturns one of:\n- `:true_color` - 24-bit color (16 million colors)\n- `:ansi_256` - 256 colors\n- `:ansi_16` - 16 colors\n- `:no_color` - No color support","ref":"Raxol.Style.Colors.Adaptive.html#detect_color_support/0"},{"type":"function","title":"Examples - Raxol.Style.Colors.Adaptive.detect_color_support/0","doc":"iex> Raxol.Style.Colors.Adaptive.detect_color_support()\n    :true_color  # Depends on your terminal","ref":"Raxol.Style.Colors.Adaptive.html#detect_color_support/0-examples"},{"type":"function","title":"Raxol.Style.Colors.Adaptive.get_optimal_format/0","doc":"Gets the optimal color format for the current terminal.\n\nReturns one of:\n- `:true_color` - 24-bit color (16 million colors)\n- `:ansi_256` - 256 colors\n- `:ansi_16` - 16 colors\n- `:no_color` - No color support\n\nThis is currently an alias for `detect_color_support/0`.","ref":"Raxol.Style.Colors.Adaptive.html#get_optimal_format/0"},{"type":"function","title":"Raxol.Style.Colors.Adaptive.init/0","doc":"Initializes the terminal capabilities cache.\n\nThis should be called once, usually during application startup.\nIt creates the ETS table used for caching detected capabilities.","ref":"Raxol.Style.Colors.Adaptive.html#init/0"},{"type":"function","title":"Raxol.Style.Colors.Adaptive.is_dark_terminal?/0","doc":"Checks if the terminal has a dark background.","ref":"Raxol.Style.Colors.Adaptive.html#is_dark_terminal?/0"},{"type":"function","title":"Examples - Raxol.Style.Colors.Adaptive.is_dark_terminal?/0","doc":"iex> Raxol.Style.Colors.Adaptive.is_dark_terminal?()\n    true  # Depends on your terminal","ref":"Raxol.Style.Colors.Adaptive.html#is_dark_terminal?/0-examples"},{"type":"function","title":"Raxol.Style.Colors.Adaptive.optimal_format/0","doc":"Gets the optimal color format for the current terminal.\n\nReturns one of:\n- `:true_color` - 24-bit color (16 million colors)\n- `:ansi_256` - 256 colors\n- `:ansi_16` - 16 colors\n- `:no_color` - No color support","ref":"Raxol.Style.Colors.Adaptive.html#optimal_format/0"},{"type":"function","title":"Examples - Raxol.Style.Colors.Adaptive.optimal_format/0","doc":"iex> Raxol.Style.Colors.Adaptive.optimal_format()\n    :true_color  # Depends on your terminal","ref":"Raxol.Style.Colors.Adaptive.html#optimal_format/0-examples"},{"type":"function","title":"Raxol.Style.Colors.Adaptive.reset_detection/0","doc":"Resets the cached terminal capabilities.\n\nThis forces the next call to detection functions to re-evaluate\nthe terminal environment.","ref":"Raxol.Style.Colors.Adaptive.html#reset_detection/0"},{"type":"function","title":"Raxol.Style.Colors.Adaptive.supports_256_colors?/0","doc":"Checks if the terminal supports 256 colors.","ref":"Raxol.Style.Colors.Adaptive.html#supports_256_colors?/0"},{"type":"function","title":"Examples - Raxol.Style.Colors.Adaptive.supports_256_colors?/0","doc":"iex> Raxol.Style.Colors.Adaptive.supports_256_colors?()\n    true  # Depends on your terminal","ref":"Raxol.Style.Colors.Adaptive.html#supports_256_colors?/0-examples"},{"type":"function","title":"Raxol.Style.Colors.Adaptive.supports_true_color?/0","doc":"Checks if the terminal supports true color (24-bit color).","ref":"Raxol.Style.Colors.Adaptive.html#supports_true_color?/0"},{"type":"function","title":"Examples - Raxol.Style.Colors.Adaptive.supports_true_color?/0","doc":"iex> Raxol.Style.Colors.Adaptive.supports_true_color?()\n    true  # Depends on your terminal","ref":"Raxol.Style.Colors.Adaptive.html#supports_true_color?/0-examples"},{"type":"function","title":"Raxol.Style.Colors.Adaptive.terminal_background/0","doc":"Detects the terminal background color (light or dark).\n\nReturns one of:\n- `:dark` - Dark background\n- `:light` - Light background\n- `:unknown` - Unable to determine","ref":"Raxol.Style.Colors.Adaptive.html#terminal_background/0"},{"type":"function","title":"Examples - Raxol.Style.Colors.Adaptive.terminal_background/0","doc":"iex> Raxol.Style.Colors.Adaptive.terminal_background()\n    :dark  # Depends on your terminal","ref":"Raxol.Style.Colors.Adaptive.html#terminal_background/0-examples"},{"type":"module","title":"Raxol.Style.Colors.Advanced","doc":"Provides advanced color handling capabilities for the terminal.\n\nFeatures:\n- Color blending and mixing\n- Custom color palettes\n- Enhanced color adaptation\n- Color space conversions\n- Color harmony generation","ref":"Raxol.Style.Colors.Advanced.html"},{"type":"function","title":"Raxol.Style.Colors.Advanced.adapt_color_advanced/2","doc":"Adapts a color to the current terminal capabilities with advanced options.","ref":"Raxol.Style.Colors.Advanced.html#adapt_color_advanced/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Advanced.adapt_color_advanced/2","doc":"- `color` - The color to adapt\n- `options` - Adaptation options\n  - `:preserve_brightness` - Try to maintain perceived brightness\n  - `:enhance_contrast` - Increase contrast when possible\n  - `:color_blind_safe` - Ensure color blind friendly colors","ref":"Raxol.Style.Colors.Advanced.html#adapt_color_advanced/2-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Advanced.adapt_color_advanced/2","doc":"iex> color = Color.from_hex(\"#FF0000\")\n    iex> adapted = Advanced.adapt_color_advanced(color, preserve_brightness: true)\n    iex> adapted.hex\n    \"#FF0000\"  # If terminal supports true color","ref":"Raxol.Style.Colors.Advanced.html#adapt_color_advanced/2-examples"},{"type":"function","title":"Raxol.Style.Colors.Advanced.blend_colors/3","doc":"Blends two colors together with the given ratio.","ref":"Raxol.Style.Colors.Advanced.html#blend_colors/3"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Advanced.blend_colors/3","doc":"- `color1` - First color\n- `color2` - Second color\n- `ratio` - Blend ratio (0.0 to 1.0, where 0.0 is color1 and 1.0 is color2)","ref":"Raxol.Style.Colors.Advanced.html#blend_colors/3-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Advanced.blend_colors/3","doc":"iex> color1 = Color.from_hex(\"#FF0000\")\n    iex> color2 = Color.from_hex(\"#0000FF\")\n    iex> blended = Advanced.blend_colors(color1, color2, 0.5)\n    iex> blended.hex\n    \"#800080\"  # Purple","ref":"Raxol.Style.Colors.Advanced.html#blend_colors/3-examples"},{"type":"type","title":"Raxol.Style.Colors.Advanced.color/0","doc":"","ref":"Raxol.Style.Colors.Advanced.html#t:color/0"},{"type":"type","title":"Raxol.Style.Colors.Advanced.color_space/0","doc":"","ref":"Raxol.Style.Colors.Advanced.html#t:color_space/0"},{"type":"function","title":"Raxol.Style.Colors.Advanced.convert_color_space/2","doc":"Converts a color to a different color space.","ref":"Raxol.Style.Colors.Advanced.html#convert_color_space/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Advanced.convert_color_space/2","doc":"- `color` - The color to convert\n- `target_space` - The target color space (:rgb, :hsl, :lab, or :xyz)","ref":"Raxol.Style.Colors.Advanced.html#convert_color_space/2-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Advanced.convert_color_space/2","doc":"iex> color = Color.from_hex(\"#FF0000\")\n    iex> hsl = Advanced.convert_color_space(color, :hsl)\n    iex> hsl\n    %{h: 0, s: 100, l: 50}","ref":"Raxol.Style.Colors.Advanced.html#convert_color_space/2-examples"},{"type":"function","title":"Raxol.Style.Colors.Advanced.create_gradient/3","doc":"Creates a gradient between two colors with the specified number of steps.","ref":"Raxol.Style.Colors.Advanced.html#create_gradient/3"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Advanced.create_gradient/3","doc":"- `color1` - Start color\n- `color2` - End color\n- `steps` - Number of steps in the gradient","ref":"Raxol.Style.Colors.Advanced.html#create_gradient/3-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Advanced.create_gradient/3","doc":"iex> color1 = Color.from_hex(\"#FF0000\")\n    iex> color2 = Color.from_hex(\"#0000FF\")\n    iex> gradient = Advanced.create_gradient(color1, color2, 3)\n    iex> Enum.map(gradient, & &1.hex)\n    [\"#FF0000\", \"#800080\", \"#0000FF\"]","ref":"Raxol.Style.Colors.Advanced.html#create_gradient/3-examples"},{"type":"function","title":"Raxol.Style.Colors.Advanced.create_harmony/2","doc":"Creates a color harmony based on the input color.","ref":"Raxol.Style.Colors.Advanced.html#create_harmony/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Advanced.create_harmony/2","doc":"- `color` - The base color\n- `harmony_type` - Type of harmony (:complementary, :analogous, :triadic, :tetradic)","ref":"Raxol.Style.Colors.Advanced.html#create_harmony/2-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Advanced.create_harmony/2","doc":"iex> color = Color.from_hex(\"#FF0000\")\n    iex> harmony = Advanced.create_harmony(color, :complementary)\n    iex> Enum.map(harmony, & &1.hex)\n    [\"#FF0000\", \"#00FFFF\"]","ref":"Raxol.Style.Colors.Advanced.html#create_harmony/2-examples"},{"type":"type","title":"Raxol.Style.Colors.Advanced.palette/0","doc":"","ref":"Raxol.Style.Colors.Advanced.html#t:palette/0"},{"type":"module","title":"Raxol.Style.Colors.Color","doc":"Represents a color in various formats with conversion utilities.\nSupports ANSI 16/256 colors and True Color (24-bit).","ref":"Raxol.Style.Colors.Color.html"},{"type":"module","title":"Examples - Raxol.Style.Colors.Color","doc":"```elixir\n# Creating colors\nred = Raxol.Style.Colors.Color.from_hex(\"#FF0000\")\nblue = Raxol.Style.Colors.Color.from_rgb(0, 0, 255)\ngreen = Raxol.Style.Colors.Color.from_ansi(2)\n\n# Converting colors\nhex_code = Raxol.Style.Colors.Color.to_hex(red)\nansi_code = Raxol.Style.Colors.Color.to_ansi_256(blue)\n\n# Color operations\nlight_red = Raxol.Style.Colors.Color.lighten(red, 0.2)\ndark_blue = Raxol.Style.Colors.Color.darken(blue, 0.3)\npurple = Raxol.Style.Colors.Color.mix(red, blue, 0.5)\n```","ref":"Raxol.Style.Colors.Color.html#module-examples"},{"type":"function","title":"Raxol.Style.Colors.Color.alpha_blend/3","doc":"Blends two colors with the specified alpha value (0.0 to 1.0).","ref":"Raxol.Style.Colors.Color.html#alpha_blend/3"},{"type":"function","title":"Examples - Raxol.Style.Colors.Color.alpha_blend/3","doc":"iex> color1 = Raxol.Style.Colors.Color.from_rgb(255, 0, 0)\n    iex> color2 = Raxol.Style.Colors.Color.from_rgb(0, 0, 255)\n    iex> blended = Raxol.Style.Colors.Color.alpha_blend(color1, color2, 0.5)\n    iex> {blended.r, blended.g, blended.b}\n    {127, 0, 127}","ref":"Raxol.Style.Colors.Color.html#alpha_blend/3-examples"},{"type":"function","title":"Raxol.Style.Colors.Color.complement/1","doc":"Returns the complementary color.","ref":"Raxol.Style.Colors.Color.html#complement/1"},{"type":"function","title":"Examples - Raxol.Style.Colors.Color.complement/1","doc":"iex> color = Raxol.Style.Colors.Color.from_rgb(255, 0, 0)\n    iex> complement = Raxol.Style.Colors.Color.complement(color)\n    iex> {complement.r, complement.g, complement.b}\n    {0, 255, 255}","ref":"Raxol.Style.Colors.Color.html#complement/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Color.darken/2","doc":"Darkens a color by the specified amount (0.0 to 1.0).","ref":"Raxol.Style.Colors.Color.html#darken/2"},{"type":"function","title":"Examples - Raxol.Style.Colors.Color.darken/2","doc":"iex> color = Raxol.Style.Colors.Color.from_rgb(200, 200, 200)\n    iex> darkened = Raxol.Style.Colors.Color.darken(color, 0.5)\n    iex> {darkened.r, darkened.g, darkened.b}\n    {100, 100, 100}","ref":"Raxol.Style.Colors.Color.html#darken/2-examples"},{"type":"function","title":"Raxol.Style.Colors.Color.from_ansi/1","doc":"Creates a color from an ANSI color code.","ref":"Raxol.Style.Colors.Color.html#from_ansi/1"},{"type":"function","title":"Examples - Raxol.Style.Colors.Color.from_ansi/1","doc":"iex> Raxol.Style.Colors.Color.from_ansi(1)\n    %Raxol.Style.Colors.Color{r: 128, g: 0, b: 0, ansi_code: 1, hex: \"#800000\"}","ref":"Raxol.Style.Colors.Color.html#from_ansi/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Color.from_hex/1","doc":"Creates a color from a hex string.\n\nAccepts hex strings in the following formats:\n- \"#RGB\"\n- \"#RRGGBB\"\n- \"RGB\"\n- \"RRGGBB\"\n\nReturns `{:error, :invalid_hex}` if the string is invalid.","ref":"Raxol.Style.Colors.Color.html#from_hex/1"},{"type":"function","title":"Examples - Raxol.Style.Colors.Color.from_hex/1","doc":"iex> Raxol.Style.Colors.Color.from_hex(\"#FF0000\")\n    %Raxol.Style.Colors.Color{r: 255, g: 0, b: 0, hex: \"#FF0000\"}\n\n    iex> Raxol.Style.Colors.Color.from_hex(\"0F0\")\n    %Raxol.Style.Colors.Color{r: 0, g: 255, b: 0, hex: \"#00FF00\"}","ref":"Raxol.Style.Colors.Color.html#from_hex/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Color.from_rgb/3","doc":"Creates a color from RGB values.","ref":"Raxol.Style.Colors.Color.html#from_rgb/3"},{"type":"function","title":"Examples - Raxol.Style.Colors.Color.from_rgb/3","doc":"iex> Raxol.Style.Colors.Color.from_rgb(255, 0, 0)\n    %Raxol.Style.Colors.Color{r: 255, g: 0, b: 0, hex: \"#FF0000\"}","ref":"Raxol.Style.Colors.Color.html#from_rgb/3-examples"},{"type":"function","title":"Raxol.Style.Colors.Color.lighten/2","doc":"Lightens a color by the specified amount (0.0 to 1.0).","ref":"Raxol.Style.Colors.Color.html#lighten/2"},{"type":"function","title":"Examples - Raxol.Style.Colors.Color.lighten/2","doc":"iex> color = Raxol.Style.Colors.Color.from_rgb(100, 100, 100)\n    iex> lightened = Raxol.Style.Colors.Color.lighten(color, 0.5)\n    iex> {lightened.r, lightened.g, lightened.b}\n    {177, 177, 177}","ref":"Raxol.Style.Colors.Color.html#lighten/2-examples"},{"type":"function","title":"Raxol.Style.Colors.Color.mix/3","doc":"Mixes two colors with the specified weight (0.0 to 1.0).","ref":"Raxol.Style.Colors.Color.html#mix/3"},{"type":"function","title":"Examples - Raxol.Style.Colors.Color.mix/3","doc":"iex> color1 = Raxol.Style.Colors.Color.from_rgb(255, 0, 0)\n    iex> color2 = Raxol.Style.Colors.Color.from_rgb(0, 0, 255)\n    iex> mixed = Raxol.Style.Colors.Color.mix(color1, color2, 0.5)\n    iex> {mixed.r, mixed.g, mixed.b}\n    {127, 0, 127}","ref":"Raxol.Style.Colors.Color.html#mix/3-examples"},{"type":"type","title":"Raxol.Style.Colors.Color.t/0","doc":"","ref":"Raxol.Style.Colors.Color.html#t:t/0"},{"type":"function","title":"Raxol.Style.Colors.Color.to_ansi/2","doc":"Converts a color to an ANSI code (currently defaults to 256-color code).\nThe `type` parameter (:foreground or :background) is currently ignored.\n\nTODO: Implement proper ANSI sequence generation based on type and terminal capabilities.","ref":"Raxol.Style.Colors.Color.html#to_ansi/2"},{"type":"function","title":"Raxol.Style.Colors.Color.to_ansi_16/1","doc":"Converts a color to the closest ANSI 16-color code.","ref":"Raxol.Style.Colors.Color.html#to_ansi_16/1"},{"type":"function","title":"Examples - Raxol.Style.Colors.Color.to_ansi_16/1","doc":"iex> color = Raxol.Style.Colors.Color.from_rgb(255, 0, 0)\n    iex> Raxol.Style.Colors.Color.to_ansi_16(color)\n    9","ref":"Raxol.Style.Colors.Color.html#to_ansi_16/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Color.to_ansi_256/1","doc":"Converts a color to the closest ANSI 256-color code.","ref":"Raxol.Style.Colors.Color.html#to_ansi_256/1"},{"type":"function","title":"Examples - Raxol.Style.Colors.Color.to_ansi_256/1","doc":"iex> color = Raxol.Style.Colors.Color.from_rgb(255, 0, 0)\n    iex> Raxol.Style.Colors.Color.to_ansi_256(color)\n    196","ref":"Raxol.Style.Colors.Color.html#to_ansi_256/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Color.to_hex/1","doc":"Converts a color to its hex representation.","ref":"Raxol.Style.Colors.Color.html#to_hex/1"},{"type":"function","title":"Examples - Raxol.Style.Colors.Color.to_hex/1","doc":"iex> color = Raxol.Style.Colors.Color.from_rgb(255, 0, 0)\n    iex> Raxol.Style.Colors.Color.to_hex(color)\n    \"#FF0000\"","ref":"Raxol.Style.Colors.Color.html#to_hex/1-examples"},{"type":"module","title":"Raxol.Style.Colors.Gradient","doc":"Creates and manages color gradients for terminal applications.\n\nThis module provides functionality for creating gradients between colors and\napplying them to text, creating visually striking terminal effects.","ref":"Raxol.Style.Colors.Gradient.html"},{"type":"module","title":"Examples - Raxol.Style.Colors.Gradient","doc":"```elixir\n# Create a simple linear gradient between red and blue\nalias Raxol.Style.Colors.{Color, Gradient}\n\nred = Color.from_hex(\"#FF0000\")\nblue = Color.from_hex(\"#0000FF\")\ngradient = Gradient.linear(red, blue, 10)\n\n# Apply the gradient to text\ncolored_text = Gradient.apply_to_text(gradient, \"Hello, World!\")\n\n# Create a rainbow gradient\nrainbow = Gradient.rainbow(20)\nrainbow_text = Gradient.apply_to_text(rainbow, \"Rainbow Text\")\n\n# Create a multi-stop gradient\ncolors = [\n  Color.from_hex(\"#FF0000\"),  # Red\n  Color.from_hex(\"#FFFF00\"),  # Yellow\n  Color.from_hex(\"#00FF00\")   # Green\n]\nmulti = Gradient.multi_stop(colors, 15)\n```","ref":"Raxol.Style.Colors.Gradient.html#module-examples"},{"type":"function","title":"Raxol.Style.Colors.Gradient.apply_to_text/2","doc":"Applies a gradient to text, returning an ANSI-formatted string.","ref":"Raxol.Style.Colors.Gradient.html#apply_to_text/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Gradient.apply_to_text/2","doc":"- `gradient` - The gradient to apply\n- `text` - The text to colorize","ref":"Raxol.Style.Colors.Gradient.html#apply_to_text/2-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Gradient.apply_to_text/2","doc":"iex> red = Raxol.Style.Colors.Color.from_hex(\"#FF0000\")\n    iex> blue = Raxol.Style.Colors.Color.from_hex(\"#0000FF\")\n    iex> gradient = Raxol.Style.Colors.Gradient.linear(red, blue, 5)\n    iex> Raxol.Style.Colors.Gradient.apply_to_text(gradient, \"Hello\")\n    # Returns ANSI-colored text with each character a different color","ref":"Raxol.Style.Colors.Gradient.html#apply_to_text/2-examples"},{"type":"function","title":"Raxol.Style.Colors.Gradient.at_position/2","doc":"Gets the color at a specific position in the gradient.","ref":"Raxol.Style.Colors.Gradient.html#at_position/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Gradient.at_position/2","doc":"- `gradient` - The gradient to sample from\n- `position` - A value between 0.0 and 1.0 representing the position in the gradient","ref":"Raxol.Style.Colors.Gradient.html#at_position/2-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Gradient.at_position/2","doc":"iex> red = Raxol.Style.Colors.Color.from_hex(\"#FF0000\")\n    iex> blue = Raxol.Style.Colors.Color.from_hex(\"#0000FF\")\n    iex> gradient = Raxol.Style.Colors.Gradient.linear(red, blue, 5)\n    iex> color = Raxol.Style.Colors.Gradient.at_position(gradient, 0.5)\n    iex> color.hex\n    \"#800080\"  # Purple (mix of red and blue)","ref":"Raxol.Style.Colors.Gradient.html#at_position/2-examples"},{"type":"type","title":"Raxol.Style.Colors.Gradient.gradient_type/0","doc":"","ref":"Raxol.Style.Colors.Gradient.html#t:gradient_type/0"},{"type":"function","title":"Raxol.Style.Colors.Gradient.heat_map/1","doc":"Creates a heat map gradient from cool to hot colors.","ref":"Raxol.Style.Colors.Gradient.html#heat_map/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Gradient.heat_map/1","doc":"- `steps` - The number of color steps in the heat map","ref":"Raxol.Style.Colors.Gradient.html#heat_map/1-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Gradient.heat_map/1","doc":"iex> gradient = Raxol.Style.Colors.Gradient.heat_map(5)\n    iex> length(gradient.colors)\n    5","ref":"Raxol.Style.Colors.Gradient.html#heat_map/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Gradient.linear/3","doc":"Creates a linear gradient between two colors.","ref":"Raxol.Style.Colors.Gradient.html#linear/3"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Gradient.linear/3","doc":"- `start_color` - The starting color\n- `end_color` - The ending color\n- `steps` - The number of color steps in the gradient (including start and end)","ref":"Raxol.Style.Colors.Gradient.html#linear/3-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Gradient.linear/3","doc":"iex> red = Raxol.Style.Colors.Color.from_hex(\"#FF0000\")\n    iex> blue = Raxol.Style.Colors.Color.from_hex(\"#0000FF\")\n    iex> gradient = Raxol.Style.Colors.Gradient.linear(red, blue, 5)\n    iex> length(gradient.colors)\n    5","ref":"Raxol.Style.Colors.Gradient.html#linear/3-examples"},{"type":"function","title":"Raxol.Style.Colors.Gradient.multi_stop/2","doc":"Creates a multi-stop gradient with multiple color stops.","ref":"Raxol.Style.Colors.Gradient.html#multi_stop/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Gradient.multi_stop/2","doc":"- `color_stops` - A list of colors to transition between\n- `steps` - The total number of color steps in the gradient","ref":"Raxol.Style.Colors.Gradient.html#multi_stop/2-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Gradient.multi_stop/2","doc":"iex> colors = [\n    ...>   Raxol.Style.Colors.Color.from_hex(\"#FF0000\"),\n    ...>   Raxol.Style.Colors.Color.from_hex(\"#00FF00\"),\n    ...>   Raxol.Style.Colors.Color.from_hex(\"#0000FF\")\n    ...> ]\n    iex> gradient = Raxol.Style.Colors.Gradient.multi_stop(colors, 10)\n    iex> length(gradient.colors)\n    10","ref":"Raxol.Style.Colors.Gradient.html#multi_stop/2-examples"},{"type":"function","title":"Raxol.Style.Colors.Gradient.rainbow/1","doc":"Creates a rainbow gradient with the given number of steps.","ref":"Raxol.Style.Colors.Gradient.html#rainbow/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Gradient.rainbow/1","doc":"- `steps` - The number of color steps in the rainbow","ref":"Raxol.Style.Colors.Gradient.html#rainbow/1-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Gradient.rainbow/1","doc":"iex> gradient = Raxol.Style.Colors.Gradient.rainbow(6)\n    iex> length(gradient.colors)\n    6","ref":"Raxol.Style.Colors.Gradient.html#rainbow/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Gradient.reverse/1","doc":"Reverses the direction of a gradient.","ref":"Raxol.Style.Colors.Gradient.html#reverse/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Gradient.reverse/1","doc":"- `gradient` - The gradient to reverse","ref":"Raxol.Style.Colors.Gradient.html#reverse/1-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Gradient.reverse/1","doc":"iex> red = Raxol.Style.Colors.Color.from_hex(\"#FF0000\")\n    iex> blue = Raxol.Style.Colors.Color.from_hex(\"#0000FF\")\n    iex> gradient = Raxol.Style.Colors.Gradient.linear(red, blue, 3)\n    iex> reversed = Raxol.Style.Colors.Gradient.reverse(gradient)\n    iex> hd(reversed.colors).hex\n    \"#0000FF\"","ref":"Raxol.Style.Colors.Gradient.html#reverse/1-examples"},{"type":"type","title":"Raxol.Style.Colors.Gradient.t/0","doc":"","ref":"Raxol.Style.Colors.Gradient.html#t:t/0"},{"type":"function","title":"Raxol.Style.Colors.Gradient.to_ansi_sequence/2","doc":"Alias for apply_to_text/2.","ref":"Raxol.Style.Colors.Gradient.html#to_ansi_sequence/2"},{"type":"module","title":"Raxol.Style.Colors.HSL","doc":"Provides functions for HSL color space conversions and adjustments.","ref":"Raxol.Style.Colors.HSL.html"},{"type":"function","title":"Raxol.Style.Colors.HSL.darken/2","doc":"Darkens a color by a specified amount (adjusting Lightness).","ref":"Raxol.Style.Colors.HSL.html#darken/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.HSL.darken/2","doc":"- `color` - The color to darken (Color struct)\n- `amount` - The amount to darken by (0.0 to 1.0)","ref":"Raxol.Style.Colors.HSL.html#darken/2-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.HSL.darken/2","doc":"- A Color struct representing the darkened color","ref":"Raxol.Style.Colors.HSL.html#darken/2-returns"},{"type":"function","title":"Raxol.Style.Colors.HSL.desaturate/2","doc":"Desaturates a color by a specified amount (adjusting Saturation).","ref":"Raxol.Style.Colors.HSL.html#desaturate/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.HSL.desaturate/2","doc":"- `color` - The color to desaturate (Color struct)\n- `amount` - The amount to desaturate by (0.0 to 1.0)","ref":"Raxol.Style.Colors.HSL.html#desaturate/2-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.HSL.desaturate/2","doc":"- A Color struct representing the desaturated color","ref":"Raxol.Style.Colors.HSL.html#desaturate/2-returns"},{"type":"function","title":"Raxol.Style.Colors.HSL.hsl_to_rgb/3","doc":"Converts HSL values to RGB.","ref":"Raxol.Style.Colors.HSL.html#hsl_to_rgb/3"},{"type":"function","title":"Parameters - Raxol.Style.Colors.HSL.hsl_to_rgb/3","doc":"- `h`, `s`, `l` - Hue (0-360), Saturation (0.0-1.0), Lightness (0.0-1.0)","ref":"Raxol.Style.Colors.HSL.html#hsl_to_rgb/3-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.HSL.hsl_to_rgb/3","doc":"- `{r, g, b}` tuple: Red, Green, Blue values (0-255)","ref":"Raxol.Style.Colors.HSL.html#hsl_to_rgb/3-returns"},{"type":"function","title":"Raxol.Style.Colors.HSL.lighten/2","doc":"Lightens a color by a specified amount (adjusting Lightness).","ref":"Raxol.Style.Colors.HSL.html#lighten/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.HSL.lighten/2","doc":"- `color` - The color to lighten (Color struct)\n- `amount` - The amount to lighten by (0.0 to 1.0)","ref":"Raxol.Style.Colors.HSL.html#lighten/2-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.HSL.lighten/2","doc":"- A Color struct representing the lightened color","ref":"Raxol.Style.Colors.HSL.html#lighten/2-returns"},{"type":"function","title":"Raxol.Style.Colors.HSL.rgb_to_hsl/3","doc":"Converts RGB values to HSL.","ref":"Raxol.Style.Colors.HSL.html#rgb_to_hsl/3"},{"type":"function","title":"Parameters - Raxol.Style.Colors.HSL.rgb_to_hsl/3","doc":"- `r`, `g`, `b` - Red, Green, Blue values (0-255)","ref":"Raxol.Style.Colors.HSL.html#rgb_to_hsl/3-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.HSL.rgb_to_hsl/3","doc":"- `{h, s, l}` tuple: Hue (0-360), Saturation (0.0-1.0), Lightness (0.0-1.0)","ref":"Raxol.Style.Colors.HSL.html#rgb_to_hsl/3-returns"},{"type":"function","title":"Raxol.Style.Colors.HSL.rotate_hue/2","doc":"Rotates the hue of a color by a specified number of degrees.","ref":"Raxol.Style.Colors.HSL.html#rotate_hue/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.HSL.rotate_hue/2","doc":"- `color` - The color to rotate (Color struct)\n- `degrees` - The number of degrees to rotate (positive or negative)","ref":"Raxol.Style.Colors.HSL.html#rotate_hue/2-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.HSL.rotate_hue/2","doc":"- A Color struct representing the rotated color","ref":"Raxol.Style.Colors.HSL.html#rotate_hue/2-returns"},{"type":"function","title":"Raxol.Style.Colors.HSL.saturate/2","doc":"Saturates a color by a specified amount (adjusting Saturation).","ref":"Raxol.Style.Colors.HSL.html#saturate/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.HSL.saturate/2","doc":"- `color` - The color to saturate (Color struct)\n- `amount` - The amount to saturate by (0.0 to 1.0)","ref":"Raxol.Style.Colors.HSL.html#saturate/2-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.HSL.saturate/2","doc":"- A Color struct representing the saturated color","ref":"Raxol.Style.Colors.HSL.html#saturate/2-returns"},{"type":"module","title":"Raxol.Style.Colors.Harmony","doc":"Provides functions for generating color harmonies based on a base color.","ref":"Raxol.Style.Colors.Harmony.html"},{"type":"function","title":"Raxol.Style.Colors.Harmony.analogous_colors/3","doc":"Generates analogous colors based on the HSL color wheel.\nAnalogous colors are groups of colors that are adjacent to each other on the color wheel.","ref":"Raxol.Style.Colors.Harmony.html#analogous_colors/3"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Harmony.analogous_colors/3","doc":"- `color`: The base `Color{}` struct.\n- `count`: The number of analogous colors to generate (defaults to 3).\n- `angle`: The angle separation between analogous colors (defaults to 30 degrees).","ref":"Raxol.Style.Colors.Harmony.html#analogous_colors/3-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Harmony.analogous_colors/3","doc":"A list of `Color{}` structs representing the analogous colors.","ref":"Raxol.Style.Colors.Harmony.html#analogous_colors/3-returns"},{"type":"function","title":"Raxol.Style.Colors.Harmony.complementary_colors/1","doc":"Generates complementary colors (opposite on the color wheel).\n\nReturns a list containing the base color and its complement.","ref":"Raxol.Style.Colors.Harmony.html#complementary_colors/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Harmony.complementary_colors/1","doc":"- `color` - The base color (Color struct or hex string)","ref":"Raxol.Style.Colors.Harmony.html#complementary_colors/1-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Harmony.complementary_colors/1","doc":"- A list of two Color structs: `[base_color, complement]`","ref":"Raxol.Style.Colors.Harmony.html#complementary_colors/1-returns"},{"type":"function","title":"Examples - Raxol.Style.Colors.Harmony.complementary_colors/1","doc":"iex> red = Raxol.Style.Colors.Color.from_hex(\"#FF0000\")\n    iex> [red_struct, cyan_struct] = Raxol.Style.Colors.Harmony.complementary_colors(red)\n    iex> cyan_struct.hex\n    \"#00FFFF\"","ref":"Raxol.Style.Colors.Harmony.html#complementary_colors/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Harmony.triadic_colors/1","doc":"Generates triadic colors (three colors evenly spaced on the color wheel).","ref":"Raxol.Style.Colors.Harmony.html#triadic_colors/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Harmony.triadic_colors/1","doc":"- `color` - The base color (Color struct or hex string)","ref":"Raxol.Style.Colors.Harmony.html#triadic_colors/1-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Harmony.triadic_colors/1","doc":"- A list of three Color structs","ref":"Raxol.Style.Colors.Harmony.html#triadic_colors/1-returns"},{"type":"function","title":"Examples - Raxol.Style.Colors.Harmony.triadic_colors/1","doc":"iex> red = Raxol.Style.Colors.Color.from_hex(\"#FF0000\")\n    iex> colors = Raxol.Style.Colors.Harmony.triadic_colors(red)\n    iex> length(colors)\n    3\n    # Colors will be red, green, blue (approximately)","ref":"Raxol.Style.Colors.Harmony.html#triadic_colors/1-examples"},{"type":"module","title":"Raxol.Style.Colors.HotReload","doc":"Provides hot-reloading capabilities for color themes.\n\nThis module watches for changes to theme files and automatically\nreloads them when they change. It also provides a way to subscribe\nto theme change events.","ref":"Raxol.Style.Colors.HotReload.html"},{"type":"function","title":"Raxol.Style.Colors.HotReload.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Style.Colors.HotReload.html#child_spec/1"},{"type":"function","title":"Raxol.Style.Colors.HotReload.start_link/1","doc":"","ref":"Raxol.Style.Colors.HotReload.html#start_link/1"},{"type":"function","title":"Raxol.Style.Colors.HotReload.subscribe/0","doc":"Subscribe to theme change events.","ref":"Raxol.Style.Colors.HotReload.html#subscribe/0"},{"type":"function","title":"Examples - Raxol.Style.Colors.HotReload.subscribe/0","doc":"iex> HotReload.subscribe()\n    :ok","ref":"Raxol.Style.Colors.HotReload.html#subscribe/0-examples"},{"type":"function","title":"Raxol.Style.Colors.HotReload.unsubscribe/0","doc":"Unsubscribe from theme change events.","ref":"Raxol.Style.Colors.HotReload.html#unsubscribe/0"},{"type":"function","title":"Examples - Raxol.Style.Colors.HotReload.unsubscribe/0","doc":"iex> HotReload.unsubscribe()\n    :ok","ref":"Raxol.Style.Colors.HotReload.html#unsubscribe/0-examples"},{"type":"function","title":"Raxol.Style.Colors.HotReload.watch_path/1","doc":"Add a path to watch for theme changes.","ref":"Raxol.Style.Colors.HotReload.html#watch_path/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.HotReload.watch_path/1","doc":"- `path` - The path to watch","ref":"Raxol.Style.Colors.HotReload.html#watch_path/1-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.HotReload.watch_path/1","doc":"iex> HotReload.watch_path(\"/path/to/themes\")\n    :ok","ref":"Raxol.Style.Colors.HotReload.html#watch_path/1-examples"},{"type":"module","title":"Raxol.Style.Colors.Palette","doc":"Manages collections of related colors as palettes.\nProvides standard palettes and custom palette creation.","ref":"Raxol.Style.Colors.Palette.html"},{"type":"module","title":"Examples - Raxol.Style.Colors.Palette","doc":"```elixir\n# Using standard palettes\npalette = Raxol.Style.Colors.Palette.standard_16()\nsolarized = Raxol.Style.Colors.Palette.solarized()\n\n# Creating a custom palette from a base color\nbase_color = Raxol.Style.Colors.Color.from_hex(\"#4285F4\")  # Google Blue\ncustom_palette = Raxol.Style.Colors.Palette.from_base_color(base_color)\n\n# Accessing colors from a palette\nprimary = Raxol.Style.Colors.Palette.get_color(palette, :primary)\nbackground = Raxol.Style.Colors.Palette.get_color(palette, :background)\n```","ref":"Raxol.Style.Colors.Palette.html#module-examples"},{"type":"function","title":"Raxol.Style.Colors.Palette.add_color/3","doc":"Adds a color to a palette with the given name.","ref":"Raxol.Style.Colors.Palette.html#add_color/3"},{"type":"function","title":"Examples - Raxol.Style.Colors.Palette.add_color/3","doc":"iex> palette = Raxol.Style.Colors.Palette.standard_16()\n    iex> color = Raxol.Style.Colors.Color.from_hex(\"#FF00FF\")\n    iex> updated = Raxol.Style.Colors.Palette.add_color(palette, :hot_pink, color)\n    iex> Raxol.Style.Colors.Palette.get_color(updated, :hot_pink) == color\n    true","ref":"Raxol.Style.Colors.Palette.html#add_color/3-examples"},{"type":"function","title":"Raxol.Style.Colors.Palette.analogous/1","doc":"Creates an analogous color palette based on a base color.","ref":"Raxol.Style.Colors.Palette.html#analogous/1"},{"type":"function","title":"Examples - Raxol.Style.Colors.Palette.analogous/1","doc":"iex> base = Raxol.Style.Colors.Color.from_hex(\"#4285F4\")\n    iex> palette = Raxol.Style.Colors.Palette.analogous(base)\n    iex> palette.name\n    \"Analogous\"","ref":"Raxol.Style.Colors.Palette.html#analogous/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Palette.ansi_256/0","doc":"Creates an ANSI 256 color palette.\nCurrently this is a placeholder that returns the standard 16 colors.","ref":"Raxol.Style.Colors.Palette.html#ansi_256/0"},{"type":"function","title":"Examples - Raxol.Style.Colors.Palette.ansi_256/0","doc":"iex> palette = Raxol.Style.Colors.Palette.ansi_256()\n    iex> palette.name\n    \"ANSI 256\"","ref":"Raxol.Style.Colors.Palette.html#ansi_256/0-examples"},{"type":"function","title":"Raxol.Style.Colors.Palette.complementary/1","doc":"Creates a complementary palette based on a base color.","ref":"Raxol.Style.Colors.Palette.html#complementary/1"},{"type":"function","title":"Examples - Raxol.Style.Colors.Palette.complementary/1","doc":"iex> base = Raxol.Style.Colors.Color.from_hex(\"#4285F4\")\n    iex> palette = Raxol.Style.Colors.Palette.complementary(base)\n    iex> palette.name\n    \"Complementary\"","ref":"Raxol.Style.Colors.Palette.html#complementary/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Palette.dracula/0","doc":"Creates a Dracula color palette.","ref":"Raxol.Style.Colors.Palette.html#dracula/0"},{"type":"function","title":"Examples - Raxol.Style.Colors.Palette.dracula/0","doc":"iex> palette = Raxol.Style.Colors.Palette.dracula()\n    iex> palette.name\n    \"Dracula\"","ref":"Raxol.Style.Colors.Palette.html#dracula/0-examples"},{"type":"function","title":"Raxol.Style.Colors.Palette.from_base_color/2","doc":"Creates a new palette from a base color.","ref":"Raxol.Style.Colors.Palette.html#from_base_color/2"},{"type":"function","title":"Examples - Raxol.Style.Colors.Palette.from_base_color/2","doc":"iex> base = Raxol.Style.Colors.Color.from_hex(\"#4285F4\")\n    iex> palette = Raxol.Style.Colors.Palette.from_base_color(base)\n    iex> palette.name\n    \"Custom\"","ref":"Raxol.Style.Colors.Palette.html#from_base_color/2-examples"},{"type":"function","title":"Raxol.Style.Colors.Palette.get_color/2","doc":"Gets a color from a palette by name.","ref":"Raxol.Style.Colors.Palette.html#get_color/2"},{"type":"function","title":"Examples - Raxol.Style.Colors.Palette.get_color/2","doc":"iex> palette = Raxol.Style.Colors.Palette.standard_16()\n    iex> color = Raxol.Style.Colors.Palette.get_color(palette, :red)\n    iex> color.hex\n    \"#800000\"","ref":"Raxol.Style.Colors.Palette.html#get_color/2-examples"},{"type":"function","title":"Raxol.Style.Colors.Palette.merge_palettes/2","doc":"Merges two palettes, with the second palette's colors taking precedence.","ref":"Raxol.Style.Colors.Palette.html#merge_palettes/2"},{"type":"function","title":"Examples - Raxol.Style.Colors.Palette.merge_palettes/2","doc":"iex> p1 = Raxol.Style.Colors.Palette.standard_16()\n    iex> p2 = Raxol.Style.Colors.Palette.solarized()\n    iex> merged = Raxol.Style.Colors.Palette.merge_palettes(p1, p2)\n    iex> merged.name\n    \"ANSI 16 + Solarized\"","ref":"Raxol.Style.Colors.Palette.html#merge_palettes/2-examples"},{"type":"function","title":"Raxol.Style.Colors.Palette.monochromatic/2","doc":"Creates a monochromatic color palette with specified number of steps.","ref":"Raxol.Style.Colors.Palette.html#monochromatic/2"},{"type":"function","title":"Examples - Raxol.Style.Colors.Palette.monochromatic/2","doc":"iex> base = Raxol.Style.Colors.Color.from_hex(\"#4285F4\")\n    iex> palette = Raxol.Style.Colors.Palette.monochromatic(base, 5)\n    iex> palette.name\n    \"Monochromatic\"","ref":"Raxol.Style.Colors.Palette.html#monochromatic/2-examples"},{"type":"function","title":"Raxol.Style.Colors.Palette.nord/0","doc":"Creates a Nord color palette.","ref":"Raxol.Style.Colors.Palette.html#nord/0"},{"type":"function","title":"Examples - Raxol.Style.Colors.Palette.nord/0","doc":"iex> palette = Raxol.Style.Colors.Palette.nord()\n    iex> palette.name\n    \"Nord\"","ref":"Raxol.Style.Colors.Palette.html#nord/0-examples"},{"type":"function","title":"Raxol.Style.Colors.Palette.remove_color/2","doc":"Removes a color from a palette by name.","ref":"Raxol.Style.Colors.Palette.html#remove_color/2"},{"type":"function","title":"Examples - Raxol.Style.Colors.Palette.remove_color/2","doc":"iex> palette = Raxol.Style.Colors.Palette.standard_16()\n    iex> updated = Raxol.Style.Colors.Palette.remove_color(palette, :red)\n    iex> Raxol.Style.Colors.Palette.get_color(updated, :red)\n    nil","ref":"Raxol.Style.Colors.Palette.html#remove_color/2-examples"},{"type":"function","title":"Raxol.Style.Colors.Palette.solarized/0","doc":"Creates a Solarized color palette.","ref":"Raxol.Style.Colors.Palette.html#solarized/0"},{"type":"function","title":"Examples - Raxol.Style.Colors.Palette.solarized/0","doc":"iex> palette = Raxol.Style.Colors.Palette.solarized()\n    iex> palette.name\n    \"Solarized\"","ref":"Raxol.Style.Colors.Palette.html#solarized/0-examples"},{"type":"function","title":"Raxol.Style.Colors.Palette.standard_16/0","doc":"Creates a standard 16-color ANSI palette.","ref":"Raxol.Style.Colors.Palette.html#standard_16/0"},{"type":"function","title":"Examples - Raxol.Style.Colors.Palette.standard_16/0","doc":"iex> palette = Raxol.Style.Colors.Palette.standard_16()\n    iex> Map.keys(palette.colors) |> length()\n    16","ref":"Raxol.Style.Colors.Palette.html#standard_16/0-examples"},{"type":"type","title":"Raxol.Style.Colors.Palette.t/0","doc":"","ref":"Raxol.Style.Colors.Palette.html#t:t/0"},{"type":"function","title":"Raxol.Style.Colors.Palette.triadic/1","doc":"Creates a triadic color palette based on a base color.","ref":"Raxol.Style.Colors.Palette.html#triadic/1"},{"type":"function","title":"Examples - Raxol.Style.Colors.Palette.triadic/1","doc":"iex> base = Raxol.Style.Colors.Color.from_hex(\"#4285F4\")\n    iex> palette = Raxol.Style.Colors.Palette.triadic(base)\n    iex> palette.name\n    \"Triadic\"","ref":"Raxol.Style.Colors.Palette.html#triadic/1-examples"},{"type":"module","title":"Raxol.Style.Colors.PaletteManager","doc":"Manages color palettes for the Raxol terminal emulator.\n\nThis module provides functionality to create, store, and retrieve color palettes.\nIt works with the ColorSystem to provide a comprehensive color management solution\nthat respects user preferences and accessibility settings.","ref":"Raxol.Style.Colors.PaletteManager.html"},{"type":"module","title":"Features - Raxol.Style.Colors.PaletteManager","doc":"- Create and manage named color palettes\n- Generate color scales (light to dark variations)\n- Create accessible color combinations\n- Calculate contrast ratios\n- Support for user preference persistence\n- Integration with the accessibility system","ref":"Raxol.Style.Colors.PaletteManager.html#module-features"},{"type":"module","title":"Usage - Raxol.Style.Colors.PaletteManager","doc":"```elixir\n# Initialize the palette manager\nPaletteManager.init()\n\n# Register a custom palette\nPaletteManager.register_palette(:brand, %{\n  main: \"#0077CC\",\n  accent: \"#FF5722\",\n  neutral: \"#F0F0F0\"\n})\n\n# Generate a color scale\nscale = PaletteManager.generate_scale(\"#0077CC\", 9)\n```","ref":"Raxol.Style.Colors.PaletteManager.html#module-usage"},{"type":"function","title":"Raxol.Style.Colors.PaletteManager.generate_scale/3","doc":"Generate a color scale from a base color.\n\nCreates a series of color variations from light to dark based on the given color.","ref":"Raxol.Style.Colors.PaletteManager.html#generate_scale/3"},{"type":"function","title":"Parameters - Raxol.Style.Colors.PaletteManager.generate_scale/3","doc":"* `base_color` - The starting color (hex string like \"#0077CC\")\n* `steps` - The number of steps in the scale (default: 9)\n* `opts` - Additional options","ref":"Raxol.Style.Colors.PaletteManager.html#generate_scale/3-parameters"},{"type":"function","title":"Options - Raxol.Style.Colors.PaletteManager.generate_scale/3","doc":"* `:name` - Name to identify this scale\n* `:lightness_range` - Tuple of {min_lightness, max_lightness} (default: {0.1, 0.9})\n* `:saturation_adjust` - Adjustment to saturation for each step (default: 0.05)","ref":"Raxol.Style.Colors.PaletteManager.html#generate_scale/3-options"},{"type":"function","title":"Examples - Raxol.Style.Colors.PaletteManager.generate_scale/3","doc":"iex> PaletteManager.generate_scale(\"#0077CC\", 9)\n    [\n      \"#E6F0FA\", \"#CCE0F5\", \"#B3D1F0\", \"#99C2EB\",\n      \"#80B3E6\", \"#66A3E0\", \"#4D94DB\", \"#3385D6\", \"#0077CC\"\n    ]","ref":"Raxol.Style.Colors.PaletteManager.html#generate_scale/3-examples"},{"type":"function","title":"Raxol.Style.Colors.PaletteManager.get_color/2","doc":"Get a color from a registered palette.","ref":"Raxol.Style.Colors.PaletteManager.html#get_color/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.PaletteManager.get_color/2","doc":"* `palette_name` - The name of the palette\n* `color_name` - The name of the color within the palette","ref":"Raxol.Style.Colors.PaletteManager.html#get_color/2-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.PaletteManager.get_color/2","doc":"iex> PaletteManager.get_color(:ocean, :main)\n    \"#0077CC\"","ref":"Raxol.Style.Colors.PaletteManager.html#get_color/2-examples"},{"type":"function","title":"Raxol.Style.Colors.PaletteManager.get_palettes/1","doc":"Get all registered palettes.","ref":"Raxol.Style.Colors.PaletteManager.html#get_palettes/1"},{"type":"function","title":"Options - Raxol.Style.Colors.PaletteManager.get_palettes/1","doc":"* `:category` - Filter palettes by category\n* `:tags` - Filter palettes by tags\n* `:accessible` - Filter by accessibility","ref":"Raxol.Style.Colors.PaletteManager.html#get_palettes/1-options"},{"type":"function","title":"Examples - Raxol.Style.Colors.PaletteManager.get_palettes/1","doc":"iex> PaletteManager.get_palettes()\n    %{ocean: %{colors: %{main: \"#0077CC\", ...}, ...}, ...}\n\n    iex> PaletteManager.get_palettes(category: :brand)\n    %{brand: %{colors: %{main: \"#FF5722\", ...}, ...}}","ref":"Raxol.Style.Colors.PaletteManager.html#get_palettes/1-examples"},{"type":"function","title":"Raxol.Style.Colors.PaletteManager.get_user_preferences/1","doc":"Get user color preferences.","ref":"Raxol.Style.Colors.PaletteManager.html#get_user_preferences/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.PaletteManager.get_user_preferences/1","doc":"* `user_id` - Identifier for the user","ref":"Raxol.Style.Colors.PaletteManager.html#get_user_preferences/1-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.PaletteManager.get_user_preferences/1","doc":"iex> PaletteManager.get_user_preferences(\"user123\")\n    %{theme: :dark, accent_color: \"#FF5722\"}","ref":"Raxol.Style.Colors.PaletteManager.html#get_user_preferences/1-examples"},{"type":"function","title":"Raxol.Style.Colors.PaletteManager.init/0","doc":"Initialize the palette manager.\n\nThis sets up the necessary state for managing color palettes and\nintegrates with the ColorSystem.","ref":"Raxol.Style.Colors.PaletteManager.html#init/0"},{"type":"function","title":"Examples - Raxol.Style.Colors.PaletteManager.init/0","doc":"iex> PaletteManager.init()\n    :ok","ref":"Raxol.Style.Colors.PaletteManager.html#init/0-examples"},{"type":"function","title":"Raxol.Style.Colors.PaletteManager.register_palette/3","doc":"Register a color palette.","ref":"Raxol.Style.Colors.PaletteManager.html#register_palette/3"},{"type":"function","title":"Parameters - Raxol.Style.Colors.PaletteManager.register_palette/3","doc":"* `palette_name` - Unique identifier for the palette\n* `colors` - Map of color names to color values\n* `opts` - Additional options","ref":"Raxol.Style.Colors.PaletteManager.html#register_palette/3-parameters"},{"type":"function","title":"Options - Raxol.Style.Colors.PaletteManager.register_palette/3","doc":"* `:description` - Description of the palette\n* `:category` - Category for organizing palettes\n* `:tags` - List of tags for filtering\n* `:accessible` - Whether the palette is designed for accessibility","ref":"Raxol.Style.Colors.PaletteManager.html#register_palette/3-options"},{"type":"function","title":"Examples - Raxol.Style.Colors.PaletteManager.register_palette/3","doc":"iex> PaletteManager.register_palette(:ocean, %{\n    ...>   main: \"#0077CC\",\n    ...>   accent: \"#00AAFF\",\n    ...>   background: \"#F0F7FF\"\n    ...> })\n    :ok","ref":"Raxol.Style.Colors.PaletteManager.html#register_palette/3-examples"},{"type":"function","title":"Raxol.Style.Colors.PaletteManager.save_user_preferences/2","doc":"Save user color preferences.","ref":"Raxol.Style.Colors.PaletteManager.html#save_user_preferences/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.PaletteManager.save_user_preferences/2","doc":"* `user_id` - Identifier for the user\n* `preferences` - Map of color preferences","ref":"Raxol.Style.Colors.PaletteManager.html#save_user_preferences/2-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.PaletteManager.save_user_preferences/2","doc":"iex> PaletteManager.save_user_preferences(\"user123\", %{\n    ...>   theme: :dark,\n    ...>   accent_color: \"#FF5722\"\n    ...> })\n    :ok","ref":"Raxol.Style.Colors.PaletteManager.html#save_user_preferences/2-examples"},{"type":"function","title":"Raxol.Style.Colors.PaletteManager.suggest_accessible_color/3","doc":"Suggest an accessible color alternative for a given color.","ref":"Raxol.Style.Colors.PaletteManager.html#suggest_accessible_color/3"},{"type":"function","title":"Parameters - Raxol.Style.Colors.PaletteManager.suggest_accessible_color/3","doc":"* `color` - The original color\n* `background` - The background color the text will appear on\n* `level` - The WCAG level to achieve (`:aa` or `:aaa`) (default: `:aa`)","ref":"Raxol.Style.Colors.PaletteManager.html#suggest_accessible_color/3-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.PaletteManager.suggest_accessible_color/3","doc":"iex> PaletteManager.suggest_accessible_color(\"#777777\", \"#FFFFFF\")\n    \"#595959\"","ref":"Raxol.Style.Colors.PaletteManager.html#suggest_accessible_color/3-examples"},{"type":"module","title":"Raxol.Style.Colors.Persistence","doc":"Handles persistence of color themes and user preferences.\n\nThis module provides functionality for:\n- Saving and loading themes\n- Managing user preferences\n- Handling theme file storage","ref":"Raxol.Style.Colors.Persistence.html"},{"type":"function","title":"Raxol.Style.Colors.Persistence.delete_theme/1","doc":"Deletes a theme.","ref":"Raxol.Style.Colors.Persistence.html#delete_theme/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Persistence.delete_theme/1","doc":"- `theme_name` - The name of the theme to delete","ref":"Raxol.Style.Colors.Persistence.html#delete_theme/1-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Persistence.delete_theme/1","doc":"- `:ok` on success\n- `{:error, reason}` on failure","ref":"Raxol.Style.Colors.Persistence.html#delete_theme/1-returns"},{"type":"function","title":"Raxol.Style.Colors.Persistence.list_themes/0","doc":"Lists all available themes.","ref":"Raxol.Style.Colors.Persistence.html#list_themes/0"},{"type":"function","title":"Returns - Raxol.Style.Colors.Persistence.list_themes/0","doc":"- A list of theme names","ref":"Raxol.Style.Colors.Persistence.html#list_themes/0-returns"},{"type":"function","title":"Raxol.Style.Colors.Persistence.load_current_theme/0","doc":"Loads the current theme from user preferences.","ref":"Raxol.Style.Colors.Persistence.html#load_current_theme/0"},{"type":"function","title":"Returns - Raxol.Style.Colors.Persistence.load_current_theme/0","doc":"- `{:ok, theme}` on success\n- `{:error, reason}` on failure","ref":"Raxol.Style.Colors.Persistence.html#load_current_theme/0-returns"},{"type":"function","title":"Raxol.Style.Colors.Persistence.load_theme/1","doc":"Loads a theme from a file.","ref":"Raxol.Style.Colors.Persistence.html#load_theme/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Persistence.load_theme/1","doc":"- `theme_name` - The name of the theme to load","ref":"Raxol.Style.Colors.Persistence.html#load_theme/1-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Persistence.load_theme/1","doc":"- `{:ok, theme}` on success\n- `{:error, reason}` on failure","ref":"Raxol.Style.Colors.Persistence.html#load_theme/1-returns"},{"type":"function","title":"Raxol.Style.Colors.Persistence.load_user_preferences/0","doc":"Loads user preferences from file.","ref":"Raxol.Style.Colors.Persistence.html#load_user_preferences/0"},{"type":"function","title":"Returns - Raxol.Style.Colors.Persistence.load_user_preferences/0","doc":"- `{:ok, preferences}` on success\n- `{:error, reason}` on failure","ref":"Raxol.Style.Colors.Persistence.html#load_user_preferences/0-returns"},{"type":"function","title":"Raxol.Style.Colors.Persistence.save_theme/1","doc":"Saves a theme to a file.","ref":"Raxol.Style.Colors.Persistence.html#save_theme/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Persistence.save_theme/1","doc":"- `theme` - The theme to save","ref":"Raxol.Style.Colors.Persistence.html#save_theme/1-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Persistence.save_theme/1","doc":"- `:ok` on success\n- `{:error, reason}` on failure","ref":"Raxol.Style.Colors.Persistence.html#save_theme/1-returns"},{"type":"function","title":"Raxol.Style.Colors.Persistence.save_user_preferences/1","doc":"Saves user preferences to file.","ref":"Raxol.Style.Colors.Persistence.html#save_user_preferences/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Persistence.save_user_preferences/1","doc":"- `preferences` - The preferences to save","ref":"Raxol.Style.Colors.Persistence.html#save_user_preferences/1-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Persistence.save_user_preferences/1","doc":"- `:ok` on success\n- `{:error, reason}` on failure","ref":"Raxol.Style.Colors.Persistence.html#save_user_preferences/1-returns"},{"type":"module","title":"Raxol.Style.Colors.System","doc":"Core color system for the Raxol terminal emulator.\n\nThis module provides a robust color system that:\n- Manages color palettes with semantic naming\n- Provides accessible color alternatives for high contrast mode\n- Supports theme customization\n- Calculates contrast ratios for text/background combinations\n- Automatically adjusts colors for optimal readability\n- Integrates with the accessibility module","ref":"Raxol.Style.Colors.System.html"},{"type":"module","title":"Usage - Raxol.Style.Colors.System","doc":"```elixir\n# Initialize the color system\nColorSystem.init()\n\n# Get a semantic color (will respect accessibility settings)\ncolor = ColorSystem.get_color(:primary)\n\n# Get a specific color variation\nhover_color = ColorSystem.get_color(:primary, :hover)\n\n# Register a custom theme\nColorSystem.register_theme(:ocean, %{\n  primary: \"#0077CC\",\n  secondary: \"#00AAFF\",\n  background: \"#001133\",\n  foreground: \"#FFFFFF\",\n  accent: \"#FF9900\"\n})\n\n# Apply a theme\nColorSystem.apply_theme(:ocean)\n```","ref":"Raxol.Style.Colors.System.html#module-usage"},{"type":"function","title":"Raxol.Style.Colors.System.apply_theme/2","doc":"Applies a theme to the color system.","ref":"Raxol.Style.Colors.System.html#apply_theme/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.System.apply_theme/2","doc":"- `theme` - The theme to apply\n- `opts` - Additional options\n  - `:high_contrast` - Whether to apply high contrast mode (default: current setting)","ref":"Raxol.Style.Colors.System.html#apply_theme/2-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.System.apply_theme/2","doc":"- `:ok` on success\n- `{:error, reason}` on failure","ref":"Raxol.Style.Colors.System.html#apply_theme/2-returns"},{"type":"function","title":"Raxol.Style.Colors.System.get_color/2","doc":"Get a color from the current theme.\n\nThis function respects the current accessibility settings, automatically\nreturning high-contrast alternatives when needed.","ref":"Raxol.Style.Colors.System.html#get_color/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.System.get_color/2","doc":"* `color_name` - The semantic name of the color (e.g., `:primary`, `:error`)\n* `variant` - The variant of the color (e.g., `:base`, `:hover`, `:active`) (default: `:base`)","ref":"Raxol.Style.Colors.System.html#get_color/2-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.System.get_color/2","doc":"iex> ColorSystem.get_color(:primary)\n    \"#0077CC\"\n\n    iex> ColorSystem.get_color(:primary, :hover)\n    \"#0088DD\"","ref":"Raxol.Style.Colors.System.html#get_color/2-examples"},{"type":"function","title":"Raxol.Style.Colors.System.handle_high_contrast/1","doc":"Handle high contrast mode changes from the accessibility module.","ref":"Raxol.Style.Colors.System.html#handle_high_contrast/1"},{"type":"function","title":"Raxol.Style.Colors.System.init/1","doc":"Initialize the color system.\n\nThis sets up the default themes, registers event handlers for accessibility changes,\nand establishes the default color palette.","ref":"Raxol.Style.Colors.System.html#init/1"},{"type":"function","title":"Options - Raxol.Style.Colors.System.init/1","doc":"* `:theme` - The initial theme to use (default: `:standard`)\n* `:high_contrast` - Whether to start in high contrast mode (default: from accessibility settings)","ref":"Raxol.Style.Colors.System.html#init/1-options"},{"type":"function","title":"Examples - Raxol.Style.Colors.System.init/1","doc":"iex> ColorSystem.init()\n    :ok\n\n    iex> ColorSystem.init(theme: :dark)\n    :ok","ref":"Raxol.Style.Colors.System.html#init/1-examples"},{"type":"function","title":"Raxol.Style.Colors.System.register_theme/3","doc":"Register a custom theme.","ref":"Raxol.Style.Colors.System.html#register_theme/3"},{"type":"function","title":"Parameters - Raxol.Style.Colors.System.register_theme/3","doc":"* `theme_name` - Unique identifier for the theme\n* `colors` - Map of color names to color values\n* `opts` - Additional options","ref":"Raxol.Style.Colors.System.html#register_theme/3-parameters"},{"type":"function","title":"Options - Raxol.Style.Colors.System.register_theme/3","doc":"* `:high_contrast_colors` - Map of high contrast alternatives\n* `:variants` - Map of color variants (hover, active, etc.)","ref":"Raxol.Style.Colors.System.html#register_theme/3-options"},{"type":"function","title":"Examples - Raxol.Style.Colors.System.register_theme/3","doc":"iex> ColorSystem.register_theme(:ocean, %{\n    ...>   primary: \"#0077CC\",\n    ...>   secondary: \"#00AAFF\",\n    ...>   background: \"#001133\",\n    ...>   foreground: \"#FFFFFF\",\n    ...>   accent: \"#FF9900\"\n    ...> })\n    :ok","ref":"Raxol.Style.Colors.System.html#register_theme/3-examples"},{"type":"module","title":"Raxol.Style.Colors.Theme","doc":"Manages color themes for the Raxol application.\n\nThis module provides functionality for:\n- Creating and managing themes\n- Applying themes to the application\n- Accessing theme colors\n- Updating theme colors","ref":"Raxol.Style.Colors.Theme.html"},{"type":"function","title":"Raxol.Style.Colors.Theme.apply_theme/1","doc":"Applies a theme to the application.","ref":"Raxol.Style.Colors.Theme.html#apply_theme/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Theme.apply_theme/1","doc":"- `theme` - The theme to apply","ref":"Raxol.Style.Colors.Theme.html#apply_theme/1-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Theme.apply_theme/1","doc":"- `:ok` on success\n- `{:error, reason}` on failure","ref":"Raxol.Style.Colors.Theme.html#apply_theme/1-returns"},{"type":"type","title":"Raxol.Style.Colors.Theme.color/0","doc":"","ref":"Raxol.Style.Colors.Theme.html#t:color/0"},{"type":"function","title":"Raxol.Style.Colors.Theme.create_dark_theme/1","doc":"Creates a dark mode version of a theme.","ref":"Raxol.Style.Colors.Theme.html#create_dark_theme/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Theme.create_dark_theme/1","doc":"- `theme` - The theme to create a dark mode version of","ref":"Raxol.Style.Colors.Theme.html#create_dark_theme/1-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Theme.create_dark_theme/1","doc":"- A new theme with dark mode colors","ref":"Raxol.Style.Colors.Theme.html#create_dark_theme/1-returns"},{"type":"function","title":"Raxol.Style.Colors.Theme.create_high_contrast_theme/1","doc":"Creates a high contrast version of a theme.","ref":"Raxol.Style.Colors.Theme.html#create_high_contrast_theme/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Theme.create_high_contrast_theme/1","doc":"- `theme` - The theme to create a high contrast version of","ref":"Raxol.Style.Colors.Theme.html#create_high_contrast_theme/1-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Theme.create_high_contrast_theme/1","doc":"- A new theme with high contrast colors","ref":"Raxol.Style.Colors.Theme.html#create_high_contrast_theme/1-returns"},{"type":"function","title":"Raxol.Style.Colors.Theme.from_palette/2","doc":"Creates a new theme from a given palette map and optional name.\n\nAssumes the input palette map contains Color structs or maps convertible to Color structs.","ref":"Raxol.Style.Colors.Theme.html#from_palette/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Theme.from_palette/2","doc":"- `palette` - A map representing the color palette (e.g., %{\"primary\" => %{r: 0, g: 119, b: 204, a: 1.0}, ...})\n- `name` (optional) - The name for the theme. Defaults to \"Custom\".","ref":"Raxol.Style.Colors.Theme.html#from_palette/2-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Theme.from_palette/2","doc":"- A new theme struct.","ref":"Raxol.Style.Colors.Theme.html#from_palette/2-returns"},{"type":"function","title":"Examples - Raxol.Style.Colors.Theme.from_palette/2","doc":"iex> nord_palette = Raxol.Style.Colors.Palette.nord()\n    iex> theme = Raxol.Style.Colors.Theme.from_palette(nord_palette, \"Nord Theme\")\n    iex> theme.name\n    \"Nord Theme\"\n    iex> theme.palette[\"polar_night_1\"]\n    %{r: 46, g: 52, b: 64, a: 1.0}","ref":"Raxol.Style.Colors.Theme.html#from_palette/2-examples"},{"type":"function","title":"Raxol.Style.Colors.Theme.get_all_ui_colors/1","doc":"Gets all UI colors from a theme.","ref":"Raxol.Style.Colors.Theme.html#get_all_ui_colors/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Theme.get_all_ui_colors/1","doc":"- `theme` - The theme to get the colors from","ref":"Raxol.Style.Colors.Theme.html#get_all_ui_colors/1-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Theme.get_all_ui_colors/1","doc":"- A map of UI elements to their colors","ref":"Raxol.Style.Colors.Theme.html#get_all_ui_colors/1-returns"},{"type":"function","title":"Raxol.Style.Colors.Theme.get_ui_color/2","doc":"Gets a UI color from a theme.","ref":"Raxol.Style.Colors.Theme.html#get_ui_color/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Theme.get_ui_color/2","doc":"- `theme` - The theme to get the color from\n- `element` - The UI element to get the color for","ref":"Raxol.Style.Colors.Theme.html#get_ui_color/2-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Theme.get_ui_color/2","doc":"- The color for the specified UI element","ref":"Raxol.Style.Colors.Theme.html#get_ui_color/2-returns"},{"type":"function","title":"Raxol.Style.Colors.Theme.standard_theme/0","doc":"Creates a standard theme with default colors.","ref":"Raxol.Style.Colors.Theme.html#standard_theme/0"},{"type":"function","title":"Returns - Raxol.Style.Colors.Theme.standard_theme/0","doc":"- A new theme with default colors","ref":"Raxol.Style.Colors.Theme.html#standard_theme/0-returns"},{"type":"type","title":"Raxol.Style.Colors.Theme.theme/0","doc":"","ref":"Raxol.Style.Colors.Theme.html#t:theme/0"},{"type":"function","title":"Raxol.Style.Colors.Theme.update_ui_colors/2","doc":"Updates UI colors in a theme.","ref":"Raxol.Style.Colors.Theme.html#update_ui_colors/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Theme.update_ui_colors/2","doc":"- `theme` - The theme to update\n- `colors` - A map of UI elements to their new colors","ref":"Raxol.Style.Colors.Theme.html#update_ui_colors/2-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Theme.update_ui_colors/2","doc":"- The updated theme","ref":"Raxol.Style.Colors.Theme.html#update_ui_colors/2-returns"},{"type":"module","title":"Raxol.Style.Colors.Utilities","doc":"Provides basic color utility functions.\n\nIncludes checks for dark colors, brightness, luminance, and hex format.","ref":"Raxol.Style.Colors.Utilities.html"},{"type":"module","title":"Examples - Raxol.Style.Colors.Utilities","doc":"```elixir\nalias Raxol.Style.Colors.{Color, Utilities}\n\n# Check if a color is dark\nUtilities.dark_color?(\"#333333\") # true\n\n# Get perceived brightness\nUtilities.brightness(Color.from_hex(\"#FF0000\")) # 76\n\n# Check hex format\nUtilities.hex_color?(\"#ABC\") # true\nUtilities.hex_color?(\"blue\") # false\n```","ref":"Raxol.Style.Colors.Utilities.html#module-examples"},{"type":"function","title":"Raxol.Style.Colors.Utilities.brightness/1","doc":"Calculates the perceived brightness of a color.\n\nReturns a value between 0 (darkest) and 255 (brightest).","ref":"Raxol.Style.Colors.Utilities.html#brightness/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Utilities.brightness/1","doc":"- `color` - The color to analyze","ref":"Raxol.Style.Colors.Utilities.html#brightness/1-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Utilities.brightness/1","doc":"iex> black = Raxol.Style.Colors.Color.from_hex(\"#000000\")\n    iex> Raxol.Style.Colors.Utilities.brightness(black)\n    0\n\n    iex> white = Raxol.Style.Colors.Color.from_hex(\"#FFFFFF\")\n    iex> Raxol.Style.Colors.Utilities.brightness(white)\n    255","ref":"Raxol.Style.Colors.Utilities.html#brightness/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Utilities.contrast_ratio/2","doc":"Calculates the contrast ratio between two colors according to WCAG guidelines.","ref":"Raxol.Style.Colors.Utilities.html#contrast_ratio/2"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Utilities.contrast_ratio/2","doc":"- `color1` - The first color (hex string or Color struct)\n- `color2` - The second color (hex string or Color struct)","ref":"Raxol.Style.Colors.Utilities.html#contrast_ratio/2-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Utilities.contrast_ratio/2","doc":"- A float representing the contrast ratio (1:1 to 21:1)","ref":"Raxol.Style.Colors.Utilities.html#contrast_ratio/2-returns"},{"type":"function","title":"Examples - Raxol.Style.Colors.Utilities.contrast_ratio/2","doc":"iex> Raxol.Style.Colors.Utilities.contrast_ratio(\"#000000\", \"#FFFFFF\")\n    21.0\n\n    iex> Raxol.Style.Colors.Utilities.contrast_ratio(\"#777777\", \"#999999\")\n    1.3","ref":"Raxol.Style.Colors.Utilities.html#contrast_ratio/2-examples"},{"type":"function","title":"Raxol.Style.Colors.Utilities.dark_color?/1","doc":"Checks if a color is considered dark.\n\nUses relative luminance (a value < 0.5 is considered dark).","ref":"Raxol.Style.Colors.Utilities.html#dark_color?/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Utilities.dark_color?/1","doc":"- `color` - The color to check (hex string or Color struct)","ref":"Raxol.Style.Colors.Utilities.html#dark_color?/1-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Utilities.dark_color?/1","doc":"- `true` if the color is dark, `false` otherwise","ref":"Raxol.Style.Colors.Utilities.html#dark_color?/1-returns"},{"type":"function","title":"Examples - Raxol.Style.Colors.Utilities.dark_color?/1","doc":"iex> Raxol.Style.Colors.Utilities.dark_color?(\"#000000\")\n    true\n\n    iex> Raxol.Style.Colors.Utilities.dark_color?(\"#FFFFFF\")\n    false","ref":"Raxol.Style.Colors.Utilities.html#dark_color?/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Utilities.hex_color?/1","doc":"Checks if a hex string is a valid hex color.","ref":"Raxol.Style.Colors.Utilities.html#hex_color?/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Utilities.hex_color?/1","doc":"- `hex_string` - The hex string to check","ref":"Raxol.Style.Colors.Utilities.html#hex_color?/1-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Utilities.hex_color?/1","doc":"- `true` if the hex string is a valid hex color, `false` otherwise","ref":"Raxol.Style.Colors.Utilities.html#hex_color?/1-returns"},{"type":"function","title":"Examples - Raxol.Style.Colors.Utilities.hex_color?/1","doc":"iex> Raxol.Style.Colors.Utilities.hex_color?(\"#FF00AA\")\n    true\n    iex> Raxol.Style.Colors.Utilities.hex_color?(\"blue\")\n    false","ref":"Raxol.Style.Colors.Utilities.html#hex_color?/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Utilities.luminance/1","doc":"Calculates the relative luminance of a color according to WCAG.\n\nReturns a value between 0 (darkest) and 1 (brightest).","ref":"Raxol.Style.Colors.Utilities.html#luminance/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Utilities.luminance/1","doc":"- `color` - The color to analyze","ref":"Raxol.Style.Colors.Utilities.html#luminance/1-parameters"},{"type":"function","title":"Examples - Raxol.Style.Colors.Utilities.luminance/1","doc":"iex> black = Raxol.Style.Colors.Color.from_hex(\"#000000\")\n    iex> Raxol.Style.Colors.Utilities.luminance(black)\n    0.0\n\n    iex> white = Raxol.Style.Colors.Color.from_hex(\"#FFFFFF\")\n    iex> Raxol.Style.Colors.Utilities.luminance(white)\n    1.0","ref":"Raxol.Style.Colors.Utilities.html#luminance/1-examples"},{"type":"function","title":"Raxol.Style.Colors.Utilities.relative_luminance/1","doc":"Calculates the relative luminance of a color according to WCAG guidelines.","ref":"Raxol.Style.Colors.Utilities.html#relative_luminance/1"},{"type":"function","title":"Parameters - Raxol.Style.Colors.Utilities.relative_luminance/1","doc":"- `color` - The color to calculate luminance for (hex string or Color struct)","ref":"Raxol.Style.Colors.Utilities.html#relative_luminance/1-parameters"},{"type":"function","title":"Returns - Raxol.Style.Colors.Utilities.relative_luminance/1","doc":"- A float between 0 and 1 representing the relative luminance","ref":"Raxol.Style.Colors.Utilities.html#relative_luminance/1-returns"},{"type":"function","title":"Examples - Raxol.Style.Colors.Utilities.relative_luminance/1","doc":"iex> Raxol.Style.Colors.Utilities.relative_luminance(\"#000000\")\n    0.0\n\n    iex> Raxol.Style.Colors.Utilities.relative_luminance(\"#FFFFFF\")\n    1.0","ref":"Raxol.Style.Colors.Utilities.html#relative_luminance/1-examples"},{"type":"module","title":"Raxol.Style.Layout","doc":"Defines layout properties for terminal UI elements.","ref":"Raxol.Style.Layout.html"},{"type":"function","title":"Raxol.Style.Layout.merge/2","doc":"Merges two layout structs, with the second overriding the first.","ref":"Raxol.Style.Layout.html#merge/2"},{"type":"function","title":"Raxol.Style.Layout.new/0","doc":"Creates a new layout with default values.","ref":"Raxol.Style.Layout.html#new/0"},{"type":"function","title":"Raxol.Style.Layout.new/1","doc":"Creates a new layout with the specified values.","ref":"Raxol.Style.Layout.html#new/1"},{"type":"type","title":"Raxol.Style.Layout.t/0","doc":"","ref":"Raxol.Style.Layout.html#t:t/0"},{"type":"module","title":"Raxol.Style.Theme","doc":"Theme management for Raxol applications.\n\nThis module provides functionality for creating, switching, and customizing themes.\nThemes define the visual appearance of the application, including colors, borders,\nand component-specific styles.","ref":"Raxol.Style.Theme.html"},{"type":"function","title":"Raxol.Style.Theme.apply_theme/1","doc":"Applies a theme by its name, setting it as the current theme for the process.\n\nReturns `:ok` if the theme was found and applied, `:error` otherwise.","ref":"Raxol.Style.Theme.html#apply_theme/1"},{"type":"function","title":"Raxol.Style.Theme.available_themes/0","doc":"","ref":"Raxol.Style.Theme.html#available_themes/0"},{"type":"function","title":"Raxol.Style.Theme.create_high_contrast_variant/0","doc":"Creates and registers a high-contrast variant based on predefined high-contrast colors.\nThis variant overrides the color palette.","ref":"Raxol.Style.Theme.html#create_high_contrast_variant/0"},{"type":"function","title":"Raxol.Style.Theme.current/0","doc":"Gets the current active theme.\nReturns the default theme if none is set.","ref":"Raxol.Style.Theme.html#current/0"},{"type":"function","title":"Raxol.Style.Theme.export/0","doc":"Exports the current theme as a map suitable for serialization.","ref":"Raxol.Style.Theme.html#export/0"},{"type":"function","title":"Raxol.Style.Theme.get_color/2","doc":"Gets a color from the current theme's palette, considering active variants.\nChecks the active variant first, then the base palette.\n(Note: Need a way to know the active variant - maybe from Accessibility state?)\nThis is a placeholder - the logic to check active variant needs refinement.","ref":"Raxol.Style.Theme.html#get_color/2"},{"type":"function","title":"Raxol.Style.Theme.get_style/1","doc":"Gets a style from the current theme by name.","ref":"Raxol.Style.Theme.html#get_style/1"},{"type":"function","title":"Raxol.Style.Theme.get_theme_by_name/1","doc":"Gets a specific theme struct by its name.\nReturns nil if the theme name is not found.","ref":"Raxol.Style.Theme.html#get_theme_by_name/1"},{"type":"function","title":"Raxol.Style.Theme.import/1","doc":"Imports a theme from the given map data.","ref":"Raxol.Style.Theme.html#import/1"},{"type":"function","title":"Raxol.Style.Theme.list_themes/0","doc":"Returns a list of available theme structs.","ref":"Raxol.Style.Theme.html#list_themes/0"},{"type":"function","title":"Raxol.Style.Theme.new/1","doc":"Creates a new theme with the specified attributes.","ref":"Raxol.Style.Theme.html#new/1"},{"type":"function","title":"Raxol.Style.Theme.register_style/2","doc":"Registers a new style in the current theme.","ref":"Raxol.Style.Theme.html#register_style/2"},{"type":"function","title":"Raxol.Style.Theme.register_variant/2","doc":"Registers a theme variant.\nTheme variants allow for alternate visual styles like high-contrast, dark mode, etc.\nA variant can include overrides for both :styles and :color_palette.","ref":"Raxol.Style.Theme.html#register_variant/2"},{"type":"function","title":"Raxol.Style.Theme.set_color_palette/1","doc":"Sets the color palette for the current theme.","ref":"Raxol.Style.Theme.html#set_color_palette/1"},{"type":"function","title":"Raxol.Style.Theme.set_current/1","doc":"Sets the current active theme.","ref":"Raxol.Style.Theme.html#set_current/1"},{"type":"type","title":"Raxol.Style.Theme.t/0","doc":"","ref":"Raxol.Style.Theme.html#t:t/0"},{"type":"module","title":"Raxol.System.DeltaUpdater","doc":"Handles delta updates for the Raxol terminal emulator.","ref":"Raxol.System.DeltaUpdater.html"},{"type":"function","title":"Raxol.System.DeltaUpdater.apply_delta_update/2","doc":"","ref":"Raxol.System.DeltaUpdater.html#apply_delta_update/2"},{"type":"function","title":"Raxol.System.DeltaUpdater.check_delta_availability/1","doc":"","ref":"Raxol.System.DeltaUpdater.html#check_delta_availability/1"},{"type":"module","title":"Raxol.System.Platform","doc":"Platform-specific functionality and detection for Raxol.\n\nThis module handles detection of the current platform, providing platform-specific\ninformation, and managing platform-dependent operations.","ref":"Raxol.System.Platform.html"},{"type":"function","title":"Raxol.System.Platform.get_current_platform/0","doc":"Returns the current platform as an atom.","ref":"Raxol.System.Platform.html#get_current_platform/0"},{"type":"function","title":"Returns - Raxol.System.Platform.get_current_platform/0","doc":"* `:macos` - macOS (Darwin)\n* `:linux` - Linux variants\n* `:windows` - Windows","ref":"Raxol.System.Platform.html#get_current_platform/0-returns"},{"type":"function","title":"Examples - Raxol.System.Platform.get_current_platform/0","doc":"iex> Platform.get_current_platform()\n    :macos","ref":"Raxol.System.Platform.html#get_current_platform/0-examples"},{"type":"function","title":"Raxol.System.Platform.get_executable_name/0","doc":"Returns the executable name for the current platform.","ref":"Raxol.System.Platform.html#get_executable_name/0"},{"type":"function","title":"Returns - Raxol.System.Platform.get_executable_name/0","doc":"* `\"raxol.exe\"` - Windows platforms\n* `\"raxol\"` - Unix platforms (macOS, Linux)","ref":"Raxol.System.Platform.html#get_executable_name/0-returns"},{"type":"function","title":"Examples - Raxol.System.Platform.get_executable_name/0","doc":"iex> Platform.get_executable_name()\n    \"raxol\"","ref":"Raxol.System.Platform.html#get_executable_name/0-examples"},{"type":"function","title":"Raxol.System.Platform.get_platform_extension/0","doc":"Returns the file extension for the current platform.","ref":"Raxol.System.Platform.html#get_platform_extension/0"},{"type":"function","title":"Returns - Raxol.System.Platform.get_platform_extension/0","doc":"* `\"zip\"` - Windows platforms\n* `\"tar.gz\"` - Unix platforms (macOS, Linux)","ref":"Raxol.System.Platform.html#get_platform_extension/0-returns"},{"type":"function","title":"Examples - Raxol.System.Platform.get_platform_extension/0","doc":"iex> Platform.get_platform_extension()\n    \"tar.gz\"","ref":"Raxol.System.Platform.html#get_platform_extension/0-examples"},{"type":"function","title":"Raxol.System.Platform.get_platform_info/0","doc":"Gathers detailed information about the current platform.","ref":"Raxol.System.Platform.html#get_platform_info/0"},{"type":"function","title":"Returns - Raxol.System.Platform.get_platform_info/0","doc":"A map containing platform details including:\n\n* `:name` - Platform name (e.g., \"macOS\", \"Linux\", \"Windows\")\n* `:version` - OS version if available\n* `:architecture` - CPU architecture (e.g., \"x86_64\", \"arm64\")\n* `:terminal` - Current terminal information if available","ref":"Raxol.System.Platform.html#get_platform_info/0-returns"},{"type":"function","title":"Examples - Raxol.System.Platform.get_platform_info/0","doc":"iex> Platform.get_platform_info()\n    %{\n      name: \"macOS\",\n      version: \"12.6\",\n      architecture: \"arm64\",\n      terminal: \"iTerm.app\"\n    }","ref":"Raxol.System.Platform.html#get_platform_info/0-examples"},{"type":"function","title":"Raxol.System.Platform.get_platform_name/0","doc":"Returns the platform name as a string.","ref":"Raxol.System.Platform.html#get_platform_name/0"},{"type":"function","title":"Returns - Raxol.System.Platform.get_platform_name/0","doc":"* `\"macos\"` - macOS (Darwin)\n* `\"linux\"` - Linux variants\n* `\"windows\"` - Windows","ref":"Raxol.System.Platform.html#get_platform_name/0-returns"},{"type":"function","title":"Examples - Raxol.System.Platform.get_platform_name/0","doc":"iex> Platform.get_platform_name()\n    \"macos\"","ref":"Raxol.System.Platform.html#get_platform_name/0-examples"},{"type":"function","title":"Raxol.System.Platform.supports_feature?/1","doc":"Detects if the feature is supported on the current platform.","ref":"Raxol.System.Platform.html#supports_feature?/1"},{"type":"function","title":"Parameters - Raxol.System.Platform.supports_feature?/1","doc":"* `feature` - Feature name as an atom (e.g., `:true_color`, `:unicode`, `:mouse`)","ref":"Raxol.System.Platform.html#supports_feature?/1-parameters"},{"type":"function","title":"Returns - Raxol.System.Platform.supports_feature?/1","doc":"* `true` - Feature is supported on the current platform\n* `false` - Feature is not supported or support is uncertain","ref":"Raxol.System.Platform.html#supports_feature?/1-returns"},{"type":"function","title":"Examples - Raxol.System.Platform.supports_feature?/1","doc":"iex> Platform.supports_feature?(:true_color)\n    true","ref":"Raxol.System.Platform.html#supports_feature?/1-examples"},{"type":"module","title":"Raxol.System.TerminalPlatform","doc":"Terminal-specific platform features and compatibility checks.\n\nThis module provides detailed information about terminal capabilities,\nfeature support, and compatibility across different platforms and terminal emulators.","ref":"Raxol.System.TerminalPlatform.html"},{"type":"function","title":"Raxol.System.TerminalPlatform.get_supported_features/0","doc":"Returns the list of all supported terminal features.","ref":"Raxol.System.TerminalPlatform.html#get_supported_features/0"},{"type":"function","title":"Returns - Raxol.System.TerminalPlatform.get_supported_features/0","doc":"List of supported feature atoms.","ref":"Raxol.System.TerminalPlatform.html#get_supported_features/0-returns"},{"type":"function","title":"Examples - Raxol.System.TerminalPlatform.get_supported_features/0","doc":"iex> TerminalPlatform.get_supported_features()\n    [:true_color, :unicode, :mouse, :clipboard]","ref":"Raxol.System.TerminalPlatform.html#get_supported_features/0-examples"},{"type":"function","title":"Raxol.System.TerminalPlatform.get_terminal_capabilities/0","doc":"Returns detailed information about the current terminal's capabilities.","ref":"Raxol.System.TerminalPlatform.html#get_terminal_capabilities/0"},{"type":"function","title":"Returns - Raxol.System.TerminalPlatform.get_terminal_capabilities/0","doc":"A map containing terminal capabilities including:\n\n* `:name` - Terminal name/type\n* `:version` - Terminal version if available\n* `:features` - List of supported features\n* `:colors` - Color support information\n* `:unicode` - Unicode support details\n* `:input` - Input capabilities\n* `:output` - Output capabilities","ref":"Raxol.System.TerminalPlatform.html#get_terminal_capabilities/0-returns"},{"type":"function","title":"Examples - Raxol.System.TerminalPlatform.get_terminal_capabilities/0","doc":"iex> TerminalPlatform.get_terminal_capabilities()\n    %{\n      name: \"iTerm2\",\n      version: \"3.5.0\",\n      features: [:true_color, :unicode, :mouse, :clipboard],\n      colors: %{\n        basic: true,\n        true_color: true,\n        palette: \"default\"\n      },\n      unicode: %{\n        support: true,\n        width: :ambiguous,\n        emoji: true\n      },\n      input: %{\n        mouse: true,\n        bracketed_paste: true,\n        focus: true\n      },\n      output: %{\n        title: true,\n        bell: true,\n        alternate_screen: true\n      }\n    }","ref":"Raxol.System.TerminalPlatform.html#get_terminal_capabilities/0-examples"},{"type":"function","title":"Raxol.System.TerminalPlatform.supports_feature?/1","doc":"Checks if a specific terminal feature is supported.","ref":"Raxol.System.TerminalPlatform.html#supports_feature?/1"},{"type":"function","title":"Parameters - Raxol.System.TerminalPlatform.supports_feature?/1","doc":"* `feature` - Feature to check for support","ref":"Raxol.System.TerminalPlatform.html#supports_feature?/1-parameters"},{"type":"function","title":"Returns - Raxol.System.TerminalPlatform.supports_feature?/1","doc":"* `true` - Feature is supported\n* `false` - Feature is not supported","ref":"Raxol.System.TerminalPlatform.html#supports_feature?/1-returns"},{"type":"function","title":"Examples - Raxol.System.TerminalPlatform.supports_feature?/1","doc":"iex> TerminalPlatform.supports_feature?(:true_color)\n    true","ref":"Raxol.System.TerminalPlatform.html#supports_feature?/1-examples"},{"type":"type","title":"Raxol.System.TerminalPlatform.terminal_feature/0","doc":"","ref":"Raxol.System.TerminalPlatform.html#t:terminal_feature/0"},{"type":"module","title":"Raxol.System.Updater","doc":"Provides version management and self-update functionality for Raxol.\n\nThis module handles:\n- Checking for updates from GitHub releases\n- Comparing versions to determine if updates are available\n- Self-updating the application when running as a compiled binary\n- Managing update settings and configurations","ref":"Raxol.System.Updater.html"},{"type":"function","title":"Raxol.System.Updater.check_for_updates/1","doc":"Checks if a newer version of Raxol is available.\n\nReturns a tuple with the check result and the latest version if available:\n- `{:no_update, current_version}` - No update available\n- `{:update_available, latest_version}` - Update available\n- `{:error, reason}` - Error occurred during check","ref":"Raxol.System.Updater.html#check_for_updates/1"},{"type":"function","title":"Parameters - Raxol.System.Updater.check_for_updates/1","doc":"- `force`: When set to `true`, bypasses the update check interval. Defaults to `false`.","ref":"Raxol.System.Updater.html#check_for_updates/1-parameters"},{"type":"function","title":"Examples - Raxol.System.Updater.check_for_updates/1","doc":"iex> Raxol.System.Updater.check_for_updates()\n    {:no_update, \"0.1.0\"}\n\n    iex> Raxol.System.Updater.check_for_updates(force: true)\n    {:update_available, \"0.2.0\"}","ref":"Raxol.System.Updater.html#check_for_updates/1-examples"},{"type":"function","title":"Raxol.System.Updater.do_replace_executable/3","doc":"","ref":"Raxol.System.Updater.html#do_replace_executable/3"},{"type":"function","title":"Raxol.System.Updater.notify_if_update_available/0","doc":"Displays update information to the user, if an update is available.\n\nThis function checks for updates (respecting the check interval) and\noutputs a message to the user if an update is available.","ref":"Raxol.System.Updater.html#notify_if_update_available/0"},{"type":"function","title":"Examples - Raxol.System.Updater.notify_if_update_available/0","doc":"iex> Raxol.System.Updater.notify_if_update_available()\n    :ok","ref":"Raxol.System.Updater.html#notify_if_update_available/0-examples"},{"type":"function","title":"Raxol.System.Updater.self_update/2","doc":"Performs a self-update of the application if running as a compiled binary.\n\nReturns:\n- `:ok` - Update successfully completed\n- `{:error, reason}` - Error occurred during update\n- `{:no_update, current_version}` - No update needed","ref":"Raxol.System.Updater.html#self_update/2"},{"type":"function","title":"Parameters - Raxol.System.Updater.self_update/2","doc":"- `version`: The version to update to. If not provided, updates to the latest version.\n- `opts`: Options for the update process:\n  - `:use_delta`: Whether to try using delta updates (default: true)","ref":"Raxol.System.Updater.html#self_update/2-parameters"},{"type":"function","title":"Examples - Raxol.System.Updater.self_update/2","doc":"iex> Raxol.System.Updater.self_update()\n    :ok\n\n    iex> Raxol.System.Updater.self_update(\"0.2.0\")\n    {:error, \"Not running as a compiled binary\"}","ref":"Raxol.System.Updater.html#self_update/2-examples"},{"type":"function","title":"Raxol.System.Updater.set_auto_check/1","doc":"Enables or disables automatic update checks.","ref":"Raxol.System.Updater.html#set_auto_check/1"},{"type":"function","title":"Parameters - Raxol.System.Updater.set_auto_check/1","doc":"- `enabled`: Whether to enable or disable automatic update checks","ref":"Raxol.System.Updater.html#set_auto_check/1-parameters"},{"type":"function","title":"Examples - Raxol.System.Updater.set_auto_check/1","doc":"iex> Raxol.System.Updater.set_auto_check(true)\n    :ok\n\n    iex> Raxol.System.Updater.set_auto_check(false)\n    :ok","ref":"Raxol.System.Updater.html#set_auto_check/1-examples"},{"type":"module","title":"Raxol.Terminal.ANSI","doc":"ANSI escape sequence handling.\n\nDEPRECATED: This module is being refactored into smaller, more focused modules.\nUse the modules in the Raxol.Terminal.ANSI namespace instead:\n\n- Raxol.Terminal.ANSI.Parser - For parsing ANSI sequences\n- Raxol.Terminal.ANSI.Emitter - For generating ANSI sequences\n- Raxol.Terminal.ANSI.Processor - For processing ANSI sequences\n- Raxol.Terminal.ANSI.Sequences.{Cursor, Colors, Modes} - For specific sequence types\n\nThis module is maintained for backward compatibility and will be removed in a future release.","ref":"Raxol.Terminal.ANSI.html"},{"type":"function","title":"Raxol.Terminal.ANSI.colors/0","doc":"Returns a map of ANSI color codes.\n\nDEPRECATED: Use Raxol.Terminal.ANSI.Sequences.Colors.color_codes/0 instead.","ref":"Raxol.Terminal.ANSI.html#colors/0"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.colors/0","doc":"A map of color names to ANSI codes.","ref":"Raxol.Terminal.ANSI.html#colors/0-returns"},{"type":"function","title":"Migration Path - Raxol.Terminal.ANSI.colors/0","doc":"```elixir\n# Before\ncolors = Raxol.Terminal.ANSI.colors()\n\n# After\ncolors = Raxol.Terminal.ANSI.Sequences.Colors.color_codes()\n```","ref":"Raxol.Terminal.ANSI.html#colors/0-migration-path"},{"type":"function","title":"Raxol.Terminal.ANSI.parse/1","doc":"Parses ANSI escape sequences from a string.\n\nDEPRECATED: Use Raxol.Terminal.ANSI.Parser.parse/1 instead.","ref":"Raxol.Terminal.ANSI.html#parse/1"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.parse/1","doc":"* `input` - The string containing ANSI escape sequences","ref":"Raxol.Terminal.ANSI.html#parse/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.parse/1","doc":"A list of parsed tokens.","ref":"Raxol.Terminal.ANSI.html#parse/1-returns"},{"type":"function","title":"Migration Path - Raxol.Terminal.ANSI.parse/1","doc":"```elixir\n# Before\ntokens = Raxol.Terminal.ANSI.parse(input)\n\n# After\ntokens = Raxol.Terminal.ANSI.Parser.parse(input)\n```","ref":"Raxol.Terminal.ANSI.html#parse/1-migration-path"},{"type":"function","title":"Raxol.Terminal.ANSI.process_escape/2","doc":"Processes an ANSI escape sequence.\n\nDEPRECATED: Use the Processor and specific sequence handler modules instead.","ref":"Raxol.Terminal.ANSI.html#process_escape/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.process_escape/2","doc":"* `sequence` - The ANSI escape sequence to process\n* `state` - The current state","ref":"Raxol.Terminal.ANSI.html#process_escape/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.process_escape/2","doc":"Updated state after processing the sequence.","ref":"Raxol.Terminal.ANSI.html#process_escape/2-returns"},{"type":"function","title":"Migration Path - Raxol.Terminal.ANSI.process_escape/2","doc":"```elixir\n# Before\nnew_state = Raxol.Terminal.ANSI.process_escape(sequence, state)\n\n# After\nparsed = Raxol.Terminal.ANSI.Parser.parse_sequence(sequence)\nnew_state = Raxol.Terminal.ANSI.Processor.process(parsed, state)\n```","ref":"Raxol.Terminal.ANSI.html#process_escape/2-migration-path"},{"type":"module","title":"Raxol.Terminal.ANSI.CharacterSets","doc":"Manages character set switching and translation for the terminal emulator.\nSupports G0, G1, G2, G3 character sets and their switching operations.","ref":"Raxol.Terminal.ANSI.CharacterSets.html"},{"type":"type","title":"Raxol.Terminal.ANSI.CharacterSets.charset/0","doc":"","ref":"Raxol.Terminal.ANSI.CharacterSets.html#t:charset/0"},{"type":"type","title":"Raxol.Terminal.ANSI.CharacterSets.charset_state/0","doc":"","ref":"Raxol.Terminal.ANSI.CharacterSets.html#t:charset_state/0"},{"type":"function","title":"Raxol.Terminal.ANSI.CharacterSets.designate_charset/3","doc":"Designates a character set for a specific G-set (G0-G3).\n`gset_index` is 0, 1, 2, or 3.\n`charset_code` is the character byte following ESC (, ESC ), ESC *, or ESC +.","ref":"Raxol.Terminal.ANSI.CharacterSets.html#designate_charset/3"},{"type":"function","title":"Raxol.Terminal.ANSI.CharacterSets.get_active_charset/1","doc":"Gets the active character set based on the current state.","ref":"Raxol.Terminal.ANSI.CharacterSets.html#get_active_charset/1"},{"type":"function","title":"Raxol.Terminal.ANSI.CharacterSets.invoke_charset/2","doc":"Invokes a character set as the GL (left) character set.\nThis is used by SI/SO (Shift In/Shift Out) control codes.","ref":"Raxol.Terminal.ANSI.CharacterSets.html#invoke_charset/2"},{"type":"function","title":"Examples - Raxol.Terminal.ANSI.CharacterSets.invoke_charset/2","doc":"iex> state = Raxol.Terminal.ANSI.CharacterSets.new()\n    iex> state = Raxol.Terminal.ANSI.CharacterSets.switch_charset(state, :g1, :dec_special_graphics)\n    iex> state = Raxol.Terminal.ANSI.CharacterSets.invoke_charset(state, :g1)\n    iex> state.gl\n    :g1","ref":"Raxol.Terminal.ANSI.CharacterSets.html#invoke_charset/2-examples"},{"type":"function","title":"Raxol.Terminal.ANSI.CharacterSets.new/0","doc":"Creates a new character set state with default values.","ref":"Raxol.Terminal.ANSI.CharacterSets.html#new/0"},{"type":"function","title":"Raxol.Terminal.ANSI.CharacterSets.set_gl/2","doc":"Sets the GL (left) character set.","ref":"Raxol.Terminal.ANSI.CharacterSets.html#set_gl/2"},{"type":"function","title":"Raxol.Terminal.ANSI.CharacterSets.set_gr/2","doc":"Sets the GR (right) character set.","ref":"Raxol.Terminal.ANSI.CharacterSets.html#set_gr/2"},{"type":"function","title":"Raxol.Terminal.ANSI.CharacterSets.set_single_shift/2","doc":"Sets the single shift character set.","ref":"Raxol.Terminal.ANSI.CharacterSets.html#set_single_shift/2"},{"type":"function","title":"Raxol.Terminal.ANSI.CharacterSets.switch_charset/3","doc":"Switches the specified character set to the given charset.","ref":"Raxol.Terminal.ANSI.CharacterSets.html#switch_charset/3"},{"type":"function","title":"Raxol.Terminal.ANSI.CharacterSets.translate_char/2","doc":"Translates a character based on the active character set.","ref":"Raxol.Terminal.ANSI.CharacterSets.html#translate_char/2"},{"type":"function","title":"Raxol.Terminal.ANSI.CharacterSets.translate_string/2","doc":"Translates a string using the current character set.","ref":"Raxol.Terminal.ANSI.CharacterSets.html#translate_string/2"},{"type":"module","title":"Raxol.Terminal.ANSI.CharacterTranslations","doc":"Provides character translation tables for different character sets.\nMaps characters between different character sets according to ANSI standards.","ref":"Raxol.Terminal.ANSI.CharacterTranslations.html"},{"type":"function","title":"Raxol.Terminal.ANSI.CharacterTranslations.translate_char/2","doc":"Translates a character from the source character set to the target character set.\nReturns the translated character or the original if no translation exists.","ref":"Raxol.Terminal.ANSI.CharacterTranslations.html#translate_char/2"},{"type":"function","title":"Raxol.Terminal.ANSI.CharacterTranslations.translate_string/2","doc":"Translates a string from the source character set to the target character set.","ref":"Raxol.Terminal.ANSI.CharacterTranslations.html#translate_string/2"},{"type":"function","title":"Raxol.Terminal.ANSI.CharacterTranslations.unicode_to_ansi/0","doc":"Map of Unicode codepoints to their ANSI terminal equivalents.","ref":"Raxol.Terminal.ANSI.CharacterTranslations.html#unicode_to_ansi/0"},{"type":"module","title":"Raxol.Terminal.ANSI.DeviceStatus","doc":"Handles terminal state queries and device status reports.\nThis includes cursor position reports, device status reports,\nand terminal identification queries.","ref":"Raxol.Terminal.ANSI.DeviceStatus.html"},{"type":"function","title":"Raxol.Terminal.ANSI.DeviceStatus.cursor_position_report/1","doc":"Generates a cursor position report.","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#cursor_position_report/1"},{"type":"type","title":"Raxol.Terminal.ANSI.DeviceStatus.device_status/0","doc":"","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#t:device_status/0"},{"type":"function","title":"Raxol.Terminal.ANSI.DeviceStatus.device_status_report/2","doc":"Generates a device status report.","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#device_status_report/2"},{"type":"function","title":"Raxol.Terminal.ANSI.DeviceStatus.fourth_device_attributes/1","doc":"Generates a fourth device attributes report.","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#fourth_device_attributes/1"},{"type":"function","title":"Raxol.Terminal.ANSI.DeviceStatus.new/0","doc":"Creates a new device status map with default values.","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#new/0"},{"type":"function","title":"Raxol.Terminal.ANSI.DeviceStatus.primary_device_attributes/1","doc":"Generates a primary device attributes report.","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#primary_device_attributes/1"},{"type":"function","title":"Raxol.Terminal.ANSI.DeviceStatus.secondary_device_attributes/1","doc":"Generates a secondary device attributes report.","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#secondary_device_attributes/1"},{"type":"function","title":"Raxol.Terminal.ANSI.DeviceStatus.tertiary_device_attributes/1","doc":"Generates a tertiary device attributes report.","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#tertiary_device_attributes/1"},{"type":"function","title":"Raxol.Terminal.ANSI.DeviceStatus.update_cursor_position/2","doc":"Updates the cursor position in the device status.","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#update_cursor_position/2"},{"type":"module","title":"Raxol.Terminal.ANSI.Emitter","doc":"ANSI escape sequence generation module.\n\nProvides functions for generating ANSI escape sequences for terminal control:\n- Cursor movements\n- Colors and text attributes\n- Screen manipulation\n- Various terminal modes","ref":"Raxol.Terminal.ANSI.Emitter.html"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.alternate_buffer_off/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#alternate_buffer_off/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.alternate_buffer_on/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#alternate_buffer_on/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.auto_wrap_off/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#auto_wrap_off/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.auto_wrap_on/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#auto_wrap_on/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.background/1","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#background/1"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.background_256/1","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#background_256/1"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.background_rgb/3","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#background_rgb/3"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.blink/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#blink/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.bold/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#bold/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.bracketed_paste_off/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#bracketed_paste_off/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.bracketed_paste_on/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#bracketed_paste_on/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.clear_line/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#clear_line/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.clear_line_from_cursor/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#clear_line_from_cursor/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.clear_line_to_cursor/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#clear_line_to_cursor/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.clear_screen/0","doc":"Generates an ANSI sequence for screen manipulation.","ref":"Raxol.Terminal.ANSI.Emitter.html#clear_screen/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.clear_screen_from_cursor/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#clear_screen_from_cursor/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.clear_screen_to_cursor/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#clear_screen_to_cursor/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.conceal/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#conceal/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.cursor_backward/1","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_backward/1"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.cursor_down/1","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_down/1"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.cursor_forward/1","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_forward/1"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.cursor_hide/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_hide/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.cursor_position/2","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_position/2"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.cursor_restore_position/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_restore_position/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.cursor_save_position/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_save_position/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.cursor_show/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_show/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.cursor_up/1","doc":"Generates an ANSI sequence for cursor movement.","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_up/1"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.faint/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#faint/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.foreground/1","doc":"Generates ANSI sequences for colors.","ref":"Raxol.Terminal.ANSI.Emitter.html#foreground/1"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.foreground_256/1","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#foreground_256/1"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.foreground_rgb/3","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#foreground_rgb/3"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.inverse/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#inverse/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.italic/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#italic/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.no_blink/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#no_blink/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.no_conceal/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#no_conceal/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.no_inverse/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#no_inverse/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.no_italic/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#no_italic/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.no_strikethrough/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#no_strikethrough/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.no_underline/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#no_underline/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.normal_intensity/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#normal_intensity/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.rapid_blink/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#rapid_blink/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.reset_attributes/0","doc":"Generates ANSI sequences for text attributes.","ref":"Raxol.Terminal.ANSI.Emitter.html#reset_attributes/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.reset_mode/1","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#reset_mode/1"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.scroll_down/1","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#scroll_down/1"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.scroll_up/1","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#scroll_up/1"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.set_mode/1","doc":"Generates ANSI sequences for terminal modes.","ref":"Raxol.Terminal.ANSI.Emitter.html#set_mode/1"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.strikethrough/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#strikethrough/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Emitter.underline/0","doc":"","ref":"Raxol.Terminal.ANSI.Emitter.html#underline/0"},{"type":"module","title":"Raxol.Terminal.ANSI.MouseEvents","doc":"Handles mouse event reporting for the terminal emulator.\nSupports various mouse reporting modes including:\n- Basic mouse tracking (mode 1000)\n- Highlight mouse tracking (mode 1001)\n- Cell mouse tracking (mode 1002)\n- All mouse tracking (mode 1003)\n- Focus events (mode 1004)\n- UTF-8 mouse reporting (mode 1005)\n- SGR mouse reporting (mode 1006)\n- URXVT mouse reporting (mode 1015)\n- SGR pixels mouse reporting (mode 1016)","ref":"Raxol.Terminal.ANSI.MouseEvents.html"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.calculate_drag_state/2","doc":"Calculates the drag state based on the current and previous mouse states.","ref":"Raxol.Terminal.ANSI.MouseEvents.html#calculate_drag_state/2"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.decode_button/1","doc":"Decodes button state and modifiers from a mouse event byte.","ref":"Raxol.Terminal.ANSI.MouseEvents.html#decode_button/1"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.decode_modifiers/1","doc":"Decodes modifier keys from a mouse event byte.","ref":"Raxol.Terminal.ANSI.MouseEvents.html#decode_modifiers/1"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.decode_urxvt_button/1","doc":"Decodes button state for URXVT mouse events.","ref":"Raxol.Terminal.ANSI.MouseEvents.html#decode_urxvt_button/1"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.disable/1","doc":"Disables mouse tracking.","ref":"Raxol.Terminal.ANSI.MouseEvents.html#disable/1"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.enable/2","doc":"Enables mouse tracking with the specified mode.","ref":"Raxol.Terminal.ANSI.MouseEvents.html#enable/2"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.generate_report/1","doc":"Generates a mouse event report based on the current state.","ref":"Raxol.Terminal.ANSI.MouseEvents.html#generate_report/1"},{"type":"type","title":"Raxol.Terminal.ANSI.MouseEvents.modifier/0","doc":"","ref":"Raxol.Terminal.ANSI.MouseEvents.html#t:modifier/0"},{"type":"type","title":"Raxol.Terminal.ANSI.MouseEvents.mouse_mode/0","doc":"","ref":"Raxol.Terminal.ANSI.MouseEvents.html#t:mouse_mode/0"},{"type":"type","title":"Raxol.Terminal.ANSI.MouseEvents.mouse_state/0","doc":"","ref":"Raxol.Terminal.ANSI.MouseEvents.html#t:mouse_state/0"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.new/0","doc":"Creates a new mouse state with default values.","ref":"Raxol.Terminal.ANSI.MouseEvents.html#new/0"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.parse_coordinates/1","doc":"Parses coordinates from a mouse event string.","ref":"Raxol.Terminal.ANSI.MouseEvents.html#parse_coordinates/1"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.parse_sgr_event/1","doc":"Parses an SGR mouse event in the format:  ; ; M","ref":"Raxol.Terminal.ANSI.MouseEvents.html#parse_sgr_event/1"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.parse_sgr_pixels_event/1","doc":"Parses an SGR pixels mouse event in the format:  ; ; M","ref":"Raxol.Terminal.ANSI.MouseEvents.html#parse_sgr_pixels_event/1"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.parse_urxvt_event/1","doc":"Parses a URXVT mouse event in the format:  ; ; M","ref":"Raxol.Terminal.ANSI.MouseEvents.html#parse_urxvt_event/1"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.process_event/2","doc":"Processes a mouse event and returns the updated state and event data.\nSupports extended mouse reporting modes including SGR pixels and URXVT.","ref":"Raxol.Terminal.ANSI.MouseEvents.html#process_event/2"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.update_button_state/2","doc":"Updates the button state.","ref":"Raxol.Terminal.ANSI.MouseEvents.html#update_button_state/2"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.update_drag_state/2","doc":"Updates the drag state.","ref":"Raxol.Terminal.ANSI.MouseEvents.html#update_drag_state/2"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.update_modifiers/2","doc":"Updates the modifiers state.","ref":"Raxol.Terminal.ANSI.MouseEvents.html#update_modifiers/2"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.update_position/2","doc":"Updates the mouse position.","ref":"Raxol.Terminal.ANSI.MouseEvents.html#update_position/2"},{"type":"function","title":"Raxol.Terminal.ANSI.MouseEvents.update_state/2","doc":"Updates the mouse state with new event data.","ref":"Raxol.Terminal.ANSI.MouseEvents.html#update_state/2"},{"type":"module","title":"Raxol.Terminal.ANSI.Parser","doc":"ANSI escape sequence parser module.\n\nProvides comprehensive parsing for ANSI escape sequences, determining\nthe type of sequence and extracting its parameters for processing.\nThis is the main entry point for parsing all ANSI sequences.","ref":"Raxol.Terminal.ANSI.Parser.html"},{"type":"function","title":"Raxol.Terminal.ANSI.Parser.parse/1","doc":"Parse a string containing ANSI escape sequences into tokens.\n\nThis function scans through the input and returns a list of tokens, where each\ntoken is either a plain string or a parsed ANSI sequence.","ref":"Raxol.Terminal.ANSI.Parser.html#parse/1"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Parser.parse/1","doc":"* `input` - The string containing ANSI escape sequences","ref":"Raxol.Terminal.ANSI.Parser.html#parse/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Parser.parse/1","doc":"A list of tokens where each token is either:\n  - A binary string (plain text)\n  - A tuple representing a parsed ANSI sequence","ref":"Raxol.Terminal.ANSI.Parser.html#parse/1-returns"},{"type":"function","title":"Examples - Raxol.Terminal.ANSI.Parser.parse/1","doc":"iex> Raxol.Terminal.ANSI.Parser.parse(\"Hello\u001B[31mWorld\")\n    [\"Hello\", {:text_attributes, [{:foreground_basic, 1}]}]","ref":"Raxol.Terminal.ANSI.Parser.html#parse/1-examples"},{"type":"function","title":"Raxol.Terminal.ANSI.Parser.parse_sequence/1","doc":"Parse an ANSI escape sequence and return its type and parameters.","ref":"Raxol.Terminal.ANSI.Parser.html#parse_sequence/1"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Parser.parse_sequence/1","doc":"* `sequence` - The ANSI sequence to parse","ref":"Raxol.Terminal.ANSI.Parser.html#parse_sequence/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Parser.parse_sequence/1","doc":"Parsed sequence as a tuple of type and parameters or error","ref":"Raxol.Terminal.ANSI.Parser.html#parse_sequence/1-returns"},{"type":"module","title":"Raxol.Terminal.ANSI.Processor","doc":"ANSI sequence processor module.\n\nThis module processes ANSI escape sequences for terminal control, including:\n- Cursor movement\n- Text formatting\n- Screen manipulation\n- Terminal state changes\n- Bracketed paste mode\n- Focus reporting","ref":"Raxol.Terminal.ANSI.Processor.html"},{"type":"function","title":"Raxol.Terminal.ANSI.Processor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Terminal.ANSI.Processor.html#child_spec/1"},{"type":"function","title":"Raxol.Terminal.ANSI.Processor.get_buffer_manager/1","doc":"Gets the current buffer manager.","ref":"Raxol.Terminal.ANSI.Processor.html#get_buffer_manager/1"},{"type":"function","title":"Examples - Raxol.Terminal.ANSI.Processor.get_buffer_manager/1","doc":"iex> {:ok, processor} = Processor.start_link([])\n    iex> {:ok, buffer_manager} = Manager.new(80, 24)\n    iex> :ok = Processor.set_buffer_manager(processor, buffer_manager)\n    iex> Processor.get_buffer_manager(processor)\n    {:ok, ^buffer_manager}","ref":"Raxol.Terminal.ANSI.Processor.html#get_buffer_manager/1-examples"},{"type":"function","title":"Raxol.Terminal.ANSI.Processor.init/1","doc":"","ref":"Raxol.Terminal.ANSI.Processor.html#init/1"},{"type":"function","title":"Raxol.Terminal.ANSI.Processor.process/2","doc":"Process a parsed ANSI sequence and return the updated emulator state.\nThis is a direct interface for processing sequences without using the GenServer.","ref":"Raxol.Terminal.ANSI.Processor.html#process/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Processor.process/2","doc":"* `sequence` - The parsed ANSI sequence (result from Parser.parse_sequence/1)\n* `emulator` - The current emulator state","ref":"Raxol.Terminal.ANSI.Processor.html#process/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Processor.process/2","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Processor.html#process/2-returns"},{"type":"function","title":"Examples - Raxol.Terminal.ANSI.Processor.process/2","doc":"iex> sequence = Raxol.Terminal.ANSI.Parser.parse_sequence(\"\u001B[31m\")\n    iex> new_state = Raxol.Terminal.ANSI.Processor.process(sequence, emulator)","ref":"Raxol.Terminal.ANSI.Processor.html#process/2-examples"},{"type":"function","title":"Raxol.Terminal.ANSI.Processor.process_sequence/2","doc":"Processes an ANSI sequence.","ref":"Raxol.Terminal.ANSI.Processor.html#process_sequence/2"},{"type":"function","title":"Examples - Raxol.Terminal.ANSI.Processor.process_sequence/2","doc":"iex> {:ok, processor} = Processor.start_link([])\n    iex> {:ok, buffer_manager} = Manager.new(80, 24)\n    iex> :ok = Processor.set_buffer_manager(processor, buffer_manager)\n    iex> {:ok, _} = Processor.process_sequence(processor, \"\u001B[31m\")\n    :ok","ref":"Raxol.Terminal.ANSI.Processor.html#process_sequence/2-examples"},{"type":"type","title":"Raxol.Terminal.ANSI.Processor.sequence/0","doc":"","ref":"Raxol.Terminal.ANSI.Processor.html#t:sequence/0"},{"type":"type","title":"Raxol.Terminal.ANSI.Processor.sequence_type/0","doc":"","ref":"Raxol.Terminal.ANSI.Processor.html#t:sequence_type/0"},{"type":"function","title":"Raxol.Terminal.ANSI.Processor.set_buffer_manager/2","doc":"Sets the buffer manager for the processor.","ref":"Raxol.Terminal.ANSI.Processor.html#set_buffer_manager/2"},{"type":"function","title":"Examples - Raxol.Terminal.ANSI.Processor.set_buffer_manager/2","doc":"iex> {:ok, processor} = Processor.start_link([])\n    iex> {:ok, buffer_manager} = Manager.new(80, 24)\n    iex> :ok = Processor.set_buffer_manager(processor, buffer_manager)\n    :ok","ref":"Raxol.Terminal.ANSI.Processor.html#set_buffer_manager/2-examples"},{"type":"function","title":"Raxol.Terminal.ANSI.Processor.start_link/1","doc":"","ref":"Raxol.Terminal.ANSI.Processor.html#start_link/1"},{"type":"module","title":"Raxol.Terminal.ANSI.ScreenModes","doc":"Handles screen mode transitions and state management.\nThis includes alternate screen buffer, cursor visibility,\nline wrapping, and other terminal modes.","ref":"Raxol.Terminal.ANSI.ScreenModes.html"},{"type":"function","title":"Raxol.Terminal.ANSI.ScreenModes.clear_line/2","doc":"Clears the current line based on the mode parameter.","ref":"Raxol.Terminal.ANSI.ScreenModes.html#clear_line/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.ScreenModes.clear_line/2","doc":"* `emulator` - The terminal emulator state\n* `n` - The mode for clearing the line:\n  * 0: Clear from cursor to end of line\n  * 1: Clear from start of line to cursor\n  * 2: Clear entire line","ref":"Raxol.Terminal.ANSI.ScreenModes.html#clear_line/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.ScreenModes.clear_line/2","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.ScreenModes.html#clear_line/2-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.ScreenModes.clear_screen/2","doc":"Clears the screen based on the mode parameter.","ref":"Raxol.Terminal.ANSI.ScreenModes.html#clear_screen/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.ScreenModes.clear_screen/2","doc":"* `emulator` - The terminal emulator state\n* `n` - The mode for clearing the screen:\n  * 0: Clear from cursor to end of screen\n  * 1: Clear from start of screen to cursor\n  * 2: Clear entire screen\n  * 3: Clear entire screen and scrollback buffer","ref":"Raxol.Terminal.ANSI.ScreenModes.html#clear_screen/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.ScreenModes.clear_screen/2","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.ScreenModes.html#clear_screen/2-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.ScreenModes.delete_line/2","doc":"Deletes n lines starting from the current cursor position.","ref":"Raxol.Terminal.ANSI.ScreenModes.html#delete_line/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.ScreenModes.delete_line/2","doc":"* `emulator` - The terminal emulator state\n* `n` - The number of lines to delete","ref":"Raxol.Terminal.ANSI.ScreenModes.html#delete_line/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.ScreenModes.delete_line/2","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.ScreenModes.html#delete_line/2-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.ScreenModes.get_auto_repeat_mode/1","doc":"Gets the current auto-repeat mode.","ref":"Raxol.Terminal.ANSI.ScreenModes.html#get_auto_repeat_mode/1"},{"type":"function","title":"Raxol.Terminal.ANSI.ScreenModes.get_column_width_mode/1","doc":"Gets the current column width mode.","ref":"Raxol.Terminal.ANSI.ScreenModes.html#get_column_width_mode/1"},{"type":"function","title":"Raxol.Terminal.ANSI.ScreenModes.get_interlacing_mode/1","doc":"Gets the current interlacing mode.","ref":"Raxol.Terminal.ANSI.ScreenModes.html#get_interlacing_mode/1"},{"type":"function","title":"Raxol.Terminal.ANSI.ScreenModes.get_mode/1","doc":"Gets the current screen mode.","ref":"Raxol.Terminal.ANSI.ScreenModes.html#get_mode/1"},{"type":"function","title":"Raxol.Terminal.ANSI.ScreenModes.insert_line/2","doc":"Inserts n lines at the current cursor position.","ref":"Raxol.Terminal.ANSI.ScreenModes.html#insert_line/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.ScreenModes.insert_line/2","doc":"* `emulator` - The terminal emulator state\n* `n` - The number of lines to insert","ref":"Raxol.Terminal.ANSI.ScreenModes.html#insert_line/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.ScreenModes.insert_line/2","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.ScreenModes.html#insert_line/2-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.ScreenModes.lookup_private/1","doc":"Looks up a DEC private mode code and returns the corresponding mode atom.","ref":"Raxol.Terminal.ANSI.ScreenModes.html#lookup_private/1"},{"type":"function","title":"Raxol.Terminal.ANSI.ScreenModes.lookup_standard/1","doc":"Looks up a standard mode code and returns the corresponding mode atom.","ref":"Raxol.Terminal.ANSI.ScreenModes.html#lookup_standard/1"},{"type":"function","title":"Raxol.Terminal.ANSI.ScreenModes.mode_enabled?/2","doc":"Checks if a specific mode is enabled.","ref":"Raxol.Terminal.ANSI.ScreenModes.html#mode_enabled?/2"},{"type":"function","title":"Raxol.Terminal.ANSI.ScreenModes.new/0","doc":"Creates a new screen state with default values.","ref":"Raxol.Terminal.ANSI.ScreenModes.html#new/0"},{"type":"function","title":"Raxol.Terminal.ANSI.ScreenModes.reset_mode/2","doc":"Resets a specific screen mode flag.","ref":"Raxol.Terminal.ANSI.ScreenModes.html#reset_mode/2"},{"type":"type","title":"Raxol.Terminal.ANSI.ScreenModes.screen_mode/0","doc":"","ref":"Raxol.Terminal.ANSI.ScreenModes.html#t:screen_mode/0"},{"type":"type","title":"Raxol.Terminal.ANSI.ScreenModes.screen_state/0","doc":"","ref":"Raxol.Terminal.ANSI.ScreenModes.html#t:screen_state/0"},{"type":"function","title":"Raxol.Terminal.ANSI.ScreenModes.set_mode/2","doc":"Sets a specific screen mode flag.","ref":"Raxol.Terminal.ANSI.ScreenModes.html#set_mode/2"},{"type":"function","title":"Raxol.Terminal.ANSI.ScreenModes.switch_mode/2","doc":"Switches between screen modes, saving the current state if needed.","ref":"Raxol.Terminal.ANSI.ScreenModes.html#switch_mode/2"},{"type":"function","title":"Raxol.Terminal.ANSI.ScreenModes.switch_mode/3","doc":"Switches a specific mode on or off.","ref":"Raxol.Terminal.ANSI.ScreenModes.html#switch_mode/3"},{"type":"module","title":"Raxol.Terminal.ANSI.SequenceParser","doc":"Helper module for parsing ANSI escape sequences.\n\nThis module provides common utilities for parsing and handling ANSI sequences,\nextracted from duplicate implementations in other ANSI-related modules.","ref":"Raxol.Terminal.ANSI.SequenceParser.html"},{"type":"function","title":"Raxol.Terminal.ANSI.SequenceParser.parse_params/1","doc":"Parses parameters from an ANSI sequence.\n\nSplits the parameter string by semicolons and converts them to integers.","ref":"Raxol.Terminal.ANSI.SequenceParser.html#parse_params/1"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.SequenceParser.parse_params/1","doc":"* `{:ok, params}` - Successfully parsed parameters\n* `:error` - Failed to parse parameters","ref":"Raxol.Terminal.ANSI.SequenceParser.html#parse_params/1-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.SequenceParser.parse_sequence/2","doc":"Generic parser for ANSI sequences that follow the pattern: params + operation code.","ref":"Raxol.Terminal.ANSI.SequenceParser.html#parse_sequence/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.SequenceParser.parse_sequence/2","doc":"* `sequence` - The binary sequence to parse\n* `operation_decoder` - Function to decode operation from character code","ref":"Raxol.Terminal.ANSI.SequenceParser.html#parse_sequence/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.SequenceParser.parse_sequence/2","doc":"* `{:ok, operation, params}` - Successfully parsed sequence\n* `:error` - Failed to parse sequence","ref":"Raxol.Terminal.ANSI.SequenceParser.html#parse_sequence/2-returns"},{"type":"module","title":"Raxol.Terminal.ANSI.Sequences.Colors","doc":"ANSI Color Sequence Handler.\n\nHandles parsing and application of ANSI color control sequences,\nincluding 16-color mode, 256-color mode, and true color (24-bit) mode.","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Colors.color_code/2","doc":"Generate ANSI color code for a given color.","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#color_code/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Colors.color_code/2","doc":"* `color` - The color struct\n* `type` - Either :foreground or :background","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#color_code/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Colors.color_code/2","doc":"ANSI escape sequence as string","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#color_code/2-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Colors.color_codes/0","doc":"Returns a map of ANSI color codes.","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#color_codes/0"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Colors.color_codes/0","doc":"A map of color names to ANSI codes.","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#color_codes/0-returns"},{"type":"function","title":"Examples - Raxol.Terminal.ANSI.Sequences.Colors.color_codes/0","doc":"iex> Raxol.Terminal.ANSI.Sequences.Colors.color_codes()\n    %{\n      black: \"\u001B[30m\",\n      red: \"\u001B[31m\",\n      # ... other colors ...\n      reset: \"\u001B[0m\"\n    }","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#color_codes/0-examples"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Colors.set_background_256/2","doc":"Set background color using 256-color mode.","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_256/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Colors.set_background_256/2","doc":"* `emulator` - The terminal emulator state\n* `index` - Color index (0-255)","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_256/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Colors.set_background_256/2","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_256/2-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Colors.set_background_basic/2","doc":"Set background color using basic 16-color mode.","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_basic/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Colors.set_background_basic/2","doc":"* `emulator` - The terminal emulator state\n* `color_code` - Color code (0-15)","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_basic/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Colors.set_background_basic/2","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_basic/2-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Colors.set_background_true/4","doc":"Set background color using true (24-bit) RGB color.","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_true/4"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Colors.set_background_true/4","doc":"* `emulator` - The terminal emulator state\n* `r` - Red component (0-255)\n* `g` - Green component (0-255)\n* `b` - Blue component (0-255)","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_true/4-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Colors.set_background_true/4","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_true/4-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_256/2","doc":"Set foreground color using 256-color mode.","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_256/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_256/2","doc":"* `emulator` - The terminal emulator state\n* `index` - Color index (0-255)","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_256/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_256/2","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_256/2-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_basic/2","doc":"Set foreground color using basic 16-color mode.","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_basic/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_basic/2","doc":"* `emulator` - The terminal emulator state\n* `color_code` - Color code (0-15)","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_basic/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_basic/2","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_basic/2-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_true/4","doc":"Set foreground color using true (24-bit) RGB color.","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_true/4"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_true/4","doc":"* `emulator` - The terminal emulator state\n* `r` - Red component (0-255)\n* `g` - Green component (0-255)\n* `b` - Blue component (0-255)","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_true/4-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_true/4","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_true/4-returns"},{"type":"module","title":"Raxol.Terminal.ANSI.Sequences.Cursor","doc":"ANSI Cursor Sequence Handler.\n\nHandles parsing and application of ANSI cursor control sequences,\nincluding movement, position saving/restoring, and visibility.","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor/3","doc":"Move cursor to absolute position.","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor/3"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor/3","doc":"* `emulator` - The terminal emulator state\n* `row` - Row to move to (1-indexed)\n* `col` - Column to move to (1-indexed)","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor/3-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor/3","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor/3-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_backward/2","doc":"Move cursor backward by specified number of columns.","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_backward/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_backward/2","doc":"* `emulator` - The terminal emulator state\n* `n` - Number of columns to move backward","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_backward/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_backward/2","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_backward/2-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_down/2","doc":"Move cursor down by specified number of rows.","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_down/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_down/2","doc":"* `emulator` - The terminal emulator state\n* `n` - Number of rows to move down","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_down/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_down/2","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_down/2-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_forward/2","doc":"Move cursor forward by specified number of columns.","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_forward/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_forward/2","doc":"* `emulator` - The terminal emulator state\n* `n` - Number of columns to move forward","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_forward/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_forward/2","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_forward/2-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_up/2","doc":"Move cursor up by specified number of rows.","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_up/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_up/2","doc":"* `emulator` - The terminal emulator state\n* `n` - Number of rows to move up","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_up/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_up/2","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_up/2-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Cursor.restore_cursor_position/1","doc":"Restore previously saved cursor position.","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#restore_cursor_position/1"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Cursor.restore_cursor_position/1","doc":"* `emulator` - The terminal emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#restore_cursor_position/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Cursor.restore_cursor_position/1","doc":"Updated emulator state with restored cursor position","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#restore_cursor_position/1-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Cursor.save_cursor_position/1","doc":"Save current cursor position.","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#save_cursor_position/1"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Cursor.save_cursor_position/1","doc":"* `emulator` - The terminal emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#save_cursor_position/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Cursor.save_cursor_position/1","doc":"Updated emulator state with saved cursor position","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#save_cursor_position/1-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Cursor.set_cursor_visibility/2","doc":"Set cursor visibility.","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#set_cursor_visibility/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Cursor.set_cursor_visibility/2","doc":"* `emulator` - The terminal emulator state\n* `visible` - Boolean indicating visibility","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#set_cursor_visibility/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Cursor.set_cursor_visibility/2","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#set_cursor_visibility/2-returns"},{"type":"module","title":"Raxol.Terminal.ANSI.Sequences.Modes","doc":"ANSI Terminal Modes Sequence Handler.\n\nHandles parsing and application of ANSI terminal mode sequences,\nincluding screen modes, input modes, and rendering modes.","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Modes.handle_special_mode_action/3","doc":"Handle special mode actions that require additional state changes.","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#handle_special_mode_action/3"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Modes.handle_special_mode_action/3","doc":"* `emulator` - The terminal emulator state\n* `mode_name` - The name of the mode\n* `enabled` - Boolean indicating if mode is enabled or disabled","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#handle_special_mode_action/3-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Modes.handle_special_mode_action/3","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#handle_special_mode_action/3-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Modes.set_alternate_buffer/2","doc":"Switch to alternate buffer mode.","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_alternate_buffer/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Modes.set_alternate_buffer/2","doc":"* `emulator` - The terminal emulator state\n* `use_alternate` - Boolean indicating if alternate buffer should be used","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_alternate_buffer/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Modes.set_alternate_buffer/2","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_alternate_buffer/2-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Modes.set_bracketed_paste_mode/2","doc":"Enable or disable bracketed paste mode.","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_bracketed_paste_mode/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Modes.set_bracketed_paste_mode/2","doc":"* `emulator` - The terminal emulator state\n* `enabled` - Boolean indicating if mode should be enabled or disabled","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_bracketed_paste_mode/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Modes.set_bracketed_paste_mode/2","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_bracketed_paste_mode/2-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Modes.set_focus_reporting/2","doc":"Enable or disable focus reporting.","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_focus_reporting/2"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Modes.set_focus_reporting/2","doc":"* `emulator` - The terminal emulator state\n* `enabled` - Boolean indicating if mode should be enabled or disabled","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_focus_reporting/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Modes.set_focus_reporting/2","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_focus_reporting/2-returns"},{"type":"function","title":"Raxol.Terminal.ANSI.Sequences.Modes.set_screen_mode/3","doc":"Set or reset a screen mode.","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_screen_mode/3"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Modes.set_screen_mode/3","doc":"* `emulator` - The terminal emulator state\n* `mode` - Mode identifier\n* `enabled` - Boolean indicating if mode should be enabled or disabled","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_screen_mode/3-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSI.Sequences.Modes.set_screen_mode/3","doc":"Updated emulator state","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_screen_mode/3-returns"},{"type":"module","title":"Raxol.Terminal.ANSI.SixelGraphics","doc":"Handles Sixel graphics for the terminal emulator.\nSupports:\n- Sixel color palette management\n- Sixel image rendering\n- Sixel image scaling\n- Sixel image positioning\n- Sixel image attributes","ref":"Raxol.Terminal.ANSI.SixelGraphics.html"},{"type":"function","title":"Raxol.Terminal.ANSI.SixelGraphics.new/0","doc":"Creates a new Sixel state with default values.","ref":"Raxol.Terminal.ANSI.SixelGraphics.html#new/0"},{"type":"function","title":"Raxol.Terminal.ANSI.SixelGraphics.process_sequence/2","doc":"Processes a Sixel sequence (DCS P...q DATA ST) and returns the updated state.\n\nThe pixel data is stored in `state.pixel_buffer`.","ref":"Raxol.Terminal.ANSI.SixelGraphics.html#process_sequence/2"},{"type":"function","title":"Raxol.Terminal.ANSI.SixelGraphics.render_image/1","doc":"Renders the image stored in the pixel_buffer as a Sixel data stream.","ref":"Raxol.Terminal.ANSI.SixelGraphics.html#render_image/1"},{"type":"type","title":"Raxol.Terminal.ANSI.SixelGraphics.sixel_attribute/0","doc":"","ref":"Raxol.Terminal.ANSI.SixelGraphics.html#t:sixel_attribute/0"},{"type":"type","title":"Raxol.Terminal.ANSI.SixelGraphics.sixel_state/0","doc":"","ref":"Raxol.Terminal.ANSI.SixelGraphics.html#t:sixel_state/0"},{"type":"module","title":"Raxol.Terminal.ANSI.SixelGraphics.ParserState","doc":"","ref":"Raxol.Terminal.ANSI.SixelGraphics.ParserState.html"},{"type":"type","title":"Raxol.Terminal.ANSI.SixelGraphics.ParserState.t/0","doc":"","ref":"Raxol.Terminal.ANSI.SixelGraphics.ParserState.html#t:t/0"},{"type":"module","title":"Raxol.Terminal.ANSI.SixelPalette","doc":"Handles Sixel color palette management.\n\nProvides functions to initialize the default palette and potentially\nmanage custom color definitions in the future.","ref":"Raxol.Terminal.ANSI.SixelPalette.html"},{"type":"function","title":"Raxol.Terminal.ANSI.SixelPalette.initialize_palette/0","doc":"Initializes the default Sixel color palette (256 colors).","ref":"Raxol.Terminal.ANSI.SixelPalette.html#initialize_palette/0"},{"type":"function","title":"Raxol.Terminal.ANSI.SixelPalette.max_colors/0","doc":"Returns the maximum valid color index (typically 255 for a 256-color palette).","ref":"Raxol.Terminal.ANSI.SixelPalette.html#max_colors/0"},{"type":"module","title":"Raxol.Terminal.ANSI.SixelPatternMap","doc":"Provides a mapping from Sixel characters to their 6-bit pixel patterns.","ref":"Raxol.Terminal.ANSI.SixelPatternMap.html"},{"type":"function","title":"Raxol.Terminal.ANSI.SixelPatternMap.get_pattern/1","doc":"Gets the 6-bit integer pattern for a given Sixel character code.\n\nReturns 0 (empty pattern) if the character code is invalid.\nSixel characters range from ? (63) to ~ (126).","ref":"Raxol.Terminal.ANSI.SixelPatternMap.html#get_pattern/1"},{"type":"function","title":"Raxol.Terminal.ANSI.SixelPatternMap.pattern_to_pixels/1","doc":"Converts a 6-bit integer pattern into a list of 6 pixel values (0 or 1).\n\nBit 0 (LSB) corresponds to the top pixel.","ref":"Raxol.Terminal.ANSI.SixelPatternMap.html#pattern_to_pixels/1"},{"type":"module","title":"Raxol.Terminal.ANSI.TerminalState","doc":"Manages terminal state for the terminal emulator.\nHandles saving and restoring terminal state, including cursor position,\nattributes, character sets, and screen modes.","ref":"Raxol.Terminal.ANSI.TerminalState.html"},{"type":"function","title":"Raxol.Terminal.ANSI.TerminalState.clear_state/1","doc":"Clears the terminal state stack.","ref":"Raxol.Terminal.ANSI.TerminalState.html#clear_state/1"},{"type":"function","title":"Raxol.Terminal.ANSI.TerminalState.count/1","doc":"Gets the number of saved states in the stack.","ref":"Raxol.Terminal.ANSI.TerminalState.html#count/1"},{"type":"function","title":"Raxol.Terminal.ANSI.TerminalState.empty?/1","doc":"Checks if the terminal state stack is empty.","ref":"Raxol.Terminal.ANSI.TerminalState.html#empty?/1"},{"type":"function","title":"Raxol.Terminal.ANSI.TerminalState.get_state_stack/1","doc":"Gets the current terminal state stack.","ref":"Raxol.Terminal.ANSI.TerminalState.html#get_state_stack/1"},{"type":"function","title":"Raxol.Terminal.ANSI.TerminalState.new/0","doc":"Creates a new terminal state stack.","ref":"Raxol.Terminal.ANSI.TerminalState.html#new/0"},{"type":"function","title":"Raxol.Terminal.ANSI.TerminalState.restore_state/1","doc":"Restores the most recently saved terminal state from the stack.\nReturns the updated stack and the restored state.","ref":"Raxol.Terminal.ANSI.TerminalState.html#restore_state/1"},{"type":"function","title":"Raxol.Terminal.ANSI.TerminalState.save_state/2","doc":"Saves the current terminal state to the stack.","ref":"Raxol.Terminal.ANSI.TerminalState.html#save_state/2"},{"type":"type","title":"Raxol.Terminal.ANSI.TerminalState.saved_state/0","doc":"","ref":"Raxol.Terminal.ANSI.TerminalState.html#t:saved_state/0"},{"type":"type","title":"Raxol.Terminal.ANSI.TerminalState.state_stack/0","doc":"","ref":"Raxol.Terminal.ANSI.TerminalState.html#t:state_stack/0"},{"type":"module","title":"Raxol.Terminal.ANSI.TextFormatting","doc":"Handles advanced text formatting features for the terminal emulator.\nThis includes double-width and double-height characters, as well as\nother advanced text attributes and colors.","ref":"Raxol.Terminal.ANSI.TextFormatting.html"},{"type":"function","title":"Raxol.Terminal.ANSI.TextFormatting.ansi_code_to_color_name/1","doc":"Converts a standard ANSI 3/4-bit color code to a color name atom.","ref":"Raxol.Terminal.ANSI.TextFormatting.html#ansi_code_to_color_name/1"},{"type":"function","title":"Examples - Raxol.Terminal.ANSI.TextFormatting.ansi_code_to_color_name/1","doc":"iex> Raxol.Terminal.ANSI.TextFormatting.ansi_code_to_color_name(31)\n    :red\n\n    iex> Raxol.Terminal.ANSI.TextFormatting.ansi_code_to_color_name(44)\n    :blue\n\n    iex> Raxol.Terminal.ANSI.TextFormatting.ansi_code_to_color_name(99) # Unknown\n    nil","ref":"Raxol.Terminal.ANSI.TextFormatting.html#ansi_code_to_color_name/1-examples"},{"type":"function","title":"Raxol.Terminal.ANSI.TextFormatting.apply_attribute/2","doc":"Applies a text attribute to the style map.","ref":"Raxol.Terminal.ANSI.TextFormatting.html#apply_attribute/2"},{"type":"function","title":"Raxol.Terminal.ANSI.TextFormatting.apply_color/3","doc":"Applies a color attribute to the style map.","ref":"Raxol.Terminal.ANSI.TextFormatting.html#apply_color/3"},{"type":"type","title":"Raxol.Terminal.ANSI.TextFormatting.color/0","doc":"","ref":"Raxol.Terminal.ANSI.TextFormatting.html#t:color/0"},{"type":"function","title":"Raxol.Terminal.ANSI.TextFormatting.effective_width/2","doc":"Calculates the effective width of a character based on the current style.","ref":"Raxol.Terminal.ANSI.TextFormatting.html#effective_width/2"},{"type":"function","title":"Raxol.Terminal.ANSI.TextFormatting.get_background/1","doc":"Gets the background color.","ref":"Raxol.Terminal.ANSI.TextFormatting.html#get_background/1"},{"type":"function","title":"Raxol.Terminal.ANSI.TextFormatting.get_foreground/1","doc":"Gets the foreground color.","ref":"Raxol.Terminal.ANSI.TextFormatting.html#get_foreground/1"},{"type":"function","title":"Raxol.Terminal.ANSI.TextFormatting.needs_paired_line?/1","doc":"Determines if the current line needs a paired line (for double-height mode).","ref":"Raxol.Terminal.ANSI.TextFormatting.html#needs_paired_line?/1"},{"type":"function","title":"Raxol.Terminal.ANSI.TextFormatting.new/0","doc":"Creates a new text style map with default values.","ref":"Raxol.Terminal.ANSI.TextFormatting.html#new/0"},{"type":"function","title":"Raxol.Terminal.ANSI.TextFormatting.paired_line_type/1","doc":"Gets the paired line type for double-height mode.","ref":"Raxol.Terminal.ANSI.TextFormatting.html#paired_line_type/1"},{"type":"function","title":"Raxol.Terminal.ANSI.TextFormatting.reset/1","doc":"Resets all text formatting attributes to their default values.","ref":"Raxol.Terminal.ANSI.TextFormatting.html#reset/1"},{"type":"function","title":"Raxol.Terminal.ANSI.TextFormatting.reset_size/1","doc":"Resets to single-width, single-height mode.","ref":"Raxol.Terminal.ANSI.TextFormatting.html#reset_size/1"},{"type":"function","title":"Raxol.Terminal.ANSI.TextFormatting.set_background/2","doc":"Sets the background color.","ref":"Raxol.Terminal.ANSI.TextFormatting.html#set_background/2"},{"type":"function","title":"Raxol.Terminal.ANSI.TextFormatting.set_double_height_bottom/1","doc":"Sets double-height bottom half mode for the current line.","ref":"Raxol.Terminal.ANSI.TextFormatting.html#set_double_height_bottom/1"},{"type":"function","title":"Raxol.Terminal.ANSI.TextFormatting.set_double_height_top/1","doc":"Sets double-height top half mode for the current line.","ref":"Raxol.Terminal.ANSI.TextFormatting.html#set_double_height_top/1"},{"type":"function","title":"Raxol.Terminal.ANSI.TextFormatting.set_double_width/1","doc":"Sets double-width mode for the current line.","ref":"Raxol.Terminal.ANSI.TextFormatting.html#set_double_width/1"},{"type":"function","title":"Raxol.Terminal.ANSI.TextFormatting.set_foreground/2","doc":"Sets the foreground color.","ref":"Raxol.Terminal.ANSI.TextFormatting.html#set_foreground/2"},{"type":"type","title":"Raxol.Terminal.ANSI.TextFormatting.text_style/0","doc":"","ref":"Raxol.Terminal.ANSI.TextFormatting.html#t:text_style/0"},{"type":"module","title":"Raxol.Terminal.ANSI.WindowManipulation","doc":"Handles window manipulation sequences for the terminal emulator.\nSupports various window operations including:\n- Window size queries and reports\n- Window position queries and reports\n- Window title manipulation\n- Window icon manipulation\n- Window stacking order","ref":"Raxol.Terminal.ANSI.WindowManipulation.html"},{"type":"function","title":"Raxol.Terminal.ANSI.WindowManipulation.decode_operation/1","doc":"Decodes a window manipulation operation from its character code.","ref":"Raxol.Terminal.ANSI.WindowManipulation.html#decode_operation/1"},{"type":"function","title":"Raxol.Terminal.ANSI.WindowManipulation.handle_operation/3","doc":"Handles a window manipulation operation and returns the updated state and response.","ref":"Raxol.Terminal.ANSI.WindowManipulation.html#handle_operation/3"},{"type":"function","title":"Raxol.Terminal.ANSI.WindowManipulation.new/0","doc":"Creates a new window state with default values.","ref":"Raxol.Terminal.ANSI.WindowManipulation.html#new/0"},{"type":"function","title":"Raxol.Terminal.ANSI.WindowManipulation.parse_sequence/1","doc":"Parses a window manipulation sequence.","ref":"Raxol.Terminal.ANSI.WindowManipulation.html#parse_sequence/1"},{"type":"function","title":"Raxol.Terminal.ANSI.WindowManipulation.process_sequence/2","doc":"Processes a window manipulation sequence and returns the updated state and response.","ref":"Raxol.Terminal.ANSI.WindowManipulation.html#process_sequence/2"},{"type":"type","title":"Raxol.Terminal.ANSI.WindowManipulation.window_state/0","doc":"","ref":"Raxol.Terminal.ANSI.WindowManipulation.html#t:window_state/0"},{"type":"module","title":"Raxol.Terminal.ANSIFacade","doc":"DEPRECATED: Provides a simplified facade for interacting with ANSI escape sequences.\n\nThis module is being replaced by the more structured modules within\n`Raxol.Terminal.ANSI.*` (Parser, Processor, Emitter, Sequences, etc.).\n\nFunctions are kept temporarily for backward compatibility but primarily log warnings.","ref":"Raxol.Terminal.ANSIFacade.html"},{"type":"function","title":"Raxol.Terminal.ANSIFacade.new/0","doc":"","ref":"Raxol.Terminal.ANSIFacade.html#new/0"},{"type":"function","title":"Raxol.Terminal.ANSIFacade.parse/1","doc":"Parses ANSI escape sequences from a string.\n\nThis method delegates to the ANSI.Parser module for the actual parsing.","ref":"Raxol.Terminal.ANSIFacade.html#parse/1"},{"type":"function","title":"Parameters - Raxol.Terminal.ANSIFacade.parse/1","doc":"* `input` - The string containing ANSI escape sequences","ref":"Raxol.Terminal.ANSIFacade.html#parse/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.ANSIFacade.parse/1","doc":"A list of parsed tokens.","ref":"Raxol.Terminal.ANSIFacade.html#parse/1-returns"},{"type":"function","title":"Migration Path - Raxol.Terminal.ANSIFacade.parse/1","doc":"Update your code to use the Parser module directly:\n\n```elixir\n# Before\ntokens = Raxol.Terminal.ANSI.parse(input)\n\n# After\ntokens = Raxol.Terminal.ANSI.Parser.parse(input)\n```","ref":"Raxol.Terminal.ANSIFacade.html#parse/1-migration-path"},{"type":"function","title":"Raxol.Terminal.ANSIFacade.process_escape/2","doc":"","ref":"Raxol.Terminal.ANSIFacade.html#process_escape/2"},{"type":"module","title":"Raxol.Terminal.Buffer.DamageTracker","doc":"Manages damage tracking for terminal buffers.\n\nHandles marking regions as damaged and merging overlapping regions\nfor efficient redrawing.","ref":"Raxol.Terminal.Buffer.DamageTracker.html"},{"type":"function","title":"Raxol.Terminal.Buffer.DamageTracker.clear_regions/1","doc":"Clears all tracked damage regions.","ref":"Raxol.Terminal.Buffer.DamageTracker.html#clear_regions/1"},{"type":"function","title":"Raxol.Terminal.Buffer.DamageTracker.get_regions/1","doc":"Gets the list of distinct damaged regions.","ref":"Raxol.Terminal.Buffer.DamageTracker.html#get_regions/1"},{"type":"function","title":"Raxol.Terminal.Buffer.DamageTracker.mark_damaged/5","doc":"Marks a rectangular region as damaged.\n\nMerges the new region with any existing overlapping regions.","ref":"Raxol.Terminal.Buffer.DamageTracker.html#mark_damaged/5"},{"type":"function","title":"Raxol.Terminal.Buffer.DamageTracker.new/0","doc":"Creates a new, empty damage tracker.","ref":"Raxol.Terminal.Buffer.DamageTracker.html#new/0"},{"type":"type","title":"Raxol.Terminal.Buffer.DamageTracker.region/0","doc":"","ref":"Raxol.Terminal.Buffer.DamageTracker.html#t:region/0"},{"type":"type","title":"Raxol.Terminal.Buffer.DamageTracker.t/0","doc":"","ref":"Raxol.Terminal.Buffer.DamageTracker.html#t:t/0"},{"type":"module","title":"Raxol.Terminal.Buffer.Manager","doc":"Terminal buffer manager module.\n\nThis module handles the management of terminal buffers, including:\n- Double buffering implementation\n- Damage tracking system\n- Buffer synchronization\n- Memory management","ref":"Raxol.Terminal.Buffer.Manager.html"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Terminal.Buffer.Manager.html#child_spec/1"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.clear_current_line/1","doc":"Clears the current line.","ref":"Raxol.Terminal.Buffer.Manager.html#clear_current_line/1"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Manager.clear_current_line/1","doc":"iex> manager = Buffer.Manager.new(80, 24)\n    iex> manager = Buffer.Manager.set_cursor_position(manager, 10, 5)\n    iex> manager = Buffer.Manager.clear_current_line(manager)\n    iex> manager.damage_regions\n    [{0, 5, 79, 5}]","ref":"Raxol.Terminal.Buffer.Manager.html#clear_current_line/1-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.clear_damage_regions/1","doc":"Clears all damage regions.","ref":"Raxol.Terminal.Buffer.Manager.html#clear_damage_regions/1"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Manager.clear_damage_regions/1","doc":"iex> manager = Buffer.Manager.new(80, 24)\n    iex> manager = Buffer.Manager.mark_damaged(manager, 0, 0, 10, 5)\n    iex> manager = Buffer.Manager.clear_damage_regions(manager)\n    iex> length(manager.damage_regions)\n    0","ref":"Raxol.Terminal.Buffer.Manager.html#clear_damage_regions/1-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.clear_entire_display_with_scrollback/1","doc":"Clears the entire display including the scrollback buffer.","ref":"Raxol.Terminal.Buffer.Manager.html#clear_entire_display_with_scrollback/1"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Manager.clear_entire_display_with_scrollback/1","doc":"iex> manager = Buffer.Manager.new(80, 24)\n    iex> manager = Buffer.Manager.clear_entire_display_with_scrollback(manager)\n    iex> manager.damage_regions\n    [{0, 0, 79, 23}]\n    iex> manager.scrollback_buffer\n    []","ref":"Raxol.Terminal.Buffer.Manager.html#clear_entire_display_with_scrollback/1-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.clear_scroll_region/1","doc":"Clears the scroll region, making the entire buffer scrollable.","ref":"Raxol.Terminal.Buffer.Manager.html#clear_scroll_region/1"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.clear_visible_display/1","doc":"Clears the visible portion of the display (viewport) without affecting the scrollback buffer.","ref":"Raxol.Terminal.Buffer.Manager.html#clear_visible_display/1"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Manager.clear_visible_display/1","doc":"iex> manager = Buffer.Manager.new(80, 24)\n    # ... (write some data) ...\n    iex> manager = Buffer.Manager.clear_visible_display(manager)\n    iex> manager.damage_regions\n    [{0, 0, 79, 23}]\n    # Assert buffer contents are cleared, scrollback remains","ref":"Raxol.Terminal.Buffer.Manager.html#clear_visible_display/1-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.erase_from_beginning_of_line_to_cursor/1","doc":"Erases from the beginning of the current line to the cursor.","ref":"Raxol.Terminal.Buffer.Manager.html#erase_from_beginning_of_line_to_cursor/1"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Manager.erase_from_beginning_of_line_to_cursor/1","doc":"iex> manager = Buffer.Manager.new(80, 24)\n    iex> manager = Buffer.Manager.set_cursor_position(manager, 10, 5)\n    iex> manager = Buffer.Manager.erase_from_beginning_of_line_to_cursor(manager)\n    iex> manager.damage_regions\n    [{0, 5, 10, 5}]","ref":"Raxol.Terminal.Buffer.Manager.html#erase_from_beginning_of_line_to_cursor/1-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.erase_from_beginning_to_cursor/1","doc":"Erases from the beginning of the display to the cursor.","ref":"Raxol.Terminal.Buffer.Manager.html#erase_from_beginning_to_cursor/1"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Manager.erase_from_beginning_to_cursor/1","doc":"iex> manager = Buffer.Manager.new(80, 24)\n    iex> manager = Buffer.Manager.set_cursor_position(manager, 10, 5)\n    iex> manager = Buffer.Manager.erase_from_beginning_to_cursor(manager)\n    iex> manager.damage_regions\n    [{0, 0, 10, 5}]","ref":"Raxol.Terminal.Buffer.Manager.html#erase_from_beginning_to_cursor/1-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.erase_from_cursor_to_end/1","doc":"Erases from the cursor position to the end of the display.","ref":"Raxol.Terminal.Buffer.Manager.html#erase_from_cursor_to_end/1"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Manager.erase_from_cursor_to_end/1","doc":"iex> manager = Buffer.Manager.new(80, 24)\n    iex> manager = Buffer.Manager.set_cursor_position(manager, 10, 5)\n    iex> manager = Buffer.Manager.erase_from_cursor_to_end(manager)\n    iex> manager.damage_regions\n    [{10, 5, 79, 23}]","ref":"Raxol.Terminal.Buffer.Manager.html#erase_from_cursor_to_end/1-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.erase_from_cursor_to_end_of_line/1","doc":"Erases from the cursor to the end of the current line.","ref":"Raxol.Terminal.Buffer.Manager.html#erase_from_cursor_to_end_of_line/1"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Manager.erase_from_cursor_to_end_of_line/1","doc":"iex> manager = Buffer.Manager.new(80, 24)\n    iex> manager = Buffer.Manager.set_cursor_position(manager, 10, 5)\n    iex> manager = Buffer.Manager.erase_from_cursor_to_end_of_line(manager)\n    iex> manager.damage_regions\n    [{10, 5, 79, 5}]","ref":"Raxol.Terminal.Buffer.Manager.html#erase_from_cursor_to_end_of_line/1-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.get_cursor_position/1","doc":"Gets the cursor position.","ref":"Raxol.Terminal.Buffer.Manager.html#get_cursor_position/1"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Manager.get_cursor_position/1","doc":"iex> manager = Buffer.Manager.new(80, 24)\n    iex> manager = Buffer.Manager.set_cursor_position(manager, 10, 5)\n    iex> Buffer.Manager.get_cursor_position(manager)\n    {10, 5}","ref":"Raxol.Terminal.Buffer.Manager.html#get_cursor_position/1-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.get_damage_regions/1","doc":"Gets all damaged regions.","ref":"Raxol.Terminal.Buffer.Manager.html#get_damage_regions/1"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Manager.get_damage_regions/1","doc":"iex> manager = Buffer.Manager.new(80, 24)\n    iex> manager = Buffer.Manager.mark_damaged(manager, 0, 0, 10, 5)\n    iex> regions = Buffer.Manager.get_damage_regions(manager)\n    iex> length(regions)\n    1","ref":"Raxol.Terminal.Buffer.Manager.html#get_damage_regions/1-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.get_selection/1","doc":"Gets the text within the current selection.\nReturns an empty string if there is no selection.","ref":"Raxol.Terminal.Buffer.Manager.html#get_selection/1"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.get_selection_boundaries/1","doc":"Gets the boundaries of the current selection.\nReturns nil if there is no selection.","ref":"Raxol.Terminal.Buffer.Manager.html#get_selection_boundaries/1"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.in_selection?/3","doc":"Checks if the given position is within the current selection.\nReturns false if there is no selection.","ref":"Raxol.Terminal.Buffer.Manager.html#in_selection?/3"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.mark_damaged/5","doc":"Marks a region of the buffer as damaged.","ref":"Raxol.Terminal.Buffer.Manager.html#mark_damaged/5"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Manager.mark_damaged/5","doc":"iex> manager = Buffer.Manager.new(80, 24)\n    iex> manager = Buffer.Manager.mark_damaged(manager, 0, 0, 10, 5)\n    iex> length(manager.damage_regions)\n    1","ref":"Raxol.Terminal.Buffer.Manager.html#mark_damaged/5-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.new/4","doc":"Creates a new buffer manager with the given dimensions.","ref":"Raxol.Terminal.Buffer.Manager.html#new/4"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Manager.new/4","doc":"iex> {:ok, manager} = Manager.new(80, 24)\n    iex> manager.active_buffer.width\n    80\n    iex> manager.active_buffer.height\n    24","ref":"Raxol.Terminal.Buffer.Manager.html#new/4-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.scroll_down/2","doc":"Scrolls the buffer down by the specified number of lines.\nLines are restored from the scrollback buffer if available.","ref":"Raxol.Terminal.Buffer.Manager.html#scroll_down/2"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.scroll_up/2","doc":"Scrolls the buffer up by the specified number of lines.\nLines that scroll off the top are added to the scrollback buffer.","ref":"Raxol.Terminal.Buffer.Manager.html#scroll_up/2"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.set_cursor_position/3","doc":"Sets the cursor position.","ref":"Raxol.Terminal.Buffer.Manager.html#set_cursor_position/3"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Manager.set_cursor_position/3","doc":"iex> manager = Buffer.Manager.new(80, 24)\n    iex> manager = Buffer.Manager.set_cursor_position(manager, 10, 5)\n    iex> manager.cursor_position\n    {10, 5}","ref":"Raxol.Terminal.Buffer.Manager.html#set_cursor_position/3-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.set_scroll_region/3","doc":"Sets a scroll region in the buffer. All scrolling operations will be confined to this region.\nThe region is specified by start and end line numbers (inclusive).","ref":"Raxol.Terminal.Buffer.Manager.html#set_scroll_region/3"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.start_link/1","doc":"","ref":"Raxol.Terminal.Buffer.Manager.html#start_link/1"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.start_selection/3","doc":"Starts a text selection at the specified coordinates.","ref":"Raxol.Terminal.Buffer.Manager.html#start_selection/3"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.switch_buffers/1","doc":"Switches the active and back buffers.","ref":"Raxol.Terminal.Buffer.Manager.html#switch_buffers/1"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Manager.switch_buffers/1","doc":"iex> manager = Buffer.Manager.new(80, 24)\n    iex> manager = Buffer.Manager.switch_buffers(manager)\n    iex> manager.active_buffer == manager.back_buffer\n    false","ref":"Raxol.Terminal.Buffer.Manager.html#switch_buffers/1-examples"},{"type":"type","title":"Raxol.Terminal.Buffer.Manager.t/0","doc":"","ref":"Raxol.Terminal.Buffer.Manager.html#t:t/0"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.update_memory_usage/1","doc":"Updates memory usage tracking.","ref":"Raxol.Terminal.Buffer.Manager.html#update_memory_usage/1"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Manager.update_memory_usage/1","doc":"iex> manager = Buffer.Manager.new(80, 24)\n    iex> manager = Buffer.Manager.update_memory_usage(manager)\n    iex> manager.memory_usage > 0\n    true","ref":"Raxol.Terminal.Buffer.Manager.html#update_memory_usage/1-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.update_selection/3","doc":"Updates the endpoint of the current selection.","ref":"Raxol.Terminal.Buffer.Manager.html#update_selection/3"},{"type":"function","title":"Raxol.Terminal.Buffer.Manager.within_memory_limits?/1","doc":"Checks if memory usage is within limits.","ref":"Raxol.Terminal.Buffer.Manager.html#within_memory_limits?/1"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Manager.within_memory_limits?/1","doc":"iex> manager = Buffer.Manager.new(80, 24)\n    iex> Buffer.Manager.within_memory_limits?(manager)\n    true","ref":"Raxol.Terminal.Buffer.Manager.html#within_memory_limits?/1-examples"},{"type":"module","title":"Raxol.Terminal.Buffer.Operations","doc":"Provides functions for manipulating the Raxol.Terminal.ScreenBuffer grid and state.\nIncludes writing, clearing, deleting, inserting, resizing, and other operations.","ref":"Raxol.Terminal.Buffer.Operations.html"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.clear/1","doc":"Clears the entire screen buffer (excluding scrollback) with empty cells.","ref":"Raxol.Terminal.Buffer.Operations.html#clear/1"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.clear_region/5","doc":"Clears a rectangular region of the buffer by replacing cells with empty cells.","ref":"Raxol.Terminal.Buffer.Operations.html#clear_region/5"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.clear_scroll_region/1","doc":"Clears the scroll region setting in the buffer.","ref":"Raxol.Terminal.Buffer.Operations.html#clear_scroll_region/1"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.delete_characters/3","doc":"Deletes characters at the cursor position {x, y}, shifting remaining chars left.","ref":"Raxol.Terminal.Buffer.Operations.html#delete_characters/3"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.delete_lines/4","doc":"Deletes `n` lines starting from `start_y` within the scroll region.\nLines below are shifted up, blank lines added at the bottom of the region.","ref":"Raxol.Terminal.Buffer.Operations.html#delete_lines/4"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.diff/2","doc":"Calculates the difference between the current buffer state and a list of desired cell changes.\nReturns a list of {x, y, cell_map} tuples representing only the cells that need to be updated.\nInput `changes` must be a list of {x, y, map} tuples.","ref":"Raxol.Terminal.Buffer.Operations.html#diff/2"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.erase_in_display/3","doc":"Erases parts of the display based on cursor position (:to_end, :to_beginning, :all).\nRequires cursor state {x, y}.","ref":"Raxol.Terminal.Buffer.Operations.html#erase_in_display/3"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.erase_in_line/3","doc":"Erases parts of the current line based on cursor position (:to_end, :to_beginning, :all).\nRequires cursor state {x, y}.","ref":"Raxol.Terminal.Buffer.Operations.html#erase_in_line/3"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.get_cell/3","doc":"Gets a specific Cell from the buffer at {x, y}.\nReturns nil if coordinates are out of bounds.","ref":"Raxol.Terminal.Buffer.Operations.html#get_cell/3"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.get_cell_at/3","doc":"Gets the cell at the specified coordinates {x, y}.\nReturns nil if coordinates are out of bounds. Alias for get_cell/3.","ref":"Raxol.Terminal.Buffer.Operations.html#get_cell_at/3"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.get_content/1","doc":"Converts the screen buffer content to a plain text string.","ref":"Raxol.Terminal.Buffer.Operations.html#get_content/1"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.get_dimensions/1","doc":"Gets the dimensions {width, height} of the screen buffer.","ref":"Raxol.Terminal.Buffer.Operations.html#get_dimensions/1"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.get_height/1","doc":"Gets the current height of the screen buffer.","ref":"Raxol.Terminal.Buffer.Operations.html#get_height/1"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.get_line/2","doc":"Gets a specific line (list of Cells) from the buffer by index.\nReturns nil if index is out of bounds.","ref":"Raxol.Terminal.Buffer.Operations.html#get_line/2"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.get_scroll_region_boundaries/1","doc":"Gets the boundaries {top, bottom} of the current scroll region.\nReturns {0, height - 1} if no region is set.","ref":"Raxol.Terminal.Buffer.Operations.html#get_scroll_region_boundaries/1"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.get_width/1","doc":"Gets the current width of the screen buffer.","ref":"Raxol.Terminal.Buffer.Operations.html#get_width/1"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.insert_characters/4","doc":"Inserts blank characters at the cursor position {x, y}, shifting existing chars right.","ref":"Raxol.Terminal.Buffer.Operations.html#insert_characters/4"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.insert_lines/4","doc":"Inserts `n` blank lines at `start_y` within the scroll region, shifting lines down.","ref":"Raxol.Terminal.Buffer.Operations.html#insert_lines/4"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.resize/3","doc":"Resizes the screen buffer to the new dimensions.\nPreserves content that fits within the new bounds. Clears selection and scroll region.","ref":"Raxol.Terminal.Buffer.Operations.html#resize/3"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.scroll_down/4","doc":"Scrolls the buffer down by the specified number of lines, optionally within a specified scroll region.\nHandles cell manipulation using provided lines from scrollback.\nExpects `lines_to_insert` from the caller (e.g., Buffer.Manager via Buffer.Scrollback).","ref":"Raxol.Terminal.Buffer.Operations.html#scroll_down/4"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.scroll_up/3","doc":"Scrolls the buffer up by the specified number of lines, optionally within a specified scroll region.\nHandles cell manipulation.\nReturns `{updated_cells, scrolled_off_lines}`.","ref":"Raxol.Terminal.Buffer.Operations.html#scroll_up/3"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.set_scroll_region/3","doc":"Sets a scroll region in the buffer.","ref":"Raxol.Terminal.Buffer.Operations.html#set_scroll_region/3"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.update/2","doc":"Updates the buffer state by applying a list of cell changes.\nChanges must be in the format {x, y, Cell.t() | map()}.\nReturns the updated buffer.","ref":"Raxol.Terminal.Buffer.Operations.html#update/2"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.write_char/5","doc":"Writes a character to the buffer at the specified position.\nHandles wide characters by taking up two cells when necessary.\nAccepts an optional style to apply to the cell.","ref":"Raxol.Terminal.Buffer.Operations.html#write_char/5"},{"type":"function","title":"Raxol.Terminal.Buffer.Operations.write_string/4","doc":"Writes a string to the buffer at the specified position.\nHandles wide characters and bidirectional text.","ref":"Raxol.Terminal.Buffer.Operations.html#write_string/4"},{"type":"module","title":"Raxol.Terminal.Buffer.Scroll","doc":"Terminal scroll buffer module.\n\nThis module handles the management of terminal scrollback buffers, including:\n- Virtual scrolling implementation\n- Memory-efficient buffer management\n- Scroll position tracking\n- Buffer compression","ref":"Raxol.Terminal.Buffer.Scroll.html"},{"type":"function","title":"Raxol.Terminal.Buffer.Scroll.add_line/2","doc":"Adds a line to the scroll buffer.","ref":"Raxol.Terminal.Buffer.Scroll.html#add_line/2"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Scroll.add_line/2","doc":"iex> scroll = Scroll.new(1000)\n    iex> line = [Cell.new(\"A\"), Cell.new(\"B\")]\n    iex> scroll = Scroll.add_line(scroll, line)\n    iex> scroll.height\n    1","ref":"Raxol.Terminal.Buffer.Scroll.html#add_line/2-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Scroll.clear/1","doc":"Clears the scroll buffer.","ref":"Raxol.Terminal.Buffer.Scroll.html#clear/1"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Scroll.clear/1","doc":"iex> scroll = Scroll.new(1000)\n    iex> line = [Cell.new(\"A\"), Cell.new(\"B\")]\n    iex> scroll = Scroll.add_line(scroll, line)\n    iex> scroll = Scroll.clear(scroll)\n    iex> scroll.height\n    0","ref":"Raxol.Terminal.Buffer.Scroll.html#clear/1-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Scroll.get_height/1","doc":"Gets the total height of the scroll buffer.","ref":"Raxol.Terminal.Buffer.Scroll.html#get_height/1"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Scroll.get_height/1","doc":"iex> scroll = Scroll.new(1000)\n    iex> line = [Cell.new(\"A\"), Cell.new(\"B\")]\n    iex> scroll = Scroll.add_line(scroll, line)\n    iex> Scroll.get_height(scroll)\n    1","ref":"Raxol.Terminal.Buffer.Scroll.html#get_height/1-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Scroll.get_position/1","doc":"Gets the current scroll position.","ref":"Raxol.Terminal.Buffer.Scroll.html#get_position/1"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Scroll.get_position/1","doc":"iex> scroll = Scroll.new(1000)\n    iex> Scroll.get_position(scroll)\n    0","ref":"Raxol.Terminal.Buffer.Scroll.html#get_position/1-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Scroll.get_view/2","doc":"Gets a view of the scroll buffer at the current position.","ref":"Raxol.Terminal.Buffer.Scroll.html#get_view/2"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Scroll.get_view/2","doc":"iex> scroll = Scroll.new(1000)\n    iex> line = [Cell.new(\"A\"), Cell.new(\"B\")]\n    iex> scroll = Scroll.add_line(scroll, line)\n    iex> view = Scroll.get_view(scroll, 10)\n    iex> length(view)\n    1","ref":"Raxol.Terminal.Buffer.Scroll.html#get_view/2-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Scroll.new/2","doc":"Creates a new scroll buffer with the given dimensions.","ref":"Raxol.Terminal.Buffer.Scroll.html#new/2"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Scroll.new/2","doc":"iex> scroll = Scroll.new(1000)\n    iex> scroll.max_height\n    1000\n    iex> scroll.position\n    0","ref":"Raxol.Terminal.Buffer.Scroll.html#new/2-examples"},{"type":"function","title":"Raxol.Terminal.Buffer.Scroll.scroll/2","doc":"Scrolls the buffer by the given amount.","ref":"Raxol.Terminal.Buffer.Scroll.html#scroll/2"},{"type":"function","title":"Examples - Raxol.Terminal.Buffer.Scroll.scroll/2","doc":"iex> scroll = Scroll.new(1000)\n    iex> line = [Cell.new(\"A\"), Cell.new(\"B\")]\n    iex> scroll = Scroll.add_line(scroll, line)\n    iex> scroll = Scroll.scroll(scroll, 5)\n    iex> scroll.position\n    5","ref":"Raxol.Terminal.Buffer.Scroll.html#scroll/2-examples"},{"type":"type","title":"Raxol.Terminal.Buffer.Scroll.t/0","doc":"","ref":"Raxol.Terminal.Buffer.Scroll.html#t:t/0"},{"type":"module","title":"Raxol.Terminal.Buffer.Scrollback","doc":"Manages the scrollback buffer lines.\n\nStores lines scrolled off the top and provides them when scrolling down.\nEnforces a configurable size limit.","ref":"Raxol.Terminal.Buffer.Scrollback.html"},{"type":"function","title":"Raxol.Terminal.Buffer.Scrollback.add_lines/2","doc":"Adds new lines to the top of the scrollback buffer.\n\nLines are prepended. The buffer is trimmed to the limit if necessary.","ref":"Raxol.Terminal.Buffer.Scrollback.html#add_lines/2"},{"type":"function","title":"Raxol.Terminal.Buffer.Scrollback.clear/1","doc":"Clears all lines from the scrollback buffer.","ref":"Raxol.Terminal.Buffer.Scrollback.html#clear/1"},{"type":"function","title":"Raxol.Terminal.Buffer.Scrollback.new/1","doc":"Creates a new scrollback buffer with a given limit.","ref":"Raxol.Terminal.Buffer.Scrollback.html#new/1"},{"type":"function","title":"Raxol.Terminal.Buffer.Scrollback.size/1","doc":"Gets the current number of lines stored in the scrollback buffer.","ref":"Raxol.Terminal.Buffer.Scrollback.html#size/1"},{"type":"type","title":"Raxol.Terminal.Buffer.Scrollback.t/0","doc":"","ref":"Raxol.Terminal.Buffer.Scrollback.html#t:t/0"},{"type":"function","title":"Raxol.Terminal.Buffer.Scrollback.take_lines/2","doc":"Takes a number of lines from the top of the scrollback buffer.\n\nUsed when scrolling down to restore lines.\nReturns a tuple: `{restored_lines, updated_scrollback_state}`.\nFewer lines than requested may be returned if the buffer is smaller.","ref":"Raxol.Terminal.Buffer.Scrollback.html#take_lines/2"},{"type":"module","title":"Raxol.Terminal.Buffer.Selection","doc":"Handles text selection within the Raxol.Terminal.ScreenBuffer.","ref":"Raxol.Terminal.Buffer.Selection.html"},{"type":"function","title":"Raxol.Terminal.Buffer.Selection.contains?/3","doc":"Checks if a position (x, y) is within the current selection in the buffer.","ref":"Raxol.Terminal.Buffer.Selection.html#contains?/3"},{"type":"function","title":"Raxol.Terminal.Buffer.Selection.get_boundaries/1","doc":"Gets the boundaries {start_x, start_y, end_x, end_y} of the current selection.\nReturns nil if there is no selection.","ref":"Raxol.Terminal.Buffer.Selection.html#get_boundaries/1"},{"type":"function","title":"Raxol.Terminal.Buffer.Selection.get_text/1","doc":"Gets the text within the current selection in the buffer.","ref":"Raxol.Terminal.Buffer.Selection.html#get_text/1"},{"type":"function","title":"Raxol.Terminal.Buffer.Selection.get_text_in_region/5","doc":"Gets the text within a specified rectangular region of the buffer.\nCoordinates are inclusive.","ref":"Raxol.Terminal.Buffer.Selection.html#get_text_in_region/5"},{"type":"function","title":"Raxol.Terminal.Buffer.Selection.start/3","doc":"Starts a selection at the specified coordinates in the buffer.","ref":"Raxol.Terminal.Buffer.Selection.html#start/3"},{"type":"function","title":"Raxol.Terminal.Buffer.Selection.update/3","doc":"Updates the endpoint of the current selection in the buffer.","ref":"Raxol.Terminal.Buffer.Selection.html#update/3"},{"type":"module","title":"Raxol.Terminal.Cell","doc":"Terminal character cell module.\n\nThis module handles the representation and manipulation of individual\ncharacter cells in the terminal screen buffer, including:\n- Character content\n- Text attributes (color, style)\n- Cell state","ref":"Raxol.Terminal.Cell.html"},{"type":"function","title":"Raxol.Terminal.Cell.copy/1","doc":"Creates a deep copy of a cell.","ref":"Raxol.Terminal.Cell.html#copy/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cell.copy/1","doc":"iex> cell = Cell.new(\"A\", %{foreground: :red})\n    iex> copy = Cell.copy(cell)\n    iex> Cell.get_char(copy)\n    \"A\"\n    iex> Cell.get_style(copy)\n    %{foreground: :red}","ref":"Raxol.Terminal.Cell.html#copy/1-examples"},{"type":"function","title":"Raxol.Terminal.Cell.double_height?/1","doc":"Checks if the cell is in double-height mode.","ref":"Raxol.Terminal.Cell.html#double_height?/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cell.double_height?/1","doc":"iex> cell = Cell.new(\"A\", %{foreground: :red})\n    iex> Cell.double_height?(cell)\n    false","ref":"Raxol.Terminal.Cell.html#double_height?/1-examples"},{"type":"function","title":"Raxol.Terminal.Cell.double_width?/1","doc":"Checks if the cell is in double-width mode.","ref":"Raxol.Terminal.Cell.html#double_width?/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cell.double_width?/1","doc":"iex> cell = Cell.new(\"A\", %{foreground: :red})\n    iex> Cell.double_width?(cell)\n    false","ref":"Raxol.Terminal.Cell.html#double_width?/1-examples"},{"type":"function","title":"Raxol.Terminal.Cell.equals?/2","doc":"Compares two cells for equality.\n\nCells are considered equal if they have the same character and the same style map.\nHandles comparison with `nil`.","ref":"Raxol.Terminal.Cell.html#equals?/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cell.equals?/2","doc":"iex> style1 = TextFormatting.new() |> TextFormatting.apply_attribute(:bold)\n    iex> style2 = TextFormatting.new() |> TextFormatting.apply_attribute(:bold)\n    iex> style3 = TextFormatting.new() |> TextFormatting.apply_attribute(:underline)\n    iex> cell1 = Cell.new(\"A\", style1)\n    iex> cell2 = Cell.new(\"A\", style2) # Same char and style attributes\n    iex> cell3 = Cell.new(\"B\", style1) # Different char\n    iex> cell4 = Cell.new(\"A\", style3) # Different style\n    iex> Cell.equals?(cell1, cell2)\n    true\n    iex> Cell.equals?(cell1, cell3)\n    false\n    iex> Cell.equals?(cell1, cell4)\n    false\n    iex> Cell.equals?(cell1, nil)\n    false\n    iex> Cell.equals?(nil, cell1)\n    false\n    iex> Cell.equals?(nil, nil)\n    true","ref":"Raxol.Terminal.Cell.html#equals?/2-examples"},{"type":"function","title":"Raxol.Terminal.Cell.from_map/1","doc":"Creates a Cell struct from a map representation, typically from rendering.\nExpects a map like %{char: integer_codepoint, style: map, is_wide_placeholder: boolean | nil}.\nReturns nil if the map is invalid.","ref":"Raxol.Terminal.Cell.html#from_map/1"},{"type":"function","title":"Raxol.Terminal.Cell.get_char/1","doc":"Gets the character content of a cell.","ref":"Raxol.Terminal.Cell.html#get_char/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cell.get_char/1","doc":"iex> cell = Cell.new(\"A\")\n    iex> Cell.get_char(cell)\n    \"A\"","ref":"Raxol.Terminal.Cell.html#get_char/1-examples"},{"type":"function","title":"Raxol.Terminal.Cell.get_style/1","doc":"Gets the text style of the cell.","ref":"Raxol.Terminal.Cell.html#get_style/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cell.get_style/1","doc":"iex> cell = Cell.new(\"A\", %{foreground: :red})\n    iex> Cell.get_style(cell)\n    %{foreground: :red}","ref":"Raxol.Terminal.Cell.html#get_style/1-examples"},{"type":"function","title":"Raxol.Terminal.Cell.has_attribute?/2","doc":"Checks if the cell has a specific attribute.","ref":"Raxol.Terminal.Cell.html#has_attribute?/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cell.has_attribute?/2","doc":"iex> cell = Cell.new(\"A\", %{foreground: :red})\n    iex> Cell.has_attribute?(cell, :foreground)\n    true","ref":"Raxol.Terminal.Cell.html#has_attribute?/2-examples"},{"type":"function","title":"Raxol.Terminal.Cell.has_decoration?/2","doc":"Checks if the cell has a specific decoration.","ref":"Raxol.Terminal.Cell.html#has_decoration?/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cell.has_decoration?/2","doc":"iex> cell = Cell.new(\"A\", %{foreground: :red})\n    iex> Cell.has_decoration?(cell, :bold)\n    false","ref":"Raxol.Terminal.Cell.html#has_decoration?/2-examples"},{"type":"function","title":"Raxol.Terminal.Cell.is_empty?/1","doc":"Checks if a cell is empty.\n\nA cell is considered empty if it contains a space character *and*\nhas the default text formatting style.","ref":"Raxol.Terminal.Cell.html#is_empty?/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cell.is_empty?/1","doc":"iex> cell = Cell.new()\n    iex> Cell.is_empty?(cell)\n    true\n\n    iex> cell = Cell.new(\"A\")\n    iex> Cell.is_empty?(cell)\n    false\n\n    iex> bold_style = TextFormatting.new() |> TextFormatting.apply_attribute(:bold)\n    iex> cell = Cell.new(\" \", bold_style) # Space char but non-default style\n    iex> Cell.is_empty?(cell)\n    false","ref":"Raxol.Terminal.Cell.html#is_empty?/1-examples"},{"type":"function","title":"Raxol.Terminal.Cell.merge_style/2","doc":"Merges a given style map into the cell's style.\n\nOnly non-default attributes from the `style` map will overwrite existing attributes\nin the cell's style. This prevents merging default values (like `bold: false`)\nand unintentionally removing existing attributes.","ref":"Raxol.Terminal.Cell.html#merge_style/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cell.merge_style/2","doc":"iex> initial_style = TextFormatting.new() |> TextFormatting.apply_attribute(:bold) # %{bold: true, ...}\n    iex> merge_style = TextFormatting.new() |> TextFormatting.apply_attribute(:underline) # %{underline: true, bold: false, ...}\n    iex> cell = Cell.new(\"A\", initial_style)\n    iex> merged_cell = Cell.merge_style(cell, merge_style)\n    iex> Cell.get_style(merged_cell)\n    %{bold: true, underline: true} # Note: :bold remains, :underline added","ref":"Raxol.Terminal.Cell.html#merge_style/2-examples"},{"type":"function","title":"Raxol.Terminal.Cell.new/0","doc":"Creates a new cell with optional character and style.","ref":"Raxol.Terminal.Cell.html#new/0"},{"type":"function","title":"Examples - Raxol.Terminal.Cell.new/0","doc":"iex> cell = Cell.new()\n    iex> Cell.is_empty?(cell)\n    true\n\n    iex> cell = Cell.new(\"A\")\n    iex> Cell.get_char(cell)\n    \"A\"\n\n    iex> cell = Cell.new(\"A\", %{foreground: :red})\n    iex> Cell.get_char(cell)\n    \"A\"\n    iex> Cell.get_style(cell)\n    %{foreground: :red}","ref":"Raxol.Terminal.Cell.html#new/0-examples"},{"type":"function","title":"Raxol.Terminal.Cell.new/1","doc":"","ref":"Raxol.Terminal.Cell.html#new/1"},{"type":"function","title":"Raxol.Terminal.Cell.new/2","doc":"","ref":"Raxol.Terminal.Cell.html#new/2"},{"type":"function","title":"Raxol.Terminal.Cell.new_wide_placeholder/1","doc":"Creates a new cell representing the second half of a wide character.\nInherits the style from the primary cell.","ref":"Raxol.Terminal.Cell.html#new_wide_placeholder/1"},{"type":"function","title":"Raxol.Terminal.Cell.set_char/2","doc":"Sets the character content of a cell.","ref":"Raxol.Terminal.Cell.html#set_char/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cell.set_char/2","doc":"iex> cell = Cell.new()\n    iex> cell = Cell.set_char(cell, \"A\")\n    iex> Cell.get_char(cell)\n    \"A\"","ref":"Raxol.Terminal.Cell.html#set_char/2-examples"},{"type":"function","title":"Raxol.Terminal.Cell.set_style/2","doc":"Sets the text style of the cell.","ref":"Raxol.Terminal.Cell.html#set_style/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cell.set_style/2","doc":"iex> cell = Cell.new(\"A\")\n    iex> cell = Cell.set_style(cell, %{foreground: :red})\n    iex> Cell.get_style(cell)\n    %{foreground: :red}","ref":"Raxol.Terminal.Cell.html#set_style/2-examples"},{"type":"type","title":"Raxol.Terminal.Cell.t/0","doc":"","ref":"Raxol.Terminal.Cell.html#t:t/0"},{"type":"function","title":"Raxol.Terminal.Cell.with_attributes/2","doc":"Creates a copy of a cell with new attributes applied.\n\nAccepts a map of attributes or a list of attribute atoms.\nIf a list is provided, the attributes are applied sequentially, starting from the cell's *existing* style.","ref":"Raxol.Terminal.Cell.html#with_attributes/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cell.with_attributes/2","doc":"iex> cell = Cell.new(\"A\", %{bold: true})\n    iex> new_cell = Cell.with_attributes(cell, %{underline: true}) # Using a map\n    iex> Cell.get_style(new_cell)\n    %{bold: true, underline: true} # Merged\n\n    iex> cell = Cell.new(\"B\", %{bold: true})\n    iex> new_cell = Cell.with_attributes(cell, [:underline, :reverse]) # Using a list\n    iex> Cell.get_style(new_cell)\n    %{bold: true, underline: true, reverse: true} # Original bold + list applied","ref":"Raxol.Terminal.Cell.html#with_attributes/2-examples"},{"type":"function","title":"Raxol.Terminal.Cell.with_char/2","doc":"Creates a copy of a cell with a new character.","ref":"Raxol.Terminal.Cell.html#with_char/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cell.with_char/2","doc":"iex> cell = Cell.new(\"A\", %{foreground: :red})\n    iex> new_cell = Cell.with_char(cell, \"B\")\n    iex> Cell.get_char(new_cell)\n    \"B\"\n    iex> Cell.get_style(new_cell)\n    %{foreground: :red}","ref":"Raxol.Terminal.Cell.html#with_char/2-examples"},{"type":"module","title":"Raxol.Terminal.CharacterHandling","doc":"Handles wide character and bidirectional text support for the terminal emulator.\n\nThis module provides functions for:\n- Determining character width (single, double, or variable width)\n- Handling bidirectional text rendering\n- Managing character combining\n- Supporting Unicode character properties","ref":"Raxol.Terminal.CharacterHandling.html"},{"type":"function","title":"Raxol.Terminal.CharacterHandling.get_bidi_type/1","doc":"Determines the bidirectional character type.\nReturns :LTR, :RTL, :NEUTRAL, or :COMBINING.","ref":"Raxol.Terminal.CharacterHandling.html#get_bidi_type/1"},{"type":"function","title":"Raxol.Terminal.CharacterHandling.get_char_width/1","doc":"Gets the width of a character in terminal cells.\nReturns 1 for narrow characters, 2 for wide characters.","ref":"Raxol.Terminal.CharacterHandling.html#get_char_width/1"},{"type":"function","title":"Raxol.Terminal.CharacterHandling.get_string_width/1","doc":"Gets the effective width of a string, taking into account wide characters.","ref":"Raxol.Terminal.CharacterHandling.html#get_string_width/1"},{"type":"function","title":"Raxol.Terminal.CharacterHandling.is_combining_char?/1","doc":"Determines if a character is a combining character.","ref":"Raxol.Terminal.CharacterHandling.html#is_combining_char?/1"},{"type":"function","title":"Raxol.Terminal.CharacterHandling.is_wide_char?/1","doc":"Determines if a character is a wide character (takes up two cells).","ref":"Raxol.Terminal.CharacterHandling.html#is_wide_char?/1"},{"type":"function","title":"Raxol.Terminal.CharacterHandling.process_bidi_text/1","doc":"Processes a string for bidirectional text rendering.\nReturns a list of segments with their rendering order.","ref":"Raxol.Terminal.CharacterHandling.html#process_bidi_text/1"},{"type":"function","title":"Raxol.Terminal.CharacterHandling.split_at_width/2","doc":"Splits a string at a given width, respecting wide characters.","ref":"Raxol.Terminal.CharacterHandling.html#split_at_width/2"},{"type":"module","title":"Raxol.Terminal.CharacterSets","doc":"Handles character set management and translation for the terminal emulator.\n\nThis module defines the character set state, including designated G0-G3 sets\nand active GL/GR sets. It also provides translation tables for different\ncharacter sets and functions to translate characters based on the active set.","ref":"Raxol.Terminal.CharacterSets.html"},{"type":"type","title":"Raxol.Terminal.CharacterSets.charset_state/0","doc":"","ref":"Raxol.Terminal.CharacterSets.html#t:charset_state/0"},{"type":"function","title":"Raxol.Terminal.CharacterSets.invoke_designator/2","doc":"Invokes a designated character set as GL or GR.\nHandles SI (invokes G0 as GL), SO (invokes G1 as GL),\nESC ~ (invokes G1 as GR), ESC } (invokes G2 as GR), ESC | (invokes G3 as GR).\nUpdates the `active_set` based on the new GL mapping.\nNote: This implementation assumes basic SO/SI for GL.\nMore complex shift functions (LS*, SS*) modify `active_set` differently.","ref":"Raxol.Terminal.CharacterSets.html#invoke_designator/2"},{"type":"function","title":"Raxol.Terminal.CharacterSets.new/0","doc":"Creates a new character set state with default values (US-ASCII).","ref":"Raxol.Terminal.CharacterSets.html#new/0"},{"type":"function","title":"Raxol.Terminal.CharacterSets.set_designator/3","doc":"Designates a character set for a specific target (G0-G3).\n`target_set` should be :g0, :g1, :g2, or :g3.\n`charset` is the atom representing the character set (e.g., :us_ascii, :dec_special_graphics).","ref":"Raxol.Terminal.CharacterSets.html#set_designator/3"},{"type":"function","title":"Raxol.Terminal.CharacterSets.translate_active/2","doc":"Translates a codepoint based on the *currently active* character set in the state.","ref":"Raxol.Terminal.CharacterSets.html#translate_active/2"},{"type":"module","title":"Raxol.Terminal.CharacterSets.Translator","doc":"Provides translation logic for different character sets.\n\nUses map lookups for efficient character translation based on the active set.\nMaps only store differences from the base character set (implicitly US-ASCII).","ref":"Raxol.Terminal.CharacterSets.Translator.html"},{"type":"function","title":"Raxol.Terminal.CharacterSets.Translator.translate_codepoint/2","doc":"Translates a single codepoint based on the specified character set atom.\n\nIf the charset is unknown or the codepoint has no specific mapping in that\ncharset, the original codepoint is returned.","ref":"Raxol.Terminal.CharacterSets.Translator.html#translate_codepoint/2"},{"type":"module","title":"Raxol.Terminal.Clipboard","doc":"Handles clipboard operations for the terminal emulator.\n\nThis module provides functionality for:\n- Copying text to the system clipboard\n- Pasting text from the system clipboard\n- Managing clipboard history","ref":"Raxol.Terminal.Clipboard.html"},{"type":"function","title":"Raxol.Terminal.Clipboard.clear_history/1","doc":"Clears the clipboard history.","ref":"Raxol.Terminal.Clipboard.html#clear_history/1"},{"type":"function","title":"Raxol.Terminal.Clipboard.copy/2","doc":"Copies text to the system clipboard and adds it to the history.","ref":"Raxol.Terminal.Clipboard.html#copy/2"},{"type":"function","title":"Raxol.Terminal.Clipboard.enabled?/1","doc":"Checks if clipboard operations are enabled.","ref":"Raxol.Terminal.Clipboard.html#enabled?/1"},{"type":"function","title":"Raxol.Terminal.Clipboard.get_history/1","doc":"Gets the clipboard history.","ref":"Raxol.Terminal.Clipboard.html#get_history/1"},{"type":"function","title":"Raxol.Terminal.Clipboard.new/1","doc":"Creates a new clipboard manager with default values.","ref":"Raxol.Terminal.Clipboard.html#new/1"},{"type":"function","title":"Raxol.Terminal.Clipboard.paste/1","doc":"Retrieves text from the system clipboard.","ref":"Raxol.Terminal.Clipboard.html#paste/1"},{"type":"function","title":"Raxol.Terminal.Clipboard.set_enabled/2","doc":"Enables or disables clipboard operations.","ref":"Raxol.Terminal.Clipboard.html#set_enabled/2"},{"type":"type","title":"Raxol.Terminal.Clipboard.t/0","doc":"","ref":"Raxol.Terminal.Clipboard.html#t:t/0"},{"type":"module","title":"Raxol.Terminal.CommandExecutor","doc":"DEPRECATED: Handles the execution of parsed terminal commands.\n\nThis module is being replaced by `Raxol.Terminal.Commands.Executor` and\nvarious submodules within `Raxol.Terminal.Commands.*`.\n\nExisting functions are kept temporarily for backward compatibility or as\nplaceholders during refactoring, but they primarily log warnings and delegate\nto the new modules where possible.","ref":"Raxol.Terminal.CommandExecutor.html"},{"type":"function","title":"Raxol.Terminal.CommandExecutor.clear_line/2","doc":"Clears a line or part of a line based on the mode parameter.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Screen.clear_line/2 instead.","ref":"Raxol.Terminal.CommandExecutor.html#clear_line/2"},{"type":"function","title":"Raxol.Terminal.CommandExecutor.clear_screen/2","doc":"Clears the screen or a part of it based on the mode parameter.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Screen.clear_screen/2 instead.","ref":"Raxol.Terminal.CommandExecutor.html#clear_screen/2"},{"type":"function","title":"Raxol.Terminal.CommandExecutor.delete_line/2","doc":"Deletes lines at the current cursor position.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Screen.delete_lines/2 instead.","ref":"Raxol.Terminal.CommandExecutor.html#delete_line/2"},{"type":"function","title":"Raxol.Terminal.CommandExecutor.execute_csi_command/4","doc":"Executes a CSI (Control Sequence Introducer) command.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Executor.execute_csi_command/4 instead.","ref":"Raxol.Terminal.CommandExecutor.html#execute_csi_command/4"},{"type":"function","title":"Raxol.Terminal.CommandExecutor.execute_dcs_command/5","doc":"Executes a DCS (Device Control String) command.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Executor.execute_dcs_command/5 instead.","ref":"Raxol.Terminal.CommandExecutor.html#execute_dcs_command/5"},{"type":"function","title":"Raxol.Terminal.CommandExecutor.execute_osc_command/2","doc":"Executes an OSC (Operating System Command).\n\nDEPRECATED: Use Raxol.Terminal.Commands.Executor.execute_osc_command/2 instead.","ref":"Raxol.Terminal.CommandExecutor.html#execute_osc_command/2"},{"type":"function","title":"Raxol.Terminal.CommandExecutor.get_param/3","doc":"Gets a parameter at a specific index from the params list.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Parser.get_param/3 instead.","ref":"Raxol.Terminal.CommandExecutor.html#get_param/3"},{"type":"function","title":"Raxol.Terminal.CommandExecutor.handle_ansi_mode/3","doc":"Handles ANSI mode setting or resetting.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Modes.handle_ansi_mode/3 instead.","ref":"Raxol.Terminal.CommandExecutor.html#handle_ansi_mode/3"},{"type":"function","title":"Raxol.Terminal.CommandExecutor.handle_dec_private_mode/3","doc":"Handles DEC private mode setting or resetting.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Modes.handle_dec_private_mode/3 instead.","ref":"Raxol.Terminal.CommandExecutor.html#handle_dec_private_mode/3"},{"type":"function","title":"Raxol.Terminal.CommandExecutor.handle_ed/2","doc":"Erase Display handler.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Screen.erase_display/2 instead.","ref":"Raxol.Terminal.CommandExecutor.html#handle_ed/2"},{"type":"function","title":"Raxol.Terminal.CommandExecutor.handle_el/2","doc":"Erase Line handler.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Screen.erase_line/2 instead.","ref":"Raxol.Terminal.CommandExecutor.html#handle_el/2"},{"type":"function","title":"Raxol.Terminal.CommandExecutor.handle_sixel_graphics/2","doc":"Handles Sixel graphics.\n\nDEPRECATED: This should be moved to a dedicated Sixel handler module.","ref":"Raxol.Terminal.CommandExecutor.html#handle_sixel_graphics/2"},{"type":"function","title":"Raxol.Terminal.CommandExecutor.insert_line/2","doc":"Inserts blank lines at the current cursor position.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Screen.insert_lines/2 instead.","ref":"Raxol.Terminal.CommandExecutor.html#insert_line/2"},{"type":"function","title":"Raxol.Terminal.CommandExecutor.parse_params/1","doc":"Parses a raw parameter string buffer into a list of integers or nil values.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Parser.parse_params/1 instead.","ref":"Raxol.Terminal.CommandExecutor.html#parse_params/1"},{"type":"module","title":"Raxol.Terminal.Commands","doc":"Facade for the Terminal Commands functionality that maintains backward compatibility.\n\nThis module provides the same interface as the original CommandExecutor module\nbut delegates to the refactored sub-modules. This allows for a smooth transition\nwhile code that depends on the original API is updated.\n\nDEPRECATED: This module is provided for backward compatibility only. New code should\nuse the appropriate sub-modules directly:\n\n- Raxol.Terminal.Commands.Executor - Main entry point for executing commands\n- Raxol.Terminal.Commands.Parser - For parsing command parameters\n- Raxol.Terminal.Commands.Modes - For handling terminal mode setting/resetting\n- Raxol.Terminal.Commands.Screen - For screen manipulation operations\n- Raxol.Terminal.Commands.History - For command history management","ref":"Raxol.Terminal.Commands.html"},{"type":"function","title":"Raxol.Terminal.Commands.add_to_history/2","doc":"Adds a command to the history.\n\nThis method delegates to the Commands.History module.","ref":"Raxol.Terminal.Commands.html#add_to_history/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.add_to_history/2","doc":"* `history` - The history manager struct\n* `command` - The command to add","ref":"Raxol.Terminal.Commands.html#add_to_history/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.add_to_history/2","doc":"* Updated history manager struct","ref":"Raxol.Terminal.Commands.html#add_to_history/2-returns"},{"type":"function","title":"Migration Path - Raxol.Terminal.Commands.add_to_history/2","doc":"Update your code to use the History module directly:\n\n```elixir\n# Before\nhistory = Raxol.Terminal.CommandHistory.add(history, \"ls -la\")\n\n# After\nhistory = Raxol.Terminal.Commands.History.add(history, \"ls -la\")\n```","ref":"Raxol.Terminal.Commands.html#add_to_history/2-migration-path"},{"type":"function","title":"Raxol.Terminal.Commands.clear_line/2","doc":"Clears a line or part of a line based on the mode parameter.\n\nThis method delegates to the Commands.Screen module.","ref":"Raxol.Terminal.Commands.html#clear_line/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.clear_line/2","doc":"* `emulator` - The current emulator state\n* `mode` - The mode parameter (0, 1, or 2)","ref":"Raxol.Terminal.Commands.html#clear_line/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.clear_line/2","doc":"* Updated emulator state","ref":"Raxol.Terminal.Commands.html#clear_line/2-returns"},{"type":"function","title":"Migration Path - Raxol.Terminal.Commands.clear_line/2","doc":"Update your code to use the Screen module directly:\n\n```elixir\n# Before\nnew_emulator = Raxol.Terminal.CommandExecutor.clear_line(emulator, 2)\n\n# After\nnew_emulator = Raxol.Terminal.Commands.Screen.clear_line(emulator, 2)\n```","ref":"Raxol.Terminal.Commands.html#clear_line/2-migration-path"},{"type":"function","title":"Raxol.Terminal.Commands.clear_screen/2","doc":"Clears the screen or a part of it based on the mode parameter.\n\nThis method delegates to the Commands.Screen module.","ref":"Raxol.Terminal.Commands.html#clear_screen/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.clear_screen/2","doc":"* `emulator` - The current emulator state\n* `mode` - The mode parameter (0, 1, 2, or 3)","ref":"Raxol.Terminal.Commands.html#clear_screen/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.clear_screen/2","doc":"* Updated emulator state","ref":"Raxol.Terminal.Commands.html#clear_screen/2-returns"},{"type":"function","title":"Migration Path - Raxol.Terminal.Commands.clear_screen/2","doc":"Update your code to use the Screen module directly:\n\n```elixir\n# Before\nnew_emulator = Raxol.Terminal.CommandExecutor.clear_screen(emulator, 2)\n\n# After\nnew_emulator = Raxol.Terminal.Commands.Screen.clear_screen(emulator, 2)\n```","ref":"Raxol.Terminal.Commands.html#clear_screen/2-migration-path"},{"type":"function","title":"Raxol.Terminal.Commands.delete_line/2","doc":"Deletes lines at the current cursor position.\n\nThis method delegates to the Commands.Screen module.","ref":"Raxol.Terminal.Commands.html#delete_line/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.delete_line/2","doc":"* `emulator` - The current emulator state\n* `count` - The number of lines to delete","ref":"Raxol.Terminal.Commands.html#delete_line/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.delete_line/2","doc":"* Updated emulator state","ref":"Raxol.Terminal.Commands.html#delete_line/2-returns"},{"type":"function","title":"Migration Path - Raxol.Terminal.Commands.delete_line/2","doc":"Update your code to use the Screen module directly:\n\n```elixir\n# Before\nnew_emulator = Raxol.Terminal.CommandExecutor.delete_line(emulator, 2)\n\n# After\nnew_emulator = Raxol.Terminal.Commands.Screen.delete_lines(emulator, 2)\n```","ref":"Raxol.Terminal.Commands.html#delete_line/2-migration-path"},{"type":"function","title":"Raxol.Terminal.Commands.execute_csi_command/4","doc":"Executes a CSI (Control Sequence Introducer) command.\n\nThis method delegates to the Commands.Executor module for the actual execution.","ref":"Raxol.Terminal.Commands.html#execute_csi_command/4"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.execute_csi_command/4","doc":"* `emulator` - The current emulator state\n* `params_buffer` - The parameter portion of the CSI sequence\n* `intermediates_buffer` - The intermediate bytes portion of the CSI sequence\n* `final_byte` - The final byte that determines the specific command","ref":"Raxol.Terminal.Commands.html#execute_csi_command/4-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.execute_csi_command/4","doc":"* Updated emulator state","ref":"Raxol.Terminal.Commands.html#execute_csi_command/4-returns"},{"type":"function","title":"Migration Path - Raxol.Terminal.Commands.execute_csi_command/4","doc":"Update your code to use the Executor module directly:\n\n```elixir\n# Before\nnew_emulator = Raxol.Terminal.CommandExecutor.execute_csi_command(emulator, params, intermediates, final_byte)\n\n# After\nnew_emulator = Raxol.Terminal.Commands.Executor.execute_csi_command(emulator, params, intermediates, final_byte)\n```","ref":"Raxol.Terminal.Commands.html#execute_csi_command/4-migration-path"},{"type":"function","title":"Raxol.Terminal.Commands.get_param/3","doc":"Gets a parameter at a specific index from the params list.\n\nThis method delegates to the Commands.Parser module.","ref":"Raxol.Terminal.Commands.html#get_param/3"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.get_param/3","doc":"* `params` - The list of parsed parameters\n* `index` - The index to get the parameter from\n* `default` - The default value to return if the parameter is nil or out of bounds","ref":"Raxol.Terminal.Commands.html#get_param/3-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.get_param/3","doc":"* The parameter value or the default value","ref":"Raxol.Terminal.Commands.html#get_param/3-returns"},{"type":"function","title":"Migration Path - Raxol.Terminal.Commands.get_param/3","doc":"Update your code to use the Parser module directly:\n\n```elixir\n# Before\nvalue = Raxol.Terminal.CommandExecutor.get_param(params, 1, 0)\n\n# After\nvalue = Raxol.Terminal.Commands.Parser.get_param(params, 1, 0)\n```","ref":"Raxol.Terminal.Commands.html#get_param/3-migration-path"},{"type":"function","title":"Raxol.Terminal.Commands.handle_ansi_mode/3","doc":"Handles ANSI mode setting or resetting.\n\nThis method delegates to the Commands.Modes module.","ref":"Raxol.Terminal.Commands.html#handle_ansi_mode/3"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.handle_ansi_mode/3","doc":"* `emulator` - The current emulator state\n* `params` - The parsed parameters\n* `action` - The action to perform (:set or :reset)","ref":"Raxol.Terminal.Commands.html#handle_ansi_mode/3-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.handle_ansi_mode/3","doc":"* Updated emulator state","ref":"Raxol.Terminal.Commands.html#handle_ansi_mode/3-returns"},{"type":"function","title":"Migration Path - Raxol.Terminal.Commands.handle_ansi_mode/3","doc":"Update your code to use the Modes module directly:\n\n```elixir\n# Before\nnew_emulator = Raxol.Terminal.CommandExecutor.handle_ansi_mode(emulator, params, :set)\n\n# After\nnew_emulator = Raxol.Terminal.Commands.Modes.handle_ansi_mode(emulator, params, :set)\n```","ref":"Raxol.Terminal.Commands.html#handle_ansi_mode/3-migration-path"},{"type":"function","title":"Raxol.Terminal.Commands.handle_dec_private_mode/3","doc":"Handles DEC private mode setting or resetting.\n\nThis method delegates to the Commands.Modes module.","ref":"Raxol.Terminal.Commands.html#handle_dec_private_mode/3"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.handle_dec_private_mode/3","doc":"* `emulator` - The current emulator state\n* `params` - The parsed parameters\n* `action` - The action to perform (:set or :reset)","ref":"Raxol.Terminal.Commands.html#handle_dec_private_mode/3-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.handle_dec_private_mode/3","doc":"* Updated emulator state","ref":"Raxol.Terminal.Commands.html#handle_dec_private_mode/3-returns"},{"type":"function","title":"Migration Path - Raxol.Terminal.Commands.handle_dec_private_mode/3","doc":"Update your code to use the Modes module directly:\n\n```elixir\n# Before\nnew_emulator = Raxol.Terminal.CommandExecutor.handle_dec_private_mode(emulator, params, :set)\n\n# After\nnew_emulator = Raxol.Terminal.Commands.Modes.handle_dec_private_mode(emulator, params, :set)\n```","ref":"Raxol.Terminal.Commands.html#handle_dec_private_mode/3-migration-path"},{"type":"function","title":"Raxol.Terminal.Commands.insert_line/2","doc":"Inserts blank lines at the current cursor position.\n\nThis method delegates to the Commands.Screen module.","ref":"Raxol.Terminal.Commands.html#insert_line/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.insert_line/2","doc":"* `emulator` - The current emulator state\n* `count` - The number of lines to insert","ref":"Raxol.Terminal.Commands.html#insert_line/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.insert_line/2","doc":"* Updated emulator state","ref":"Raxol.Terminal.Commands.html#insert_line/2-returns"},{"type":"function","title":"Migration Path - Raxol.Terminal.Commands.insert_line/2","doc":"Update your code to use the Screen module directly:\n\n```elixir\n# Before\nnew_emulator = Raxol.Terminal.CommandExecutor.insert_line(emulator, 2)\n\n# After\nnew_emulator = Raxol.Terminal.Commands.Screen.insert_lines(emulator, 2)\n```","ref":"Raxol.Terminal.Commands.html#insert_line/2-migration-path"},{"type":"function","title":"Raxol.Terminal.Commands.new_history/1","doc":"Creates a new command history manager.\n\nThis method delegates to the Commands.History module.","ref":"Raxol.Terminal.Commands.html#new_history/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.new_history/1","doc":"* `max_size` - The maximum number of commands to store","ref":"Raxol.Terminal.Commands.html#new_history/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.new_history/1","doc":"* A new history manager struct","ref":"Raxol.Terminal.Commands.html#new_history/1-returns"},{"type":"function","title":"Migration Path - Raxol.Terminal.Commands.new_history/1","doc":"Update your code to use the History module directly:\n\n```elixir\n# Before\nhistory = Raxol.Terminal.CommandHistory.new(1000)\n\n# After\nhistory = Raxol.Terminal.Commands.History.new(1000)\n```","ref":"Raxol.Terminal.Commands.html#new_history/1-migration-path"},{"type":"function","title":"Raxol.Terminal.Commands.parse_params/1","doc":"Parses a raw parameter string buffer into a list of integers or nil values.\n\nThis method delegates to the Commands.Parser module for the actual parsing.","ref":"Raxol.Terminal.Commands.html#parse_params/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.parse_params/1","doc":"* `params_string` - The raw parameter string from a CSI sequence","ref":"Raxol.Terminal.Commands.html#parse_params/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.parse_params/1","doc":"* A list of parsed parameters","ref":"Raxol.Terminal.Commands.html#parse_params/1-returns"},{"type":"function","title":"Migration Path - Raxol.Terminal.Commands.parse_params/1","doc":"Update your code to use the Parser module directly:\n\n```elixir\n# Before\nparams = Raxol.Terminal.CommandExecutor.parse_params(params_string)\n\n# After\nparams = Raxol.Terminal.Commands.Parser.parse_params(params_string)\n```","ref":"Raxol.Terminal.Commands.html#parse_params/1-migration-path"},{"type":"function","title":"Raxol.Terminal.Commands.previous_command/1","doc":"Retrieves the previous command in history.\n\nThis method delegates to the Commands.History module.","ref":"Raxol.Terminal.Commands.html#previous_command/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.previous_command/1","doc":"* `history`","ref":"Raxol.Terminal.Commands.html#previous_command/1-parameters"},{"type":"module","title":"Raxol.Terminal.Commands.Executor","doc":"Executes parsed terminal commands (CSI, OSC, DCS).\n\nThis module takes parsed command details and the current emulator state,\nand returns the updated emulator state after applying the command's effects.","ref":"Raxol.Terminal.Commands.Executor.html"},{"type":"function","title":"Raxol.Terminal.Commands.Executor.execute_csi_command/4","doc":"Executes a CSI (Control Sequence Introducer) command.\n\nTODO: Implement the actual logic for handling various CSI commands.\nThis likely involves pattern matching on the final_byte and intermediates,\nparsing parameters, and calling specific handler functions (e.g., from\nModes, Screen, Cursor modules).","ref":"Raxol.Terminal.Commands.Executor.html#execute_csi_command/4"},{"type":"function","title":"Raxol.Terminal.Commands.Executor.execute_dcs_command/5","doc":"Placeholder for DCS command execution","ref":"Raxol.Terminal.Commands.Executor.html#execute_dcs_command/5"},{"type":"function","title":"Raxol.Terminal.Commands.Executor.execute_osc_command/2","doc":"Placeholder for OSC command execution","ref":"Raxol.Terminal.Commands.Executor.html#execute_osc_command/2"},{"type":"module","title":"Raxol.Terminal.Commands.History","doc":"Manages command history for the terminal emulator.\n\nThis module provides functionality for:\n- Storing and retrieving command history\n- Navigating through command history\n- Persisting command history\n- Managing history size limits","ref":"Raxol.Terminal.Commands.History.html"},{"type":"function","title":"Raxol.Terminal.Commands.History.add/2","doc":"Adds a command to the history.","ref":"Raxol.Terminal.Commands.History.html#add/2"},{"type":"function","title":"Examples - Raxol.Terminal.Commands.History.add/2","doc":"iex> history = History.new(1000)\n    iex> history = History.add(history, \"ls -la\")\n    iex> history.commands\n    [\"ls -la\"]","ref":"Raxol.Terminal.Commands.History.html#add/2-examples"},{"type":"function","title":"Raxol.Terminal.Commands.History.clear/1","doc":"Clears the command history.","ref":"Raxol.Terminal.Commands.History.html#clear/1"},{"type":"function","title":"Examples - Raxol.Terminal.Commands.History.clear/1","doc":"iex> history = History.new(1000)\n    iex> history = History.add(history, \"ls -la\")\n    iex> history = History.clear(history)\n    iex> history.commands\n    []","ref":"Raxol.Terminal.Commands.History.html#clear/1-examples"},{"type":"function","title":"Raxol.Terminal.Commands.History.list/1","doc":"Returns the current command history as a list.","ref":"Raxol.Terminal.Commands.History.html#list/1"},{"type":"function","title":"Examples - Raxol.Terminal.Commands.History.list/1","doc":"iex> history = History.new(1000)\n    iex> history = History.add(history, \"ls -la\")\n    iex> history = History.add(history, \"cd /tmp\")\n    iex> History.list(history)\n    [\"cd /tmp\", \"ls -la\"]","ref":"Raxol.Terminal.Commands.History.html#list/1-examples"},{"type":"function","title":"Raxol.Terminal.Commands.History.new/1","doc":"Creates a new command history manager.","ref":"Raxol.Terminal.Commands.History.html#new/1"},{"type":"function","title":"Examples - Raxol.Terminal.Commands.History.new/1","doc":"iex> history = History.new(1000)\n    iex> history.max_size\n    1000","ref":"Raxol.Terminal.Commands.History.html#new/1-examples"},{"type":"function","title":"Raxol.Terminal.Commands.History.next/1","doc":"Retrieves the next command in history.","ref":"Raxol.Terminal.Commands.History.html#next/1"},{"type":"function","title":"Examples - Raxol.Terminal.Commands.History.next/1","doc":"iex> history = History.new(1000)\n    iex> history = History.add(history, \"ls -la\")\n    iex> history = History.add(history, \"cd /tmp\")\n    iex> {_, history} = History.previous(history)\n    iex> History.next(history)\n    {\"ls -la\", %History{...}}","ref":"Raxol.Terminal.Commands.History.html#next/1-examples"},{"type":"function","title":"Raxol.Terminal.Commands.History.previous/1","doc":"Retrieves the previous command in history.","ref":"Raxol.Terminal.Commands.History.html#previous/1"},{"type":"function","title":"Examples - Raxol.Terminal.Commands.History.previous/1","doc":"iex> history = History.new(1000)\n    iex> history = History.add(history, \"ls -la\")\n    iex> history = History.add(history, \"cd /tmp\")\n    iex> History.previous(history)\n    {\"cd /tmp\", %History{...}}","ref":"Raxol.Terminal.Commands.History.html#previous/1-examples"},{"type":"function","title":"Raxol.Terminal.Commands.History.save_input/2","doc":"Saves the current input state.","ref":"Raxol.Terminal.Commands.History.html#save_input/2"},{"type":"function","title":"Examples - Raxol.Terminal.Commands.History.save_input/2","doc":"iex> history = History.new(1000)\n    iex> history = History.save_input(history, \"ls -l\")\n    iex> history.current_input\n    \"ls -l\"","ref":"Raxol.Terminal.Commands.History.html#save_input/2-examples"},{"type":"type","title":"Raxol.Terminal.Commands.History.t/0","doc":"","ref":"Raxol.Terminal.Commands.History.html#t:t/0"},{"type":"module","title":"Raxol.Terminal.Commands.Modes","doc":"Handles terminal mode setting and resetting operations.\n\nThis module manages DEC private mode and ANSI mode setting/resetting in the terminal,\nwhich control various aspects of terminal behavior like cursor visibility, line wrapping,\nalternate screen buffer, and more.","ref":"Raxol.Terminal.Commands.Modes.html"},{"type":"function","title":"Raxol.Terminal.Commands.Modes.handle_ansi_mode/3","doc":"Handles ANSI mode setting or resetting.\n\nThese are the standard mode control sequences without the '?' prefix.","ref":"Raxol.Terminal.Commands.Modes.html#handle_ansi_mode/3"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.Modes.handle_ansi_mode/3","doc":"* `emulator` - The current emulator state\n* `params` - List of mode numbers to set or reset\n* `action` - Either `:set` to enable or `:reset` to disable","ref":"Raxol.Terminal.Commands.Modes.html#handle_ansi_mode/3-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.Modes.handle_ansi_mode/3","doc":"* Updated emulator state","ref":"Raxol.Terminal.Commands.Modes.html#handle_ansi_mode/3-returns"},{"type":"function","title":"Raxol.Terminal.Commands.Modes.handle_dec_private_mode/3","doc":"Handles DEC private mode setting or resetting.\n\nThese are the modes that are prefixed with '?' in the terminal sequences.","ref":"Raxol.Terminal.Commands.Modes.html#handle_dec_private_mode/3"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.Modes.handle_dec_private_mode/3","doc":"* `emulator` - The current emulator state\n* `params` - List of mode numbers to set or reset\n* `action` - Either `:set` to enable or `:reset` to disable","ref":"Raxol.Terminal.Commands.Modes.html#handle_dec_private_mode/3-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.Modes.handle_dec_private_mode/3","doc":"* Updated emulator state","ref":"Raxol.Terminal.Commands.Modes.html#handle_dec_private_mode/3-returns"},{"type":"module","title":"Raxol.Terminal.Commands.Parser","doc":"Handles parsing of command parameters in terminal sequences.\n\nThis module is part of the terminal command execution system. It provides\nutilities for parsing and extracting parameters from CSI, OSC, and DCS\nsequence parameter strings.","ref":"Raxol.Terminal.Commands.Parser.html"},{"type":"function","title":"Raxol.Terminal.Commands.Parser.get_param/3","doc":"Gets a parameter at a specific index from the params list.\n\nIf the parameter is not available, returns the provided default value.","ref":"Raxol.Terminal.Commands.Parser.html#get_param/3"},{"type":"function","title":"Examples - Raxol.Terminal.Commands.Parser.get_param/3","doc":"iex> Parser.get_param([5, 10, 15], 2)\n    10\n\n    iex> Parser.get_param([5, 10], 3)\n    1\n\n    iex> Parser.get_param([5, 10], 3, 0)\n    0","ref":"Raxol.Terminal.Commands.Parser.html#get_param/3-examples"},{"type":"function","title":"Raxol.Terminal.Commands.Parser.parse_int/1","doc":"Safely parses a string into an integer.\n\nReturns the parsed integer, or nil on failure.","ref":"Raxol.Terminal.Commands.Parser.html#parse_int/1"},{"type":"function","title":"Examples - Raxol.Terminal.Commands.Parser.parse_int/1","doc":"iex> Parser.parse_int(\"123\")\n    123\n\n    iex> Parser.parse_int(\"abc\")\n    nil","ref":"Raxol.Terminal.Commands.Parser.html#parse_int/1-examples"},{"type":"function","title":"Raxol.Terminal.Commands.Parser.parse_params/1","doc":"Parses a raw parameter string buffer into a list of integers or nil values.\n\nHandles empty or malformed parameters by converting them to nil.\nHandles parameters with sub-parameters (separated by ':')","ref":"Raxol.Terminal.Commands.Parser.html#parse_params/1"},{"type":"function","title":"Examples - Raxol.Terminal.Commands.Parser.parse_params/1","doc":"iex> Parser.parse_params(\"5;10;15\")\n    [5, 10, 15]\n\n    iex> Parser.parse_params(\"5;10;;15\")\n    [5, 10, nil, 15]\n\n    iex> Parser.parse_params(\"5:1;10:2;15:3\")\n    [[5, 1], [10, 2], [15, 3]]","ref":"Raxol.Terminal.Commands.Parser.html#parse_params/1-examples"},{"type":"module","title":"Raxol.Terminal.Commands.Screen","doc":"Handles screen manipulation commands in the terminal.\n\nThis module provides functions for clearing the screen or parts of it,\ninserting and deleting lines, and other screen manipulation operations.","ref":"Raxol.Terminal.Commands.Screen.html"},{"type":"function","title":"Raxol.Terminal.Commands.Screen.clear_line/2","doc":"Clears a line or part of a line based on the mode parameter.","ref":"Raxol.Terminal.Commands.Screen.html#clear_line/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.Screen.clear_line/2","doc":"* `emulator` - The current emulator state\n* `mode` - The clear mode:\n  * 0 - Clear from cursor to end of line\n  * 1 - Clear from beginning of line to cursor\n  * 2 - Clear entire line","ref":"Raxol.Terminal.Commands.Screen.html#clear_line/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.Screen.clear_line/2","doc":"* Updated emulator state","ref":"Raxol.Terminal.Commands.Screen.html#clear_line/2-returns"},{"type":"function","title":"Raxol.Terminal.Commands.Screen.clear_screen/2","doc":"Clears the screen or a part of it based on the mode parameter.","ref":"Raxol.Terminal.Commands.Screen.html#clear_screen/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.Screen.clear_screen/2","doc":"* `emulator` - The current emulator state\n* `mode` - The clear mode:\n  * 0 - Clear from cursor to end of screen\n  * 1 - Clear from beginning of screen to cursor\n  * 2 - Clear entire screen but don't move cursor\n  * 3 - Clear entire screen including scrollback","ref":"Raxol.Terminal.Commands.Screen.html#clear_screen/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.Screen.clear_screen/2","doc":"* Updated emulator state","ref":"Raxol.Terminal.Commands.Screen.html#clear_screen/2-returns"},{"type":"function","title":"Raxol.Terminal.Commands.Screen.delete_lines/2","doc":"Deletes lines at the current cursor position.","ref":"Raxol.Terminal.Commands.Screen.html#delete_lines/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.Screen.delete_lines/2","doc":"* `emulator` - The current emulator state\n* `count` - The number of lines to delete","ref":"Raxol.Terminal.Commands.Screen.html#delete_lines/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.Screen.delete_lines/2","doc":"* Updated emulator state","ref":"Raxol.Terminal.Commands.Screen.html#delete_lines/2-returns"},{"type":"function","title":"Raxol.Terminal.Commands.Screen.insert_lines/2","doc":"Inserts blank lines at the current cursor position.","ref":"Raxol.Terminal.Commands.Screen.html#insert_lines/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.Screen.insert_lines/2","doc":"* `emulator` - The current emulator state\n* `count` - The number of lines to insert","ref":"Raxol.Terminal.Commands.Screen.html#insert_lines/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.Screen.insert_lines/2","doc":"* Updated emulator state","ref":"Raxol.Terminal.Commands.Screen.html#insert_lines/2-returns"},{"type":"function","title":"Raxol.Terminal.Commands.Screen.scroll_down/2","doc":"Scrolls the screen down.","ref":"Raxol.Terminal.Commands.Screen.html#scroll_down/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.Screen.scroll_down/2","doc":"* `emulator` - The current emulator state\n* `count` - The number of lines to scroll","ref":"Raxol.Terminal.Commands.Screen.html#scroll_down/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.Screen.scroll_down/2","doc":"* Updated emulator state","ref":"Raxol.Terminal.Commands.Screen.html#scroll_down/2-returns"},{"type":"function","title":"Raxol.Terminal.Commands.Screen.scroll_up/2","doc":"Scrolls the screen up.","ref":"Raxol.Terminal.Commands.Screen.html#scroll_up/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Commands.Screen.scroll_up/2","doc":"* `emulator` - The current emulator state\n* `count` - The number of lines to scroll","ref":"Raxol.Terminal.Commands.Screen.html#scroll_up/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Commands.Screen.scroll_up/2","doc":"* Updated emulator state","ref":"Raxol.Terminal.Commands.Screen.html#scroll_up/2-returns"},{"type":"module","title":"Raxol.Terminal.Config","doc":"Terminal configuration system.\n\nThis module is the main entry point for terminal configuration, providing\na simplified interface to the underlying configuration modules.","ref":"Raxol.Terminal.Config.html"},{"type":"function","title":"Raxol.Terminal.Config.apply_config/2","doc":"Applies a configuration to the terminal.","ref":"Raxol.Terminal.Config.html#apply_config/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.apply_config/2","doc":"* `config` - The configuration to apply\n* `terminal_pid` - The PID of the terminal process (optional)","ref":"Raxol.Terminal.Config.html#apply_config/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.apply_config/2","doc":"`{:ok, applied_config}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.html#apply_config/2-returns"},{"type":"function","title":"Raxol.Terminal.Config.apply_partial_config/2","doc":"Applies a partial configuration update to the terminal.","ref":"Raxol.Terminal.Config.html#apply_partial_config/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.apply_partial_config/2","doc":"* `partial_config` - The partial configuration to apply\n* `terminal_pid` - The PID of the terminal process (optional)","ref":"Raxol.Terminal.Config.html#apply_partial_config/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.apply_partial_config/2","doc":"`{:ok, updated_config}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.html#apply_partial_config/2-returns"},{"type":"function","title":"Raxol.Terminal.Config.config_schema/0","doc":"Returns the configuration schema.","ref":"Raxol.Terminal.Config.html#config_schema/0"},{"type":"function","title":"Returns - Raxol.Terminal.Config.config_schema/0","doc":"A map defining the structure and types for all configuration options.","ref":"Raxol.Terminal.Config.html#config_schema/0-returns"},{"type":"function","title":"Raxol.Terminal.Config.detect_capabilities/0","doc":"Detects terminal capabilities based on the environment.","ref":"Raxol.Terminal.Config.html#detect_capabilities/0"},{"type":"function","title":"Returns - Raxol.Terminal.Config.detect_capabilities/0","doc":"A map of detected capabilities.","ref":"Raxol.Terminal.Config.html#detect_capabilities/0-returns"},{"type":"function","title":"Raxol.Terminal.Config.generate_default_config/0","doc":"Generates a default configuration based on terminal capabilities.","ref":"Raxol.Terminal.Config.html#generate_default_config/0"},{"type":"function","title":"Returns - Raxol.Terminal.Config.generate_default_config/0","doc":"A map containing default configuration values for all settings.","ref":"Raxol.Terminal.Config.html#generate_default_config/0-returns"},{"type":"function","title":"Raxol.Terminal.Config.get_current_config/1","doc":"Gets the current terminal configuration.","ref":"Raxol.Terminal.Config.html#get_current_config/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.get_current_config/1","doc":"* `terminal_pid` - The PID of the terminal process (optional)","ref":"Raxol.Terminal.Config.html#get_current_config/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.get_current_config/1","doc":"The current terminal configuration.","ref":"Raxol.Terminal.Config.html#get_current_config/1-returns"},{"type":"function","title":"Raxol.Terminal.Config.get_type/1","doc":"Returns the type information for a specific configuration path.","ref":"Raxol.Terminal.Config.html#get_type/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.get_type/1","doc":"* `path` - A list of keys representing the path to the configuration value","ref":"Raxol.Terminal.Config.html#get_type/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.get_type/1","doc":"A tuple with type information or nil if the path doesn't exist","ref":"Raxol.Terminal.Config.html#get_type/1-returns"},{"type":"function","title":"Raxol.Terminal.Config.list_profiles/0","doc":"Lists all available terminal configuration profiles.","ref":"Raxol.Terminal.Config.html#list_profiles/0"},{"type":"function","title":"Returns - Raxol.Terminal.Config.list_profiles/0","doc":"A list of profile names.","ref":"Raxol.Terminal.Config.html#list_profiles/0-returns"},{"type":"function","title":"Raxol.Terminal.Config.load_config/0","doc":"Loads terminal configuration from the default path.","ref":"Raxol.Terminal.Config.html#load_config/0"},{"type":"function","title":"Returns - Raxol.Terminal.Config.load_config/0","doc":"`{:ok, config}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.html#load_config/0-returns"},{"type":"function","title":"Raxol.Terminal.Config.load_config/1","doc":"Loads terminal configuration from the specified path.","ref":"Raxol.Terminal.Config.html#load_config/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.load_config/1","doc":"* `path` - The file path to load from","ref":"Raxol.Terminal.Config.html#load_config/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.load_config/1","doc":"`{:ok, config}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.html#load_config/1-returns"},{"type":"function","title":"Raxol.Terminal.Config.load_profile/1","doc":"Loads a specific terminal configuration profile.","ref":"Raxol.Terminal.Config.html#load_profile/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.load_profile/1","doc":"* `name` - The name of the profile to load","ref":"Raxol.Terminal.Config.html#load_profile/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.load_profile/1","doc":"`{:ok, config}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.html#load_profile/1-returns"},{"type":"function","title":"Raxol.Terminal.Config.merge_opts/2","doc":"Merges configuration options into an existing configuration map.\n\nDelegates to `Raxol.Terminal.Config.Utils.merge_opts/2`.","ref":"Raxol.Terminal.Config.html#merge_opts/2"},{"type":"function","title":"Raxol.Terminal.Config.optimized_config/0","doc":"Creates an optimized configuration based on detected capabilities.","ref":"Raxol.Terminal.Config.html#optimized_config/0"},{"type":"function","title":"Returns - Raxol.Terminal.Config.optimized_config/0","doc":"An optimized configuration for the current terminal.","ref":"Raxol.Terminal.Config.html#optimized_config/0-returns"},{"type":"function","title":"Raxol.Terminal.Config.reset_config/2","doc":"Resets terminal configuration to default values.","ref":"Raxol.Terminal.Config.html#reset_config/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.reset_config/2","doc":"* `terminal_pid` - The PID of the terminal process (optional)\n* `optimize` - Whether to optimize for detected capabilities (default: true)","ref":"Raxol.Terminal.Config.html#reset_config/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.reset_config/2","doc":"`{:ok, default_config}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.html#reset_config/2-returns"},{"type":"function","title":"Raxol.Terminal.Config.save_config/1","doc":"Saves terminal configuration to the default path.","ref":"Raxol.Terminal.Config.html#save_config/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.save_config/1","doc":"* `config` - The configuration to save","ref":"Raxol.Terminal.Config.html#save_config/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.save_config/1","doc":"`:ok` or `{:error, reason}`","ref":"Raxol.Terminal.Config.html#save_config/1-returns"},{"type":"function","title":"Raxol.Terminal.Config.save_config/2","doc":"Saves terminal configuration to the specified path.","ref":"Raxol.Terminal.Config.html#save_config/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.save_config/2","doc":"* `config` - The configuration to save\n* `path` - The file path to save to","ref":"Raxol.Terminal.Config.html#save_config/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.save_config/2","doc":"`:ok` or `{:error, reason}`","ref":"Raxol.Terminal.Config.html#save_config/2-returns"},{"type":"function","title":"Raxol.Terminal.Config.save_profile/2","doc":"Saves the current configuration as a profile.","ref":"Raxol.Terminal.Config.html#save_profile/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.save_profile/2","doc":"* `name` - The name of the profile to save\n* `config` - The configuration to save","ref":"Raxol.Terminal.Config.html#save_profile/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.save_profile/2","doc":"`:ok` or `{:error, reason}`","ref":"Raxol.Terminal.Config.html#save_profile/2-returns"},{"type":"function","title":"Raxol.Terminal.Config.validate_config/1","doc":"Validates a complete terminal configuration.","ref":"Raxol.Terminal.Config.html#validate_config/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.validate_config/1","doc":"* `config` - The configuration to validate","ref":"Raxol.Terminal.Config.html#validate_config/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.validate_config/1","doc":"`{:ok, validated_config}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.html#validate_config/1-returns"},{"type":"function","title":"Raxol.Terminal.Config.validate_value/2","doc":"Validates a specific configuration value against its schema.","ref":"Raxol.Terminal.Config.html#validate_value/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.validate_value/2","doc":"* `path` - A list of keys representing the path to the configuration value\n* `value` - The value to validate","ref":"Raxol.Terminal.Config.html#validate_value/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.validate_value/2","doc":"`{:ok, validated_value}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.html#validate_value/2-returns"},{"type":"module","title":"Raxol.Terminal.Config.AnimationCache","doc":"Manages caching for terminal animations.","ref":"Raxol.Terminal.Config.AnimationCache.html"},{"type":"function","title":"Raxol.Terminal.Config.AnimationCache.cache_animation/2","doc":"","ref":"Raxol.Terminal.Config.AnimationCache.html#cache_animation/2"},{"type":"function","title":"Raxol.Terminal.Config.AnimationCache.clear_animation_cache/0","doc":"","ref":"Raxol.Terminal.Config.AnimationCache.html#clear_animation_cache/0"},{"type":"function","title":"Raxol.Terminal.Config.AnimationCache.decompress_animation/1","doc":"","ref":"Raxol.Terminal.Config.AnimationCache.html#decompress_animation/1"},{"type":"function","title":"Raxol.Terminal.Config.AnimationCache.get_animation_cache_stats/0","doc":"","ref":"Raxol.Terminal.Config.AnimationCache.html#get_animation_cache_stats/0"},{"type":"function","title":"Raxol.Terminal.Config.AnimationCache.get_cache_size/0","doc":"","ref":"Raxol.Terminal.Config.AnimationCache.html#get_cache_size/0"},{"type":"function","title":"Raxol.Terminal.Config.AnimationCache.get_cached_animation/1","doc":"","ref":"Raxol.Terminal.Config.AnimationCache.html#get_cached_animation/1"},{"type":"function","title":"Raxol.Terminal.Config.AnimationCache.init_animation_cache/0","doc":"","ref":"Raxol.Terminal.Config.AnimationCache.html#init_animation_cache/0"},{"type":"function","title":"Raxol.Terminal.Config.AnimationCache.preload_animation/1","doc":"","ref":"Raxol.Terminal.Config.AnimationCache.html#preload_animation/1"},{"type":"function","title":"Raxol.Terminal.Config.AnimationCache.preload_animations/0","doc":"","ref":"Raxol.Terminal.Config.AnimationCache.html#preload_animations/0"},{"type":"module","title":"Raxol.Terminal.Config.Application","doc":"Terminal configuration application.\n\nThis module handles applying configuration settings to the terminal,\nensuring all changes are properly propagated throughout the system.","ref":"Raxol.Terminal.Config.Application.html"},{"type":"function","title":"Raxol.Terminal.Config.Application.apply_config/2","doc":"Applies a configuration to the terminal.\n\nThis function takes a configuration and applies it to the current terminal\ninstance, updating the terminal state and behavior.","ref":"Raxol.Terminal.Config.Application.html#apply_config/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Application.apply_config/2","doc":"* `config` - The configuration to apply\n* `terminal_pid` - The PID of the terminal process (optional)","ref":"Raxol.Terminal.Config.Application.html#apply_config/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Application.apply_config/2","doc":"`{:ok, applied_config}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.Application.html#apply_config/2-returns"},{"type":"function","title":"Raxol.Terminal.Config.Application.apply_partial_config/2","doc":"Applies a partial configuration update to the terminal.\n\nThis allows updating only specific parts of the configuration without\nchanging other settings.","ref":"Raxol.Terminal.Config.Application.html#apply_partial_config/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Application.apply_partial_config/2","doc":"* `partial_config` - The partial configuration to apply\n* `terminal_pid` - The PID of the terminal process (optional)","ref":"Raxol.Terminal.Config.Application.html#apply_partial_config/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Application.apply_partial_config/2","doc":"`{:ok, updated_config}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.Application.html#apply_partial_config/2-returns"},{"type":"function","title":"Raxol.Terminal.Config.Application.get_current_config/1","doc":"Gets the current terminal configuration.","ref":"Raxol.Terminal.Config.Application.html#get_current_config/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Application.get_current_config/1","doc":"* `terminal_pid` - The PID of the terminal process (optional)","ref":"Raxol.Terminal.Config.Application.html#get_current_config/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Application.get_current_config/1","doc":"The current terminal configuration.","ref":"Raxol.Terminal.Config.Application.html#get_current_config/1-returns"},{"type":"function","title":"Raxol.Terminal.Config.Application.reset_config/2","doc":"Resets terminal configuration to default values.","ref":"Raxol.Terminal.Config.Application.html#reset_config/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Application.reset_config/2","doc":"* `terminal_pid` - The PID of the terminal process (optional)\n* `optimize` - Whether to optimize for detected capabilities (default: true)","ref":"Raxol.Terminal.Config.Application.html#reset_config/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Application.reset_config/2","doc":"`{:ok, default_config}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.Application.html#reset_config/2-returns"},{"type":"module","title":"Raxol.Terminal.Config.Capabilities","doc":"Terminal capability detection and management.\n\nProvides functionality to detect and determine terminal capabilities\nsuch as color support, unicode support, etc.","ref":"Raxol.Terminal.Config.Capabilities.html"},{"type":"function","title":"Raxol.Terminal.Config.Capabilities.apply_capabilities/1","doc":"Merges detected capabilities with configuration.\n\nTakes a terminal configuration and enhances it with detected capabilities\nwhere those capabilities aren't already explicitly configured.","ref":"Raxol.Terminal.Config.Capabilities.html#apply_capabilities/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Capabilities.apply_capabilities/1","doc":"* `config` - The existing configuration","ref":"Raxol.Terminal.Config.Capabilities.html#apply_capabilities/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Capabilities.apply_capabilities/1","doc":"The configuration enhanced with detected capabilities.","ref":"Raxol.Terminal.Config.Capabilities.html#apply_capabilities/1-returns"},{"type":"function","title":"Raxol.Terminal.Config.Capabilities.detect_capabilities/0","doc":"Detects terminal capabilities based on the environment.\n\nThis examines environment variables, terminal responses, and other indicators\nto determine capabilities of the current terminal.","ref":"Raxol.Terminal.Config.Capabilities.html#detect_capabilities/0"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Capabilities.detect_capabilities/0","doc":"A map of detected capabilities.","ref":"Raxol.Terminal.Config.Capabilities.html#detect_capabilities/0-returns"},{"type":"function","title":"Raxol.Terminal.Config.Capabilities.optimized_config/0","doc":"Creates an optimized configuration based on detected capabilities.\n\nThis generates a configuration that's optimized for the current terminal\nenvironment, balancing features and performance.","ref":"Raxol.Terminal.Config.Capabilities.html#optimized_config/0"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Capabilities.optimized_config/0","doc":"An optimized configuration for the current terminal.","ref":"Raxol.Terminal.Config.Capabilities.html#optimized_config/0-returns"},{"type":"module","title":"Raxol.Terminal.Config.Defaults","doc":"Default terminal configuration values.\n\nProvides functions for generating default terminal configurations.","ref":"Raxol.Terminal.Config.Defaults.html"},{"type":"function","title":"Raxol.Terminal.Config.Defaults.default_animation_config/0","doc":"Generates a default animation configuration.","ref":"Raxol.Terminal.Config.Defaults.html#default_animation_config/0"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Defaults.default_animation_config/0","doc":"A map containing default animation configuration values.","ref":"Raxol.Terminal.Config.Defaults.html#default_animation_config/0-returns"},{"type":"function","title":"Raxol.Terminal.Config.Defaults.default_background_config/0","doc":"Generates a default background configuration.","ref":"Raxol.Terminal.Config.Defaults.html#default_background_config/0"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Defaults.default_background_config/0","doc":"A map containing default background configuration values.","ref":"Raxol.Terminal.Config.Defaults.html#default_background_config/0-returns"},{"type":"function","title":"Raxol.Terminal.Config.Defaults.default_behavior_config/0","doc":"Generates a default behavior configuration.","ref":"Raxol.Terminal.Config.Defaults.html#default_behavior_config/0"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Defaults.default_behavior_config/0","doc":"A map containing default behavior configuration values.","ref":"Raxol.Terminal.Config.Defaults.html#default_behavior_config/0-returns"},{"type":"function","title":"Raxol.Terminal.Config.Defaults.default_display_config/0","doc":"Generates a default display configuration.","ref":"Raxol.Terminal.Config.Defaults.html#default_display_config/0"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Defaults.default_display_config/0","doc":"A map containing default display configuration values.","ref":"Raxol.Terminal.Config.Defaults.html#default_display_config/0-returns"},{"type":"function","title":"Raxol.Terminal.Config.Defaults.default_rendering_config/0","doc":"Generates a default rendering configuration.","ref":"Raxol.Terminal.Config.Defaults.html#default_rendering_config/0"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Defaults.default_rendering_config/0","doc":"A map containing default rendering configuration values.","ref":"Raxol.Terminal.Config.Defaults.html#default_rendering_config/0-returns"},{"type":"function","title":"Raxol.Terminal.Config.Defaults.default_system_config/0","doc":"Generates a default system/performance configuration.","ref":"Raxol.Terminal.Config.Defaults.html#default_system_config/0"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Defaults.default_system_config/0","doc":"A map containing default system/performance configuration values.","ref":"Raxol.Terminal.Config.Defaults.html#default_system_config/0-returns"},{"type":"function","title":"Raxol.Terminal.Config.Defaults.generate_default_config/0","doc":"Generates a default configuration map merging all specific defaults.\n\nThis map represents the base configuration before any detection or user overrides.","ref":"Raxol.Terminal.Config.Defaults.html#generate_default_config/0"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Defaults.generate_default_config/0","doc":"A map containing default configuration values for all settings.","ref":"Raxol.Terminal.Config.Defaults.html#generate_default_config/0-returns"},{"type":"module","title":"Raxol.Terminal.Config.Persistence","doc":"Handles loading and saving terminal configuration.\n\nProvides functions for persisting configuration to disk and loading it back.","ref":"Raxol.Terminal.Config.Persistence.html"},{"type":"function","title":"Raxol.Terminal.Config.Persistence.load_config/0","doc":"Loads terminal configuration from the default path.\n\nIf the configuration file doesn't exist, returns the default configuration.","ref":"Raxol.Terminal.Config.Persistence.html#load_config/0"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Persistence.load_config/0","doc":"`{:ok, config}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.Persistence.html#load_config/0-returns"},{"type":"function","title":"Raxol.Terminal.Config.Persistence.load_config/1","doc":"Loads terminal configuration from the specified path.\n\nIf the configuration file doesn't exist, returns the default configuration.","ref":"Raxol.Terminal.Config.Persistence.html#load_config/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Persistence.load_config/1","doc":"* `path` - The file path to load from","ref":"Raxol.Terminal.Config.Persistence.html#load_config/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Persistence.load_config/1","doc":"`{:ok, config}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.Persistence.html#load_config/1-returns"},{"type":"function","title":"Raxol.Terminal.Config.Persistence.parse_config/1","doc":"Parses configuration from JSON string.","ref":"Raxol.Terminal.Config.Persistence.html#parse_config/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Persistence.parse_config/1","doc":"* `json` - The JSON string to parse","ref":"Raxol.Terminal.Config.Persistence.html#parse_config/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Persistence.parse_config/1","doc":"`{:ok, config}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.Persistence.html#parse_config/1-returns"},{"type":"function","title":"Raxol.Terminal.Config.Persistence.save_config/1","doc":"Saves terminal configuration to the default path.","ref":"Raxol.Terminal.Config.Persistence.html#save_config/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Persistence.save_config/1","doc":"* `config` - The configuration to save","ref":"Raxol.Terminal.Config.Persistence.html#save_config/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Persistence.save_config/1","doc":"`:ok` or `{:error, reason}`","ref":"Raxol.Terminal.Config.Persistence.html#save_config/1-returns"},{"type":"function","title":"Raxol.Terminal.Config.Persistence.save_config/2","doc":"Saves terminal configuration to the specified path.","ref":"Raxol.Terminal.Config.Persistence.html#save_config/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Persistence.save_config/2","doc":"* `config` - The configuration to save\n* `path` - The file path to save to","ref":"Raxol.Terminal.Config.Persistence.html#save_config/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Persistence.save_config/2","doc":"`:ok` or `{:error, reason}`","ref":"Raxol.Terminal.Config.Persistence.html#save_config/2-returns"},{"type":"module","title":"Raxol.Terminal.Config.Profiles","doc":"Terminal configuration profile management.\n\nAllows users to define, save, load, and switch between different\nterminal configuration profiles.","ref":"Raxol.Terminal.Config.Profiles.html"},{"type":"type","title":"Raxol.Terminal.Config.Profiles.animation_type/0","doc":"","ref":"Raxol.Terminal.Config.Profiles.html#t:animation_type/0"},{"type":"type","title":"Raxol.Terminal.Config.Profiles.background_type/0","doc":"","ref":"Raxol.Terminal.Config.Profiles.html#t:background_type/0"},{"type":"type","title":"Raxol.Terminal.Config.Profiles.color_mode/0","doc":"","ref":"Raxol.Terminal.Config.Profiles.html#t:color_mode/0"},{"type":"type","title":"Raxol.Terminal.Config.Profiles.config/0","doc":"","ref":"Raxol.Terminal.Config.Profiles.html#t:config/0"},{"type":"function","title":"Raxol.Terminal.Config.Profiles.create_default_profile/1","doc":"Creates a new profile with default settings.","ref":"Raxol.Terminal.Config.Profiles.html#create_default_profile/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Profiles.create_default_profile/1","doc":"* `name` - The name of the new profile","ref":"Raxol.Terminal.Config.Profiles.html#create_default_profile/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Profiles.create_default_profile/1","doc":"`{:ok, config}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.Profiles.html#create_default_profile/1-returns"},{"type":"function","title":"Raxol.Terminal.Config.Profiles.delete_profile/1","doc":"Deletes a terminal configuration profile.","ref":"Raxol.Terminal.Config.Profiles.html#delete_profile/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Profiles.delete_profile/1","doc":"* `name` - The name of the profile to delete","ref":"Raxol.Terminal.Config.Profiles.html#delete_profile/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Profiles.delete_profile/1","doc":"`:ok` or `{:error, reason}`","ref":"Raxol.Terminal.Config.Profiles.html#delete_profile/1-returns"},{"type":"function","title":"Raxol.Terminal.Config.Profiles.duplicate_profile/2","doc":"Duplicates an existing profile with a new name.","ref":"Raxol.Terminal.Config.Profiles.html#duplicate_profile/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Profiles.duplicate_profile/2","doc":"* `source_name` - The name of the profile to duplicate\n* `target_name` - The name for the new profile","ref":"Raxol.Terminal.Config.Profiles.html#duplicate_profile/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Profiles.duplicate_profile/2","doc":"`{:ok, config}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.Profiles.html#duplicate_profile/2-returns"},{"type":"function","title":"Raxol.Terminal.Config.Profiles.list_profiles/0","doc":"Lists all available terminal configuration profiles.","ref":"Raxol.Terminal.Config.Profiles.html#list_profiles/0"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Profiles.list_profiles/0","doc":"A list of profile names.","ref":"Raxol.Terminal.Config.Profiles.html#list_profiles/0-returns"},{"type":"function","title":"Raxol.Terminal.Config.Profiles.load_profile/1","doc":"Loads a specific terminal configuration profile.","ref":"Raxol.Terminal.Config.Profiles.html#load_profile/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Profiles.load_profile/1","doc":"* `name` - The name of the profile to load","ref":"Raxol.Terminal.Config.Profiles.html#load_profile/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Profiles.load_profile/1","doc":"`{:ok, config}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.Profiles.html#load_profile/1-returns"},{"type":"function","title":"Raxol.Terminal.Config.Profiles.save_profile/2","doc":"Saves the current configuration as a profile.","ref":"Raxol.Terminal.Config.Profiles.html#save_profile/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Profiles.save_profile/2","doc":"* `name` - The name of the profile to save\n* `config` - The configuration to save","ref":"Raxol.Terminal.Config.Profiles.html#save_profile/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Profiles.save_profile/2","doc":"`:ok` or `{:error, reason}`","ref":"Raxol.Terminal.Config.Profiles.html#save_profile/2-returns"},{"type":"type","title":"Raxol.Terminal.Config.Profiles.terminal_type/0","doc":"","ref":"Raxol.Terminal.Config.Profiles.html#t:terminal_type/0"},{"type":"type","title":"Raxol.Terminal.Config.Profiles.theme_map/0","doc":"","ref":"Raxol.Terminal.Config.Profiles.html#t:theme_map/0"},{"type":"function","title":"Raxol.Terminal.Config.Profiles.update_profile/2","doc":"Updates an existing profile with new settings.","ref":"Raxol.Terminal.Config.Profiles.html#update_profile/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Profiles.update_profile/2","doc":"* `name` - The name of the profile to update\n* `config` - The new configuration","ref":"Raxol.Terminal.Config.Profiles.html#update_profile/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Profiles.update_profile/2","doc":"`:ok` or `{:error, reason}`","ref":"Raxol.Terminal.Config.Profiles.html#update_profile/2-returns"},{"type":"module","title":"Raxol.Terminal.Config.Schema","doc":"Schema definitions for terminal configuration.\n\nDefines the structure and types for all terminal configuration options.","ref":"Raxol.Terminal.Config.Schema.html"},{"type":"function","title":"Raxol.Terminal.Config.Schema.config_schema/0","doc":"Defines the schema for terminal configuration.\n\nThis includes all possible configuration fields with their types,\ndefault values, and descriptions.","ref":"Raxol.Terminal.Config.Schema.html#config_schema/0"},{"type":"function","title":"Raxol.Terminal.Config.Schema.default_config/0","doc":"Returns the default configuration values.\nThis delegates to the Defaults module for actual values.","ref":"Raxol.Terminal.Config.Schema.html#default_config/0"},{"type":"function","title":"Raxol.Terminal.Config.Schema.get_type/1","doc":"Returns the type information for a specific configuration path.","ref":"Raxol.Terminal.Config.Schema.html#get_type/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Schema.get_type/1","doc":"* `path` - A list of keys representing the path to the configuration value","ref":"Raxol.Terminal.Config.Schema.html#get_type/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Schema.get_type/1","doc":"A tuple with type information or nil if the path doesn't exist","ref":"Raxol.Terminal.Config.Schema.html#get_type/1-returns"},{"type":"module","title":"Raxol.Terminal.Config.Utils","doc":"Utility functions for handling terminal configuration maps.","ref":"Raxol.Terminal.Config.Utils.html"},{"type":"function","title":"Raxol.Terminal.Config.Utils.deep_merge/2","doc":"Deeply merges two maps.\n\nKeys in the right map take precedence. If both values for a key are maps,\nthey are merged recursively.","ref":"Raxol.Terminal.Config.Utils.html#deep_merge/2"},{"type":"function","title":"Raxol.Terminal.Config.Utils.merge_opts/2","doc":"Merges configuration options into an existing configuration map.\n\nThe `opts` are first converted into a nested map structure and then\ndeeply merged into the `current_config`.","ref":"Raxol.Terminal.Config.Utils.html#merge_opts/2"},{"type":"function","title":"Raxol.Terminal.Config.Utils.opts_to_nested_map/1","doc":"Converts a keyword list or map of potentially nested options into a nested map.\n\nHandles flat keys like `theme: \"light\"` and nested paths represented\nby lists like `[behavior: [scrollback: 100]]` within the keyword list.","ref":"Raxol.Terminal.Config.Utils.html#opts_to_nested_map/1"},{"type":"module","title":"Raxol.Terminal.Config.Validation","doc":"Validation logic for terminal configuration.\n\nEnsures that configuration values are valid according to their schema.","ref":"Raxol.Terminal.Config.Validation.html"},{"type":"function","title":"Raxol.Terminal.Config.Validation.validate_config/1","doc":"Validates a complete terminal configuration.","ref":"Raxol.Terminal.Config.Validation.html#validate_config/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Validation.validate_config/1","doc":"* `config` - The configuration to validate","ref":"Raxol.Terminal.Config.Validation.html#validate_config/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Validation.validate_config/1","doc":"`{:ok, validated_config}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.Validation.html#validate_config/1-returns"},{"type":"function","title":"Raxol.Terminal.Config.Validation.validate_value/2","doc":"Validates a specific configuration value against its schema.","ref":"Raxol.Terminal.Config.Validation.html#validate_value/2"},{"type":"function","title":"Parameters - Raxol.Terminal.Config.Validation.validate_value/2","doc":"* `path` - A list of keys representing the path to the configuration value\n* `value` - The value to validate","ref":"Raxol.Terminal.Config.Validation.html#validate_value/2-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Config.Validation.validate_value/2","doc":"`{:ok, validated_value}` or `{:error, reason}`","ref":"Raxol.Terminal.Config.Validation.html#validate_value/2-returns"},{"type":"module","title":"Raxol.Terminal.Configuration","doc":"Manages the core Raxol terminal configuration struct.\n\nThis module defines the main configuration structure and provides functions\nfor creating and updating configuration based on defaults and user-provided options.\n\nIt collaborates with other modules under `Raxol.Terminal.Config.*` for specific\nfunctionalities like defaults, profiles, capabilities detection, and applying\nsettings to the running terminal.","ref":"Raxol.Terminal.Configuration.html"},{"type":"type","title":"Raxol.Terminal.Configuration.animation_type/0","doc":"","ref":"Raxol.Terminal.Configuration.html#t:animation_type/0"},{"type":"type","title":"Raxol.Terminal.Configuration.background_type/0","doc":"","ref":"Raxol.Terminal.Configuration.html#t:background_type/0"},{"type":"type","title":"Raxol.Terminal.Configuration.color_mode/0","doc":"","ref":"Raxol.Terminal.Configuration.html#t:color_mode/0"},{"type":"function","title":"Raxol.Terminal.Configuration.new/1","doc":"Creates a new configuration struct, merging defaults with provided options.\n\nFetches the base default configuration map and then merges any overrides\nprovided in `opts`. The final result is converted into the `%__MODULE__{}` struct.","ref":"Raxol.Terminal.Configuration.html#new/1"},{"type":"type","title":"Raxol.Terminal.Configuration.t/0","doc":"","ref":"Raxol.Terminal.Configuration.html#t:t/0"},{"type":"type","title":"Raxol.Terminal.Configuration.terminal_type/0","doc":"","ref":"Raxol.Terminal.Configuration.html#t:terminal_type/0"},{"type":"function","title":"Raxol.Terminal.Configuration.update/2","doc":"Updates an existing configuration struct with new values from a keyword list.","ref":"Raxol.Terminal.Configuration.html#update/2"},{"type":"module","title":"Raxol.Terminal.Constants","doc":"Re-exports constants from ExTermbox NIF v2.0.1 for use within Raxol.\n\nThis module provides a convenience wrapper around the constant values\ndefined in the ExTermbox module.","ref":"Raxol.Terminal.Constants.html"},{"type":"function","title":"Raxol.Terminal.Constants.attribute/1","doc":"Returns the numeric value for the given attribute name","ref":"Raxol.Terminal.Constants.html#attribute/1"},{"type":"function","title":"Raxol.Terminal.Constants.color/1","doc":"Returns the numeric value for the given color name","ref":"Raxol.Terminal.Constants.html#color/1"},{"type":"function","title":"Raxol.Terminal.Constants.event_type/1","doc":"Returns the numeric value for the given event type","ref":"Raxol.Terminal.Constants.html#event_type/1"},{"type":"function","title":"Raxol.Terminal.Constants.key/1","doc":"Returns the numeric value for the given key name","ref":"Raxol.Terminal.Constants.html#key/1"},{"type":"module","title":"Raxol.Terminal.ControlCodes","doc":"Handles C0 control codes and simple ESC sequences.\n\nExtracted from Terminal.Emulator for better organization.\nRelies on Emulator state and ScreenBuffer for actions.","ref":"Raxol.Terminal.ControlCodes.html"},{"type":"function","title":"Raxol.Terminal.ControlCodes.handle_bel/1","doc":"","ref":"Raxol.Terminal.ControlCodes.html#handle_bel/1"},{"type":"function","title":"Raxol.Terminal.ControlCodes.handle_bs/1","doc":"Handle Backspace (BS)","ref":"Raxol.Terminal.ControlCodes.html#handle_bs/1"},{"type":"function","title":"Raxol.Terminal.ControlCodes.handle_can/1","doc":"","ref":"Raxol.Terminal.ControlCodes.html#handle_can/1"},{"type":"function","title":"Raxol.Terminal.ControlCodes.handle_cr/1","doc":"Handle Carriage Return (CR)","ref":"Raxol.Terminal.ControlCodes.html#handle_cr/1"},{"type":"function","title":"Raxol.Terminal.ControlCodes.handle_decrc/1","doc":"","ref":"Raxol.Terminal.ControlCodes.html#handle_decrc/1"},{"type":"function","title":"Raxol.Terminal.ControlCodes.handle_decsc/1","doc":"","ref":"Raxol.Terminal.ControlCodes.html#handle_decsc/1"},{"type":"function","title":"Raxol.Terminal.ControlCodes.handle_ht/1","doc":"Handle Horizontal Tab (HT)","ref":"Raxol.Terminal.ControlCodes.html#handle_ht/1"},{"type":"function","title":"Raxol.Terminal.ControlCodes.handle_hts/1","doc":"","ref":"Raxol.Terminal.ControlCodes.html#handle_hts/1"},{"type":"function","title":"Raxol.Terminal.ControlCodes.handle_ind/1","doc":"","ref":"Raxol.Terminal.ControlCodes.html#handle_ind/1"},{"type":"function","title":"Raxol.Terminal.ControlCodes.handle_lf/1","doc":"Handle Line Feed (LF), New Line (NL), Vertical Tab (VT)","ref":"Raxol.Terminal.ControlCodes.html#handle_lf/1"},{"type":"function","title":"Raxol.Terminal.ControlCodes.handle_nel/1","doc":"","ref":"Raxol.Terminal.ControlCodes.html#handle_nel/1"},{"type":"function","title":"Raxol.Terminal.ControlCodes.handle_ri/1","doc":"Handle Reverse Index (RI) - ESC M","ref":"Raxol.Terminal.ControlCodes.html#handle_ri/1"},{"type":"function","title":"Raxol.Terminal.ControlCodes.handle_ris/1","doc":"","ref":"Raxol.Terminal.ControlCodes.html#handle_ris/1"},{"type":"function","title":"Raxol.Terminal.ControlCodes.handle_si/1","doc":"","ref":"Raxol.Terminal.ControlCodes.html#handle_si/1"},{"type":"function","title":"Raxol.Terminal.ControlCodes.handle_so/1","doc":"","ref":"Raxol.Terminal.ControlCodes.html#handle_so/1"},{"type":"function","title":"Raxol.Terminal.ControlCodes.handle_sub/1","doc":"","ref":"Raxol.Terminal.ControlCodes.html#handle_sub/1"},{"type":"module","title":"Raxol.Terminal.Cursor.Manager","doc":"Terminal cursor manager module.\n\nThis module handles the management of terminal cursors, including:\n- Multiple cursor styles\n- State persistence\n- Animation system\n- Position tracking","ref":"Raxol.Terminal.Cursor.Manager.html"},{"type":"function","title":"Raxol.Terminal.Cursor.Manager.add_to_history/1","doc":"Adds the current cursor state to history.","ref":"Raxol.Terminal.Cursor.Manager.html#add_to_history/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Manager.add_to_history/1","doc":"iex> alias Raxol.Terminal.Cursor.Manager\n    iex> cursor = Raxol.Terminal.Cursor.Manager.new()\n    iex> cursor = Raxol.Terminal.Cursor.Manager.add_to_history(cursor)\n    iex> length(cursor.history)\n    1","ref":"Raxol.Terminal.Cursor.Manager.html#add_to_history/1-examples"},{"type":"type","title":"Raxol.Terminal.Cursor.Manager.cursor_shape/0","doc":"","ref":"Raxol.Terminal.Cursor.Manager.html#t:cursor_shape/0"},{"type":"type","title":"Raxol.Terminal.Cursor.Manager.cursor_state/0","doc":"","ref":"Raxol.Terminal.Cursor.Manager.html#t:cursor_state/0"},{"type":"type","title":"Raxol.Terminal.Cursor.Manager.cursor_style/0","doc":"","ref":"Raxol.Terminal.Cursor.Manager.html#t:cursor_style/0"},{"type":"function","title":"Raxol.Terminal.Cursor.Manager.move_down/2","doc":"Moves the cursor down by the specified number of rows.","ref":"Raxol.Terminal.Cursor.Manager.html#move_down/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Manager.move_down/2","doc":"iex> alias Raxol.Terminal.Cursor.Manager\n    iex> cursor = Raxol.Terminal.Cursor.Manager.new()\n    iex> cursor = Raxol.Terminal.Cursor.Manager.move_down(cursor, 3)\n    iex> cursor.position\n    {0, 3}","ref":"Raxol.Terminal.Cursor.Manager.html#move_down/2-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Manager.move_left/2","doc":"Moves the cursor left by the specified number of columns.","ref":"Raxol.Terminal.Cursor.Manager.html#move_left/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Manager.move_left/2","doc":"iex> alias Raxol.Terminal.Cursor.Manager\n    iex> cursor = Raxol.Terminal.Cursor.Manager.new()\n    iex> cursor = Raxol.Terminal.Cursor.Manager.move_to(cursor, 5, 0)\n    iex> cursor = Raxol.Terminal.Cursor.Manager.move_left(cursor, 3)\n    iex> cursor.position\n    {2, 0}","ref":"Raxol.Terminal.Cursor.Manager.html#move_left/2-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Manager.move_right/2","doc":"Moves the cursor right by the specified number of columns.","ref":"Raxol.Terminal.Cursor.Manager.html#move_right/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Manager.move_right/2","doc":"iex> alias Raxol.Terminal.Cursor.Manager\n    iex> cursor = Raxol.Terminal.Cursor.Manager.new()\n    iex> cursor = Raxol.Terminal.Cursor.Manager.move_right(cursor, 3)\n    iex> cursor.position\n    {3, 0}","ref":"Raxol.Terminal.Cursor.Manager.html#move_right/2-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Manager.move_to/3","doc":"Moves the cursor to a new position.","ref":"Raxol.Terminal.Cursor.Manager.html#move_to/3"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Manager.move_to/3","doc":"iex> alias Raxol.Terminal.Cursor.Manager\n    iex> cursor = Raxol.Terminal.Cursor.Manager.new()\n    iex> cursor = Raxol.Terminal.Cursor.Manager.move_to(cursor, 10, 5)\n    iex> cursor.position\n    {10, 5}","ref":"Raxol.Terminal.Cursor.Manager.html#move_to/3-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Manager.move_to_col/2","doc":"Moves the cursor to a specific column while maintaining the current row.","ref":"Raxol.Terminal.Cursor.Manager.html#move_to_col/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Manager.move_to_col/2","doc":"iex> alias Raxol.Terminal.Cursor.Manager\n    iex> cursor = Raxol.Terminal.Cursor.Manager.new()\n    iex> cursor = Raxol.Terminal.Cursor.Manager.move_to(cursor, 0, 5)\n    iex> cursor = Raxol.Terminal.Cursor.Manager.move_to_col(cursor, 10)\n    iex> cursor.position\n    {10, 5}","ref":"Raxol.Terminal.Cursor.Manager.html#move_to_col/2-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Manager.move_up/2","doc":"Moves the cursor up by the specified number of rows.","ref":"Raxol.Terminal.Cursor.Manager.html#move_up/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Manager.move_up/2","doc":"iex> alias Raxol.Terminal.Cursor.Manager\n    iex> cursor = Raxol.Terminal.Cursor.Manager.new()\n    iex> cursor = Raxol.Terminal.Cursor.Manager.move_to(cursor, 5, 5)\n    iex> cursor = Raxol.Terminal.Cursor.Manager.move_up(cursor, 3)\n    iex> cursor.position\n    {5, 2}","ref":"Raxol.Terminal.Cursor.Manager.html#move_up/2-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Manager.new/0","doc":"Creates a new cursor manager.","ref":"Raxol.Terminal.Cursor.Manager.html#new/0"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Manager.new/0","doc":"iex> alias Raxol.Terminal.Cursor.Manager\n    iex> cursor = Raxol.Terminal.Cursor.Manager.new()\n    iex> cursor.position\n    {0, 0}\n    iex> cursor.style\n    :block","ref":"Raxol.Terminal.Cursor.Manager.html#new/0-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Manager.restore_from_history/1","doc":"Restores the cursor state from history.","ref":"Raxol.Terminal.Cursor.Manager.html#restore_from_history/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Manager.restore_from_history/1","doc":"iex> alias Raxol.Terminal.Cursor.Manager\n    iex> cursor = Raxol.Terminal.Cursor.Manager.new()\n    iex> cursor = Raxol.Terminal.Cursor.Manager.add_to_history(cursor)\n    iex> cursor = Raxol.Terminal.Cursor.Manager.move_to(cursor, 10, 5)\n    iex> cursor = Raxol.Terminal.Cursor.Manager.restore_from_history(cursor)\n    iex> cursor.position\n    {0, 0}","ref":"Raxol.Terminal.Cursor.Manager.html#restore_from_history/1-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Manager.restore_position/1","doc":"Restores the saved cursor position.","ref":"Raxol.Terminal.Cursor.Manager.html#restore_position/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Manager.restore_position/1","doc":"iex> alias Raxol.Terminal.Cursor.Manager\n    iex> cursor = Raxol.Terminal.Cursor.Manager.new()\n    iex> cursor = Raxol.Terminal.Cursor.Manager.move_to(cursor, 10, 5)\n    iex> cursor = Raxol.Terminal.Cursor.Manager.save_position(cursor)\n    iex> cursor = Raxol.Terminal.Cursor.Manager.move_to(cursor, 0, 0)\n    iex> cursor = Raxol.Terminal.Cursor.Manager.restore_position(cursor)\n    iex> cursor.position\n    {10, 5}","ref":"Raxol.Terminal.Cursor.Manager.html#restore_position/1-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Manager.save_position/1","doc":"Saves the current cursor position.","ref":"Raxol.Terminal.Cursor.Manager.html#save_position/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Manager.save_position/1","doc":"iex> alias Raxol.Terminal.Cursor.Manager\n    iex> cursor = Raxol.Terminal.Cursor.Manager.new()\n    iex> cursor = Raxol.Terminal.Cursor.Manager.move_to(cursor, 10, 5)\n    iex> cursor = Raxol.Terminal.Cursor.Manager.save_position(cursor)\n    iex> cursor.saved_position\n    {10, 5}","ref":"Raxol.Terminal.Cursor.Manager.html#save_position/1-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Manager.set_custom_shape/3","doc":"Sets a custom cursor shape.","ref":"Raxol.Terminal.Cursor.Manager.html#set_custom_shape/3"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Manager.set_custom_shape/3","doc":"iex> alias Raxol.Terminal.Cursor.Manager\n    iex> cursor = Raxol.Terminal.Cursor.Manager.new()\n    iex> cursor = Raxol.Terminal.Cursor.Manager.set_custom_shape(cursor, \"█\", {2, 1})\n    iex> cursor.style\n    :custom\n    iex> cursor.custom_shape\n    \"█\"","ref":"Raxol.Terminal.Cursor.Manager.html#set_custom_shape/3-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Manager.set_state/2","doc":"Sets the cursor state.","ref":"Raxol.Terminal.Cursor.Manager.html#set_state/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Manager.set_state/2","doc":"iex> alias Raxol.Terminal.Cursor.Manager\n    iex> cursor = Raxol.Terminal.Cursor.Manager.new()\n    iex> cursor = Raxol.Terminal.Cursor.Manager.set_state(cursor, :hidden)\n    iex> cursor.state\n    :hidden","ref":"Raxol.Terminal.Cursor.Manager.html#set_state/2-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Manager.set_style/2","doc":"Sets the cursor style.","ref":"Raxol.Terminal.Cursor.Manager.html#set_style/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Manager.set_style/2","doc":"iex> alias Raxol.Terminal.Cursor.Manager\n    iex> cursor = Raxol.Terminal.Cursor.Manager.new()\n    iex> cursor = Raxol.Terminal.Cursor.Manager.set_style(cursor, :underline)\n    iex> cursor.style\n    :underline","ref":"Raxol.Terminal.Cursor.Manager.html#set_style/2-examples"},{"type":"type","title":"Raxol.Terminal.Cursor.Manager.t/0","doc":"","ref":"Raxol.Terminal.Cursor.Manager.html#t:t/0"},{"type":"function","title":"Raxol.Terminal.Cursor.Manager.update_blink/1","doc":"Updates the cursor blink state.","ref":"Raxol.Terminal.Cursor.Manager.html#update_blink/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Manager.update_blink/1","doc":"iex> alias Raxol.Terminal.Cursor.Manager\n    iex> cursor = Raxol.Terminal.Cursor.Manager.new()\n    iex> cursor = Raxol.Terminal.Cursor.Manager.set_state(cursor, :blinking)\n    iex> {cursor, visible} = Raxol.Terminal.Cursor.Manager.update_blink(cursor)\n    iex> is_boolean(visible)\n    true","ref":"Raxol.Terminal.Cursor.Manager.html#update_blink/1-examples"},{"type":"module","title":"Raxol.Terminal.Cursor.Movement","doc":"Handles cursor movement and positioning for the terminal emulator.\n\nThis module provides functions for moving the cursor in various directions,\nhandling relative and absolute positioning, and managing cursor boundaries.","ref":"Raxol.Terminal.Cursor.Movement.html"},{"type":"function","title":"Raxol.Terminal.Cursor.Movement.move_down/2","doc":"Moves the cursor down by the specified number of lines.","ref":"Raxol.Terminal.Cursor.Movement.html#move_down/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Movement.move_down/2","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Movement.move_down(cursor, 2)\n    iex> cursor.position\n    {0, 2}","ref":"Raxol.Terminal.Cursor.Movement.html#move_down/2-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Movement.move_home/1","doc":"Moves the cursor to the home position (0, 0).","ref":"Raxol.Terminal.Cursor.Movement.html#move_home/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Movement.move_home/1","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Manager.move_to(cursor, 10, 5)\n    iex> cursor = Movement.move_home(cursor)\n    iex> cursor.position\n    {0, 0}","ref":"Raxol.Terminal.Cursor.Movement.html#move_home/1-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Movement.move_left/2","doc":"Moves the cursor left by the specified number of columns.","ref":"Raxol.Terminal.Cursor.Movement.html#move_left/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Movement.move_left/2","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Manager.move_to(cursor, 5, 0)\n    iex> cursor = Movement.move_left(cursor, 2)\n    iex> cursor.position\n    {3, 0}","ref":"Raxol.Terminal.Cursor.Movement.html#move_left/2-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Movement.move_right/2","doc":"Moves the cursor right by the specified number of columns.","ref":"Raxol.Terminal.Cursor.Movement.html#move_right/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Movement.move_right/2","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Movement.move_right(cursor, 2)\n    iex> cursor.position\n    {2, 0}","ref":"Raxol.Terminal.Cursor.Movement.html#move_right/2-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Movement.move_to_column/2","doc":"Moves the cursor to the specified column.","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_column/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Movement.move_to_column/2","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Movement.move_to_column(cursor, 10)\n    iex> cursor.position\n    {10, 0}","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_column/2-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Movement.move_to_line/2","doc":"Moves the cursor to the specified line.","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_line/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Movement.move_to_line/2","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Movement.move_to_line(cursor, 5)\n    iex> cursor.position\n    {0, 5}","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_line/2-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Movement.move_to_line_end/2","doc":"Moves the cursor to the end of the line.","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_line_end/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Movement.move_to_line_end/2","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Movement.move_to_line_end(cursor, 80)\n    iex> cursor.position\n    {79, 0}","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_line_end/2-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Movement.move_to_line_start/1","doc":"Moves the cursor to the beginning of the line.","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_line_start/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Movement.move_to_line_start/1","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Manager.move_to(cursor, 10, 0)\n    iex> cursor = Movement.move_to_line_start(cursor)\n    iex> cursor.position\n    {0, 0}","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_line_start/1-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Movement.move_to_next_tab/2","doc":"Moves the cursor to the next tab stop.","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_next_tab/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Movement.move_to_next_tab/2","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Movement.move_to_next_tab(cursor, 8)\n    iex> cursor.position\n    {8, 0}","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_next_tab/2-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Movement.move_to_position/3","doc":"Moves the cursor to the specified position.","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_position/3"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Movement.move_to_position/3","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Movement.move_to_position(cursor, 10, 5)\n    iex> cursor.position\n    {10, 5}","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_position/3-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Movement.move_to_prev_tab/2","doc":"Moves the cursor to the previous tab stop.","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_prev_tab/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Movement.move_to_prev_tab/2","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Manager.move_to(cursor, 10, 0)\n    iex> cursor = Movement.move_to_prev_tab(cursor, 8)\n    iex> cursor.position\n    {8, 0}","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_prev_tab/2-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Movement.move_up/2","doc":"Moves the cursor up by the specified number of lines.","ref":"Raxol.Terminal.Cursor.Movement.html#move_up/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Movement.move_up/2","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Movement.move_up(cursor, 2)\n    iex> cursor.position\n    {0, 0}  # Already at top, no change","ref":"Raxol.Terminal.Cursor.Movement.html#move_up/2-examples"},{"type":"module","title":"Raxol.Terminal.Cursor.Style","doc":"Handles cursor style and visibility control for the terminal emulator.\n\nThis module provides functions for changing cursor appearance, controlling\nvisibility, and managing cursor blinking.","ref":"Raxol.Terminal.Cursor.Style.html"},{"type":"function","title":"Raxol.Terminal.Cursor.Style.blink/1","doc":"Makes the cursor blink.","ref":"Raxol.Terminal.Cursor.Style.html#blink/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Style.blink/1","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.blink(cursor)\n    iex> cursor.state\n    :blinking","ref":"Raxol.Terminal.Cursor.Style.html#blink/1-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Style.hide/1","doc":"Hides the cursor.","ref":"Raxol.Terminal.Cursor.Style.html#hide/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Style.hide/1","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.hide(cursor)\n    iex> cursor.state\n    :hidden","ref":"Raxol.Terminal.Cursor.Style.html#hide/1-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Style.set_bar/1","doc":"Sets the cursor style to bar.","ref":"Raxol.Terminal.Cursor.Style.html#set_bar/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Style.set_bar/1","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.set_bar(cursor)\n    iex> cursor.style\n    :bar","ref":"Raxol.Terminal.Cursor.Style.html#set_bar/1-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Style.set_blink_rate/2","doc":"Sets the cursor blink rate in milliseconds.","ref":"Raxol.Terminal.Cursor.Style.html#set_blink_rate/2"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Style.set_blink_rate/2","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.set_blink_rate(cursor, 1000)\n    iex> cursor.blink_rate\n    1000","ref":"Raxol.Terminal.Cursor.Style.html#set_blink_rate/2-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Style.set_block/1","doc":"Sets the cursor style to block.","ref":"Raxol.Terminal.Cursor.Style.html#set_block/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Style.set_block/1","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.set_block(cursor)\n    iex> cursor.style\n    :block","ref":"Raxol.Terminal.Cursor.Style.html#set_block/1-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Style.set_custom/3","doc":"Sets a custom cursor shape.","ref":"Raxol.Terminal.Cursor.Style.html#set_custom/3"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Style.set_custom/3","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.set_custom(cursor, \"█\", {2, 1})\n    iex> cursor.style\n    :custom\n    iex> cursor.custom_shape\n    \"█\"","ref":"Raxol.Terminal.Cursor.Style.html#set_custom/3-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Style.set_underline/1","doc":"Sets the cursor style to underline.","ref":"Raxol.Terminal.Cursor.Style.html#set_underline/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Style.set_underline/1","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.set_underline(cursor)\n    iex> cursor.style\n    :underline","ref":"Raxol.Terminal.Cursor.Style.html#set_underline/1-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Style.show/1","doc":"Makes the cursor visible.","ref":"Raxol.Terminal.Cursor.Style.html#show/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Style.show/1","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Manager.set_state(cursor, :hidden)\n    iex> cursor = Style.show(cursor)\n    iex> cursor.state\n    :visible","ref":"Raxol.Terminal.Cursor.Style.html#show/1-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Style.toggle_blink/1","doc":"Toggles the cursor blinking state.","ref":"Raxol.Terminal.Cursor.Style.html#toggle_blink/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Style.toggle_blink/1","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.toggle_blink(cursor)\n    iex> cursor.state\n    :blinking\n    iex> cursor = Style.toggle_blink(cursor)\n    iex> cursor.state\n    :visible","ref":"Raxol.Terminal.Cursor.Style.html#toggle_blink/1-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Style.toggle_visibility/1","doc":"Toggles the cursor visibility.","ref":"Raxol.Terminal.Cursor.Style.html#toggle_visibility/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Style.toggle_visibility/1","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.toggle_visibility(cursor)\n    iex> cursor.state\n    :hidden\n    iex> cursor = Style.toggle_visibility(cursor)\n    iex> cursor.state\n    :visible","ref":"Raxol.Terminal.Cursor.Style.html#toggle_visibility/1-examples"},{"type":"function","title":"Raxol.Terminal.Cursor.Style.update_blink/1","doc":"Updates the cursor blink state and returns the updated cursor and visibility.","ref":"Raxol.Terminal.Cursor.Style.html#update_blink/1"},{"type":"function","title":"Examples - Raxol.Terminal.Cursor.Style.update_blink/1","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.blink(cursor)\n    iex> {cursor, visible} = Style.update_blink(cursor)\n    iex> is_boolean(visible)\n    true","ref":"Raxol.Terminal.Cursor.Style.html#update_blink/1-examples"},{"type":"module","title":"Raxol.Terminal.Display.AsciiArt","doc":"ASCII art rendering system for the Raxol terminal emulator.\n\nThis module provides functionality for:\n- Rendering ASCII art templates\n- Creating custom ASCII art\n- Animating ASCII art\n- Integrating with the terminal display system","ref":"Raxol.Terminal.Display.AsciiArt.html"},{"type":"function","title":"Raxol.Terminal.Display.AsciiArt.box/1","doc":"Returns an ASCII art box with the given text.","ref":"Raxol.Terminal.Display.AsciiArt.html#box/1"},{"type":"function","title":"Raxol.Terminal.Display.AsciiArt.error/0","doc":"Returns an ASCII art error indicator.","ref":"Raxol.Terminal.Display.AsciiArt.html#error/0"},{"type":"function","title":"Raxol.Terminal.Display.AsciiArt.header/1","doc":"Returns a stylized header with the given text.","ref":"Raxol.Terminal.Display.AsciiArt.html#header/1"},{"type":"function","title":"Raxol.Terminal.Display.AsciiArt.help/0","doc":"Returns an ASCII art help screen.","ref":"Raxol.Terminal.Display.AsciiArt.html#help/0"},{"type":"function","title":"Raxol.Terminal.Display.AsciiArt.loading/2","doc":"Returns an ASCII art loading animation for the given text.","ref":"Raxol.Terminal.Display.AsciiArt.html#loading/2"},{"type":"function","title":"Raxol.Terminal.Display.AsciiArt.logo/0","doc":"Returns the ASCII art logo for the Raxol project.","ref":"Raxol.Terminal.Display.AsciiArt.html#logo/0"},{"type":"function","title":"Raxol.Terminal.Display.AsciiArt.progress_bar/1","doc":"Returns an ASCII art progress bar with the given percentage.","ref":"Raxol.Terminal.Display.AsciiArt.html#progress_bar/1"},{"type":"function","title":"Raxol.Terminal.Display.AsciiArt.spinner/1","doc":"Returns an ASCII art spinner animation frame for the given step.","ref":"Raxol.Terminal.Display.AsciiArt.html#spinner/1"},{"type":"function","title":"Raxol.Terminal.Display.AsciiArt.success/0","doc":"Returns an ASCII art success indicator.","ref":"Raxol.Terminal.Display.AsciiArt.html#success/0"},{"type":"function","title":"Raxol.Terminal.Display.AsciiArt.table/2","doc":"Returns an ASCII art table with the given headers and rows.","ref":"Raxol.Terminal.Display.AsciiArt.html#table/2"},{"type":"function","title":"Raxol.Terminal.Display.AsciiArt.theme_preview/0","doc":"Returns an ASCII art theme preview.","ref":"Raxol.Terminal.Display.AsciiArt.html#theme_preview/0"},{"type":"function","title":"Raxol.Terminal.Display.AsciiArt.warning/0","doc":"Returns an ASCII art warning indicator.","ref":"Raxol.Terminal.Display.AsciiArt.html#warning/0"},{"type":"module","title":"Raxol.Terminal.Driver","doc":"Handles raw terminal input/output and event generation.\n\nResponsibilities:\n- Setting terminal mode (raw, echo)\n- Reading input events via rrex_termbox NIF v2.0.1\n- Parsing input events into `Raxol.Core.Events.Event` structs\n- Detecting terminal resize events\n- Sending parsed events to the `Dispatcher`\n- Restoring terminal state on exit","ref":"Raxol.Terminal.Driver.html"},{"type":"function","title":"Raxol.Terminal.Driver.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Terminal.Driver.html#child_spec/1"},{"type":"type","title":"Raxol.Terminal.Driver.dispatcher_pid/0","doc":"","ref":"Raxol.Terminal.Driver.html#t:dispatcher_pid/0"},{"type":"type","title":"Raxol.Terminal.Driver.original_stty/0","doc":"","ref":"Raxol.Terminal.Driver.html#t:original_stty/0"},{"type":"function","title":"Raxol.Terminal.Driver.start_link/1","doc":"Starts the Terminal Driver process.","ref":"Raxol.Terminal.Driver.html#start_link/1"},{"type":"module","title":"Raxol.Terminal.Emulator","doc":"Manages the state of the terminal emulator, including screen buffer,\ncursor position, attributes, and modes.","ref":"Raxol.Terminal.Emulator.html"},{"type":"type","title":"Raxol.Terminal.Emulator.cursor_style_type/0","doc":"","ref":"Raxol.Terminal.Emulator.html#t:cursor_style_type/0"},{"type":"function","title":"Raxol.Terminal.Emulator.get_active_buffer/1","doc":"Gets the currently active screen buffer.","ref":"Raxol.Terminal.Emulator.html#get_active_buffer/1"},{"type":"function","title":"Raxol.Terminal.Emulator.get_cursor_position/1","doc":"Gets the current cursor position from the emulator.","ref":"Raxol.Terminal.Emulator.html#get_cursor_position/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Emulator.get_cursor_position/1","doc":"* `emulator` - The emulator to get the cursor position from","ref":"Raxol.Terminal.Emulator.html#get_cursor_position/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Emulator.get_cursor_position/1","doc":"A tuple {x, y} representing the cursor position","ref":"Raxol.Terminal.Emulator.html#get_cursor_position/1-returns"},{"type":"function","title":"Raxol.Terminal.Emulator.get_cursor_visible/1","doc":"Gets whether the cursor is currently visible.","ref":"Raxol.Terminal.Emulator.html#get_cursor_visible/1"},{"type":"function","title":"Parameters - Raxol.Terminal.Emulator.get_cursor_visible/1","doc":"* `emulator` - The emulator to check","ref":"Raxol.Terminal.Emulator.html#get_cursor_visible/1-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Emulator.get_cursor_visible/1","doc":"Boolean indicating if cursor is visible","ref":"Raxol.Terminal.Emulator.html#get_cursor_visible/1-returns"},{"type":"function","title":"Raxol.Terminal.Emulator.new/3","doc":"Creates a new terminal emulator instance with the specified dimensions and options.","ref":"Raxol.Terminal.Emulator.html#new/3"},{"type":"function","title":"Examples - Raxol.Terminal.Emulator.new/3","doc":"iex> emulator = Raxol.Terminal.Emulator.new(80, 24, %{})\n    iex> emulator.width\n    80\n    iex> emulator.height\n    24\n    iex> emulator.cursor.position\n    {0, 0}","ref":"Raxol.Terminal.Emulator.html#new/3-examples"},{"type":"function","title":"Raxol.Terminal.Emulator.process_character/2","doc":"","ref":"Raxol.Terminal.Emulator.html#process_character/2"},{"type":"function","title":"Raxol.Terminal.Emulator.process_input/2","doc":"Processes input from the user, handling both regular characters and escape sequences.\nProcesses the entire input string recursively.","ref":"Raxol.Terminal.Emulator.html#process_input/2"},{"type":"function","title":"Examples - Raxol.Terminal.Emulator.process_input/2","doc":"iex> emulator = Raxol.Terminal.Emulator.new(80, 24, %{})\n    iex> {emulator, _} = Raxol.Terminal.Emulator.process_input(emulator, \"a\")\n    # Cursor position is now 1-based, so {1, 1} after 'a'\n    iex> emulator.cursor.position\n    {1, 1}\n    iex> emulator = Raxol.Terminal.Emulator.new()\n    iex> {emulator, _} = Raxol.Terminal.Emulator.process_input(emulator, \"\\e[1;31mRed\\e[0m Text\")\n    iex> {x, y} = emulator.cursor.position\n    iex> x # Length of \"Red Text\" (8 chars) + starting at 1 = 9\n    9\n    iex> emulator.style.foreground # Should be reset by \\e[0m\n    nil","ref":"Raxol.Terminal.Emulator.html#process_input/2-examples"},{"type":"function","title":"Raxol.Terminal.Emulator.resize/3","doc":"Resizes the emulator's screen buffers.","ref":"Raxol.Terminal.Emulator.html#resize/3"},{"type":"function","title":"Parameters - Raxol.Terminal.Emulator.resize/3","doc":"* `emulator` - The emulator to resize\n* `new_width` - New width in columns\n* `new_height` - New height in rows","ref":"Raxol.Terminal.Emulator.html#resize/3-parameters"},{"type":"function","title":"Returns - Raxol.Terminal.Emulator.resize/3","doc":"Updated emulator with resized buffers","ref":"Raxol.Terminal.Emulator.html#resize/3-returns"},{"type":"type","title":"Raxol.Terminal.Emulator.t/0","doc":"","ref":"Raxol.Terminal.Emulator.html#t:t/0"},{"type":"function","title":"Raxol.Terminal.Emulator.update_active_buffer/2","doc":"Updates the currently active screen buffer.","ref":"Raxol.Terminal.Emulator.html#update_active_buffer/2"},{"type":"module","title":"Raxol.Terminal.EscapeSequence","doc":"Handles parsing of ANSI escape sequences and other control sequences.\n\nThis module provides functions for parsing ANSI escape sequences\ninto structured data representing terminal commands.","ref":"Raxol.Terminal.EscapeSequence.html"},{"type":"function","title":"Raxol.Terminal.EscapeSequence.parse/1","doc":"Parses an input string, potentially containing an escape sequence.\n\nReturns:\n  * `{:ok, command_data, remaining_input}` if a complete sequence is parsed.\n  * `{:incomplete, remaining_input}` if the input is potentially part of a sequence but incomplete.\n  * `{:error, :invalid_sequence, remaining_input}` if the sequence is malformed.\n  * `{:error, :not_escape_sequence, input}` if the input doesn't start with ESC.\n\n`command_data` is a tuple representing the parsed command, e.g.:\n  * `{:cursor_position, {row, col}}`\n  * `{:cursor_move, :up, count}`\n  * `{:set_mode, :dec_private, mode_code, boolean_value}`\n  * `{:set_mode, :standard, mode_code, boolean_value}`\n  * `{:designate_charset, target_g_set, charset_atom}`\n  * `{:invoke_charset, target_g_set}`\n  * etc.","ref":"Raxol.Terminal.EscapeSequence.html#parse/1"},{"type":"module","title":"Raxol.Terminal.Input","doc":"Terminal input module.\n\nThis module handles keyboard and mouse input events for the terminal, including:\n- Input buffering\n- Mode management\n- Input history\n- Special key handling","ref":"Raxol.Terminal.Input.html"},{"type":"function","title":"Raxol.Terminal.Input.add_to_history/2","doc":"Adds a command to the history.","ref":"Raxol.Terminal.Input.html#add_to_history/2"},{"type":"function","title":"Examples - Raxol.Terminal.Input.add_to_history/2","doc":"iex> input = Input.new()\n    iex> input = Input.add_to_history(input, \"test\")\n    iex> length(input.history)\n    1","ref":"Raxol.Terminal.Input.html#add_to_history/2-examples"},{"type":"function","title":"Raxol.Terminal.Input.clear_buffer/1","doc":"Clears the input buffer.","ref":"Raxol.Terminal.Input.html#clear_buffer/1"},{"type":"function","title":"Examples - Raxol.Terminal.Input.clear_buffer/1","doc":"iex> input = Input.new()\n    iex> input = Input.process_keyboard(input, \"test\")\n    iex> input = Input.clear_buffer(input)\n    iex> Input.get_buffer(input)\n    \"\"","ref":"Raxol.Terminal.Input.html#clear_buffer/1-examples"},{"type":"function","title":"Raxol.Terminal.Input.get_buffer/1","doc":"Gets the current input buffer.","ref":"Raxol.Terminal.Input.html#get_buffer/1"},{"type":"function","title":"Examples - Raxol.Terminal.Input.get_buffer/1","doc":"iex> input = Input.new()\n    iex> input = Input.process_keyboard(input, \"test\")\n    iex> Input.get_buffer(input)\n    \"test\"","ref":"Raxol.Terminal.Input.html#get_buffer/1-examples"},{"type":"function","title":"Raxol.Terminal.Input.get_mode/1","doc":"Gets the input mode.","ref":"Raxol.Terminal.Input.html#get_mode/1"},{"type":"function","title":"Examples - Raxol.Terminal.Input.get_mode/1","doc":"iex> input = Input.new()\n    iex> Input.get_mode(input)\n    :normal","ref":"Raxol.Terminal.Input.html#get_mode/1-examples"},{"type":"function","title":"Raxol.Terminal.Input.new/1","doc":"Creates a new input handler.","ref":"Raxol.Terminal.Input.html#new/1"},{"type":"function","title":"Examples - Raxol.Terminal.Input.new/1","doc":"iex> input = Input.new()\n    iex> input.mode\n    :normal\n    iex> input.buffer\n    \"\"","ref":"Raxol.Terminal.Input.html#new/1-examples"},{"type":"function","title":"Raxol.Terminal.Input.next_command/1","doc":"Gets the next command from history.","ref":"Raxol.Terminal.Input.html#next_command/1"},{"type":"function","title":"Examples - Raxol.Terminal.Input.next_command/1","doc":"iex> input = Input.new()\n    iex> input = Input.add_to_history(input, \"test\")\n    iex> input = Input.previous_command(input)\n    iex> input = Input.next_command(input)\n    iex> input.buffer\n    \"\"","ref":"Raxol.Terminal.Input.html#next_command/1-examples"},{"type":"function","title":"Raxol.Terminal.Input.previous_command/1","doc":"Gets the previous command from history.","ref":"Raxol.Terminal.Input.html#previous_command/1"},{"type":"function","title":"Examples - Raxol.Terminal.Input.previous_command/1","doc":"iex> input = Input.new()\n    iex> input = Input.add_to_history(input, \"test\")\n    iex> input = Input.previous_command(input)\n    iex> input.buffer\n    \"test\"","ref":"Raxol.Terminal.Input.html#previous_command/1-examples"},{"type":"function","title":"Raxol.Terminal.Input.process_keyboard/2","doc":"Processes a keyboard event.","ref":"Raxol.Terminal.Input.html#process_keyboard/2"},{"type":"function","title":"Examples - Raxol.Terminal.Input.process_keyboard/2","doc":"iex> input = Input.new()\n    iex> input = Input.process_keyboard(input, \"a\")\n    iex> input.buffer\n    \"a\"","ref":"Raxol.Terminal.Input.html#process_keyboard/2-examples"},{"type":"function","title":"Raxol.Terminal.Input.process_mouse/2","doc":"Processes a mouse event.","ref":"Raxol.Terminal.Input.html#process_mouse/2"},{"type":"function","title":"Examples - Raxol.Terminal.Input.process_mouse/2","doc":"iex> input = Input.new()\n    iex> input = Input.process_mouse(input, {:click, 1, 2, 1})\n    iex> input.buffer\n    \"\"","ref":"Raxol.Terminal.Input.html#process_mouse/2-examples"},{"type":"function","title":"Raxol.Terminal.Input.set_mode/2","doc":"Sets the input mode.","ref":"Raxol.Terminal.Input.html#set_mode/2"},{"type":"function","title":"Examples - Raxol.Terminal.Input.set_mode/2","doc":"iex> input = Input.new()\n    iex> input = Input.set_mode(input, :insert)\n    iex> input.mode\n    :insert","ref":"Raxol.Terminal.Input.html#set_mode/2-examples"},{"type":"type","title":"Raxol.Terminal.Input.t/0","doc":"","ref":"Raxol.Terminal.Input.html#t:t/0"},{"type":"module","title":"Raxol.Terminal.Input.InputBuffer","doc":"Handles input buffering for the terminal emulator.\nProvides functionality for storing, retrieving, and manipulating input data.","ref":"Raxol.Terminal.Input.InputBuffer.html"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.append/2","doc":"Appends data to the buffer, handling escape sequences appropriately.","ref":"Raxol.Terminal.Input.InputBuffer.html#append/2"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.backspace/1","doc":"Removes the last character from the buffer.\nUses graphemes to handle multi-byte characters correctly.","ref":"Raxol.Terminal.Input.InputBuffer.html#backspace/1"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.clear/1","doc":"Clears the buffer.","ref":"Raxol.Terminal.Input.InputBuffer.html#clear/1"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.delete_first/1","doc":"Removes the first character from the buffer.","ref":"Raxol.Terminal.Input.InputBuffer.html#delete_first/1"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.empty?/1","doc":"Checks if the buffer is empty.","ref":"Raxol.Terminal.Input.InputBuffer.html#empty?/1"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.get_contents/1","doc":"Gets the buffer contents.","ref":"Raxol.Terminal.Input.InputBuffer.html#get_contents/1"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.handle_escape_sequence/2","doc":"Handles escape sequence processing.","ref":"Raxol.Terminal.Input.InputBuffer.html#handle_escape_sequence/2"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.handle_resize/2","doc":"","ref":"Raxol.Terminal.Input.InputBuffer.html#handle_resize/2"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.insert_at/3","doc":"Inserts a character at the specified position.\nRaises ArgumentError if position is out of bounds.","ref":"Raxol.Terminal.Input.InputBuffer.html#insert_at/3"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.max_size/1","doc":"Gets the maximum size of the buffer.","ref":"Raxol.Terminal.Input.InputBuffer.html#max_size/1"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.move_cursor_to_end_of_line/1","doc":"","ref":"Raxol.Terminal.Input.InputBuffer.html#move_cursor_to_end_of_line/1"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.new/2","doc":"Creates a new input buffer with default values.","ref":"Raxol.Terminal.Input.InputBuffer.html#new/2"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.overflow_mode/1","doc":"Gets the overflow mode of the buffer.","ref":"Raxol.Terminal.Input.InputBuffer.html#overflow_mode/1"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.prepend/2","doc":"Prepends data to the buffer.","ref":"Raxol.Terminal.Input.InputBuffer.html#prepend/2"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.replace_at/3","doc":"Replaces a character at the specified position.\nRaises ArgumentError if position is out of bounds.","ref":"Raxol.Terminal.Input.InputBuffer.html#replace_at/3"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.set_contents/2","doc":"Sets the buffer contents.","ref":"Raxol.Terminal.Input.InputBuffer.html#set_contents/2"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.set_max_size/2","doc":"Sets the maximum size of the buffer.\nIf the current content exceeds the new max size, it will be handled\naccording to the current overflow mode.","ref":"Raxol.Terminal.Input.InputBuffer.html#set_max_size/2"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.set_overflow_mode/2","doc":"Sets the overflow mode of the buffer.","ref":"Raxol.Terminal.Input.InputBuffer.html#set_overflow_mode/2"},{"type":"function","title":"Raxol.Terminal.Input.InputBuffer.size/1","doc":"Gets the current size of the buffer.","ref":"Raxol.Terminal.Input.InputBuffer.html#size/1"},{"type":"type","title":"Raxol.Terminal.Input.InputBuffer.t/0","doc":"","ref":"Raxol.Terminal.Input.InputBuffer.html#t:t/0"},{"type":"module","title":"Raxol.Terminal.Input.InputBufferUtils","doc":"Utility functions for Raxol.Terminal.Input.InputBuffer.","ref":"Raxol.Terminal.Input.InputBufferUtils.html"},{"type":"function","title":"Raxol.Terminal.Input.InputBufferUtils.calculate_new_cursor_pos_v2/5","doc":"","ref":"Raxol.Terminal.Input.InputBufferUtils.html#calculate_new_cursor_pos_v2/5"},{"type":"function","title":"Raxol.Terminal.Input.InputBufferUtils.find_logical_position/2","doc":"","ref":"Raxol.Terminal.Input.InputBufferUtils.html#find_logical_position/2"},{"type":"function","title":"Raxol.Terminal.Input.InputBufferUtils.wrap_line/2","doc":"","ref":"Raxol.Terminal.Input.InputBufferUtils.html#wrap_line/2"},{"type":"module","title":"Raxol.Terminal.Input.InputHandler","doc":"Handles input processing for the terminal emulator, including:\n- Mouse events (clicks, movement, scrolling)\n- Special key handling\n- Input mode switching\n- Input buffering\n- Extended key combinations\n- Tab completion","ref":"Raxol.Terminal.Input.InputHandler.html"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.add_to_history/1","doc":"Adds the current buffer contents to the input history.\nResets the history navigation index and clears the buffer.","ref":"Raxol.Terminal.Input.InputHandler.html#add_to_history/1"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.buffer_empty?/1","doc":"Checks if the buffer is empty.","ref":"Raxol.Terminal.Input.InputHandler.html#buffer_empty?/1"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.clear_buffer/1","doc":"Clears the input buffer.","ref":"Raxol.Terminal.Input.InputHandler.html#clear_buffer/1"},{"type":"type","title":"Raxol.Terminal.Input.InputHandler.completion_callback/0","doc":"","ref":"Raxol.Terminal.Input.InputHandler.html#t:completion_callback/0"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.get_buffer_contents/1","doc":"Gets the contents of the internal input buffer.","ref":"Raxol.Terminal.Input.InputHandler.html#get_buffer_contents/1"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.get_history_entry/2","doc":"Retrieves a specific input from history by its index (0 is most recent).\nSets the history_index to track navigation.","ref":"Raxol.Terminal.Input.InputHandler.html#get_history_entry/2"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.get_mode/1","doc":"Gets the current input mode.","ref":"Raxol.Terminal.Input.InputHandler.html#get_mode/1"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.handle_tab/1","doc":"Processes tab completion.","ref":"Raxol.Terminal.Input.InputHandler.html#handle_tab/1"},{"type":"type","title":"Raxol.Terminal.Input.InputHandler.input_mode/0","doc":"","ref":"Raxol.Terminal.Input.InputHandler.html#t:input_mode/0"},{"type":"type","title":"Raxol.Terminal.Input.InputHandler.mouse_button/0","doc":"","ref":"Raxol.Terminal.Input.InputHandler.html#t:mouse_button/0"},{"type":"type","title":"Raxol.Terminal.Input.InputHandler.mouse_event/0","doc":"","ref":"Raxol.Terminal.Input.InputHandler.html#t:mouse_event/0"},{"type":"type","title":"Raxol.Terminal.Input.InputHandler.mouse_event_type/0","doc":"","ref":"Raxol.Terminal.Input.InputHandler.html#t:mouse_event_type/0"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.new/0","doc":"Creates a new input handler with default values.","ref":"Raxol.Terminal.Input.InputHandler.html#new/0"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.next_history_entry/1","doc":"Moves to the next history entry (newer / Down Arrow).","ref":"Raxol.Terminal.Input.InputHandler.html#next_history_entry/1"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.previous_history_entry/1","doc":"Moves to the previous history entry (older / Up Arrow).\nIf not currently navigating history, it starts from the most recent entry (index 0).","ref":"Raxol.Terminal.Input.InputHandler.html#previous_history_entry/1"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.process_key_with_modifiers/2","doc":"Processes a key with the current modifier state.","ref":"Raxol.Terminal.Input.InputHandler.html#process_key_with_modifiers/2"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.process_keyboard/2","doc":"Processes a keyboard input event.","ref":"Raxol.Terminal.Input.InputHandler.html#process_keyboard/2"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.process_mouse/2","doc":"Processes a mouse event.","ref":"Raxol.Terminal.Input.InputHandler.html#process_mouse/2"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.process_special_key/2","doc":"Processes a special key event.","ref":"Raxol.Terminal.Input.InputHandler.html#process_special_key/2"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.set_completion_callback/2","doc":"Sets a completion callback function for tab completion.","ref":"Raxol.Terminal.Input.InputHandler.html#set_completion_callback/2"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.set_mode/2","doc":"Sets the input mode.","ref":"Raxol.Terminal.Input.InputHandler.html#set_mode/2"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.set_mouse_enabled/2","doc":"Enables or disables mouse event handling.","ref":"Raxol.Terminal.Input.InputHandler.html#set_mouse_enabled/2"},{"type":"type","title":"Raxol.Terminal.Input.InputHandler.special_key/0","doc":"","ref":"Raxol.Terminal.Input.InputHandler.html#t:special_key/0"},{"type":"type","title":"Raxol.Terminal.Input.InputHandler.t/0","doc":"","ref":"Raxol.Terminal.Input.InputHandler.html#t:t/0"},{"type":"function","title":"Raxol.Terminal.Input.InputHandler.update_modifier/3","doc":"Updates the modifier state for a key.","ref":"Raxol.Terminal.Input.InputHandler.html#update_modifier/3"},{"type":"module","title":"Raxol.Terminal.Input.SpecialKeys","doc":"Handles special key combinations and their escape sequences.\n\nThis module provides functionality for:\n- Detecting special key combinations (Ctrl, Alt, Shift, Meta)\n- Converting special keys to their corresponding escape sequences\n- Handling modifier key state\n- Supporting extended key combinations","ref":"Raxol.Terminal.Input.SpecialKeys.html"},{"type":"type","title":"Raxol.Terminal.Input.SpecialKeys.modifier/0","doc":"","ref":"Raxol.Terminal.Input.SpecialKeys.html#t:modifier/0"},{"type":"type","title":"Raxol.Terminal.Input.SpecialKeys.modifier_state/0","doc":"","ref":"Raxol.Terminal.Input.SpecialKeys.html#t:modifier_state/0"},{"type":"function","title":"Raxol.Terminal.Input.SpecialKeys.new_state/0","doc":"Creates a new modifier state.","ref":"Raxol.Terminal.Input.SpecialKeys.html#new_state/0"},{"type":"function","title":"Examples - Raxol.Terminal.Input.SpecialKeys.new_state/0","doc":"iex> state = SpecialKeys.new_state()\n    iex> state.ctrl\n    false","ref":"Raxol.Terminal.Input.SpecialKeys.html#new_state/0-examples"},{"type":"function","title":"Raxol.Terminal.Input.SpecialKeys.to_escape_sequence/2","doc":"Converts a key combination to its corresponding escape sequence.","ref":"Raxol.Terminal.Input.SpecialKeys.html#to_escape_sequence/2"},{"type":"function","title":"Examples - Raxol.Terminal.Input.SpecialKeys.to_escape_sequence/2","doc":"iex> state = SpecialKeys.new_state() |> SpecialKeys.update_state(\"Control\", true)\n    iex> SpecialKeys.to_escape_sequence(state, \"c\")\n    \"\u001B[99\"","ref":"Raxol.Terminal.Input.SpecialKeys.html#to_escape_sequence/2-examples"},{"type":"function","title":"Raxol.Terminal.Input.SpecialKeys.update_state/3","doc":"Updates the modifier state based on a key event.","ref":"Raxol.Terminal.Input.SpecialKeys.html#update_state/3"},{"type":"function","title":"Examples - Raxol.Terminal.Input.SpecialKeys.update_state/3","doc":"iex> state = SpecialKeys.new_state()\n    iex> state = SpecialKeys.update_state(state, \"Control\", true)\n    iex> state.ctrl\n    true","ref":"Raxol.Terminal.Input.SpecialKeys.html#update_state/3-examples"},{"type":"module","title":"Raxol.Terminal.Input.Types","doc":"Defines shared types for the Raxol terminal input subsystem.","ref":"Raxol.Terminal.Input.Types.html"},{"type":"type","title":"Raxol.Terminal.Input.Types.input_buffer/0","doc":"Represents the state of the terminal input buffer.","ref":"Raxol.Terminal.Input.Types.html#t:input_buffer/0"},{"type":"module","title":"Raxol.Terminal.InputHandler","doc":"Handles input processing for the terminal emulator.\n\nThis module is responsible for processing input from stdin and other sources,\nmanaging the input buffer, and handling special keys and combinations.\n\nNote: When running in certain environments, stdin may be excluded from Credo analysis\ndue to how it's processed. This is expected behavior and doesn't affect functionality.","ref":"Raxol.Terminal.InputHandler.html"},{"type":"function","title":"Raxol.Terminal.InputHandler.handle_copy/1","doc":"Handles clipboard copy operation.","ref":"Raxol.Terminal.InputHandler.html#handle_copy/1"},{"type":"function","title":"Raxol.Terminal.InputHandler.handle_cut/1","doc":"Handles clipboard cut operation.","ref":"Raxol.Terminal.InputHandler.html#handle_cut/1"},{"type":"function","title":"Raxol.Terminal.InputHandler.handle_paste/1","doc":"Handles clipboard paste operation.","ref":"Raxol.Terminal.InputHandler.html#handle_paste/1"},{"type":"function","title":"Raxol.Terminal.InputHandler.insert_text/3","doc":"Inserts text at the specified position in the buffer.","ref":"Raxol.Terminal.InputHandler.html#insert_text/3"},{"type":"function","title":"Raxol.Terminal.InputHandler.new/0","doc":"Creates a new input handler with default values.","ref":"Raxol.Terminal.InputHandler.html#new/0"},{"type":"type","title":"Raxol.Terminal.InputHandler.t/0","doc":"","ref":"Raxol.Terminal.InputHandler.html#t:t/0"},{"type":"module","title":"Raxol.Terminal.Integration","doc":"Integrates various terminal components like Emulator, Buffer Manager, Cursor Manager, etc.\n\nThis module acts as a central orchestrator, managing interactions between:\n- Terminal Emulator state (`Raxol.Terminal.Emulator`)\n- Screen buffer management (`Raxol.Terminal.Buffer.Manager`)\n- Cursor state and rendering (`Raxol.Terminal.Cursor.Manager`)\n- Scrollback buffer (`Raxol.Terminal.Buffer.Scroll`)\n- Input handling and command history (`Raxol.Terminal.Commands.History`)\n- Terminal configuration (`Raxol.Terminal.Config`)\n- Managing memory and performance optimizations\n- Command history management","ref":"Raxol.Terminal.Integration.html"},{"type":"function","title":"Raxol.Terminal.Integration.clear_damage_regions/1","doc":"Clears the damage regions in the buffer manager.","ref":"Raxol.Terminal.Integration.html#clear_damage_regions/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.clear_damage_regions/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.write(integration, \"Hello\")\n    iex> integration = Integration.clear_damage_regions(integration)\n    iex> Integration.get_damage_regions(integration)\n    []","ref":"Raxol.Terminal.Integration.html#clear_damage_regions/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.clear_screen/1","doc":"Clears the screen with integrated buffer management.","ref":"Raxol.Terminal.Integration.html#clear_screen/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.clear_screen/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.write(integration, \"Hello\")\n    iex> integration = Integration.clear_screen(integration)\n    iex> Integration.get_visible_content(integration)\n    \"\"","ref":"Raxol.Terminal.Integration.html#clear_screen/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.clear_scroll_buffer/1","doc":"Clears the scroll buffer with integrated scroll buffer management.","ref":"Raxol.Terminal.Integration.html#clear_scroll_buffer/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.clear_scroll_buffer/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.write(integration, \"Line 1\nLine 2\nLine 3\")\n    iex> integration = Integration.clear_scroll_buffer(integration)\n    iex> Integration.get_scroll_height(integration)\n    0","ref":"Raxol.Terminal.Integration.html#clear_scroll_buffer/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.execute_command/2","doc":"Executes a command and updates the command history.","ref":"Raxol.Terminal.Integration.html#execute_command/2"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.execute_command/2","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.execute_command(integration, \"ls -la\")","ref":"Raxol.Terminal.Integration.html#execute_command/2-examples"},{"type":"function","title":"Raxol.Terminal.Integration.get_cursor_position/1","doc":"Gets the current cursor position with integrated cursor management.","ref":"Raxol.Terminal.Integration.html#get_cursor_position/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.get_cursor_position/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.move_cursor(integration, 10, 5)\n    iex> Integration.get_cursor_position(integration)\n    {10, 5}","ref":"Raxol.Terminal.Integration.html#get_cursor_position/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.get_cursor_state/1","doc":"Gets the current cursor state with integrated cursor management.","ref":"Raxol.Terminal.Integration.html#get_cursor_state/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.get_cursor_state/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.hide_cursor(integration)\n    iex> Integration.get_cursor_state(integration)\n    :hidden","ref":"Raxol.Terminal.Integration.html#get_cursor_state/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.get_cursor_style/1","doc":"Gets the current cursor style with integrated cursor management.","ref":"Raxol.Terminal.Integration.html#get_cursor_style/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.get_cursor_style/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.set_cursor_style(integration, :underline)\n    iex> Integration.get_cursor_style(integration)\n    :underline","ref":"Raxol.Terminal.Integration.html#get_cursor_style/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.get_damage_regions/1","doc":"Gets the damage regions from the buffer manager.","ref":"Raxol.Terminal.Integration.html#get_damage_regions/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.get_damage_regions/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.write(integration, \"Hello\")\n    iex> regions = Integration.get_damage_regions(integration)\n    iex> length(regions)\n    1","ref":"Raxol.Terminal.Integration.html#get_damage_regions/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.get_scroll_height/1","doc":"Gets the total scroll height with integrated scroll buffer management.","ref":"Raxol.Terminal.Integration.html#get_scroll_height/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.get_scroll_height/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.write(integration, \"Line 1\nLine 2\nLine 3\")\n    iex> Integration.get_scroll_height(integration)\n    3","ref":"Raxol.Terminal.Integration.html#get_scroll_height/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.get_scroll_position/1","doc":"Gets the current scroll position with integrated scroll buffer management.","ref":"Raxol.Terminal.Integration.html#get_scroll_position/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.get_scroll_position/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.scroll(integration, 5)\n    iex> Integration.get_scroll_position(integration)\n    5","ref":"Raxol.Terminal.Integration.html#get_scroll_position/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.get_scroll_view/2","doc":"Gets a view of the scroll buffer with integrated scroll buffer management.","ref":"Raxol.Terminal.Integration.html#get_scroll_view/2"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.get_scroll_view/2","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.write(integration, \"Line 1\nLine 2\nLine 3\")\n    iex> view = Integration.get_scroll_view(integration, 2)\n    iex> length(view)\n    2","ref":"Raxol.Terminal.Integration.html#get_scroll_view/2-examples"},{"type":"function","title":"Raxol.Terminal.Integration.get_visible_content/1","doc":"Gets the visible content of the terminal with integrated buffer management.","ref":"Raxol.Terminal.Integration.html#get_visible_content/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.get_visible_content/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.write(integration, \"Hello\")\n    iex> Integration.get_visible_content(integration)\n    \"Hello\"","ref":"Raxol.Terminal.Integration.html#get_visible_content/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.handle_device_status_query/2","doc":"Handles a device status query.","ref":"Raxol.Terminal.Integration.html#handle_device_status_query/2"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.handle_device_status_query/2","doc":"iex> integration = Integration.new(80, 24)\n    iex> response = Integration.handle_device_status_query(integration, \"6\")\n    iex> response\n    \"\u001B[1;1R\"","ref":"Raxol.Terminal.Integration.html#handle_device_status_query/2-examples"},{"type":"function","title":"Raxol.Terminal.Integration.handle_event/2","doc":"","ref":"Raxol.Terminal.Integration.html#handle_event/2"},{"type":"function","title":"Raxol.Terminal.Integration.handle_input/2","doc":"Handles input from the user, including command history navigation.","ref":"Raxol.Terminal.Integration.html#handle_input/2"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.handle_input/2","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.handle_input(integration, \"ls -la\")\n    iex> integration = Integration.handle_input(integration, :up_arrow)","ref":"Raxol.Terminal.Integration.html#handle_input/2-examples"},{"type":"function","title":"Raxol.Terminal.Integration.hide_cursor/1","doc":"Hides the cursor with integrated cursor management.","ref":"Raxol.Terminal.Integration.html#hide_cursor/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.hide_cursor/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.hide_cursor(integration)\n    iex> integration.cursor_manager.state\n    :hidden","ref":"Raxol.Terminal.Integration.html#hide_cursor/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.invoke_character_set/2","doc":"Invokes a character set.","ref":"Raxol.Terminal.Integration.html#invoke_character_set/2"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.invoke_character_set/2","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.invoke_character_set(integration, \"0\")","ref":"Raxol.Terminal.Integration.html#invoke_character_set/2-examples"},{"type":"function","title":"Raxol.Terminal.Integration.move_cursor/3","doc":"Moves the cursor to the specified position with integrated cursor management.","ref":"Raxol.Terminal.Integration.html#move_cursor/3"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.move_cursor/3","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.move_cursor(integration, 10, 5)\n    iex> integration.cursor_manager.position\n    {10, 5}","ref":"Raxol.Terminal.Integration.html#move_cursor/3-examples"},{"type":"function","title":"Raxol.Terminal.Integration.new/3","doc":"Creates a new integrated terminal system with the specified dimensions.","ref":"Raxol.Terminal.Integration.html#new/3"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.new/3","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration.emulator.width\n    80\n    iex> integration.emulator.height\n    24","ref":"Raxol.Terminal.Integration.html#new/3-examples"},{"type":"function","title":"Raxol.Terminal.Integration.reset_screen_mode/2","doc":"Resets a specific screen mode in the emulator.","ref":"Raxol.Terminal.Integration.html#reset_screen_mode/2"},{"type":"function","title":"Raxol.Terminal.Integration.restore_cursor/1","doc":"Restores the previously saved cursor position with integrated cursor management.","ref":"Raxol.Terminal.Integration.html#restore_cursor/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.restore_cursor/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.move_cursor(integration, 10, 5)\n    iex> integration = Integration.save_cursor(integration)\n    iex> integration = Integration.move_cursor(integration, 0, 0)\n    iex> integration = Integration.restore_cursor(integration)\n    iex> integration.cursor_manager.position\n    {10, 5}","ref":"Raxol.Terminal.Integration.html#restore_cursor/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.save_cursor/1","doc":"Saves the current cursor position with integrated cursor management.","ref":"Raxol.Terminal.Integration.html#save_cursor/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.save_cursor/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.move_cursor(integration, 10, 5)\n    iex> integration = Integration.save_cursor(integration)\n    iex> integration.cursor_manager.saved_position\n    {10, 5}","ref":"Raxol.Terminal.Integration.html#save_cursor/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.screen_mode_enabled?/2","doc":"Checks if a screen mode is enabled.","ref":"Raxol.Terminal.Integration.html#screen_mode_enabled?/2"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.screen_mode_enabled?/2","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.screen_mode_enabled?(integration, :alternate_screen)\n    false","ref":"Raxol.Terminal.Integration.html#screen_mode_enabled?/2-examples"},{"type":"function","title":"Raxol.Terminal.Integration.scroll/2","doc":"Scrolls the terminal content with integrated scroll buffer management.","ref":"Raxol.Terminal.Integration.html#scroll/2"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.scroll/2","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.write(integration, \"Line 1\nLine 2\nLine 3\")\n    iex> integration = Integration.scroll(integration, 1)\n    iex> Integration.get_visible_content(integration)\n    \"Line 2\nLine 3\"","ref":"Raxol.Terminal.Integration.html#scroll/2-examples"},{"type":"function","title":"Raxol.Terminal.Integration.set_character_set/3","doc":"Sets a character set for a G-set.","ref":"Raxol.Terminal.Integration.html#set_character_set/3"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.set_character_set/3","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.set_character_set(integration, \"0\", \"B\")","ref":"Raxol.Terminal.Integration.html#set_character_set/3-examples"},{"type":"function","title":"Raxol.Terminal.Integration.set_cursor_blink_rate/2","doc":"Sets the cursor blink rate with integrated cursor management.","ref":"Raxol.Terminal.Integration.html#set_cursor_blink_rate/2"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.set_cursor_blink_rate/2","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.set_cursor_blink_rate(integration, 1000)\n    iex> integration.cursor_manager.blink_rate\n    1000","ref":"Raxol.Terminal.Integration.html#set_cursor_blink_rate/2-examples"},{"type":"function","title":"Raxol.Terminal.Integration.set_cursor_style/2","doc":"Sets the cursor style with integrated cursor management.","ref":"Raxol.Terminal.Integration.html#set_cursor_style/2"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.set_cursor_style/2","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.set_cursor_style(integration, :underline)\n    iex> integration.cursor_manager.style\n    :underline","ref":"Raxol.Terminal.Integration.html#set_cursor_style/2-examples"},{"type":"function","title":"Raxol.Terminal.Integration.set_screen_mode/2","doc":"Sets a specific screen mode in the emulator.","ref":"Raxol.Terminal.Integration.html#set_screen_mode/2"},{"type":"function","title":"Raxol.Terminal.Integration.show_cursor/1","doc":"Shows the cursor with integrated cursor management.","ref":"Raxol.Terminal.Integration.html#show_cursor/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.show_cursor/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.hide_cursor(integration)\n    iex> integration = Integration.show_cursor(integration)\n    iex> integration.cursor_manager.state\n    :visible","ref":"Raxol.Terminal.Integration.html#show_cursor/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.switch_buffers/1","doc":"Switches the active and back buffers in the buffer manager.","ref":"Raxol.Terminal.Integration.html#switch_buffers/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.switch_buffers/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.write(integration, \"Hello\")\n    iex> integration = Integration.switch_buffers(integration)\n    iex> integration.buffer_manager.active_buffer != integration.buffer_manager.back_buffer\n    true","ref":"Raxol.Terminal.Integration.html#switch_buffers/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.switch_to_alternate_buffer/1","doc":"Switches to the alternate screen buffer.","ref":"Raxol.Terminal.Integration.html#switch_to_alternate_buffer/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.switch_to_alternate_buffer/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.switch_to_alternate_buffer(integration)","ref":"Raxol.Terminal.Integration.html#switch_to_alternate_buffer/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.switch_to_main_buffer/1","doc":"Switches back to the main screen buffer.","ref":"Raxol.Terminal.Integration.html#switch_to_main_buffer/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.switch_to_main_buffer/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.switch_to_main_buffer(integration)","ref":"Raxol.Terminal.Integration.html#switch_to_main_buffer/1-examples"},{"type":"type","title":"Raxol.Terminal.Integration.t/0","doc":"","ref":"Raxol.Terminal.Integration.html#t:t/0"},{"type":"function","title":"Raxol.Terminal.Integration.update_config/2","doc":"Updates the terminal configuration.\n\nMerges the provided `opts` into the current configuration and validates\nthe result before applying.","ref":"Raxol.Terminal.Integration.html#update_config/2"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.update_config/2","doc":"iex> integration = Integration.new(80, 24)\n    iex> {:ok, integration} = Integration.update_config(integration, theme: \"light\", behavior: [scrollback_lines: 2000])\n    iex> integration.config.theme\n    \"light\"\n    iex> integration.config.behavior.scrollback_lines\n    2000\n\n    iex> {:error, _reason} = Integration.update_config(integration, invalid_opt: :bad)","ref":"Raxol.Terminal.Integration.html#update_config/2-examples"},{"type":"function","title":"Raxol.Terminal.Integration.update_cursor_blink/1","doc":"Updates the cursor blink state with integrated cursor management.","ref":"Raxol.Terminal.Integration.html#update_cursor_blink/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.update_cursor_blink/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.set_cursor_style(integration, :blinking)\n    iex> {integration, visible} = Integration.update_cursor_blink(integration)\n    iex> is_boolean(visible)\n    true","ref":"Raxol.Terminal.Integration.html#update_cursor_blink/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.update_memory_usage/1","doc":"Updates memory usage tracking in the buffer manager.","ref":"Raxol.Terminal.Integration.html#update_memory_usage/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.update_memory_usage/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.update_memory_usage(integration)\n    iex> integration.buffer_manager.memory_usage > 0\n    true","ref":"Raxol.Terminal.Integration.html#update_memory_usage/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.within_memory_limits?/1","doc":"Checks if memory usage is within limits.","ref":"Raxol.Terminal.Integration.html#within_memory_limits?/1"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.within_memory_limits?/1","doc":"iex> integration = Integration.new(80, 24)\n    iex> Integration.within_memory_limits?(integration)\n    true","ref":"Raxol.Terminal.Integration.html#within_memory_limits?/1-examples"},{"type":"function","title":"Raxol.Terminal.Integration.write/2","doc":"Writes text to the terminal with integrated buffer and cursor management.","ref":"Raxol.Terminal.Integration.html#write/2"},{"type":"function","title":"Examples - Raxol.Terminal.Integration.write/2","doc":"iex> integration = Integration.new(80, 24)\n    iex> integration = Integration.write(integration, \"Hello\")\n    iex> Integration.get_visible_content(integration)\n    \"Hello\"","ref":"Raxol.Terminal.Integration.html#write/2-examples"},{"type":"module","title":"Raxol.Terminal.Manager","doc":"Terminal manager module.\n\nThis module manages terminal sessions, including:\n- Session creation\n- Session destruction\n- Session listing\n- Session monitoring","ref":"Raxol.Terminal.Manager.html"},{"type":"function","title":"Raxol.Terminal.Manager.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Terminal.Manager.html#child_spec/1"},{"type":"function","title":"Raxol.Terminal.Manager.count_sessions/1","doc":"Gets the count of terminal sessions.","ref":"Raxol.Terminal.Manager.html#count_sessions/1"},{"type":"function","title":"Examples - Raxol.Terminal.Manager.count_sessions/1","doc":"iex> {:ok, pid} = Manager.start_link()\n    iex> {:ok, _} = Manager.create_session(pid)\n    iex> {:ok, _} = Manager.create_session(pid)\n    iex> Manager.count_sessions(pid)\n    2","ref":"Raxol.Terminal.Manager.html#count_sessions/1-examples"},{"type":"function","title":"Raxol.Terminal.Manager.create_session/2","doc":"Creates a new terminal session.","ref":"Raxol.Terminal.Manager.html#create_session/2"},{"type":"function","title":"Examples - Raxol.Terminal.Manager.create_session/2","doc":"iex> {:ok, pid} = Manager.start_link()\n    iex> {:ok, session_id} = Manager.create_session(pid, %{width: 80, height: 24})\n    iex> is_binary(session_id)\n    true","ref":"Raxol.Terminal.Manager.html#create_session/2-examples"},{"type":"function","title":"Raxol.Terminal.Manager.destroy_session/2","doc":"Destroys a terminal session.","ref":"Raxol.Terminal.Manager.html#destroy_session/2"},{"type":"function","title":"Examples - Raxol.Terminal.Manager.destroy_session/2","doc":"iex> {:ok, pid} = Manager.start_link()\n    iex> {:ok, session_id} = Manager.create_session(pid)\n    iex> :ok = Manager.destroy_session(pid, session_id)\n    iex> Manager.get_session(pid, session_id)\n    {:error, :not_found}","ref":"Raxol.Terminal.Manager.html#destroy_session/2-examples"},{"type":"function","title":"Raxol.Terminal.Manager.get_session/2","doc":"Gets a terminal session by ID.","ref":"Raxol.Terminal.Manager.html#get_session/2"},{"type":"function","title":"Examples - Raxol.Terminal.Manager.get_session/2","doc":"iex> {:ok, pid} = Manager.start_link()\n    iex> {:ok, session_id} = Manager.create_session(pid)\n    iex> {:ok, session} = Manager.get_session(pid, session_id)\n    iex> session.id\n    session_id","ref":"Raxol.Terminal.Manager.html#get_session/2-examples"},{"type":"function","title":"Raxol.Terminal.Manager.get_state/0","doc":"","ref":"Raxol.Terminal.Manager.html#get_state/0"},{"type":"function","title":"Raxol.Terminal.Manager.list_sessions/1","doc":"Lists all terminal sessions.","ref":"Raxol.Terminal.Manager.html#list_sessions/1"},{"type":"function","title":"Examples - Raxol.Terminal.Manager.list_sessions/1","doc":"iex> {:ok, pid} = Manager.start_link()\n    iex> {:ok, session_id1} = Manager.create_session(pid)\n    iex> {:ok, session_id2} = Manager.create_session(pid)\n    iex> sessions = Manager.list_sessions(pid)\n    iex> length(sessions)\n    2","ref":"Raxol.Terminal.Manager.html#list_sessions/1-examples"},{"type":"function","title":"Raxol.Terminal.Manager.monitor_session/2","doc":"Monitors a terminal session.","ref":"Raxol.Terminal.Manager.html#monitor_session/2"},{"type":"function","title":"Examples - Raxol.Terminal.Manager.monitor_session/2","doc":"iex> {:ok, pid} = Manager.start_link()\n    iex> {:ok, session_id} = Manager.create_session(pid)\n    iex> :ok = Manager.monitor_session(pid, session_id)\n    iex> Process.whereis({:via, Registry, {Registry, session_id}})\n    #PID<0.123.0>","ref":"Raxol.Terminal.Manager.html#monitor_session/2-examples"},{"type":"function","title":"Raxol.Terminal.Manager.start_link/1","doc":"Starts the terminal manager.","ref":"Raxol.Terminal.Manager.html#start_link/1"},{"type":"function","title":"Examples - Raxol.Terminal.Manager.start_link/1","doc":"iex> {:ok, pid} = Manager.start_link()\n    iex> Process.alive?(pid)\n    true","ref":"Raxol.Terminal.Manager.html#start_link/1-examples"},{"type":"type","title":"Raxol.Terminal.Manager.t/0","doc":"","ref":"Raxol.Terminal.Manager.html#t:t/0"},{"type":"function","title":"Raxol.Terminal.Manager.unmonitor_session/2","doc":"Unmonitors a terminal session.","ref":"Raxol.Terminal.Manager.html#unmonitor_session/2"},{"type":"function","title":"Examples - Raxol.Terminal.Manager.unmonitor_session/2","doc":"iex> {:ok, pid} = Manager.start_link()\n    iex> {:ok, session_id} = Manager.create_session(pid)\n    iex> :ok = Manager.monitor_session(pid, session_id)\n    iex> :ok = Manager.unmonitor_session(pid, session_id)\n    iex> Process.whereis({:via, Registry, {Registry, session_id}})\n    nil","ref":"Raxol.Terminal.Manager.html#unmonitor_session/2-examples"},{"type":"function","title":"Raxol.Terminal.Manager.update_state/1","doc":"","ref":"Raxol.Terminal.Manager.html#update_state/1"},{"type":"module","title":"Raxol.Terminal.MemoryManager","doc":"Monitors and manages memory usage for terminal processes.\n\nCan trigger actions like trimming scrollback when limits are exceeded.","ref":"Raxol.Terminal.MemoryManager.html"},{"type":"function","title":"Raxol.Terminal.MemoryManager.check_and_cleanup/1","doc":"Checks if memory usage exceeds the limit and performs cleanup if necessary.\n\nThis function should be called periodically.","ref":"Raxol.Terminal.MemoryManager.html#check_and_cleanup/1"},{"type":"function","title":"Raxol.Terminal.MemoryManager.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Terminal.MemoryManager.html#child_spec/1"},{"type":"function","title":"Raxol.Terminal.MemoryManager.perform_cleanup/1","doc":"Performs memory cleanup operations on relevant terminal components.\n\nCurrently focuses on trimming the buffer manager.","ref":"Raxol.Terminal.MemoryManager.html#perform_cleanup/1"},{"type":"module","title":"Raxol.Terminal.Modes","doc":"Handles terminal modes and state transitions for the terminal emulator.\n\nThis module provides functions for managing terminal modes, processing\nescape sequences, and handling terminal state transitions.","ref":"Raxol.Terminal.Modes.html"},{"type":"function","title":"Raxol.Terminal.Modes.active?/2","doc":"Checks if a terminal mode is active.","ref":"Raxol.Terminal.Modes.html#active?/2"},{"type":"function","title":"Examples - Raxol.Terminal.Modes.active?/2","doc":"iex> modes = Modes.new()\n    iex> Modes.active?(modes, :normal)\n    true\n    iex> Modes.active?(modes, :insert)\n    false","ref":"Raxol.Terminal.Modes.html#active?/2-examples"},{"type":"function","title":"Raxol.Terminal.Modes.active_modes/1","doc":"Returns a list of all active terminal modes.","ref":"Raxol.Terminal.Modes.html#active_modes/1"},{"type":"function","title":"Examples - Raxol.Terminal.Modes.active_modes/1","doc":"iex> modes = Modes.new()\n    iex> Modes.active_modes(modes)\n    [:normal, :replace]","ref":"Raxol.Terminal.Modes.html#active_modes/1-examples"},{"type":"type","title":"Raxol.Terminal.Modes.mode/0","doc":"","ref":"Raxol.Terminal.Modes.html#t:mode/0"},{"type":"type","title":"Raxol.Terminal.Modes.mode_state/0","doc":"","ref":"Raxol.Terminal.Modes.html#t:mode_state/0"},{"type":"function","title":"Raxol.Terminal.Modes.new/0","doc":"Creates a new terminal mode state.","ref":"Raxol.Terminal.Modes.html#new/0"},{"type":"function","title":"Examples - Raxol.Terminal.Modes.new/0","doc":"iex> modes = Modes.new()\n    iex> modes.insert\n    false","ref":"Raxol.Terminal.Modes.html#new/0-examples"},{"type":"function","title":"Raxol.Terminal.Modes.process_escape/2","doc":"Processes an escape sequence for terminal mode changes.","ref":"Raxol.Terminal.Modes.html#process_escape/2"},{"type":"function","title":"Examples - Raxol.Terminal.Modes.process_escape/2","doc":"iex> modes = Modes.new()\n    iex> {modes, _} = Modes.process_escape(modes, \"?1049h\")\n    iex> Modes.active?(modes, :alternate_screen)\n    true","ref":"Raxol.Terminal.Modes.html#process_escape/2-examples"},{"type":"function","title":"Raxol.Terminal.Modes.reset_mode/2","doc":"Resets a specific terminal mode to its default value.","ref":"Raxol.Terminal.Modes.html#reset_mode/2"},{"type":"function","title":"Examples - Raxol.Terminal.Modes.reset_mode/2","doc":"iex> modes = Modes.new() |> Modes.set_mode(:insert)\n    iex> modes.insert\n    true\n    iex> modes = Modes.reset_mode(modes, :insert)\n    iex> modes.insert\n    false\n    iex> modes = Modes.reset_mode(modes, :replace) # replace defaults to true\n    iex> modes.replace\n    true","ref":"Raxol.Terminal.Modes.html#reset_mode/2-examples"},{"type":"function","title":"Raxol.Terminal.Modes.restore_state/2","doc":"Restores a previously saved terminal mode state.","ref":"Raxol.Terminal.Modes.html#restore_state/2"},{"type":"function","title":"Examples - Raxol.Terminal.Modes.restore_state/2","doc":"iex> modes = Modes.new()\n    iex> {modes, saved_modes} = Modes.save_state(modes)\n    iex> modes = Modes.set_mode(modes, :insert)\n    iex> modes = Modes.restore_state(modes, saved_modes)\n    iex> Modes.active?(modes, :normal)\n    true","ref":"Raxol.Terminal.Modes.html#restore_state/2-examples"},{"type":"function","title":"Raxol.Terminal.Modes.save_state/1","doc":"Saves the current terminal mode state.","ref":"Raxol.Terminal.Modes.html#save_state/1"},{"type":"function","title":"Examples - Raxol.Terminal.Modes.save_state/1","doc":"iex> modes = Modes.new()\n    iex> {modes, saved_modes} = Modes.save_state(modes)\n    iex> modes = Modes.set_mode(modes, :insert)\n    iex> modes = Modes.restore_state(modes, saved_modes)\n    iex> Modes.active?(modes, :normal)\n    true","ref":"Raxol.Terminal.Modes.html#save_state/1-examples"},{"type":"function","title":"Raxol.Terminal.Modes.set_mode/2","doc":"Sets a terminal mode.","ref":"Raxol.Terminal.Modes.html#set_mode/2"},{"type":"function","title":"Examples - Raxol.Terminal.Modes.set_mode/2","doc":"iex> modes = Modes.new()\n    iex> modes = Modes.set_mode(modes, :insert)\n    iex> modes.insert\n    true\n    iex> modes.replace\n    false","ref":"Raxol.Terminal.Modes.html#set_mode/2-examples"},{"type":"function","title":"Raxol.Terminal.Modes.to_string/1","doc":"Returns a string representation of the terminal mode state.","ref":"Raxol.Terminal.Modes.html#to_string/1"},{"type":"function","title":"Examples - Raxol.Terminal.Modes.to_string/1","doc":"iex> modes = Modes.new()\n    iex> Modes.to_string(modes)\n    \"Terminal Modes: normal, replace\"","ref":"Raxol.Terminal.Modes.html#to_string/1-examples"},{"type":"module","title":"Raxol.Terminal.Parser","doc":"Parses raw byte streams into terminal events and commands.\nHandles escape sequences (CSI, OSC, DCS, etc.) and plain text.","ref":"Raxol.Terminal.Parser.html"},{"type":"function","title":"Raxol.Terminal.Parser.parse_chunk/2","doc":"Parses a chunk of input using a state machine.\n\nTakes the current emulator state and input binary, returns the updated emulator state\nafter processing the input chunk.\n\nDelegates actual state modification (character writing, command execution)\nback to the Emulator module.","ref":"Raxol.Terminal.Parser.html#parse_chunk/2"},{"type":"module","title":"Raxol.Terminal.Parser.States.CSIEntryState","doc":"Handles the :csi_entry state of the terminal parser.","ref":"Raxol.Terminal.Parser.States.CSIEntryState.html"},{"type":"function","title":"Raxol.Terminal.Parser.States.CSIEntryState.handle/3","doc":"Processes input when the parser is in the :csi_entry state.","ref":"Raxol.Terminal.Parser.States.CSIEntryState.html#handle/3"},{"type":"module","title":"Raxol.Terminal.Parser.States.CSIIntermediateState","doc":"Handles the :csi_intermediate state of the terminal parser.","ref":"Raxol.Terminal.Parser.States.CSIIntermediateState.html"},{"type":"function","title":"Raxol.Terminal.Parser.States.CSIIntermediateState.handle/3","doc":"Processes input when the parser is in the :csi_intermediate state.","ref":"Raxol.Terminal.Parser.States.CSIIntermediateState.html#handle/3"},{"type":"module","title":"Raxol.Terminal.Parser.States.CSIParamState","doc":"Handles the :csi_param state of the terminal parser.","ref":"Raxol.Terminal.Parser.States.CSIParamState.html"},{"type":"function","title":"Raxol.Terminal.Parser.States.CSIParamState.handle/3","doc":"Processes input when the parser is in the :csi_param state.","ref":"Raxol.Terminal.Parser.States.CSIParamState.html#handle/3"},{"type":"module","title":"Raxol.Terminal.Parser.States.DCSEntryState","doc":"Handles the :dcs_entry state of the terminal parser.","ref":"Raxol.Terminal.Parser.States.DCSEntryState.html"},{"type":"function","title":"Raxol.Terminal.Parser.States.DCSEntryState.handle/3","doc":"Processes input when the parser is in the :dcs_entry state.","ref":"Raxol.Terminal.Parser.States.DCSEntryState.html#handle/3"},{"type":"module","title":"Raxol.Terminal.Parser.States.DCSPassthroughMaybeSTState","doc":"Handles the :dcs_passthrough_maybe_st state of the terminal parser.","ref":"Raxol.Terminal.Parser.States.DCSPassthroughMaybeSTState.html"},{"type":"function","title":"Raxol.Terminal.Parser.States.DCSPassthroughMaybeSTState.handle/3","doc":"Processes input when the parser is in the :dcs_passthrough_maybe_st state.","ref":"Raxol.Terminal.Parser.States.DCSPassthroughMaybeSTState.html#handle/3"},{"type":"module","title":"Raxol.Terminal.Parser.States.DCSPassthroughState","doc":"Handles the :dcs_passthrough state of the terminal parser.","ref":"Raxol.Terminal.Parser.States.DCSPassthroughState.html"},{"type":"function","title":"Raxol.Terminal.Parser.States.DCSPassthroughState.handle/3","doc":"Processes input when the parser is in the :dcs_passthrough state.","ref":"Raxol.Terminal.Parser.States.DCSPassthroughState.html#handle/3"},{"type":"module","title":"Raxol.Terminal.Parser.States.DesignateCharsetState","doc":"Handles the :designate_charset state of the terminal parser.","ref":"Raxol.Terminal.Parser.States.DesignateCharsetState.html"},{"type":"function","title":"Raxol.Terminal.Parser.States.DesignateCharsetState.handle/3","doc":"Processes input when the parser is in the :designate_charset state.","ref":"Raxol.Terminal.Parser.States.DesignateCharsetState.html#handle/3"},{"type":"module","title":"Raxol.Terminal.Parser.States.EscapeState","doc":"Handles the :escape state of the terminal parser.","ref":"Raxol.Terminal.Parser.States.EscapeState.html"},{"type":"function","title":"Raxol.Terminal.Parser.States.EscapeState.handle/3","doc":"Processes input when the parser is in the :escape state.","ref":"Raxol.Terminal.Parser.States.EscapeState.html#handle/3"},{"type":"module","title":"Raxol.Terminal.Parser.States.GroundState","doc":"Handles the :ground state of the terminal parser.","ref":"Raxol.Terminal.Parser.States.GroundState.html"},{"type":"function","title":"Raxol.Terminal.Parser.States.GroundState.handle/3","doc":"Processes input when the parser is in the :ground state.\n\nReturns:\n  - `{:continue, new_emulator, next_parser_state, remaining_input}` to continue parsing.\n  - `{:handled, final_emulator}` if the input is fully processed or an error occurs.","ref":"Raxol.Terminal.Parser.States.GroundState.html#handle/3"},{"type":"module","title":"Raxol.Terminal.Parser.States.OSCStringMaybeSTState","doc":"Handles the :osc_string_maybe_st state of the terminal parser.","ref":"Raxol.Terminal.Parser.States.OSCStringMaybeSTState.html"},{"type":"function","title":"Raxol.Terminal.Parser.States.OSCStringMaybeSTState.handle/3","doc":"Processes input when the parser is in the :osc_string_maybe_st state.","ref":"Raxol.Terminal.Parser.States.OSCStringMaybeSTState.html#handle/3"},{"type":"module","title":"Raxol.Terminal.Parser.States.OSCStringState","doc":"Handles the :osc_string state of the terminal parser.","ref":"Raxol.Terminal.Parser.States.OSCStringState.html"},{"type":"function","title":"Raxol.Terminal.Parser.States.OSCStringState.handle/3","doc":"Processes input when the parser is in the :osc_string state.","ref":"Raxol.Terminal.Parser.States.OSCStringState.html#handle/3"},{"type":"module","title":"Raxol.Terminal.Registry","doc":"Terminal registry module.\n\nThis module manages the registry of terminal sessions, including:\n- Session registration\n- Session lookup\n- Session cleanup","ref":"Raxol.Terminal.Registry.html"},{"type":"function","title":"Raxol.Terminal.Registry.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Terminal.Registry.html#child_spec/1"},{"type":"function","title":"Raxol.Terminal.Registry.count/0","doc":"","ref":"Raxol.Terminal.Registry.html#count/0"},{"type":"function","title":"Raxol.Terminal.Registry.exclude_by_id/1","doc":"","ref":"Raxol.Terminal.Registry.html#exclude_by_id/1"},{"type":"function","title":"Raxol.Terminal.Registry.filter_by_id/1","doc":"","ref":"Raxol.Terminal.Registry.html#filter_by_id/1"},{"type":"function","title":"Raxol.Terminal.Registry.init/1","doc":"","ref":"Raxol.Terminal.Registry.html#init/1"},{"type":"function","title":"Raxol.Terminal.Registry.list/0","doc":"","ref":"Raxol.Terminal.Registry.html#list/0"},{"type":"function","title":"Raxol.Terminal.Registry.lookup/1","doc":"","ref":"Raxol.Terminal.Registry.html#lookup/1"},{"type":"function","title":"Raxol.Terminal.Registry.match/1","doc":"","ref":"Raxol.Terminal.Registry.html#match/1"},{"type":"function","title":"Raxol.Terminal.Registry.match_except/1","doc":"","ref":"Raxol.Terminal.Registry.html#match_except/1"},{"type":"function","title":"Raxol.Terminal.Registry.register/2","doc":"","ref":"Raxol.Terminal.Registry.html#register/2"},{"type":"function","title":"Raxol.Terminal.Registry.start_link/0","doc":"","ref":"Raxol.Terminal.Registry.html#start_link/0"},{"type":"function","title":"Raxol.Terminal.Registry.unregister/1","doc":"","ref":"Raxol.Terminal.Registry.html#unregister/1"},{"type":"module","title":"Raxol.Terminal.Renderer","doc":"Terminal renderer module.\n\nThis module handles rendering of terminal output, including:\n- Character cell rendering\n- Text styling\n- Cursor rendering\n- Performance optimizations","ref":"Raxol.Terminal.Renderer.html"},{"type":"function","title":"Raxol.Terminal.Renderer.clear_cursor/1","doc":"Clears the cursor position.","ref":"Raxol.Terminal.Renderer.html#clear_cursor/1"},{"type":"function","title":"Examples - Raxol.Terminal.Renderer.clear_cursor/1","doc":"iex> screen_buffer = ScreenBuffer.new(80, 24)\n    iex> renderer = Renderer.new(screen_buffer)\n    iex> renderer = Renderer.set_cursor(renderer, {10, 5})\n    iex> renderer = Renderer.clear_cursor(renderer)\n    iex> renderer.cursor\n    nil","ref":"Raxol.Terminal.Renderer.html#clear_cursor/1-examples"},{"type":"function","title":"Raxol.Terminal.Renderer.new/3","doc":"Creates a new renderer with the given screen buffer.","ref":"Raxol.Terminal.Renderer.html#new/3"},{"type":"function","title":"Examples - Raxol.Terminal.Renderer.new/3","doc":"iex> screen_buffer = ScreenBuffer.new(80, 24)\n    iex> renderer = Renderer.new(screen_buffer)\n    iex> renderer.screen_buffer\n    %ScreenBuffer{}","ref":"Raxol.Terminal.Renderer.html#new/3-examples"},{"type":"function","title":"Raxol.Terminal.Renderer.render/1","doc":"Renders the screen buffer to a string.","ref":"Raxol.Terminal.Renderer.html#render/1"},{"type":"function","title":"Examples - Raxol.Terminal.Renderer.render/1","doc":"iex> screen_buffer = ScreenBuffer.new(80, 24)\n    iex> renderer = Renderer.new(screen_buffer)\n    iex> output = Renderer.render(renderer)\n    iex> is_binary(output)\n    true","ref":"Raxol.Terminal.Renderer.html#render/1-examples"},{"type":"function","title":"Raxol.Terminal.Renderer.set_cursor/2","doc":"Sets the cursor position.","ref":"Raxol.Terminal.Renderer.html#set_cursor/2"},{"type":"function","title":"Examples - Raxol.Terminal.Renderer.set_cursor/2","doc":"iex> screen_buffer = ScreenBuffer.new(80, 24)\n    iex> renderer = Renderer.new(screen_buffer)\n    iex> renderer = Renderer.set_cursor(renderer, {10, 5})\n    iex> renderer.cursor\n    {10, 5}","ref":"Raxol.Terminal.Renderer.html#set_cursor/2-examples"},{"type":"function","title":"Raxol.Terminal.Renderer.set_font_settings/2","doc":"Sets the font settings.","ref":"Raxol.Terminal.Renderer.html#set_font_settings/2"},{"type":"function","title":"Examples - Raxol.Terminal.Renderer.set_font_settings/2","doc":"iex> screen_buffer = ScreenBuffer.new(80, 24)\n    iex> renderer = Renderer.new(screen_buffer)\n    iex> font_settings = %{family: \"monospace\", size: 14}\n    iex> renderer = Renderer.set_font_settings(renderer, font_settings)\n    iex> renderer.font_settings\n    %{family: \"monospace\", size: 14}","ref":"Raxol.Terminal.Renderer.html#set_font_settings/2-examples"},{"type":"function","title":"Raxol.Terminal.Renderer.set_theme/2","doc":"Sets the theme.","ref":"Raxol.Terminal.Renderer.html#set_theme/2"},{"type":"function","title":"Examples - Raxol.Terminal.Renderer.set_theme/2","doc":"iex> screen_buffer = ScreenBuffer.new(80, 24)\n    iex> renderer = Renderer.new(screen_buffer)\n    iex> theme = %{foreground: %{default: \"#FFFFFF\"}}\n    iex> renderer = Renderer.set_theme(renderer, theme)\n    iex> renderer.theme\n    %{foreground: %{default: \"#FFFFFF\"}}","ref":"Raxol.Terminal.Renderer.html#set_theme/2-examples"},{"type":"type","title":"Raxol.Terminal.Renderer.t/0","doc":"","ref":"Raxol.Terminal.Renderer.html#t:t/0"},{"type":"module","title":"Raxol.Terminal.ScreenBuffer","doc":"Manages the terminal's screen buffer state (grid, scrollback, selection).\nDelegates operations to specialized modules in Raxol.Terminal.Buffer.*","ref":"Raxol.Terminal.ScreenBuffer.html"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.clear/1","doc":"Clears buffer. See `Raxol.Terminal.Buffer.Operations.clear/1`.","ref":"Raxol.Terminal.ScreenBuffer.html#clear/1"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.clear_region/5","doc":"Clears region. See `Raxol.Terminal.Buffer.Operations.clear_region/5`.","ref":"Raxol.Terminal.ScreenBuffer.html#clear_region/5"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.clear_scroll_region/1","doc":"Clears scroll region. See `Raxol.Terminal.Buffer.Operations.clear_scroll_region/1`.","ref":"Raxol.Terminal.ScreenBuffer.html#clear_scroll_region/1"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.delete_characters/3","doc":"Deletes characters. See `Raxol.Terminal.Buffer.Operations.delete_characters/3`.","ref":"Raxol.Terminal.ScreenBuffer.html#delete_characters/3"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.delete_lines/4","doc":"Deletes lines. See `Raxol.Terminal.Buffer.Operations.delete_lines/4`.","ref":"Raxol.Terminal.ScreenBuffer.html#delete_lines/4"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.diff/2","doc":"Calculates diff. See `Raxol.Terminal.Buffer.Operations.diff/2`.","ref":"Raxol.Terminal.ScreenBuffer.html#diff/2"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.erase_in_display/3","doc":"Erases in display. See `Raxol.Terminal.Buffer.Operations.erase_in_display/3`.","ref":"Raxol.Terminal.ScreenBuffer.html#erase_in_display/3"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.erase_in_line/3","doc":"Erases in line. See `Raxol.Terminal.Buffer.Operations.erase_in_line/3`.","ref":"Raxol.Terminal.ScreenBuffer.html#erase_in_line/3"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.get_cell/3","doc":"Gets cell. See `Raxol.Terminal.Buffer.Operations.get_cell/3`.","ref":"Raxol.Terminal.ScreenBuffer.html#get_cell/3"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.get_cell_at/3","doc":"Gets cell at. See `Raxol.Terminal.Buffer.Operations.get_cell_at/3`.","ref":"Raxol.Terminal.ScreenBuffer.html#get_cell_at/3"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.get_content/1","doc":"Gets content as string. See `Raxol.Terminal.Buffer.Operations.get_content/1`.","ref":"Raxol.Terminal.ScreenBuffer.html#get_content/1"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.get_dimensions/1","doc":"Gets dimensions. See `Raxol.Terminal.Buffer.Operations.get_dimensions/1`.","ref":"Raxol.Terminal.ScreenBuffer.html#get_dimensions/1"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.get_height/1","doc":"Gets height. See `Raxol.Terminal.Buffer.Operations.get_height/1`.","ref":"Raxol.Terminal.ScreenBuffer.html#get_height/1"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.get_line/2","doc":"Gets line. See `Raxol.Terminal.Buffer.Operations.get_line/2`.","ref":"Raxol.Terminal.ScreenBuffer.html#get_line/2"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.get_scroll_position/1","doc":"Gets scrollback size. See `Raxol.Terminal.Buffer.Scrollback.size/1`.","ref":"Raxol.Terminal.ScreenBuffer.html#get_scroll_position/1"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.get_scroll_region_boundaries/1","doc":"Gets scroll region boundaries. See `Raxol.Terminal.Buffer.Operations.get_scroll_region_boundaries/1`.","ref":"Raxol.Terminal.ScreenBuffer.html#get_scroll_region_boundaries/1"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.get_selection/1","doc":"Gets selected text. See `Raxol.Terminal.Buffer.Selection.get_text/1`.","ref":"Raxol.Terminal.ScreenBuffer.html#get_selection/1"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.get_selection_boundaries/1","doc":"Gets selection boundaries. See `Raxol.Terminal.Buffer.Selection.get_boundaries/1`.","ref":"Raxol.Terminal.ScreenBuffer.html#get_selection_boundaries/1"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.get_text_in_region/5","doc":"Gets text in region. See `Raxol.Terminal.Buffer.Selection.get_text_in_region/5`.","ref":"Raxol.Terminal.ScreenBuffer.html#get_text_in_region/5"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.get_width/1","doc":"Gets width. See `Raxol.Terminal.Buffer.Operations.get_width/1`.","ref":"Raxol.Terminal.ScreenBuffer.html#get_width/1"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.in_selection?/3","doc":"Checks if in selection. See `Raxol.Terminal.Buffer.Selection.contains?/3`.","ref":"Raxol.Terminal.ScreenBuffer.html#in_selection?/3"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.insert_characters/4","doc":"Inserts characters. See `Raxol.Terminal.Buffer.Operations.insert_characters/4`.","ref":"Raxol.Terminal.ScreenBuffer.html#insert_characters/4"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.insert_lines/4","doc":"Inserts lines. See `Raxol.Terminal.Buffer.Operations.insert_lines/4`.","ref":"Raxol.Terminal.ScreenBuffer.html#insert_lines/4"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.new/3","doc":"Creates a new screen buffer with the specified dimensions.","ref":"Raxol.Terminal.ScreenBuffer.html#new/3"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.resize/3","doc":"Resizes buffer. See `Raxol.Terminal.Buffer.Operations.resize/3`.","ref":"Raxol.Terminal.ScreenBuffer.html#resize/3"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.scroll_down/3","doc":"Scrolls down. See `Raxol.Terminal.Buffer.Operations.scroll_down/3`.","ref":"Raxol.Terminal.ScreenBuffer.html#scroll_down/3"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.scroll_up/3","doc":"Scrolls up. See `Raxol.Terminal.Buffer.Operations.scroll_up/3`.","ref":"Raxol.Terminal.ScreenBuffer.html#scroll_up/3"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.set_scroll_region/3","doc":"Sets scroll region. See `Raxol.Terminal.Buffer.Operations.set_scroll_region/3`.","ref":"Raxol.Terminal.ScreenBuffer.html#set_scroll_region/3"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.start_selection/3","doc":"Starts selection. See `Raxol.Terminal.Buffer.Selection.start/3`.","ref":"Raxol.Terminal.ScreenBuffer.html#start_selection/3"},{"type":"type","title":"Raxol.Terminal.ScreenBuffer.t/0","doc":"","ref":"Raxol.Terminal.ScreenBuffer.html#t:t/0"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.update/2","doc":"Updates buffer from changes. See `Raxol.Terminal.Buffer.Operations.update/2`.","ref":"Raxol.Terminal.ScreenBuffer.html#update/2"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.update_selection/3","doc":"Updates selection. See `Raxol.Terminal.Buffer.Selection.update/3`.","ref":"Raxol.Terminal.ScreenBuffer.html#update_selection/3"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.write_char/5","doc":"Writes a character. See `Raxol.Terminal.Buffer.Operations.write_char/5`.","ref":"Raxol.Terminal.ScreenBuffer.html#write_char/5"},{"type":"function","title":"Raxol.Terminal.ScreenBuffer.write_string/4","doc":"Writes a string. See `Raxol.Terminal.Buffer.Operations.write_string/4`.","ref":"Raxol.Terminal.ScreenBuffer.html#write_string/4"},{"type":"module","title":"Raxol.Terminal.ScreenModes","doc":"Alias module for Raxol.Terminal.ANSI.ScreenModes.\nThis module re-exports the functionality from ANSI.ScreenModes to maintain compatibility.","ref":"Raxol.Terminal.ScreenModes.html"},{"type":"function","title":"Raxol.Terminal.ScreenModes.get_auto_repeat_mode/1","doc":"","ref":"Raxol.Terminal.ScreenModes.html#get_auto_repeat_mode/1"},{"type":"function","title":"Raxol.Terminal.ScreenModes.get_column_width_mode/1","doc":"","ref":"Raxol.Terminal.ScreenModes.html#get_column_width_mode/1"},{"type":"function","title":"Raxol.Terminal.ScreenModes.get_interlacing_mode/1","doc":"","ref":"Raxol.Terminal.ScreenModes.html#get_interlacing_mode/1"},{"type":"function","title":"Raxol.Terminal.ScreenModes.get_mode/1","doc":"","ref":"Raxol.Terminal.ScreenModes.html#get_mode/1"},{"type":"function","title":"Raxol.Terminal.ScreenModes.lookup_private/1","doc":"","ref":"Raxol.Terminal.ScreenModes.html#lookup_private/1"},{"type":"function","title":"Raxol.Terminal.ScreenModes.lookup_standard/1","doc":"","ref":"Raxol.Terminal.ScreenModes.html#lookup_standard/1"},{"type":"function","title":"Raxol.Terminal.ScreenModes.mode_enabled?/2","doc":"","ref":"Raxol.Terminal.ScreenModes.html#mode_enabled?/2"},{"type":"function","title":"Raxol.Terminal.ScreenModes.new/0","doc":"","ref":"Raxol.Terminal.ScreenModes.html#new/0"},{"type":"function","title":"Raxol.Terminal.ScreenModes.reset_mode/2","doc":"","ref":"Raxol.Terminal.ScreenModes.html#reset_mode/2"},{"type":"function","title":"Raxol.Terminal.ScreenModes.set_mode/2","doc":"","ref":"Raxol.Terminal.ScreenModes.html#set_mode/2"},{"type":"function","title":"Raxol.Terminal.ScreenModes.switch_mode/2","doc":"","ref":"Raxol.Terminal.ScreenModes.html#switch_mode/2"},{"type":"function","title":"Raxol.Terminal.ScreenModes.switch_mode/3","doc":"","ref":"Raxol.Terminal.ScreenModes.html#switch_mode/3"},{"type":"module","title":"Raxol.Terminal.Session","doc":"Terminal session module.\n\nThis module manages terminal sessions, including:\n- Session lifecycle\n- Input/output handling\n- State management\n- Configuration","ref":"Raxol.Terminal.Session.html"},{"type":"function","title":"Raxol.Terminal.Session.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Terminal.Session.html#child_spec/1"},{"type":"function","title":"Raxol.Terminal.Session.count_active_sessions/0","doc":"","ref":"Raxol.Terminal.Session.html#count_active_sessions/0"},{"type":"function","title":"Raxol.Terminal.Session.get_state/1","doc":"Gets the current state of a terminal session.","ref":"Raxol.Terminal.Session.html#get_state/1"},{"type":"function","title":"Examples - Raxol.Terminal.Session.get_state/1","doc":"iex> {:ok, pid} = Session.start_link()\n    iex> state = Session.get_state(pid)\n    iex> state.width\n    80","ref":"Raxol.Terminal.Session.html#get_state/1-examples"},{"type":"function","title":"Raxol.Terminal.Session.send_input/2","doc":"Sends input to a terminal session.","ref":"Raxol.Terminal.Session.html#send_input/2"},{"type":"function","title":"Examples - Raxol.Terminal.Session.send_input/2","doc":"iex> {:ok, pid} = Session.start_link()\n    iex> :ok = Session.send_input(pid, \"test\")\n    iex> state = Session.get_state(pid)\n    iex> state.input.buffer\n    \"test\"","ref":"Raxol.Terminal.Session.html#send_input/2-examples"},{"type":"function","title":"Raxol.Terminal.Session.start_link/1","doc":"Starts a new terminal session.","ref":"Raxol.Terminal.Session.html#start_link/1"},{"type":"function","title":"Examples - Raxol.Terminal.Session.start_link/1","doc":"iex> {:ok, pid} = Session.start_link(%{width: 80, height: 24})\n    iex> Process.alive?(pid)\n    true","ref":"Raxol.Terminal.Session.html#start_link/1-examples"},{"type":"function","title":"Raxol.Terminal.Session.stop/1","doc":"Stops a terminal session.","ref":"Raxol.Terminal.Session.html#stop/1"},{"type":"function","title":"Examples - Raxol.Terminal.Session.stop/1","doc":"iex> {:ok, pid} = Session.start_link()\n    iex> :ok = Session.stop(pid)\n    iex> Process.alive?(pid)\n    false","ref":"Raxol.Terminal.Session.html#stop/1-examples"},{"type":"type","title":"Raxol.Terminal.Session.t/0","doc":"","ref":"Raxol.Terminal.Session.html#t:t/0"},{"type":"function","title":"Raxol.Terminal.Session.update_config/2","doc":"Updates the configuration of a terminal session.","ref":"Raxol.Terminal.Session.html#update_config/2"},{"type":"function","title":"Examples - Raxol.Terminal.Session.update_config/2","doc":"iex> {:ok, pid} = Session.start_link()\n    iex> :ok = Session.update_config(pid, %{width: 100, height: 30})\n    iex> state = Session.get_state(pid)\n    iex> state.width\n    100","ref":"Raxol.Terminal.Session.html#update_config/2-examples"},{"type":"module","title":"Raxol.Terminal.Supervisor","doc":"Supervisor for terminal-related processes.","ref":"Raxol.Terminal.Supervisor.html"},{"type":"function","title":"Raxol.Terminal.Supervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Terminal.Supervisor.html#child_spec/1"},{"type":"function","title":"Raxol.Terminal.Supervisor.start_link/1","doc":"","ref":"Raxol.Terminal.Supervisor.html#start_link/1"},{"type":"module","title":"Raxol.Terminal.TerminalUtils","doc":"Utility functions for terminal operations, providing cross-platform and\nconsistent handling of terminal capabilities and dimensions.","ref":"Raxol.Terminal.TerminalUtils.html"},{"type":"function","title":"Raxol.Terminal.TerminalUtils.cursor_position/0","doc":"Returns the current cursor position, if available.","ref":"Raxol.Terminal.TerminalUtils.html#cursor_position/0"},{"type":"function","title":"Raxol.Terminal.TerminalUtils.detect_dimensions/0","doc":"Detects terminal dimensions using a multi-layered approach:\n1. Uses `:io.columns` and `:io.rows` (preferred)\n2. Falls back to rrex_termbox v2.0.1 NIF if `:io` methods fail\n3. Falls back to `stty size` system command if needed\n4. Finally uses hardcoded default dimensions if all else fails\n\nReturns a tuple of {width, height}.","ref":"Raxol.Terminal.TerminalUtils.html#detect_dimensions/0"},{"type":"function","title":"Raxol.Terminal.TerminalUtils.get_bounds_map/0","doc":"Creates a bounds map with dimensions, starting at origin (0,0)","ref":"Raxol.Terminal.TerminalUtils.html#get_bounds_map/0"},{"type":"function","title":"Raxol.Terminal.TerminalUtils.get_dimensions_map/0","doc":"Gets terminal dimensions and returns them in a map format.","ref":"Raxol.Terminal.TerminalUtils.html#get_dimensions_map/0"},{"type":"module","title":"Raxol.Terminal.TextFormatting","doc":"Alias module for Raxol.Terminal.ANSI.TextFormatting.\nThis module re-exports the functionality from ANSI.TextFormatting to maintain compatibility.","ref":"Raxol.Terminal.TextFormatting.html"},{"type":"function","title":"Raxol.Terminal.TextFormatting.ansi_code_to_color_name/1","doc":"","ref":"Raxol.Terminal.TextFormatting.html#ansi_code_to_color_name/1"},{"type":"function","title":"Raxol.Terminal.TextFormatting.apply_attribute/2","doc":"","ref":"Raxol.Terminal.TextFormatting.html#apply_attribute/2"},{"type":"function","title":"Raxol.Terminal.TextFormatting.apply_color/3","doc":"","ref":"Raxol.Terminal.TextFormatting.html#apply_color/3"},{"type":"function","title":"Raxol.Terminal.TextFormatting.effective_width/2","doc":"","ref":"Raxol.Terminal.TextFormatting.html#effective_width/2"},{"type":"function","title":"Raxol.Terminal.TextFormatting.get_background/1","doc":"","ref":"Raxol.Terminal.TextFormatting.html#get_background/1"},{"type":"function","title":"Raxol.Terminal.TextFormatting.get_foreground/1","doc":"","ref":"Raxol.Terminal.TextFormatting.html#get_foreground/1"},{"type":"function","title":"Raxol.Terminal.TextFormatting.needs_paired_line?/1","doc":"","ref":"Raxol.Terminal.TextFormatting.html#needs_paired_line?/1"},{"type":"function","title":"Raxol.Terminal.TextFormatting.new/0","doc":"","ref":"Raxol.Terminal.TextFormatting.html#new/0"},{"type":"function","title":"Raxol.Terminal.TextFormatting.paired_line_type/1","doc":"","ref":"Raxol.Terminal.TextFormatting.html#paired_line_type/1"},{"type":"function","title":"Raxol.Terminal.TextFormatting.reset_size/1","doc":"","ref":"Raxol.Terminal.TextFormatting.html#reset_size/1"},{"type":"function","title":"Raxol.Terminal.TextFormatting.set_background/2","doc":"","ref":"Raxol.Terminal.TextFormatting.html#set_background/2"},{"type":"function","title":"Raxol.Terminal.TextFormatting.set_double_height_bottom/1","doc":"","ref":"Raxol.Terminal.TextFormatting.html#set_double_height_bottom/1"},{"type":"function","title":"Raxol.Terminal.TextFormatting.set_double_height_top/1","doc":"","ref":"Raxol.Terminal.TextFormatting.html#set_double_height_top/1"},{"type":"function","title":"Raxol.Terminal.TextFormatting.set_double_width/1","doc":"","ref":"Raxol.Terminal.TextFormatting.html#set_double_width/1"},{"type":"function","title":"Raxol.Terminal.TextFormatting.set_foreground/2","doc":"","ref":"Raxol.Terminal.TextFormatting.html#set_foreground/2"},{"type":"module","title":"Raxol.Test.ButtonHelpers","doc":"Helper functions for testing button components.\n\nThis module provides specialized functions for:\n- Button component setup\n- Interaction testing\n- Visual verification\n- Style testing","ref":"Raxol.Test.ButtonHelpers.html"},{"type":"function","title":"Raxol.Test.ButtonHelpers.assert_aligned/2","doc":"","ref":"Raxol.Test.ButtonHelpers.html#assert_aligned/2"},{"type":"function","title":"Raxol.Test.ButtonHelpers.assert_child_received/2","doc":"Asserts that a child component received an event from parent.","ref":"Raxol.Test.ButtonHelpers.html#assert_child_received/2"},{"type":"function","title":"Raxol.Test.ButtonHelpers.assert_error_contained/3","doc":"Verifies that error handling works properly between components.","ref":"Raxol.Test.ButtonHelpers.html#assert_error_contained/3"},{"type":"function","title":"Raxol.Test.ButtonHelpers.assert_matches_snapshot/2","doc":"","ref":"Raxol.Test.ButtonHelpers.html#assert_matches_snapshot/2"},{"type":"function","title":"Raxol.Test.ButtonHelpers.assert_parent_updated/2","doc":"Asserts that a parent component was updated after a child event.","ref":"Raxol.Test.ButtonHelpers.html#assert_parent_updated/2"},{"type":"function","title":"Raxol.Test.ButtonHelpers.assert_renders_with/2","doc":"","ref":"Raxol.Test.ButtonHelpers.html#assert_renders_with/2"},{"type":"function","title":"Raxol.Test.ButtonHelpers.assert_responsive/2","doc":"","ref":"Raxol.Test.ButtonHelpers.html#assert_responsive/2"},{"type":"function","title":"Raxol.Test.ButtonHelpers.assert_state_synchronized/2","doc":"Verifies that state is synchronized between components.","ref":"Raxol.Test.ButtonHelpers.html#assert_state_synchronized/2"},{"type":"function","title":"Raxol.Test.ButtonHelpers.assert_styled_with/2","doc":"","ref":"Raxol.Test.ButtonHelpers.html#assert_styled_with/2"},{"type":"function","title":"Raxol.Test.ButtonHelpers.assert_system_events_handled/2","doc":"Verifies that a component properly handles system events.","ref":"Raxol.Test.ButtonHelpers.html#assert_system_events_handled/2"},{"type":"function","title":"Raxol.Test.ButtonHelpers.assert_theme_consistent/2","doc":"","ref":"Raxol.Test.ButtonHelpers.html#assert_theme_consistent/2"},{"type":"function","title":"Raxol.Test.ButtonHelpers.capture_render/1","doc":"Captures the rendered output of a component.","ref":"Raxol.Test.ButtonHelpers.html#capture_render/1"},{"type":"function","title":"Raxol.Test.ButtonHelpers.matches_box_edges/1","doc":"","ref":"Raxol.Test.ButtonHelpers.html#matches_box_edges/1"},{"type":"function","title":"Raxol.Test.ButtonHelpers.matches_color/3","doc":"","ref":"Raxol.Test.ButtonHelpers.html#matches_color/3"},{"type":"function","title":"Raxol.Test.ButtonHelpers.matches_component/3","doc":"","ref":"Raxol.Test.ButtonHelpers.html#matches_component/3"},{"type":"function","title":"Raxol.Test.ButtonHelpers.matches_layout/3","doc":"","ref":"Raxol.Test.ButtonHelpers.html#matches_layout/3"},{"type":"function","title":"Raxol.Test.ButtonHelpers.matches_style/3","doc":"","ref":"Raxol.Test.ButtonHelpers.html#matches_style/3"},{"type":"function","title":"Raxol.Test.ButtonHelpers.setup_component_hierarchy/2","doc":"Sets up a component hierarchy for testing parent-child interactions.\n\nParameters:\n  - `parent_module`: The parent component module\n  - `child_module`: The child/button component module\n\nReturns:\n  - `{:ok, parent, child}` with initialized components","ref":"Raxol.Test.ButtonHelpers.html#setup_component_hierarchy/2"},{"type":"function","title":"Raxol.Test.ButtonHelpers.setup_isolated_component/2","doc":"Sets up an isolated component for button testing.\n\nParameters:\n  - `module`: The button component module\n  - `props`: Optional properties to initialize the button with\n\nReturns:\n  - `{:ok, button}` with the initialized button component","ref":"Raxol.Test.ButtonHelpers.html#setup_isolated_component/2"},{"type":"function","title":"Raxol.Test.ButtonHelpers.setup_visual_component/2","doc":"Sets up a component for visual testing.","ref":"Raxol.Test.ButtonHelpers.html#setup_visual_component/2"},{"type":"function","title":"Raxol.Test.ButtonHelpers.simulate_event/2","doc":"Simulates a user event on the button.\n\nParameters:\n  - `button`: The button component\n  - `event`: The event to simulate (e.g., click, focus)\n\nReturns:\n  - Updated button and any commands emitted","ref":"Raxol.Test.ButtonHelpers.html#simulate_event/2"},{"type":"function","title":"Raxol.Test.ButtonHelpers.simulate_user_action/2","doc":"Simulates a user action on the button component.\n\nParameters:\n  - `button`: The button component\n  - `action`: The action to simulate","ref":"Raxol.Test.ButtonHelpers.html#simulate_user_action/2"},{"type":"module","title":"Raxol.Test.Integration","doc":"Provides utilities for testing component interactions and system integration.\n\nThis module focuses on testing:\n- Multi-component interactions\n- Event propagation between components\n- State synchronization\n- Terminal I/O simulation\n- Component hierarchy behavior","ref":"Raxol.Test.Integration.html"},{"type":"module","title":"Example - Raxol.Test.Integration","doc":"defmodule MyApp.IntegrationTest do\n      use ExUnit.Case\n      use Raxol.Test.Integration\n\n      test_scenario \"parent-child communication\", %{parent: Parent, child: Child} do\n        # Set up component hierarchy\n        {:ok, parent, child} = setup_component_hierarchy(Parent, Child)\n\n        # Simulate user interaction\n        simulate_user_action(parent, {:click, {10, 10}})\n\n        # Verify component interaction\n        assert_child_received(child, :parent_clicked)\n        assert_parent_updated(parent, :child_responded)\n      end\n    end","ref":"Raxol.Test.Integration.html#module-example"},{"type":"function","title":"Raxol.Test.Integration.assert_handles_system_event/2","doc":"Verifies that a component properly handles a system event.","ref":"Raxol.Test.Integration.html#assert_handles_system_event/2"},{"type":"function","title":"Raxol.Test.Integration.mount_component/2","doc":"Simulates component mounting in the application.","ref":"Raxol.Test.Integration.html#mount_component/2"},{"type":"function","title":"Raxol.Test.Integration.setup_component_hierarchy/3","doc":"Sets up a parent-child component hierarchy for testing.\n\nReturns the initialized parent and child components with proper event routing.","ref":"Raxol.Test.Integration.html#setup_component_hierarchy/3"},{"type":"function","title":"Raxol.Test.Integration.setup_test_scenario/1","doc":"Sets up a test scenario with multiple components.\n\nThis function:\n1. Initializes all components\n2. Sets up event routing\n3. Configures component relationships\n4. Establishes test monitoring","ref":"Raxol.Test.Integration.html#setup_test_scenario/1"},{"type":"function","title":"Raxol.Test.Integration.simulate_user_action/2","doc":"Simulates a user action on a component.\n\nHandles various types of user interactions and ensures proper event propagation.","ref":"Raxol.Test.Integration.html#simulate_user_action/2"},{"type":"macro","title":"Raxol.Test.Integration.test_scenario/3","doc":"","ref":"Raxol.Test.Integration.html#test_scenario/3"},{"type":"function","title":"Raxol.Test.Integration.unmount_component/1","doc":"Simulates component unmounting from the application.","ref":"Raxol.Test.Integration.html#unmount_component/1"},{"type":"module","title":"Raxol.Test.Integration.Assertions","doc":"Provides custom assertions for integration testing of Raxol components.\n\nThis module includes assertions for:\n- Component interaction verification\n- Event propagation validation\n- State synchronization checking\n- Command routing verification\n- Component lifecycle testing","ref":"Raxol.Test.Integration.Assertions.html"},{"type":"function","title":"Raxol.Test.Integration.Assertions.assert_child_received/2","doc":"Asserts that a child component received an event from its parent.","ref":"Raxol.Test.Integration.Assertions.html#assert_child_received/2"},{"type":"function","title":"Example - Raxol.Test.Integration.Assertions.assert_child_received/2","doc":"assert_child_received child, :parent_clicked","ref":"Raxol.Test.Integration.Assertions.html#assert_child_received/2-example"},{"type":"function","title":"Raxol.Test.Integration.Assertions.assert_command_routing/3","doc":"Asserts that commands are properly routed between components.","ref":"Raxol.Test.Integration.Assertions.html#assert_command_routing/3"},{"type":"function","title":"Example - Raxol.Test.Integration.Assertions.assert_command_routing/3","doc":"assert_command_routing source, target, command","ref":"Raxol.Test.Integration.Assertions.html#assert_command_routing/3-example"},{"type":"function","title":"Raxol.Test.Integration.Assertions.assert_error_contained/3","doc":"Asserts that error boundaries contain component failures.","ref":"Raxol.Test.Integration.Assertions.html#assert_error_contained/3"},{"type":"function","title":"Example - Raxol.Test.Integration.Assertions.assert_error_contained/3","doc":"assert_error_contained parent, child, fn ->\n      simulate_user_action(child, :trigger_error)\n    end","ref":"Raxol.Test.Integration.Assertions.html#assert_error_contained/3-example"},{"type":"function","title":"Raxol.Test.Integration.Assertions.assert_event_propagation/3","doc":"Asserts that events are properly propagated through the component hierarchy.","ref":"Raxol.Test.Integration.Assertions.html#assert_event_propagation/3"},{"type":"function","title":"Example - Raxol.Test.Integration.Assertions.assert_event_propagation/3","doc":"assert_event_propagation [parent, child1, child2], event, fn components ->\n      # Verify each component's response\n    end","ref":"Raxol.Test.Integration.Assertions.html#assert_event_propagation/3-example"},{"type":"function","title":"Raxol.Test.Integration.Assertions.assert_hierarchy_valid/2","doc":"Asserts that components are properly connected in a hierarchy.","ref":"Raxol.Test.Integration.Assertions.html#assert_hierarchy_valid/2"},{"type":"function","title":"Example - Raxol.Test.Integration.Assertions.assert_hierarchy_valid/2","doc":"assert_hierarchy_valid parent, [child1, child2]","ref":"Raxol.Test.Integration.Assertions.html#assert_hierarchy_valid/2-example"},{"type":"function","title":"Raxol.Test.Integration.Assertions.assert_lifecycle_handled/2","doc":"Asserts that a component properly handles mounting and unmounting.","ref":"Raxol.Test.Integration.Assertions.html#assert_lifecycle_handled/2"},{"type":"function","title":"Example - Raxol.Test.Integration.Assertions.assert_lifecycle_handled/2","doc":"assert_lifecycle_handled component, fn comp ->\n      mount_component(comp)\n      # Test mounted state\n      unmount_component(comp)\n      # Test unmounted state\n    end","ref":"Raxol.Test.Integration.Assertions.html#assert_lifecycle_handled/2-example"},{"type":"function","title":"Raxol.Test.Integration.Assertions.assert_parent_updated/2","doc":"Asserts that a parent component was updated in response to a child event.","ref":"Raxol.Test.Integration.Assertions.html#assert_parent_updated/2"},{"type":"function","title":"Example - Raxol.Test.Integration.Assertions.assert_parent_updated/2","doc":"assert_parent_updated parent, :child_responded","ref":"Raxol.Test.Integration.Assertions.html#assert_parent_updated/2-example"},{"type":"function","title":"Raxol.Test.Integration.Assertions.assert_state_synchronized/2","doc":"Asserts that component state is synchronized after interactions.","ref":"Raxol.Test.Integration.Assertions.html#assert_state_synchronized/2"},{"type":"function","title":"Example - Raxol.Test.Integration.Assertions.assert_state_synchronized/2","doc":"assert_state_synchronized [comp1, comp2], fn states ->\n      Enum.all?(states, & &1.counter == 0)\n    end","ref":"Raxol.Test.Integration.Assertions.html#assert_state_synchronized/2-example"},{"type":"function","title":"Raxol.Test.Integration.Assertions.assert_system_events_handled/2","doc":"Asserts that a component handles system events without corruption.","ref":"Raxol.Test.Integration.Assertions.html#assert_system_events_handled/2"},{"type":"function","title":"Example - Raxol.Test.Integration.Assertions.assert_system_events_handled/2","doc":"assert_system_events_handled component, [:resize, :focus, :blur]","ref":"Raxol.Test.Integration.Assertions.html#assert_system_events_handled/2-example"},{"type":"module","title":"Raxol.Test.MockApplicationSupervisor","doc":"","ref":"Raxol.Test.MockApplicationSupervisor.html"},{"type":"function","title":"Raxol.Test.MockApplicationSupervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Test.MockApplicationSupervisor.html#child_spec/1"},{"type":"function","title":"Raxol.Test.MockApplicationSupervisor.start_link/1","doc":"","ref":"Raxol.Test.MockApplicationSupervisor.html#start_link/1"},{"type":"module","title":"Raxol.Test.MockTermbox","doc":"Mock implementation of rrex_termbox v2.0.1 for testing environments.\n\nThis module provides stub implementations of all rrex_termbox NIF-based functions\nto allow tests to run in CI environments where a real TTY may not be available.","ref":"Raxol.Test.MockTermbox.html"},{"type":"function","title":"Raxol.Test.MockTermbox.change_cell/6","doc":"","ref":"Raxol.Test.MockTermbox.html#change_cell/6"},{"type":"function","title":"Raxol.Test.MockTermbox.clear/1","doc":"","ref":"Raxol.Test.MockTermbox.html#clear/1"},{"type":"function","title":"Raxol.Test.MockTermbox.height/1","doc":"","ref":"Raxol.Test.MockTermbox.html#height/1"},{"type":"function","title":"Raxol.Test.MockTermbox.init/1","doc":"","ref":"Raxol.Test.MockTermbox.html#init/1"},{"type":"function","title":"Raxol.Test.MockTermbox.present/1","doc":"","ref":"Raxol.Test.MockTermbox.html#present/1"},{"type":"function","title":"Raxol.Test.MockTermbox.select_input_mode/2","doc":"","ref":"Raxol.Test.MockTermbox.html#select_input_mode/2"},{"type":"function","title":"Raxol.Test.MockTermbox.set_cell/5","doc":"","ref":"Raxol.Test.MockTermbox.html#set_cell/5"},{"type":"function","title":"Raxol.Test.MockTermbox.set_cursor/3","doc":"","ref":"Raxol.Test.MockTermbox.html#set_cursor/3"},{"type":"function","title":"Raxol.Test.MockTermbox.set_output_mode/2","doc":"","ref":"Raxol.Test.MockTermbox.html#set_output_mode/2"},{"type":"function","title":"Raxol.Test.MockTermbox.shutdown/1","doc":"","ref":"Raxol.Test.MockTermbox.html#shutdown/1"},{"type":"function","title":"Raxol.Test.MockTermbox.size/0","doc":"","ref":"Raxol.Test.MockTermbox.html#size/0"},{"type":"function","title":"Raxol.Test.MockTermbox.start_link/0","doc":"","ref":"Raxol.Test.MockTermbox.html#start_link/0"},{"type":"function","title":"Raxol.Test.MockTermbox.subscribe/0","doc":"","ref":"Raxol.Test.MockTermbox.html#subscribe/0"},{"type":"function","title":"Raxol.Test.MockTermbox.unsubscribe/0","doc":"","ref":"Raxol.Test.MockTermbox.html#unsubscribe/0"},{"type":"function","title":"Raxol.Test.MockTermbox.width/1","doc":"","ref":"Raxol.Test.MockTermbox.html#width/1"},{"type":"module","title":"Raxol.Test.MockTermbox.Constants","doc":"","ref":"Raxol.Test.MockTermbox.Constants.html"},{"type":"function","title":"Raxol.Test.MockTermbox.Constants.attribute/1","doc":"","ref":"Raxol.Test.MockTermbox.Constants.html#attribute/1"},{"type":"function","title":"Raxol.Test.MockTermbox.Constants.color/1","doc":"","ref":"Raxol.Test.MockTermbox.Constants.html#color/1"},{"type":"function","title":"Raxol.Test.MockTermbox.Constants.event_type/1","doc":"","ref":"Raxol.Test.MockTermbox.Constants.html#event_type/1"},{"type":"function","title":"Raxol.Test.MockTermbox.Constants.key/1","doc":"","ref":"Raxol.Test.MockTermbox.Constants.html#key/1"},{"type":"module","title":"Raxol.Test.Performance","doc":"Provides utilities for performance testing of Raxol components.\n\nThis module includes:\n- Render time benchmarking\n- Memory usage profiling\n- Event handling latency testing\n- Resource utilization tracking","ref":"Raxol.Test.Performance.html"},{"type":"function","title":"Raxol.Test.Performance.measure_event_latency/2","doc":"Measures event handling latency.","ref":"Raxol.Test.Performance.html#measure_event_latency/2"},{"type":"function","title":"Raxol.Test.Performance.measure_memory_usage/2","doc":"Measures memory usage during component operations.","ref":"Raxol.Test.Performance.html#measure_memory_usage/2"},{"type":"function","title":"Raxol.Test.Performance.measure_render_time/2","doc":"Measures the time taken to render a component multiple times.","ref":"Raxol.Test.Performance.html#measure_render_time/2"},{"type":"function","title":"Raxol.Test.Performance.run_benchmark_suite/1","doc":"Runs a benchmark suite for a component.","ref":"Raxol.Test.Performance.html#run_benchmark_suite/1"},{"type":"function","title":"Raxol.Test.Performance.setup_benchmark_component/2","doc":"Sets up a component for performance testing with benchmark configuration.","ref":"Raxol.Test.Performance.html#setup_benchmark_component/2"},{"type":"function","title":"Raxol.Test.Performance.track_resource_utilization/2","doc":"Tracks resource utilization over time.","ref":"Raxol.Test.Performance.html#track_resource_utilization/2"},{"type":"module","title":"Raxol.Test.Performance.Assertions","doc":"Provides assertions for performance testing of Raxol components.\n\nThis module includes assertions for:\n- Render time thresholds\n- Memory usage limits\n- Event latency requirements\n- Resource utilization bounds","ref":"Raxol.Test.Performance.Assertions.html"},{"type":"function","title":"Raxol.Test.Performance.Assertions.assert_event_latency/3","doc":"Asserts that event handling latency stays within acceptable bounds.","ref":"Raxol.Test.Performance.Assertions.html#assert_event_latency/3"},{"type":"function","title":"Example - Raxol.Test.Performance.Assertions.assert_event_latency/3","doc":"assert_event_latency component, :click, under: 10 # milliseconds","ref":"Raxol.Test.Performance.Assertions.html#assert_event_latency/3-example"},{"type":"function","title":"Raxol.Test.Performance.Assertions.assert_memory_usage/3","doc":"Asserts that a component's memory usage stays within specified limits.","ref":"Raxol.Test.Performance.Assertions.html#assert_memory_usage/3"},{"type":"function","title":"Example - Raxol.Test.Performance.Assertions.assert_memory_usage/3","doc":"assert_memory_usage component, fn ->\n      render_with_large_dataset(component)\n    end, under: 1024 * 1024 # 1MB","ref":"Raxol.Test.Performance.Assertions.html#assert_memory_usage/3-example"},{"type":"function","title":"Raxol.Test.Performance.Assertions.assert_no_performance_regression/2","doc":"Asserts that a component's performance hasn't regressed from baseline.","ref":"Raxol.Test.Performance.Assertions.html#assert_no_performance_regression/2"},{"type":"function","title":"Example - Raxol.Test.Performance.Assertions.assert_no_performance_regression/2","doc":"assert_no_performance_regression component, \"button_baseline\"","ref":"Raxol.Test.Performance.Assertions.html#assert_no_performance_regression/2-example"},{"type":"function","title":"Raxol.Test.Performance.Assertions.assert_performance_requirements/2","doc":"Asserts that a component's performance metrics meet all requirements.","ref":"Raxol.Test.Performance.Assertions.html#assert_performance_requirements/2"},{"type":"function","title":"Example - Raxol.Test.Performance.Assertions.assert_performance_requirements/2","doc":"assert_performance_requirements component, %{\n      render_time: 100,\n      memory_usage: 1024 * 1024,\n      event_latency: 10\n    }","ref":"Raxol.Test.Performance.Assertions.html#assert_performance_requirements/2-example"},{"type":"function","title":"Raxol.Test.Performance.Assertions.assert_render_time/3","doc":"Asserts that a component renders within a specified time limit.","ref":"Raxol.Test.Performance.Assertions.html#assert_render_time/3"},{"type":"function","title":"Example - Raxol.Test.Performance.Assertions.assert_render_time/3","doc":"assert_render_time component, fn ->\n      render_iterations(component, 1000)\n    end, under: 100 # milliseconds","ref":"Raxol.Test.Performance.Assertions.html#assert_render_time/3-example"},{"type":"function","title":"Raxol.Test.Performance.Assertions.assert_stable_resource_usage/2","doc":"Asserts that a component's resource utilization remains stable.","ref":"Raxol.Test.Performance.Assertions.html#assert_stable_resource_usage/2"},{"type":"function","title":"Example - Raxol.Test.Performance.Assertions.assert_stable_resource_usage/2","doc":"assert_stable_resource_usage component, duration: 1000","ref":"Raxol.Test.Performance.Assertions.html#assert_stable_resource_usage/2-example"},{"type":"module","title":"Raxol.Test.TestHelper","doc":"Provides common test utilities and setup functions for Raxol tests.\n\nThis module includes:\n- Test environment setup\n- Mock data generation\n- Common test scenarios\n- Cleanup utilities","ref":"Raxol.Test.TestHelper.html"},{"type":"function","title":"Raxol.Test.TestHelper.capture_terminal_output/1","doc":"Captures all terminal output during a test.","ref":"Raxol.Test.TestHelper.html#capture_terminal_output/1"},{"type":"function","title":"Raxol.Test.TestHelper.cleanup_test_env/1","doc":"Cleans up test resources and resets the environment.","ref":"Raxol.Test.TestHelper.html#cleanup_test_env/1"},{"type":"function","title":"Raxol.Test.TestHelper.create_test_component/2","doc":"Creates a test component with the given module and initial state.","ref":"Raxol.Test.TestHelper.html#create_test_component/2"},{"type":"function","title":"Raxol.Test.TestHelper.setup_test_env/0","doc":"Sets up a test environment with all necessary dependencies.\n\nReturns a context map with initialized services.","ref":"Raxol.Test.TestHelper.html#setup_test_env/0"},{"type":"function","title":"Raxol.Test.TestHelper.setup_test_terminal/0","doc":"Creates a mock terminal for testing.","ref":"Raxol.Test.TestHelper.html#setup_test_terminal/0"},{"type":"function","title":"Raxol.Test.TestHelper.simulate_event_sequence/2","doc":"Simulates a sequence of events on a component.","ref":"Raxol.Test.TestHelper.html#simulate_event_sequence/2"},{"type":"function","title":"Raxol.Test.TestHelper.test_events/0","doc":"Generates test events for common scenarios.","ref":"Raxol.Test.TestHelper.html#test_events/0"},{"type":"function","title":"Raxol.Test.TestHelper.test_layouts/0","doc":"Generates test layouts for component positioning.","ref":"Raxol.Test.TestHelper.html#test_layouts/0"},{"type":"function","title":"Raxol.Test.TestHelper.test_styles/0","doc":"Generates test styles for component rendering.","ref":"Raxol.Test.TestHelper.html#test_styles/0"},{"type":"module","title":"Raxol.Test.Unit","doc":"Provides utilities for unit testing Raxol components and modules.\n\nThis module offers a comprehensive set of tools for:\n- Component isolation and testing\n- Event simulation and verification\n- State management testing\n- Render output validation","ref":"Raxol.Test.Unit.html"},{"type":"module","title":"Example - Raxol.Test.Unit","doc":"defmodule MyComponent.Test do\n      use ExUnit.Case\n      use Raxol.Test.Unit\n\n      test_component \"handles keyboard input\", MyComponent do\n        event = keyboard_event(:enter)\n        result = simulate_event(component, event)\n\n        assert_state(component, %{text: \"\"})\n        assert_command_emitted(result, :submit)\n      end\n    end","ref":"Raxol.Test.Unit.html#module-example"},{"type":"function","title":"Raxol.Test.Unit.assert_command_emitted/2","doc":"Asserts that a command was emitted by the component.","ref":"Raxol.Test.Unit.html#assert_command_emitted/2"},{"type":"function","title":"Raxol.Test.Unit.assert_event_handled/3","doc":"Asserts that a specific event was handled by the component.","ref":"Raxol.Test.Unit.html#assert_event_handled/3"},{"type":"function","title":"Raxol.Test.Unit.assert_state/2","doc":"Asserts that a component's state matches the expected state.","ref":"Raxol.Test.Unit.html#assert_state/2"},{"type":"function","title":"Raxol.Test.Unit.custom_event/1","doc":"Creates a custom event for testing.","ref":"Raxol.Test.Unit.html#custom_event/1"},{"type":"function","title":"Raxol.Test.Unit.keyboard_event/1","doc":"Creates a keyboard event for testing.","ref":"Raxol.Test.Unit.html#keyboard_event/1"},{"type":"function","title":"Raxol.Test.Unit.setup_isolated_component/1","doc":"Sets up a component for isolated testing.\n\nThis function:\n1. Creates a mock event system\n2. Initializes the component\n3. Sets up state tracking\n4. Configures test subscriptions","ref":"Raxol.Test.Unit.html#setup_isolated_component/1"},{"type":"function","title":"Raxol.Test.Unit.simulate_event/2","doc":"Simulates an event being sent to a component.\n\nReturns the updated state and any emitted commands.","ref":"Raxol.Test.Unit.html#simulate_event/2"},{"type":"macro","title":"Raxol.Test.Unit.test_component/3","doc":"","ref":"Raxol.Test.Unit.html#test_component/3"},{"type":"function","title":"Raxol.Test.Unit.window_event/3","doc":"Creates a window event for testing.","ref":"Raxol.Test.Unit.html#window_event/3"},{"type":"module","title":"Raxol.Test.Unit.Assertions","doc":"Provides custom assertions for testing Raxol components.\n\nThis module includes assertions for:\n- Component state validation\n- Event handling verification\n- Command emission checking\n- Render output validation\n- Layout verification\n- Style application testing","ref":"Raxol.Test.Unit.Assertions.html"},{"type":"function","title":"Raxol.Test.Unit.Assertions.assert_command_sequence/2","doc":"Asserts that a component emitted specific commands in sequence.","ref":"Raxol.Test.Unit.Assertions.html#assert_command_sequence/2"},{"type":"function","title":"Example - Raxol.Test.Unit.Assertions.assert_command_sequence/2","doc":"assert_command_sequence component, [\n      {:update, :text},\n      {:notify, :changed},\n      {:submit}\n    ]","ref":"Raxol.Test.Unit.Assertions.html#assert_command_sequence/2-example"},{"type":"function","title":"Raxol.Test.Unit.Assertions.assert_handles_error/2","doc":"Asserts that a component properly handles an error condition.","ref":"Raxol.Test.Unit.Assertions.html#assert_handles_error/2"},{"type":"function","title":"Example - Raxol.Test.Unit.Assertions.assert_handles_error/2","doc":"assert_handles_error component, fn ->\n      simulate_event(component, invalid_event())\n    end","ref":"Raxol.Test.Unit.Assertions.html#assert_handles_error/2-example"},{"type":"function","title":"Raxol.Test.Unit.Assertions.assert_layout/2","doc":"Asserts that a component's layout matches the expected constraints.","ref":"Raxol.Test.Unit.Assertions.html#assert_layout/2"},{"type":"function","title":"Example - Raxol.Test.Unit.Assertions.assert_layout/2","doc":"assert_layout component, %{\n      width: 10,\n      height: 5,\n      x: 0,\n      y: 0\n    }","ref":"Raxol.Test.Unit.Assertions.html#assert_layout/2-example"},{"type":"macro","title":"Raxol.Test.Unit.Assertions.assert_rendered/2","doc":"Asserts that a component's rendered output matches the expected output.","ref":"Raxol.Test.Unit.Assertions.html#assert_rendered/2"},{"type":"macro","title":"Example - Raxol.Test.Unit.Assertions.assert_rendered/2","doc":"assert_rendered component, fn output ->\n      assert output.type == :text\n      assert output.content == \"Hello, World!\"\n    end","ref":"Raxol.Test.Unit.Assertions.html#assert_rendered/2-example"},{"type":"function","title":"Raxol.Test.Unit.Assertions.assert_state_history/2","doc":"Asserts that a component's state history includes specific changes.","ref":"Raxol.Test.Unit.Assertions.html#assert_state_history/2"},{"type":"function","title":"Example - Raxol.Test.Unit.Assertions.assert_state_history/2","doc":"assert_state_history component, [\n      %{text: \"\"},\n      %{text: \"Hello\"},\n      %{text: \"Hello, World!\"}\n    ]","ref":"Raxol.Test.Unit.Assertions.html#assert_state_history/2-example"},{"type":"function","title":"Raxol.Test.Unit.Assertions.assert_state_match/2","doc":"","ref":"Raxol.Test.Unit.Assertions.html#assert_state_match/2"},{"type":"function","title":"Raxol.Test.Unit.Assertions.assert_style/2","doc":"Asserts that a style is properly applied to a component.","ref":"Raxol.Test.Unit.Assertions.html#assert_style/2"},{"type":"function","title":"Example - Raxol.Test.Unit.Assertions.assert_style/2","doc":"assert_style component, %{\n      color: :blue,\n      background: :white,\n      bold: true\n    }","ref":"Raxol.Test.Unit.Assertions.html#assert_style/2-example"},{"type":"function","title":"Raxol.Test.Unit.Assertions.assert_subscribed/2","doc":"Asserts that a component has specific subscriptions active.","ref":"Raxol.Test.Unit.Assertions.html#assert_subscribed/2"},{"type":"function","title":"Example - Raxol.Test.Unit.Assertions.assert_subscribed/2","doc":"assert_subscribed component, [:keyboard, :mouse]","ref":"Raxol.Test.Unit.Assertions.html#assert_subscribed/2-example"},{"type":"module","title":"Raxol.Test.Visual","doc":"Provides utilities for visual testing of Raxol components.\n\nThis module handles:\n- Component rendering verification\n- Layout testing\n- Style validation\n- Terminal output comparison\n- Cross-terminal compatibility testing","ref":"Raxol.Test.Visual.html"},{"type":"module","title":"Example - Raxol.Test.Visual","doc":"defmodule MyComponent.VisualTest do\n      use ExUnit.Case\n      use Raxol.Test.Visual\n\n      test \"renders correctly\" do\n        component = setup_visual_component(MyComponent)\n\n        assert_renders_as component, fn output ->\n          assert output =~ \"Expected Content\"\n          assert_layout_matches output, width: 10, height: 5\n        end\n      end\n    end","ref":"Raxol.Test.Visual.html#module-example"},{"type":"function","title":"Raxol.Test.Visual.assert_renders_as/2","doc":"Verifies that a component renders as expected.\n\nTakes a function that can make assertions about the rendered output.","ref":"Raxol.Test.Visual.html#assert_renders_as/2"},{"type":"function","title":"Raxol.Test.Visual.capture_render/1","doc":"Captures the rendered output of a component.\n\nReturns the terminal output as a string for comparison.","ref":"Raxol.Test.Visual.html#capture_render/1"},{"type":"function","title":"Raxol.Test.Visual.compare_with_snapshot/3","doc":"Compares a component's current render with its snapshot.\n\nReturns a detailed diff if there are differences.","ref":"Raxol.Test.Visual.html#compare_with_snapshot/3"},{"type":"function","title":"Raxol.Test.Visual.setup_visual_component/2","doc":"Sets up a component for visual testing.\n\nThis function:\n1. Initializes the component\n2. Sets up the render context\n3. Configures the test terminal\n4. Prepares snapshot directories","ref":"Raxol.Test.Visual.html#setup_visual_component/2"},{"type":"function","title":"Raxol.Test.Visual.snapshot_component/3","doc":"Creates or updates a snapshot of the component's rendered output.\n\nUsed for visual regression testing.","ref":"Raxol.Test.Visual.html#snapshot_component/3"},{"type":"function","title":"Raxol.Test.Visual.test_responsive_rendering/2","doc":"Tests a component's rendering across different terminal sizes.\n\nVerifies responsive behavior and layout adaptability.","ref":"Raxol.Test.Visual.html#test_responsive_rendering/2"},{"type":"function","title":"Raxol.Test.Visual.test_themed_rendering/2","doc":"Tests a component's rendering with different style themes.\n\nVerifies proper style application and theme switching.","ref":"Raxol.Test.Visual.html#test_themed_rendering/2"},{"type":"module","title":"Raxol.Test.Visual.Assertions","doc":"Provides custom assertions for visual testing of Raxol components.\n\nThis module includes assertions for:\n- Component rendering verification\n- Layout validation\n- Style checking\n- Visual regression testing\n- Terminal output comparison","ref":"Raxol.Test.Visual.Assertions.html"},{"type":"function","title":"Raxol.Test.Visual.Assertions.assert_aligned/2","doc":"Asserts that a component's borders and edges align properly.","ref":"Raxol.Test.Visual.Assertions.html#assert_aligned/2"},{"type":"function","title":"Example - Raxol.Test.Visual.Assertions.assert_aligned/2","doc":"assert_aligned component, :all\n    assert_aligned component, [:top, :left]","ref":"Raxol.Test.Visual.Assertions.html#assert_aligned/2-example"},{"type":"function","title":"Raxol.Test.Visual.Assertions.assert_matches_snapshot/3","doc":"Asserts that a component's rendered output matches the expected snapshot.","ref":"Raxol.Test.Visual.Assertions.html#assert_matches_snapshot/3"},{"type":"function","title":"Example - Raxol.Test.Visual.Assertions.assert_matches_snapshot/3","doc":"assert_matches_snapshot(component, \"button_primary\")","ref":"Raxol.Test.Visual.Assertions.html#assert_matches_snapshot/3-example"},{"type":"function","title":"Raxol.Test.Visual.Assertions.assert_renders_with/2","doc":"Asserts that a component renders with the expected content.","ref":"Raxol.Test.Visual.Assertions.html#assert_renders_with/2"},{"type":"function","title":"Example - Raxol.Test.Visual.Assertions.assert_renders_with/2","doc":"assert_renders_with component, \"Expected Content\"","ref":"Raxol.Test.Visual.Assertions.html#assert_renders_with/2-example"},{"type":"function","title":"Raxol.Test.Visual.Assertions.assert_responsive/2","doc":"Asserts that a component renders correctly at different terminal sizes.","ref":"Raxol.Test.Visual.Assertions.html#assert_responsive/2"},{"type":"function","title":"Example - Raxol.Test.Visual.Assertions.assert_responsive/2","doc":"assert_responsive component, [\n      {80, 24},\n      {40, 12},\n      {20, 6}\n    ]","ref":"Raxol.Test.Visual.Assertions.html#assert_responsive/2-example"},{"type":"function","title":"Raxol.Test.Visual.Assertions.assert_styled_with/2","doc":"Asserts that a component's style matches the expected theme.","ref":"Raxol.Test.Visual.Assertions.html#assert_styled_with/2"},{"type":"function","title":"Example - Raxol.Test.Visual.Assertions.assert_styled_with/2","doc":"assert_styled_with component, %{color: :blue, bold: true}","ref":"Raxol.Test.Visual.Assertions.html#assert_styled_with/2-example"},{"type":"function","title":"Raxol.Test.Visual.Assertions.assert_theme_consistent/2","doc":"Asserts that a component renders consistently across different themes.","ref":"Raxol.Test.Visual.Assertions.html#assert_theme_consistent/2"},{"type":"function","title":"Example - Raxol.Test.Visual.Assertions.assert_theme_consistent/2","doc":"assert_theme_consistent component, %{\n      light: light_theme,\n      dark: dark_theme\n    }","ref":"Raxol.Test.Visual.Assertions.html#assert_theme_consistent/2-example"},{"type":"module","title":"Raxol.Test.Visual.Matchers","doc":"Provides pattern matching helpers for visual testing of Raxol components.\n\nThis module includes matchers for:\n- ANSI color and style patterns\n- Terminal layout patterns\n- Border and edge patterns\n- Component structure patterns","ref":"Raxol.Test.Visual.Matchers.html"},{"type":"function","title":"Raxol.Test.Visual.Matchers.matches_alignment/3","doc":"Matches specific text alignment patterns in the output.","ref":"Raxol.Test.Visual.Matchers.html#matches_alignment/3"},{"type":"function","title":"Example - Raxol.Test.Visual.Matchers.matches_alignment/3","doc":"output\n    |> matches_alignment(:left)\n    |> matches_alignment(:right, width: 80)","ref":"Raxol.Test.Visual.Matchers.html#matches_alignment/3-example"},{"type":"function","title":"Raxol.Test.Visual.Matchers.matches_box_edges/1","doc":"Matches box drawing characters in the output.","ref":"Raxol.Test.Visual.Matchers.html#matches_box_edges/1"},{"type":"function","title":"Example - Raxol.Test.Visual.Matchers.matches_box_edges/1","doc":"output\n    |> matches_box_edges()\n    |> matches_box_corners()","ref":"Raxol.Test.Visual.Matchers.html#matches_box_edges/1-example"},{"type":"function","title":"Raxol.Test.Visual.Matchers.matches_color/3","doc":"Matches ANSI color codes in the output.","ref":"Raxol.Test.Visual.Matchers.html#matches_color/3"},{"type":"function","title":"Example - Raxol.Test.Visual.Matchers.matches_color/3","doc":"output\n    |> matches_color(:red, \"Error message\")\n    |> matches_color(:green, \"Success\")","ref":"Raxol.Test.Visual.Matchers.html#matches_color/3-example"},{"type":"function","title":"Raxol.Test.Visual.Matchers.matches_component/3","doc":"Matches specific component patterns in the output.","ref":"Raxol.Test.Visual.Matchers.html#matches_component/3"},{"type":"function","title":"Example - Raxol.Test.Visual.Matchers.matches_component/3","doc":"output\n    |> matches_component(:button, \"Click me\")\n    |> matches_component(:input, placeholder: \"Enter text\")","ref":"Raxol.Test.Visual.Matchers.html#matches_component/3-example"},{"type":"function","title":"Raxol.Test.Visual.Matchers.matches_layout/3","doc":"Matches specific layout patterns in the output.","ref":"Raxol.Test.Visual.Matchers.html#matches_layout/3"},{"type":"function","title":"Example - Raxol.Test.Visual.Matchers.matches_layout/3","doc":"output\n    |> matches_layout(:centered)\n    |> matches_layout(:padded, padding: 2)","ref":"Raxol.Test.Visual.Matchers.html#matches_layout/3-example"},{"type":"function","title":"Raxol.Test.Visual.Matchers.matches_style/3","doc":"Matches ANSI style codes in the output.","ref":"Raxol.Test.Visual.Matchers.html#matches_style/3"},{"type":"function","title":"Example - Raxol.Test.Visual.Matchers.matches_style/3","doc":"output\n    |> matches_style(:bold, \"Important\")\n    |> matches_style(:underline, \"Link\")","ref":"Raxol.Test.Visual.Matchers.html#matches_style/3-example"},{"type":"behaviour","title":"Raxol.UI.Components.Base.Component","doc":"Defines the behavior for UI components in the Raxol system.\n\nThis module provides the core structure for building reusable UI components\nwith lifecycle hooks, state management, and event handling. Components follow\na similar pattern to the main application architecture but at a smaller scale.","ref":"Raxol.UI.Components.Base.Component.html"},{"type":"behaviour","title":"Component Lifecycle - Raxol.UI.Components.Base.Component","doc":"1. `init/1` - Initialize component state with props\n2. `mount/1` - Called when the component is first mounted\n3. `update/2` - Handle messages and update component state\n4. `render/1` - Generate the visual representation of the component\n5. `handle_event/2` - Handle UI events\n6. `unmount/1` - Clean up resources when component is removed","ref":"Raxol.UI.Components.Base.Component.html#module-component-lifecycle"},{"type":"behaviour","title":"Example - Raxol.UI.Components.Base.Component","doc":"defmodule MyComponent do\n      use Raxol.UI.Components.Base.Component\n\n      def init(props) do\n        Map.merge(%{count: 0}, props)\n      end\n\n      def mount(state) do\n        {state, []}\n      end\n\n      def update(:increment, state) do\n        %{state | count: state.count + 1}\n      end\n\n      def render(state) do\n        row do\n          button(label: \"-\", on_click: :decrement)\n          text(\"Count: #{state.count}\")\n          button(label: \"+\", on_click: :increment)\n        end\n      end\n\n      def handle_event({:click, :increment}, state) do\n        {update(:increment, state), []}\n      end\n\n      def handle_event({:click, :decrement}, state) do\n        {%{state | count: state.count - 1}, []}\n      end\n    end","ref":"Raxol.UI.Components.Base.Component.html#module-example"},{"type":"type","title":"Raxol.UI.Components.Base.Component.command/0","doc":"","ref":"Raxol.UI.Components.Base.Component.html#t:command/0"},{"type":"type","title":"Raxol.UI.Components.Base.Component.context/0","doc":"","ref":"Raxol.UI.Components.Base.Component.html#t:context/0"},{"type":"type","title":"Raxol.UI.Components.Base.Component.element/0","doc":"","ref":"Raxol.UI.Components.Base.Component.html#t:element/0"},{"type":"type","title":"Raxol.UI.Components.Base.Component.event/0","doc":"","ref":"Raxol.UI.Components.Base.Component.html#t:event/0"},{"type":"callback","title":"Raxol.UI.Components.Base.Component.handle_event/3","doc":"Handles UI events that occur on the component.\n\nThe context map provides additional event details or UI state.\nReturns the potentially modified state and any commands to execute.","ref":"Raxol.UI.Components.Base.Component.html#c:handle_event/3"},{"type":"callback","title":"Raxol.UI.Components.Base.Component.init/1","doc":"Initializes the component with the given props.\n\nCalled when the component is created. Should merge default values with\nthe provided props to create the initial state.","ref":"Raxol.UI.Components.Base.Component.html#c:init/1"},{"type":"type","title":"Raxol.UI.Components.Base.Component.message/0","doc":"","ref":"Raxol.UI.Components.Base.Component.html#t:message/0"},{"type":"callback","title":"Raxol.UI.Components.Base.Component.mount/1","doc":"Called when the component is mounted in the UI.\n\nThis is where you can set up subscriptions, execute initial commands,\nor perform other setup tasks. Returns the potentially modified state\nand any commands to execute.","ref":"Raxol.UI.Components.Base.Component.html#c:mount/1"},{"type":"type","title":"Raxol.UI.Components.Base.Component.props/0","doc":"","ref":"Raxol.UI.Components.Base.Component.html#t:props/0"},{"type":"callback","title":"Raxol.UI.Components.Base.Component.render/2","doc":"Renders the component based on its current state.\n\nReturns an element tree that will be rendered to the screen. The context\nmap contains theme, layout constraints, etc.","ref":"Raxol.UI.Components.Base.Component.html#c:render/2"},{"type":"type","title":"Raxol.UI.Components.Base.Component.state/0","doc":"","ref":"Raxol.UI.Components.Base.Component.html#t:state/0"},{"type":"callback","title":"Raxol.UI.Components.Base.Component.unmount/1","doc":"Called when the component is being removed from the UI.\n\nUse this to clean up any resources or perform final actions.","ref":"Raxol.UI.Components.Base.Component.html#c:unmount/1"},{"type":"callback","title":"Raxol.UI.Components.Base.Component.update/2","doc":"Updates the component state in response to messages.\n\nSimilar to the application update function, this handles messages sent to\nthe component and returns the new state.","ref":"Raxol.UI.Components.Base.Component.html#c:update/2"},{"type":"module","title":"Raxol.UI.Components.Base.Lifecycle","doc":"Provides component lifecycle hooks and management for UI components.\n\nThis module handles:\n- Component mounting and initialization\n- Update propagation to components\n- Component unmounting and cleanup\n- Lifecycle event tracking","ref":"Raxol.UI.Components.Base.Lifecycle.html"},{"type":"function","title":"Raxol.UI.Components.Base.Lifecycle.add_lifecycle_event/2","doc":"Adds a lifecycle event to the component for debugging purposes.","ref":"Raxol.UI.Components.Base.Lifecycle.html#add_lifecycle_event/2"},{"type":"function","title":"Parameters - Raxol.UI.Components.Base.Lifecycle.add_lifecycle_event/2","doc":"* `component` - The component to add the event to\n* `event` - The lifecycle event to record","ref":"Raxol.UI.Components.Base.Lifecycle.html#add_lifecycle_event/2-parameters"},{"type":"function","title":"Returns - Raxol.UI.Components.Base.Lifecycle.add_lifecycle_event/2","doc":"The component with the added lifecycle event","ref":"Raxol.UI.Components.Base.Lifecycle.html#add_lifecycle_event/2-returns"},{"type":"function","title":"Raxol.UI.Components.Base.Lifecycle.get_lifecycle_events/1","doc":"Gets the lifecycle events recorded for a component.","ref":"Raxol.UI.Components.Base.Lifecycle.html#get_lifecycle_events/1"},{"type":"function","title":"Parameters - Raxol.UI.Components.Base.Lifecycle.get_lifecycle_events/1","doc":"* `component` - The component to get events for","ref":"Raxol.UI.Components.Base.Lifecycle.html#get_lifecycle_events/1-parameters"},{"type":"function","title":"Returns - Raxol.UI.Components.Base.Lifecycle.get_lifecycle_events/1","doc":"List of lifecycle events with timestamps","ref":"Raxol.UI.Components.Base.Lifecycle.html#get_lifecycle_events/1-returns"},{"type":"function","title":"Raxol.UI.Components.Base.Lifecycle.mount/3","doc":"Mounts a component, initializing its state and triggering mount-time effects.","ref":"Raxol.UI.Components.Base.Lifecycle.html#mount/3"},{"type":"function","title":"Parameters - Raxol.UI.Components.Base.Lifecycle.mount/3","doc":"* `component` - The component to mount\n* `props` - Initial properties for the component\n* `context` - The rendering context","ref":"Raxol.UI.Components.Base.Lifecycle.html#mount/3-parameters"},{"type":"function","title":"Returns - Raxol.UI.Components.Base.Lifecycle.mount/3","doc":"The mounted component","ref":"Raxol.UI.Components.Base.Lifecycle.html#mount/3-returns"},{"type":"function","title":"Raxol.UI.Components.Base.Lifecycle.process_event/3","doc":"Processes an event on a component.","ref":"Raxol.UI.Components.Base.Lifecycle.html#process_event/3"},{"type":"function","title":"Parameters - Raxol.UI.Components.Base.Lifecycle.process_event/3","doc":"* `component` - The component to process the event on\n* `event` - The event to process\n* `context` - The event context","ref":"Raxol.UI.Components.Base.Lifecycle.html#process_event/3-parameters"},{"type":"function","title":"Returns - Raxol.UI.Components.Base.Lifecycle.process_event/3","doc":"`{:update, updated_component}` if the component state changed,\n`{:handled, component}` if the event was handled but state didn't change,\n`:passthrough` if the event wasn't handled by the component.","ref":"Raxol.UI.Components.Base.Lifecycle.html#process_event/3-returns"},{"type":"function","title":"Raxol.UI.Components.Base.Lifecycle.render/2","doc":"Renders a component, creating its view representation.\n\nThis is a wrapper around the component's render function that ensures\nconsistent handling of the rendering process.","ref":"Raxol.UI.Components.Base.Lifecycle.html#render/2"},{"type":"function","title":"Parameters - Raxol.UI.Components.Base.Lifecycle.render/2","doc":"* `component` - The component to render\n* `context` - The rendering context","ref":"Raxol.UI.Components.Base.Lifecycle.html#render/2-parameters"},{"type":"function","title":"Returns - Raxol.UI.Components.Base.Lifecycle.render/2","doc":"The rendered view representation and updated component state","ref":"Raxol.UI.Components.Base.Lifecycle.html#render/2-returns"},{"type":"function","title":"Raxol.UI.Components.Base.Lifecycle.unmount/2","doc":"Unmounts a component, allowing it to clean up resources.","ref":"Raxol.UI.Components.Base.Lifecycle.html#unmount/2"},{"type":"function","title":"Parameters - Raxol.UI.Components.Base.Lifecycle.unmount/2","doc":"* `component` - The component to unmount\n* `context` - The rendering context","ref":"Raxol.UI.Components.Base.Lifecycle.html#unmount/2-parameters"},{"type":"function","title":"Returns - Raxol.UI.Components.Base.Lifecycle.unmount/2","doc":"The unmounted component, typically for tracking/debugging only","ref":"Raxol.UI.Components.Base.Lifecycle.html#unmount/2-returns"},{"type":"function","title":"Raxol.UI.Components.Base.Lifecycle.update/3","doc":"Updates a component with new props.","ref":"Raxol.UI.Components.Base.Lifecycle.html#update/3"},{"type":"function","title":"Parameters - Raxol.UI.Components.Base.Lifecycle.update/3","doc":"* `component` - The component to update\n* `props` - New properties to apply\n* `context` - The rendering context","ref":"Raxol.UI.Components.Base.Lifecycle.html#update/3-parameters"},{"type":"function","title":"Returns - Raxol.UI.Components.Base.Lifecycle.update/3","doc":"The updated component","ref":"Raxol.UI.Components.Base.Lifecycle.html#update/3-returns"},{"type":"module","title":"Raxol.UI.Components.Display.Progress","doc":"A progress bar component for displaying completion status.\n\nFeatures:\n* Customizable colors\n* Percentage display option\n* Custom width\n* Animated progress\n* Optional label","ref":"Raxol.UI.Components.Display.Progress.html"},{"type":"type","title":"Raxol.UI.Components.Display.Progress.props/0","doc":"","ref":"Raxol.UI.Components.Display.Progress.html#t:props/0"},{"type":"type","title":"Raxol.UI.Components.Display.Progress.state/0","doc":"","ref":"Raxol.UI.Components.Display.Progress.html#t:state/0"},{"type":"module","title":"Raxol.UI.Components.Display.Table","doc":"A component for displaying tabular data with sorting, filtering, and pagination.","ref":"Raxol.UI.Components.Display.Table.html"},{"type":"type","title":"Raxol.UI.Components.Display.Table.cell/0","doc":"","ref":"Raxol.UI.Components.Display.Table.html#t:cell/0"},{"type":"type","title":"Raxol.UI.Components.Display.Table.header/0","doc":"","ref":"Raxol.UI.Components.Display.Table.html#t:header/0"},{"type":"type","title":"Raxol.UI.Components.Display.Table.headers/0","doc":"","ref":"Raxol.UI.Components.Display.Table.html#t:headers/0"},{"type":"type","title":"Raxol.UI.Components.Display.Table.props/0","doc":"","ref":"Raxol.UI.Components.Display.Table.html#t:props/0"},{"type":"type","title":"Raxol.UI.Components.Display.Table.row/0","doc":"","ref":"Raxol.UI.Components.Display.Table.html#t:row/0"},{"type":"type","title":"Raxol.UI.Components.Display.Table.rows/0","doc":"","ref":"Raxol.UI.Components.Display.Table.html#t:rows/0"},{"type":"type","title":"Raxol.UI.Components.Display.Table.state/0","doc":"","ref":"Raxol.UI.Components.Display.Table.html#t:state/0"},{"type":"type","title":"Raxol.UI.Components.Display.Table.t/0","doc":"","ref":"Raxol.UI.Components.Display.Table.html#t:t/0"},{"type":"module","title":"Raxol.UI.Components.Input.Button","doc":"Button component for interactive UI elements.\n\nThis component provides a clickable button with customizable appearance and behavior.","ref":"Raxol.UI.Components.Input.Button.html"},{"type":"function","title":"Raxol.UI.Components.Input.Button.handle_event/3","doc":"Handles input events for the button component.","ref":"Raxol.UI.Components.Input.Button.html#handle_event/3"},{"type":"function","title":"Parameters - Raxol.UI.Components.Input.Button.handle_event/3","doc":"* `button` - The button component\n* `event` - The input event to handle\n* `context` - The event context","ref":"Raxol.UI.Components.Input.Button.html#handle_event/3-parameters"},{"type":"function","title":"Returns - Raxol.UI.Components.Input.Button.handle_event/3","doc":"`{:update, updated_button}` if the button state changed,\n`{:handled, button}` if the event was handled but state didn't change,\n`:passthrough` if the event wasn't handled by the button.","ref":"Raxol.UI.Components.Input.Button.html#handle_event/3-returns"},{"type":"function","title":"Raxol.UI.Components.Input.Button.init/1","doc":"Initializes the button component state.","ref":"Raxol.UI.Components.Input.Button.html#init/1"},{"type":"function","title":"Raxol.UI.Components.Input.Button.new/1","doc":"Creates a new button component with the given options.","ref":"Raxol.UI.Components.Input.Button.html#new/1"},{"type":"function","title":"Options - Raxol.UI.Components.Input.Button.new/1","doc":"* `:id` - Unique identifier for the button\n* `:label` - Text to display on the button\n* `:on_click` - Function to call when the button is clicked\n* `:disabled` - Whether the button is disabled\n* `:focused` - Whether the button currently has focus (default: false)\n* `:theme` - Theme overrides for the button\n* `:width` - Optional fixed width for the button\n* `:height` - Optional fixed height for the button\n* `:shortcut` - Optional keyboard shortcut for the button\n* `:tooltip` - Optional tooltip text\n* `:role` - Optional semantic role affecting appearance (:primary, :secondary, :danger, :success)","ref":"Raxol.UI.Components.Input.Button.html#new/1-options"},{"type":"function","title":"Returns - Raxol.UI.Components.Input.Button.new/1","doc":"A new button component struct.","ref":"Raxol.UI.Components.Input.Button.html#new/1-returns"},{"type":"function","title":"Raxol.UI.Components.Input.Button.render/2","doc":"Renders the button component based on its current state.","ref":"Raxol.UI.Components.Input.Button.html#render/2"},{"type":"function","title":"Parameters - Raxol.UI.Components.Input.Button.render/2","doc":"* `button` - The button component to render\n* `context` - The rendering context","ref":"Raxol.UI.Components.Input.Button.html#render/2-parameters"},{"type":"function","title":"Returns - Raxol.UI.Components.Input.Button.render/2","doc":"A rendered view representation of the button.","ref":"Raxol.UI.Components.Input.Button.html#render/2-returns"},{"type":"type","title":"Raxol.UI.Components.Input.Button.t/0","doc":"","ref":"Raxol.UI.Components.Input.Button.html#t:t/0"},{"type":"function","title":"Raxol.UI.Components.Input.Button.update/2","doc":"Updates the button component state based on external messages.","ref":"Raxol.UI.Components.Input.Button.html#update/2"},{"type":"module","title":"Raxol.UI.Components.Input.Checkbox","doc":"Checkbox component for toggling boolean values.\n\nThis component provides a selectable checkbox with customizable appearance and behavior.","ref":"Raxol.UI.Components.Input.Checkbox.html"},{"type":"function","title":"Raxol.UI.Components.Input.Checkbox.new/1","doc":"Creates a new checkbox component with the given options.","ref":"Raxol.UI.Components.Input.Checkbox.html#new/1"},{"type":"function","title":"Options - Raxol.UI.Components.Input.Checkbox.new/1","doc":"* `:id` - Unique identifier for the checkbox\n* `:label` - Text to display next to the checkbox\n* `:checked` - Whether the checkbox is checked\n* `:on_change` - Function to call when the checkbox state changes\n* `:disabled` - Whether the checkbox is disabled\n* `:theme` - Theme overrides for the checkbox\n* `:tooltip` - Optional tooltip text\n* `:required` - Whether the checkbox is required\n* `:aria_label` - Accessibility label","ref":"Raxol.UI.Components.Input.Checkbox.html#new/1-options"},{"type":"function","title":"Returns - Raxol.UI.Components.Input.Checkbox.new/1","doc":"A new checkbox component struct.","ref":"Raxol.UI.Components.Input.Checkbox.html#new/1-returns"},{"type":"type","title":"Raxol.UI.Components.Input.Checkbox.t/0","doc":"","ref":"Raxol.UI.Components.Input.Checkbox.html#t:t/0"},{"type":"module","title":"Raxol.UI.Components.Input.SelectList","doc":"A component that allows users to select an option from a list.\n\nAllows single or multiple selections.\n* Supports scrolling for long lists.","ref":"Raxol.UI.Components.Input.SelectList.html"},{"type":"type","title":"Raxol.UI.Components.Input.SelectList.option/0","doc":"","ref":"Raxol.UI.Components.Input.SelectList.html#t:option/0"},{"type":"type","title":"Raxol.UI.Components.Input.SelectList.options/0","doc":"","ref":"Raxol.UI.Components.Input.SelectList.html#t:options/0"},{"type":"type","title":"Raxol.UI.Components.Input.SelectList.props/0","doc":"","ref":"Raxol.UI.Components.Input.SelectList.html#t:props/0"},{"type":"type","title":"Raxol.UI.Components.Input.SelectList.state/0","doc":"","ref":"Raxol.UI.Components.Input.SelectList.html#t:state/0"},{"type":"module","title":"Raxol.UI.Components.Input.TextField","doc":"A text field component for single-line text input.\n\nIt supports validation, placeholders, masks, and styling.","ref":"Raxol.UI.Components.Input.TextField.html"},{"type":"module","title":"Raxol.UI.Components.Input.TextInput","doc":"A text input component for capturing user text input.\n\nFeatures:\n* Customizable placeholder text\n* Value binding\n* Focus handling\n* Character validation\n* Input masking (for password fields)\n* Event callbacks","ref":"Raxol.UI.Components.Input.TextInput.html"},{"type":"function","title":"Raxol.UI.Components.Input.TextInput.handle_event/2","doc":"","ref":"Raxol.UI.Components.Input.TextInput.html#handle_event/2"},{"type":"type","title":"Raxol.UI.Components.Input.TextInput.props/0","doc":"","ref":"Raxol.UI.Components.Input.TextInput.html#t:props/0"},{"type":"function","title":"Raxol.UI.Components.Input.TextInput.render/1","doc":"","ref":"Raxol.UI.Components.Input.TextInput.html#render/1"},{"type":"type","title":"Raxol.UI.Components.Input.TextInput.state/0","doc":"","ref":"Raxol.UI.Components.Input.TextInput.html#t:state/0"},{"type":"module","title":"Raxol.UI.Layout.Containers","doc":"Handles layout calculations for container elements like rows and columns.\n\nThis module is responsible for:\n* Row layout calculations\n* Column layout calculations\n* Flexbox-like distribution of space\n* Gap and alignment handling","ref":"Raxol.UI.Layout.Containers.html"},{"type":"function","title":"Raxol.UI.Layout.Containers.measure_column/2","doc":"Measures the space needed by a column element.","ref":"Raxol.UI.Layout.Containers.html#measure_column/2"},{"type":"function","title":"Parameters - Raxol.UI.Layout.Containers.measure_column/2","doc":"* `column` - The column element to measure\n* `available_space` - The available space for the column","ref":"Raxol.UI.Layout.Containers.html#measure_column/2-parameters"},{"type":"function","title":"Returns - Raxol.UI.Layout.Containers.measure_column/2","doc":"The dimensions of the column: %{width: w, height: h}","ref":"Raxol.UI.Layout.Containers.html#measure_column/2-returns"},{"type":"function","title":"Raxol.UI.Layout.Containers.measure_row/2","doc":"Measures the space needed by a row element.","ref":"Raxol.UI.Layout.Containers.html#measure_row/2"},{"type":"function","title":"Parameters - Raxol.UI.Layout.Containers.measure_row/2","doc":"* `row` - The row element to measure\n* `available_space` - The available space for the row","ref":"Raxol.UI.Layout.Containers.html#measure_row/2-parameters"},{"type":"function","title":"Returns - Raxol.UI.Layout.Containers.measure_row/2","doc":"The dimensions of the row: %{width: w, height: h}","ref":"Raxol.UI.Layout.Containers.html#measure_row/2-returns"},{"type":"function","title":"Raxol.UI.Layout.Containers.process_column/3","doc":"Processes a column element, calculating layout for it and its children.","ref":"Raxol.UI.Layout.Containers.html#process_column/3"},{"type":"function","title":"Parameters - Raxol.UI.Layout.Containers.process_column/3","doc":"* `column` - The column element to process\n* `space` - The available space for the column\n* `acc` - The accumulator for rendered elements","ref":"Raxol.UI.Layout.Containers.html#process_column/3-parameters"},{"type":"function","title":"Returns - Raxol.UI.Layout.Containers.process_column/3","doc":"A list of positioned elements with absolute coordinates.","ref":"Raxol.UI.Layout.Containers.html#process_column/3-returns"},{"type":"function","title":"Raxol.UI.Layout.Containers.process_row/3","doc":"Processes a row element, calculating layout for it and its children.","ref":"Raxol.UI.Layout.Containers.html#process_row/3"},{"type":"function","title":"Parameters - Raxol.UI.Layout.Containers.process_row/3","doc":"* `row` - The row element to process\n* `space` - The available space for the row\n* `acc` - The accumulator for rendered elements","ref":"Raxol.UI.Layout.Containers.html#process_row/3-parameters"},{"type":"function","title":"Returns - Raxol.UI.Layout.Containers.process_row/3","doc":"A list of positioned elements with absolute coordinates.","ref":"Raxol.UI.Layout.Containers.html#process_row/3-returns"},{"type":"module","title":"Raxol.UI.Layout.Engine","doc":"Core layout engine that translates the logical view structure into absolute positions.\n\nThis module is responsible for:\n* Calculating element positions based on available space\n* Resolving layout constraints\n* Managing the layout pipeline","ref":"Raxol.UI.Layout.Engine.html"},{"type":"function","title":"Raxol.UI.Layout.Engine.apply_layout/2","doc":"Applies layout to a view, calculating absolute positions for all elements.","ref":"Raxol.UI.Layout.Engine.html#apply_layout/2"},{"type":"function","title":"Parameters - Raxol.UI.Layout.Engine.apply_layout/2","doc":"* `view` - The view to calculate layout for\n* `dimensions` - Terminal dimensions `%{width: w, height: h}`","ref":"Raxol.UI.Layout.Engine.html#apply_layout/2-parameters"},{"type":"function","title":"Returns - Raxol.UI.Layout.Engine.apply_layout/2","doc":"A list of positioned elements with absolute coordinates.","ref":"Raxol.UI.Layout.Engine.html#apply_layout/2-returns"},{"type":"function","title":"Raxol.UI.Layout.Engine.measure_element/2","doc":"Calculates the intrinsic dimensions (width, height) of an element.\n\nThis function determines the natural size of an element before layout constraints\nare applied. For containers, it might recursively measure children.","ref":"Raxol.UI.Layout.Engine.html#measure_element/2"},{"type":"function","title":"Parameters - Raxol.UI.Layout.Engine.measure_element/2","doc":"* `element` - The element map to measure.\n* `available_space` - Map providing context (e.g., max width).\n- Defaults to an empty map.","ref":"Raxol.UI.Layout.Engine.html#measure_element/2-parameters"},{"type":"function","title":"Returns - Raxol.UI.Layout.Engine.measure_element/2","doc":"A map representing the dimensions: `%{width: integer(), height: integer()}`.","ref":"Raxol.UI.Layout.Engine.html#measure_element/2-returns"},{"type":"function","title":"Raxol.UI.Layout.Engine.process_element/3","doc":"","ref":"Raxol.UI.Layout.Engine.html#process_element/3"},{"type":"module","title":"Raxol.UI.Layout.Grid","doc":"Handles layout calculations for grid UI elements.\n\nThis module is responsible for:\n* Grid-based layout calculations\n* Cell sizing and positioning\n* Column and row spanning elements\n* Grid-specific spacing and constraints","ref":"Raxol.UI.Layout.Grid.html"},{"type":"function","title":"Raxol.UI.Layout.Grid.calculate_grid_cells/2","doc":"Creates grid cell information for a grid layout.","ref":"Raxol.UI.Layout.Grid.html#calculate_grid_cells/2"},{"type":"function","title":"Parameters - Raxol.UI.Layout.Grid.calculate_grid_cells/2","doc":"* `grid_attrs` - The grid attributes\n* `space` - The available space","ref":"Raxol.UI.Layout.Grid.html#calculate_grid_cells/2-parameters"},{"type":"function","title":"Returns - Raxol.UI.Layout.Grid.calculate_grid_cells/2","doc":"A map containing cell dimensions and grid information.","ref":"Raxol.UI.Layout.Grid.html#calculate_grid_cells/2-returns"},{"type":"function","title":"Raxol.UI.Layout.Grid.cell_position/4","doc":"Calculates the position for a cell in the grid.","ref":"Raxol.UI.Layout.Grid.html#cell_position/4"},{"type":"function","title":"Parameters - Raxol.UI.Layout.Grid.cell_position/4","doc":"* `col` - The column index (0-based)\n* `row` - The row index (0-based)\n* `grid_cells` - The grid cell information from `calculate_grid_cells/2`\n* `space` - The base space for the grid","ref":"Raxol.UI.Layout.Grid.html#cell_position/4-parameters"},{"type":"function","title":"Returns - Raxol.UI.Layout.Grid.cell_position/4","doc":"A space map with x, y, width, and height for the cell.","ref":"Raxol.UI.Layout.Grid.html#cell_position/4-returns"},{"type":"function","title":"Raxol.UI.Layout.Grid.measure_grid/2","doc":"Measures the space needed by a grid element.","ref":"Raxol.UI.Layout.Grid.html#measure_grid/2"},{"type":"function","title":"Parameters - Raxol.UI.Layout.Grid.measure_grid/2","doc":"* `grid` - The grid element to measure\n* `available_space` - The available space for the grid","ref":"Raxol.UI.Layout.Grid.html#measure_grid/2-parameters"},{"type":"function","title":"Returns - Raxol.UI.Layout.Grid.measure_grid/2","doc":"The dimensions of the grid: %{width: w, height: h}","ref":"Raxol.UI.Layout.Grid.html#measure_grid/2-returns"},{"type":"function","title":"Raxol.UI.Layout.Grid.process/3","doc":"Processes a grid element, calculating layout for it and its children.","ref":"Raxol.UI.Layout.Grid.html#process/3"},{"type":"function","title":"Parameters - Raxol.UI.Layout.Grid.process/3","doc":"* `grid` - The grid element to process\n* `space` - The available space for the grid\n* `acc` - The accumulator for rendered elements","ref":"Raxol.UI.Layout.Grid.html#process/3-parameters"},{"type":"function","title":"Returns - Raxol.UI.Layout.Grid.process/3","doc":"A list of positioned elements with absolute coordinates.","ref":"Raxol.UI.Layout.Grid.html#process/3-returns"},{"type":"module","title":"Raxol.UI.Layout.Panels","doc":"Handles layout calculations for panel UI elements.\n\nThis module is responsible for:\n* Panel border rendering\n* Panel content layout\n* Panel title positioning\n* Panel-specific spacing and constraints","ref":"Raxol.UI.Layout.Panels.html"},{"type":"function","title":"Raxol.UI.Layout.Panels.measure_panel/2","doc":"Measures the space required by a panel element.","ref":"Raxol.UI.Layout.Panels.html#measure_panel/2"},{"type":"function","title":"Parameters - Raxol.UI.Layout.Panels.measure_panel/2","doc":"* `panel` - The panel element to measure\n* `available_space` - The available space for the panel","ref":"Raxol.UI.Layout.Panels.html#measure_panel/2-parameters"},{"type":"function","title":"Returns - Raxol.UI.Layout.Panels.measure_panel/2","doc":"The dimensions of the panel: %{width: w, height: h}","ref":"Raxol.UI.Layout.Panels.html#measure_panel/2-returns"},{"type":"function","title":"Raxol.UI.Layout.Panels.process/3","doc":"Processes a panel element, calculating layout for it and its children.","ref":"Raxol.UI.Layout.Panels.html#process/3"},{"type":"function","title":"Parameters - Raxol.UI.Layout.Panels.process/3","doc":"* `panel` - The panel element to process\n* `space` - The available space for the panel\n* `acc` - The accumulator for rendered elements","ref":"Raxol.UI.Layout.Panels.html#process/3-parameters"},{"type":"function","title":"Returns - Raxol.UI.Layout.Panels.process/3","doc":"A list of positioned elements with absolute coordinates.","ref":"Raxol.UI.Layout.Panels.html#process/3-returns"},{"type":"module","title":"Raxol.UI.Layout.Table","doc":"Handles measurement and positioning logic for Table elements within the LayoutEngine.","ref":"Raxol.UI.Layout.Table.html"},{"type":"function","title":"Raxol.UI.Layout.Table.measure_and_position/3","doc":"Measures the required space for a table and returns a single positioned table element.","ref":"Raxol.UI.Layout.Table.html#measure_and_position/3"},{"type":"module","title":"Raxol.UI.Renderer","doc":"Translates a positioned element tree into a flat list of renderable cells.\n\nTakes the output of the Layout Engine and converts UI primitives (text, boxes, etc.)\ninto styled characters at specific coordinates.","ref":"Raxol.UI.Renderer.html"},{"type":"type","title":"Raxol.UI.Renderer.cell/0","doc":"","ref":"Raxol.UI.Renderer.html#t:cell/0"},{"type":"type","title":"Raxol.UI.Renderer.positioned_element/0","doc":"","ref":"Raxol.UI.Renderer.html#t:positioned_element/0"},{"type":"function","title":"Raxol.UI.Renderer.render_to_cells/2","doc":"Renders a tree of positioned elements into a list of cells.\n\nArgs:\n  - `elements`: A list or single map representing positioned elements from the Layout Engine.\n  - `theme`: The current theme map (expected %Theme{}).\n\nReturns:\n  - `list(cell())`","ref":"Raxol.UI.Renderer.html#render_to_cells/2"},{"type":"type","title":"Raxol.UI.Renderer.theme/0","doc":"","ref":"Raxol.UI.Renderer.html#t:theme/0"},{"type":"module","title":"Raxol.UI.Rendering.Pipeline","doc":"Manages the rendering pipeline for the UI.","ref":"Raxol.UI.Rendering.Pipeline.html"},{"type":"function","title":"Raxol.UI.Rendering.Pipeline.apply_animation_settings/8","doc":"","ref":"Raxol.UI.Rendering.Pipeline.html#apply_animation_settings/8"},{"type":"module","title":"Raxol.UI.Terminal","doc":"A terminal UI rendering module for Raxol.\n\nThis module provides basic terminal rendering capabilities for Raxol applications,\nwith support for accessibility features, internationalization, and color system\nintegration.","ref":"Raxol.UI.Terminal.html"},{"type":"module","title":"Features - Raxol.UI.Terminal","doc":"- Terminal screen management (clearing, cursor positioning)\n- Text rendering with colors and styles\n- Input handling with support for keyboard shortcuts\n- Basic UI elements (boxes, lines, progress bars)\n- RTL rendering support\n- Accessibility-friendly output formatting","ref":"Raxol.UI.Terminal.html#module-features"},{"type":"function","title":"Raxol.UI.Terminal.clear/0","doc":"Clear the terminal screen.","ref":"Raxol.UI.Terminal.html#clear/0"},{"type":"function","title":"Examples - Raxol.UI.Terminal.clear/0","doc":"iex> Terminal.clear()\n    :ok","ref":"Raxol.UI.Terminal.html#clear/0-examples"},{"type":"function","title":"Raxol.UI.Terminal.move_cursor/2","doc":"Move the cursor to a specific position.","ref":"Raxol.UI.Terminal.html#move_cursor/2"},{"type":"function","title":"Parameters - Raxol.UI.Terminal.move_cursor/2","doc":"* `row` - The row (1-indexed)\n* `col` - The column (1-indexed)","ref":"Raxol.UI.Terminal.html#move_cursor/2-parameters"},{"type":"function","title":"Examples - Raxol.UI.Terminal.move_cursor/2","doc":"iex> Terminal.move_cursor(1, 1)\n    :ok","ref":"Raxol.UI.Terminal.html#move_cursor/2-examples"},{"type":"function","title":"Raxol.UI.Terminal.print/2","doc":"Print text with optional styling.","ref":"Raxol.UI.Terminal.html#print/2"},{"type":"function","title":"Options - Raxol.UI.Terminal.print/2","doc":"* `:color` - The text color (hex string or color name)\n* `:background` - The background color (hex string or color name)\n* `:bold` - Whether to display the text in bold (default: false)\n* `:italic` - Whether to display the text in italic (default: false)\n* `:underline` - Whether to underline the text (default: false)\n* `:dim` - Whether to display the text dimmed (default: false)\n* `:blink` - Whether to make the text blink (default: false)\n* `:rtl` - Whether to render the text right-to-left (default: from I18n)","ref":"Raxol.UI.Terminal.html#print/2-options"},{"type":"function","title":"Examples - Raxol.UI.Terminal.print/2","doc":"iex> Terminal.print(\"Hello\", color: \"#FF0000\", bold: true)\n    :ok","ref":"Raxol.UI.Terminal.html#print/2-examples"},{"type":"function","title":"Raxol.UI.Terminal.print_box/2","doc":"Print a box with content.","ref":"Raxol.UI.Terminal.html#print_box/2"},{"type":"function","title":"Parameters - Raxol.UI.Terminal.print_box/2","doc":"* `content` - The text content to display inside the box\n* `opts` - Styling options","ref":"Raxol.UI.Terminal.html#print_box/2-parameters"},{"type":"function","title":"Options - Raxol.UI.Terminal.print_box/2","doc":"* `:width` - Box width (default: content width + 4)\n* `:height` - Box height (default: content lines + 2)\n* `:border_color` - Color for the border\n* `:title` - Optional title for the box\n* `:title_color` - Color for the title\n* `:centered` - Whether to center the box horizontally (default: false)","ref":"Raxol.UI.Terminal.html#print_box/2-options"},{"type":"function","title":"Examples - Raxol.UI.Terminal.print_box/2","doc":"iex> Terminal.print_box(\"Hello\nWorld\", title: \"Greeting\", border_color: \"#0000FF\")\n    :ok","ref":"Raxol.UI.Terminal.html#print_box/2-examples"},{"type":"function","title":"Raxol.UI.Terminal.print_centered/2","doc":"Print centered text.","ref":"Raxol.UI.Terminal.html#print_centered/2"},{"type":"function","title":"Options - Raxol.UI.Terminal.print_centered/2","doc":"Takes the same options as `print/2`.","ref":"Raxol.UI.Terminal.html#print_centered/2-options"},{"type":"function","title":"Examples - Raxol.UI.Terminal.print_centered/2","doc":"iex> Terminal.print_centered(\"Title\", color: \"#FF0000\", bold: true)\n    :ok","ref":"Raxol.UI.Terminal.html#print_centered/2-examples"},{"type":"function","title":"Raxol.UI.Terminal.print_horizontal_line/1","doc":"Print a horizontal line spanning the terminal width.","ref":"Raxol.UI.Terminal.html#print_horizontal_line/1"},{"type":"function","title":"Options - Raxol.UI.Terminal.print_horizontal_line/1","doc":"* `:char` - The character to use for the line (default: \"─\")\n* Other options are passed to `print/2`","ref":"Raxol.UI.Terminal.html#print_horizontal_line/1-options"},{"type":"function","title":"Examples - Raxol.UI.Terminal.print_horizontal_line/1","doc":"iex> Terminal.print_horizontal_line(char: \"-\", color: \"#CCCCCC\")\n    :ok","ref":"Raxol.UI.Terminal.html#print_horizontal_line/1-examples"},{"type":"function","title":"Raxol.UI.Terminal.println/2","doc":"Print text followed by a newline.\n\nTakes the same options as `print/2`.","ref":"Raxol.UI.Terminal.html#println/2"},{"type":"function","title":"Examples - Raxol.UI.Terminal.println/2","doc":"iex> Terminal.println(\"Hello\", color: \"#FF0000\", bold: true)\n    :ok","ref":"Raxol.UI.Terminal.html#println/2-examples"},{"type":"function","title":"Raxol.UI.Terminal.read_key/1","doc":"Read a keypress from the user.","ref":"Raxol.UI.Terminal.html#read_key/1"},{"type":"function","title":"Options - Raxol.UI.Terminal.read_key/1","doc":"* `:timeout` - Timeout in milliseconds (default: :infinity)","ref":"Raxol.UI.Terminal.html#read_key/1-options"},{"type":"function","title":"Returns - Raxol.UI.Terminal.read_key/1","doc":"* `{:ok, key}` - Where key is the key pressed\n* `:timeout` - If no key was pressed within the timeout\n* `{:error, reason}` - If an error occurred","ref":"Raxol.UI.Terminal.html#read_key/1-returns"},{"type":"function","title":"Examples - Raxol.UI.Terminal.read_key/1","doc":"iex> Terminal.read_key()\n    {:ok, :enter}\n\n    iex> Terminal.read_key(timeout: 1000)\n    :timeout","ref":"Raxol.UI.Terminal.html#read_key/1-examples"},{"type":"module","title":"Raxol.UI.Theming.Colors","doc":"Color management utilities for theme handling.\n\nThis module provides functions for:\n- Converting between color formats\n- Color manipulation (lighten, darken, alpha blend)\n- Calculating color contrast\n- Validating color accessibility","ref":"Raxol.UI.Theming.Colors.html"},{"type":"function","title":"Raxol.UI.Theming.Colors.accessible?/4","doc":"Checks if the contrast ratio between two colors meets accessibility standards.","ref":"Raxol.UI.Theming.Colors.html#accessible?/4"},{"type":"function","title":"Parameters - Raxol.UI.Theming.Colors.accessible?/4","doc":"* `color1` - The first color\n* `color2` - The second color\n* `level` - The WCAG accessibility level to check for (:aa or :aaa)\n* `type` - The text type (:normal or :large)","ref":"Raxol.UI.Theming.Colors.html#accessible?/4-parameters"},{"type":"function","title":"Examples - Raxol.UI.Theming.Colors.accessible?/4","doc":"iex> Colors.accessible?(\"#FFFFFF\", \"#000000\", :aa, :normal)\n    true","ref":"Raxol.UI.Theming.Colors.html#accessible?/4-examples"},{"type":"function","title":"Raxol.UI.Theming.Colors.blend/3","doc":"Blends two colors together with the specified alpha value.","ref":"Raxol.UI.Theming.Colors.html#blend/3"},{"type":"function","title":"Examples - Raxol.UI.Theming.Colors.blend/3","doc":"iex> Colors.blend(\"#FF0000\", \"#0000FF\", 0.5)\n    \"#800080\"","ref":"Raxol.UI.Theming.Colors.html#blend/3-examples"},{"type":"type","title":"Raxol.UI.Theming.Colors.color_hex/0","doc":"","ref":"Raxol.UI.Theming.Colors.html#t:color_hex/0"},{"type":"type","title":"Raxol.UI.Theming.Colors.color_hsl/0","doc":"","ref":"Raxol.UI.Theming.Colors.html#t:color_hsl/0"},{"type":"type","title":"Raxol.UI.Theming.Colors.color_name/0","doc":"","ref":"Raxol.UI.Theming.Colors.html#t:color_name/0"},{"type":"type","title":"Raxol.UI.Theming.Colors.color_rgb/0","doc":"","ref":"Raxol.UI.Theming.Colors.html#t:color_rgb/0"},{"type":"type","title":"Raxol.UI.Theming.Colors.color_rgba/0","doc":"","ref":"Raxol.UI.Theming.Colors.html#t:color_rgba/0"},{"type":"function","title":"Raxol.UI.Theming.Colors.contrast_ratio/2","doc":"Calculates the contrast ratio between two colors.\n\nReturns a value between 1 and 21, with 21 being the highest contrast.","ref":"Raxol.UI.Theming.Colors.html#contrast_ratio/2"},{"type":"function","title":"Examples - Raxol.UI.Theming.Colors.contrast_ratio/2","doc":"iex> Colors.contrast_ratio(\"#FFFFFF\", \"#000000\")\n    21.0","ref":"Raxol.UI.Theming.Colors.html#contrast_ratio/2-examples"},{"type":"function","title":"Raxol.UI.Theming.Colors.convert_to_basic/1","doc":"","ref":"Raxol.UI.Theming.Colors.html#convert_to_basic/1"},{"type":"function","title":"Raxol.UI.Theming.Colors.convert_to_palette/2","doc":"Converts a color or theme map to use a specific palette (e.g., 256 colors).\nFinds the closest color in the palette for each color in the theme.\n*Currently only supports named palettes like :xterm256*","ref":"Raxol.UI.Theming.Colors.html#convert_to_palette/2"},{"type":"function","title":"Raxol.UI.Theming.Colors.darken/2","doc":"Darkens a color by the specified percentage.","ref":"Raxol.UI.Theming.Colors.html#darken/2"},{"type":"function","title":"Examples - Raxol.UI.Theming.Colors.darken/2","doc":"iex> Colors.darken(\"#FF0000\", 20)\n    \"#CC0000\"","ref":"Raxol.UI.Theming.Colors.html#darken/2-examples"},{"type":"function","title":"Raxol.UI.Theming.Colors.find_closest_256_color/1","doc":"Finds the closest ANSI 256-color index (0-255) to the given RGB color.","ref":"Raxol.UI.Theming.Colors.html#find_closest_256_color/1"},{"type":"function","title":"Raxol.UI.Theming.Colors.find_closest_basic_color/1","doc":"Finds the closest ANSI basic color index (0-15) to the given RGB color.","ref":"Raxol.UI.Theming.Colors.html#find_closest_basic_color/1"},{"type":"function","title":"Raxol.UI.Theming.Colors.lighten/2","doc":"Lightens a color by the specified percentage.","ref":"Raxol.UI.Theming.Colors.html#lighten/2"},{"type":"function","title":"Examples - Raxol.UI.Theming.Colors.lighten/2","doc":"iex> Colors.lighten(\"#FF0000\", 20)\n    \"#FF6666\"","ref":"Raxol.UI.Theming.Colors.html#lighten/2-examples"},{"type":"function","title":"Raxol.UI.Theming.Colors.to_hex/1","doc":"Converts RGB values to a hex color string.","ref":"Raxol.UI.Theming.Colors.html#to_hex/1"},{"type":"function","title":"Examples - Raxol.UI.Theming.Colors.to_hex/1","doc":"iex> Colors.to_hex({255, 0, 0})\n    \"#FF0000\"","ref":"Raxol.UI.Theming.Colors.html#to_hex/1-examples"},{"type":"function","title":"Raxol.UI.Theming.Colors.to_rgb/1","doc":"Converts a color from one format to RGB values.","ref":"Raxol.UI.Theming.Colors.html#to_rgb/1"},{"type":"function","title":"Examples - Raxol.UI.Theming.Colors.to_rgb/1","doc":"iex> Colors.to_rgb(\"#FF0000\")\n    {255, 0, 0}\n\n    iex> Colors.to_rgb(:blue)\n    {0, 0, 255}","ref":"Raxol.UI.Theming.Colors.html#to_rgb/1-examples"},{"type":"module","title":"Raxol.UI.Theming.Selector","doc":"A component for selecting and applying themes.\n\nThis module provides:\n* A list-based theme selector UI\n* Theme preview capabilities\n* Theme application functionality\n* Theme management integration","ref":"Raxol.UI.Theming.Selector.html"},{"type":"function","title":"Raxol.UI.Theming.Selector.broadcast/1","doc":"","ref":"Raxol.UI.Theming.Selector.html#broadcast/1"},{"type":"function","title":"Raxol.UI.Theming.Selector.command/1","doc":"","ref":"Raxol.UI.Theming.Selector.html#command/1"},{"type":"function","title":"Raxol.UI.Theming.Selector.mount/1","doc":"","ref":"Raxol.UI.Theming.Selector.html#mount/1"},{"type":"type","title":"Raxol.UI.Theming.Selector.props/0","doc":"","ref":"Raxol.UI.Theming.Selector.html#t:props/0"},{"type":"function","title":"Raxol.UI.Theming.Selector.schedule/2","doc":"","ref":"Raxol.UI.Theming.Selector.html#schedule/2"},{"type":"type","title":"Raxol.UI.Theming.Selector.state/0","doc":"","ref":"Raxol.UI.Theming.Selector.html#t:state/0"},{"type":"type","title":"Raxol.UI.Theming.Selector.t/0","doc":"","ref":"Raxol.UI.Theming.Selector.html#t:t/0"},{"type":"function","title":"Raxol.UI.Theming.Selector.unmount/1","doc":"","ref":"Raxol.UI.Theming.Selector.html#unmount/1"},{"type":"module","title":"Raxol.UI.Theming.Theme","doc":"Defines and manages UI themes for the Raxol system.\n\nThis module provides:\n* Theme definition and registration\n* Default theme settings\n* Theme application to UI elements\n* Color scheme management","ref":"Raxol.UI.Theming.Theme.html"},{"type":"function","title":"Raxol.UI.Theming.Theme.apply_theme/2","doc":"Applies a theme to an element tree.","ref":"Raxol.UI.Theming.Theme.html#apply_theme/2"},{"type":"function","title":"Parameters - Raxol.UI.Theming.Theme.apply_theme/2","doc":"* `element` - The element tree to apply the theme to\n* `theme` - The theme to apply","ref":"Raxol.UI.Theming.Theme.html#apply_theme/2-parameters"},{"type":"function","title":"Returns - Raxol.UI.Theming.Theme.apply_theme/2","doc":"The element tree with theme applied","ref":"Raxol.UI.Theming.Theme.html#apply_theme/2-returns"},{"type":"function","title":"Raxol.UI.Theming.Theme.color/2","doc":"Gets a color from a theme.","ref":"Raxol.UI.Theming.Theme.html#color/2"},{"type":"function","title":"Parameters - Raxol.UI.Theming.Theme.color/2","doc":"* `theme` - The theme to get colors from\n* `color_name` - The name of the color to get","ref":"Raxol.UI.Theming.Theme.html#color/2-parameters"},{"type":"function","title":"Returns - Raxol.UI.Theming.Theme.color/2","doc":"The color value, or a default color if not found","ref":"Raxol.UI.Theming.Theme.html#color/2-returns"},{"type":"function","title":"Raxol.UI.Theming.Theme.component_style/2","doc":"Gets a component style from a theme.","ref":"Raxol.UI.Theming.Theme.html#component_style/2"},{"type":"function","title":"Parameters - Raxol.UI.Theming.Theme.component_style/2","doc":"* `theme` - The theme to get styles from\n* `component_type` - The type of component to get styles for","ref":"Raxol.UI.Theming.Theme.html#component_style/2-parameters"},{"type":"function","title":"Returns - Raxol.UI.Theming.Theme.component_style/2","doc":"A map of style properties for the component, or an empty map if not found","ref":"Raxol.UI.Theming.Theme.html#component_style/2-returns"},{"type":"function","title":"Raxol.UI.Theming.Theme.dark_theme/0","doc":"Gets the dark theme.","ref":"Raxol.UI.Theming.Theme.html#dark_theme/0"},{"type":"function","title":"Returns - Raxol.UI.Theming.Theme.dark_theme/0","doc":"The dark theme struct","ref":"Raxol.UI.Theming.Theme.html#dark_theme/0-returns"},{"type":"function","title":"Raxol.UI.Theming.Theme.default_theme/0","doc":"Gets the default theme.","ref":"Raxol.UI.Theming.Theme.html#default_theme/0"},{"type":"function","title":"Returns - Raxol.UI.Theming.Theme.default_theme/0","doc":"The default theme struct","ref":"Raxol.UI.Theming.Theme.html#default_theme/0-returns"},{"type":"function","title":"Raxol.UI.Theming.Theme.get/1","doc":"Gets a theme by ID.","ref":"Raxol.UI.Theming.Theme.html#get/1"},{"type":"function","title":"Parameters - Raxol.UI.Theming.Theme.get/1","doc":"* `theme_id` - The ID of the theme to retrieve","ref":"Raxol.UI.Theming.Theme.html#get/1-parameters"},{"type":"function","title":"Returns - Raxol.UI.Theming.Theme.get/1","doc":"The theme struct or nil if not found","ref":"Raxol.UI.Theming.Theme.html#get/1-returns"},{"type":"function","title":"Raxol.UI.Theming.Theme.get_color/3","doc":"Gets a color value considering the theme and an optional variant.\n\nLooks up the color in the variant's palette first, then falls back\nto the theme's base palette.","ref":"Raxol.UI.Theming.Theme.html#get_color/3"},{"type":"function","title":"Raxol.UI.Theming.Theme.init/0","doc":"Initializes the theme system.","ref":"Raxol.UI.Theming.Theme.html#init/0"},{"type":"function","title":"Raxol.UI.Theming.Theme.list/0","doc":"Lists all registered themes.","ref":"Raxol.UI.Theming.Theme.html#list/0"},{"type":"function","title":"Returns - Raxol.UI.Theming.Theme.list/0","doc":"A list of theme structs","ref":"Raxol.UI.Theming.Theme.html#list/0-returns"},{"type":"function","title":"Raxol.UI.Theming.Theme.register/1","doc":"Registers a theme for use in the application.","ref":"Raxol.UI.Theming.Theme.html#register/1"},{"type":"function","title":"Parameters - Raxol.UI.Theming.Theme.register/1","doc":"* `theme` - The theme struct to register","ref":"Raxol.UI.Theming.Theme.html#register/1-parameters"},{"type":"function","title":"Returns - Raxol.UI.Theming.Theme.register/1","doc":"`:ok`","ref":"Raxol.UI.Theming.Theme.html#register/1-returns"},{"type":"type","title":"Raxol.UI.Theming.Theme.t/0","doc":"","ref":"Raxol.UI.Theming.Theme.html#t:t/0"},{"type":"type","title":"Raxol.UI.Theming.Theme.theme_variant/0","doc":"","ref":"Raxol.UI.Theming.Theme.html#t:theme_variant/0"},{"type":"module","title":"Raxol.View.Components","doc":"Provides component functions for Raxol views.\n\nThis module contains functions for creating various UI components\nthat can be used in Raxol views.","ref":"Raxol.View.Components.html"},{"type":"function","title":"Raxol.View.Components.button/2","doc":"Creates a button component with options for label, click action, style, and disabled state.","ref":"Raxol.View.Components.html#button/2"},{"type":"function","title":"Options - Raxol.View.Components.button/2","doc":"- `:label` - The button text\n- `:on_click` - Function to call when clicked\n- `:style` - Style options for the button\n- `:disabled` - Whether the button is disabled","ref":"Raxol.View.Components.html#button/2-options"},{"type":"function","title":"Example - Raxol.View.Components.button/2","doc":"button(\"Submit\", on_click: &handle_submit/0, style: [bg: :blue])","ref":"Raxol.View.Components.html#button/2-example"},{"type":"function","title":"Raxol.View.Components.label/2","doc":"Creates a label component with options for text, width, and style.","ref":"Raxol.View.Components.html#label/2"},{"type":"function","title":"Options - Raxol.View.Components.label/2","doc":"- `:width` - Width of the label in characters\n- `:style` - Style options for the label\n- `:align` - Text alignment (:left, :center, :right)","ref":"Raxol.View.Components.html#label/2-options"},{"type":"function","title":"Example - Raxol.View.Components.label/2","doc":"label(\"Username:\", width: 10)\n    label(\"Password:\", width: 10, align: :right)","ref":"Raxol.View.Components.html#label/2-example"},{"type":"function","title":"Raxol.View.Components.space/1","doc":"Creates a space component with options for width and height.","ref":"Raxol.View.Components.html#space/1"},{"type":"function","title":"Options - Raxol.View.Components.space/1","doc":"- `:width` - Width of the space in characters\n- `:height` - Height of the space in lines\n- `:style` - Style options for the space","ref":"Raxol.View.Components.html#space/1-options"},{"type":"function","title":"Example - Raxol.View.Components.space/1","doc":"space(width: 2)\n    space(width: 1, height: 2)","ref":"Raxol.View.Components.html#space/1-example"},{"type":"function","title":"Raxol.View.Components.text/2","doc":"Creates a text component with options for content, style, foreground, and background colors.","ref":"Raxol.View.Components.html#text/2"},{"type":"function","title":"Options - Raxol.View.Components.text/2","doc":"- `:content` - The text content to display\n- `:style` - Style options for the text (font, size, etc.)\n- `:fg` - Foreground color\n- `:bg` - Background color","ref":"Raxol.View.Components.html#text/2-options"},{"type":"function","title":"Example - Raxol.View.Components.text/2","doc":"text(\"Hello World\", style: [bold: true], fg: :blue)","ref":"Raxol.View.Components.html#text/2-example"},{"type":"function","title":"Raxol.View.Components.text_input/1","doc":"Creates a text input component with options for value, placeholder, change action, and style.","ref":"Raxol.View.Components.html#text_input/1"},{"type":"function","title":"Options - Raxol.View.Components.text_input/1","doc":"- `:value` - Current input value\n- `:placeholder` - Placeholder text\n- `:on_change` - Function to call when value changes\n- `:style` - Style options for the input","ref":"Raxol.View.Components.html#text_input/1-options"},{"type":"function","title":"Example - Raxol.View.Components.text_input/1","doc":"text_input(value: name, placeholder: \"Enter your name\", on_change: &handle_name_change/1)","ref":"Raxol.View.Components.html#text_input/1-example"},{"type":"module","title":"Raxol.View.Elements","doc":"Basic UI elements for Raxol views.\n\nThis module defines the core UI elements that can be used\nin Raxol views.","ref":"Raxol.View.Elements.html"},{"type":"macro","title":"Raxol.View.Elements.box/2","doc":"Creates a box container, often used for bordering or grouping.","ref":"Raxol.View.Elements.html#box/2"},{"type":"macro","title":"Options - Raxol.View.Elements.box/2","doc":"* `:style` - Map containing styling attributes (e.g., border, padding)","ref":"Raxol.View.Elements.html#box/2-options"},{"type":"macro","title":"Example - Raxol.View.Elements.box/2","doc":"```elixir\nbox style: %{border: :single, padding: 1} do\n  text content: \"Content inside the box\"\nend\n```","ref":"Raxol.View.Elements.html#box/2-example"},{"type":"macro","title":"Raxol.View.Elements.button/1","doc":"Creates a button that can be clicked.","ref":"Raxol.View.Elements.html#button/1"},{"type":"macro","title":"Options - Raxol.View.Elements.button/1","doc":"* `:label` - The button text\n* `:on_click` - The message to send when clicked","ref":"Raxol.View.Elements.html#button/1-options"},{"type":"macro","title":"Example - Raxol.View.Elements.button/1","doc":"```elixir\nbutton label: \"Click me\", on_click: :button_clicked\n```","ref":"Raxol.View.Elements.html#button/1-example"},{"type":"macro","title":"Raxol.View.Elements.checkbox/1","doc":"Creates a checkbox.","ref":"Raxol.View.Elements.html#checkbox/1"},{"type":"macro","title":"Options - Raxol.View.Elements.checkbox/1","doc":"* `:checked` - Whether the checkbox is checked\n* `:label` - The checkbox label\n* `:on_toggle` - Function to call when toggled","ref":"Raxol.View.Elements.html#checkbox/1-options"},{"type":"macro","title":"Example - Raxol.View.Elements.checkbox/1","doc":"```elixir\ncheckbox checked: model.agreed, label: \"I agree to terms\", on_toggle: fn value -> {:update_agreed, value} end\n```","ref":"Raxol.View.Elements.html#checkbox/1-example"},{"type":"macro","title":"Raxol.View.Elements.column/2","doc":"Creates a column layout for vertical arrangement.","ref":"Raxol.View.Elements.html#column/2"},{"type":"macro","title":"Options - Raxol.View.Elements.column/2","doc":"* `:size` - The column size (1-12)","ref":"Raxol.View.Elements.html#column/2-options"},{"type":"macro","title":"Example - Raxol.View.Elements.column/2","doc":"```elixir\ncolumn size: 6 do\n  label content: \"Half width\"\nend\n```","ref":"Raxol.View.Elements.html#column/2-example"},{"type":"macro","title":"Raxol.View.Elements.input/1","doc":"Creates a text input field.","ref":"Raxol.View.Elements.html#input/1"},{"type":"macro","title":"Options - Raxol.View.Elements.input/1","doc":"* `:value` - The current input value\n* `:cursor` - The cursor position\n* `:focused` - Whether the input is focused\n* `:placeholder` - Placeholder text\n* `:password` - Whether to mask the input (boolean)","ref":"Raxol.View.Elements.html#input/1-options"},{"type":"macro","title":"Raxol.View.Elements.label/1","doc":"Creates a text label.","ref":"Raxol.View.Elements.html#label/1"},{"type":"macro","title":"Options - Raxol.View.Elements.label/1","doc":"* `:content` - The label text\n* Other options are passed as attributes","ref":"Raxol.View.Elements.html#label/1-options"},{"type":"macro","title":"Raxol.View.Elements.panel/2","doc":"Creates a panel with a title and content.","ref":"Raxol.View.Elements.html#panel/2"},{"type":"macro","title":"Options - Raxol.View.Elements.panel/2","doc":"* `:title` - The panel title\n* `:height` - The panel height (optional)\n* `:width` - The panel width (optional)","ref":"Raxol.View.Elements.html#panel/2-options"},{"type":"macro","title":"Example - Raxol.View.Elements.panel/2","doc":"```elixir\npanel title: \"Information\" do\n  label content: \"Some information\"\nend\n```","ref":"Raxol.View.Elements.html#panel/2-example"},{"type":"macro","title":"Raxol.View.Elements.row/2","doc":"Creates a row layout for horizontal arrangement.","ref":"Raxol.View.Elements.html#row/2"},{"type":"macro","title":"Example - Raxol.View.Elements.row/2","doc":"```elixir\nrow do\n  label content: \"Left\"\n  label content: \"Right\"\nend\n```","ref":"Raxol.View.Elements.html#row/2-example"},{"type":"macro","title":"Raxol.View.Elements.table/1","doc":"Creates a table for displaying tabular data.","ref":"Raxol.View.Elements.html#table/1"},{"type":"macro","title":"Options - Raxol.View.Elements.table/1","doc":"* `:headers` - List of column headers\n* `:data` - List of rows, where each row is a list of cells","ref":"Raxol.View.Elements.html#table/1-options"},{"type":"macro","title":"Example - Raxol.View.Elements.table/1","doc":"```elixir\ntable headers: [\"Name\", \"Age\", \"City\"], data: [[\"John\", \"25\", \"New York\"], [\"Jane\", \"30\", \"San Francisco\"]]\n```","ref":"Raxol.View.Elements.html#table/1-example"},{"type":"macro","title":"Raxol.View.Elements.text_input/1","doc":"Creates a text input field.","ref":"Raxol.View.Elements.html#text_input/1"},{"type":"macro","title":"Options - Raxol.View.Elements.text_input/1","doc":"* `:value` - The current input value\n* `:placeholder` - Placeholder text\n* `:on_change` - Function to call when value changes","ref":"Raxol.View.Elements.html#text_input/1-options"},{"type":"macro","title":"Example - Raxol.View.Elements.text_input/1","doc":"```elixir\ntext_input value: model.name, placeholder: \"Enter your name\", on_change: fn value -> {:update_name, value} end\n```","ref":"Raxol.View.Elements.html#text_input/1-example"},{"type":"module","title":"Raxol.View.Layout","doc":"Provides layout functions for Raxol views.\n\nThis module previously contained functions for creating layout components\nthat can be used in Raxol views.\nThese have been superseded by macros in `Raxol.View.Elements`.","ref":"Raxol.View.Layout.html"},{"type":"module","title":"Raxol.Web.Auth.Manager","doc":"Manages authentication state and operations for the Raxol application.","ref":"Raxol.Web.Auth.Manager.html"},{"type":"function","title":"Raxol.Web.Auth.Manager.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Web.Auth.Manager.html#child_spec/1"},{"type":"function","title":"Raxol.Web.Auth.Manager.init/1","doc":"","ref":"Raxol.Web.Auth.Manager.html#init/1"},{"type":"function","title":"Raxol.Web.Auth.Manager.start_link/1","doc":"","ref":"Raxol.Web.Auth.Manager.html#start_link/1"},{"type":"module","title":"Raxol.Web.Manager","doc":"Manages web sessions and terminal connections for the Raxol application.","ref":"Raxol.Web.Manager.html"},{"type":"function","title":"Raxol.Web.Manager.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Web.Manager.html#child_spec/1"},{"type":"function","title":"Raxol.Web.Manager.init/1","doc":"","ref":"Raxol.Web.Manager.html#init/1"},{"type":"function","title":"Raxol.Web.Manager.start_link/1","doc":"","ref":"Raxol.Web.Manager.html#start_link/1"},{"type":"module","title":"Raxol.Web.Session.Cleanup","doc":"Handles session cleanup for Raxol applications.\n\nThis module provides functionality to clean up expired and inactive sessions,\nensuring efficient resource usage and data hygiene.","ref":"Raxol.Web.Session.Cleanup.html"},{"type":"function","title":"Raxol.Web.Session.Cleanup.cleanup_expired_sessions/0","doc":"Clean up expired sessions.","ref":"Raxol.Web.Session.Cleanup.html#cleanup_expired_sessions/0"},{"type":"function","title":"Raxol.Web.Session.Cleanup.cleanup_old_sessions/1","doc":"Clean up old sessions.","ref":"Raxol.Web.Session.Cleanup.html#cleanup_old_sessions/1"},{"type":"function","title":"Raxol.Web.Session.Cleanup.cleanup_orphaned_sessions/0","doc":"Clean up orphaned sessions.","ref":"Raxol.Web.Session.Cleanup.html#cleanup_orphaned_sessions/0"},{"type":"function","title":"Raxol.Web.Session.Cleanup.init/0","doc":"Initialize the session cleanup system.","ref":"Raxol.Web.Session.Cleanup.html#init/0"},{"type":"module","title":"Raxol.Web.Session.Manager","doc":"Manages web sessions for Raxol applications.\n\nThis module provides comprehensive session management capabilities:\n* Session storage and retrieval\n* Session recovery and cleanup\n* Session limits and monitoring\n* Session metadata management","ref":"Raxol.Web.Session.Manager.html"},{"type":"function","title":"Raxol.Web.Session.Manager.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Web.Session.Manager.html#child_spec/1"},{"type":"function","title":"Raxol.Web.Session.Manager.cleanup_sessions/0","doc":"","ref":"Raxol.Web.Session.Manager.html#cleanup_sessions/0"},{"type":"function","title":"Raxol.Web.Session.Manager.create_session/2","doc":"","ref":"Raxol.Web.Session.Manager.html#create_session/2"},{"type":"function","title":"Raxol.Web.Session.Manager.end_session/1","doc":"","ref":"Raxol.Web.Session.Manager.html#end_session/1"},{"type":"function","title":"Raxol.Web.Session.Manager.get_active_sessions/0","doc":"","ref":"Raxol.Web.Session.Manager.html#get_active_sessions/0"},{"type":"function","title":"Raxol.Web.Session.Manager.get_session/1","doc":"","ref":"Raxol.Web.Session.Manager.html#get_session/1"},{"type":"function","title":"Raxol.Web.Session.Manager.start_link/1","doc":"","ref":"Raxol.Web.Session.Manager.html#start_link/1"},{"type":"function","title":"Raxol.Web.Session.Manager.update_session/2","doc":"","ref":"Raxol.Web.Session.Manager.html#update_session/2"},{"type":"module","title":"Raxol.Web.Session.Monitor","doc":"Handles session monitoring for Raxol applications.\n\nThis module provides functionality to monitor active sessions, track usage\npatterns, and detect potential issues.","ref":"Raxol.Web.Session.Monitor.html"},{"type":"function","title":"Raxol.Web.Session.Monitor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Web.Session.Monitor.html#child_spec/1"},{"type":"function","title":"Raxol.Web.Session.Monitor.get_active_users/0","doc":"","ref":"Raxol.Web.Session.Monitor.html#get_active_users/0"},{"type":"function","title":"Raxol.Web.Session.Monitor.get_session_stats/0","doc":"","ref":"Raxol.Web.Session.Monitor.html#get_session_stats/0"},{"type":"function","title":"Raxol.Web.Session.Monitor.start_link/1","doc":"","ref":"Raxol.Web.Session.Monitor.html#start_link/1"},{"type":"module","title":"Raxol.Web.Session.Recovery","doc":"Handles session recovery for Raxol applications.\n\nThis module provides functionality to recover sessions after crashes or\nunexpected terminations, ensuring session continuity and data integrity.","ref":"Raxol.Web.Session.Recovery.html"},{"type":"function","title":"Raxol.Web.Session.Recovery.init/0","doc":"Initialize the session recovery system.","ref":"Raxol.Web.Session.Recovery.html#init/0"},{"type":"function","title":"Raxol.Web.Session.Recovery.recover_session/1","doc":"Recover a specific session.","ref":"Raxol.Web.Session.Recovery.html#recover_session/1"},{"type":"module","title":"Raxol.Web.Session.Session","doc":"Database schema for session storage.","ref":"Raxol.Web.Session.Session.html"},{"type":"function","title":"Raxol.Web.Session.Session.changeset/2","doc":"Creates a changeset for a session.","ref":"Raxol.Web.Session.Session.html#changeset/2"},{"type":"module","title":"Raxol.Web.Session.Storage","doc":"Handles session storage and retrieval for Raxol applications.\n\nThis module provides persistent storage for session data using ETS tables\nand optional database storage for long-term persistence.","ref":"Raxol.Web.Session.Storage.html"},{"type":"function","title":"Raxol.Web.Session.Storage.delete/1","doc":"Delete a session from storage.","ref":"Raxol.Web.Session.Storage.html#delete/1"},{"type":"function","title":"Raxol.Web.Session.Storage.get/1","doc":"Retrieve a session from storage.","ref":"Raxol.Web.Session.Storage.html#get/1"},{"type":"function","title":"Raxol.Web.Session.Storage.get_active_sessions/0","doc":"Get all active sessions.","ref":"Raxol.Web.Session.Storage.html#get_active_sessions/0"},{"type":"function","title":"Raxol.Web.Session.Storage.get_expired_sessions/1","doc":"Get all expired sessions.","ref":"Raxol.Web.Session.Storage.html#get_expired_sessions/1"},{"type":"function","title":"Raxol.Web.Session.Storage.init/0","doc":"Initialize the session storage system.","ref":"Raxol.Web.Session.Storage.html#init/0"},{"type":"function","title":"Raxol.Web.Session.Storage.store/1","doc":"Store a session in the storage system.","ref":"Raxol.Web.Session.Storage.html#store/1"},{"type":"module","title":"Raxol.Web.Supervisor","doc":"Supervisor for web-related processes.","ref":"Raxol.Web.Supervisor.html"},{"type":"function","title":"Raxol.Web.Supervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Raxol.Web.Supervisor.html#child_spec/1"},{"type":"function","title":"Raxol.Web.Supervisor.start_link/1","doc":"","ref":"Raxol.Web.Supervisor.html#start_link/1"},{"type":"module","title":"RaxolWeb","doc":"The entrypoint for defining your web interface, such\nas controllers, components, channels, and so on.\n\nThis can be used in your application as:\n\n    use RaxolWeb, :controller\n    use RaxolWeb, :live_view\n    use RaxolWeb, :live_component\n    use RaxolWeb, :channel\n\nThe definitions below will be executed for every component,\ncontroller, etc, so keep them short and clean, focused\non imports, uses and aliases.","ref":"RaxolWeb.html"},{"type":"macro","title":"RaxolWeb.__using__/1","doc":"When used, dispatch to the appropriate controller/view/etc.","ref":"RaxolWeb.html#__using__/1"},{"type":"function","title":"RaxolWeb.channel/0","doc":"","ref":"RaxolWeb.html#channel/0"},{"type":"function","title":"RaxolWeb.controller/0","doc":"","ref":"RaxolWeb.html#controller/0"},{"type":"function","title":"RaxolWeb.live_component/0","doc":"","ref":"RaxolWeb.html#live_component/0"},{"type":"function","title":"RaxolWeb.live_view/0","doc":"","ref":"RaxolWeb.html#live_view/0"},{"type":"function","title":"RaxolWeb.router/0","doc":"","ref":"RaxolWeb.html#router/0"},{"type":"function","title":"RaxolWeb.static_paths/0","doc":"","ref":"RaxolWeb.html#static_paths/0"},{"type":"function","title":"RaxolWeb.verified_routes/0","doc":"","ref":"RaxolWeb.html#verified_routes/0"},{"type":"function","title":"RaxolWeb.view/0","doc":"","ref":"RaxolWeb.html#view/0"},{"type":"module","title":"RaxolWeb.AccessibilityComponent","doc":"","ref":"RaxolWeb.AccessibilityComponent.html"},{"type":"function","title":"RaxolWeb.AccessibilityComponent.handle_event/3","doc":"","ref":"RaxolWeb.AccessibilityComponent.html#handle_event/3"},{"type":"function","title":"RaxolWeb.AccessibilityComponent.render/1","doc":"","ref":"RaxolWeb.AccessibilityComponent.html#render/1"},{"type":"module","title":"RaxolWeb.AuthPlug","doc":"","ref":"RaxolWeb.AuthPlug.html"},{"type":"function","title":"RaxolWeb.AuthPlug.call/2","doc":"","ref":"RaxolWeb.AuthPlug.html#call/2"},{"type":"function","title":"RaxolWeb.AuthPlug.init/1","doc":"","ref":"RaxolWeb.AuthPlug.html#init/1"},{"type":"module","title":"RaxolWeb.CoreComponents","doc":"Provides core UI components for the Raxol web interface.","ref":"RaxolWeb.CoreComponents.html"},{"type":"function","title":"RaxolWeb.CoreComponents.button/1","doc":"Renders a button with the given text and options.","ref":"RaxolWeb.CoreComponents.html#button/1"},{"type":"function","title":"Attributes - RaxolWeb.CoreComponents.button/1","doc":"* `type` (`:string`) - Defaults to `\"button\"`.\n* `class` (`:string`) - Defaults to `nil`.\n* `disabled` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. Supports all globals plus: `[\"form\", \"name\", \"value\"]`.","ref":"RaxolWeb.CoreComponents.html#button/1-attributes"},{"type":"function","title":"Slots - RaxolWeb.CoreComponents.button/1","doc":"* `inner_block` (required)","ref":"RaxolWeb.CoreComponents.html#button/1-slots"},{"type":"function","title":"RaxolWeb.CoreComponents.flash/1","doc":"Renders a flash message.","ref":"RaxolWeb.CoreComponents.html#flash/1"},{"type":"function","title":"Attributes - RaxolWeb.CoreComponents.flash/1","doc":"* `kind` (`:string`) (required)\n* `title` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted. Supports all globals plus: `[\"phx-click\", \"phx-value\"]`.","ref":"RaxolWeb.CoreComponents.html#flash/1-attributes"},{"type":"function","title":"Slots - RaxolWeb.CoreComponents.flash/1","doc":"* `inner_block` (required)","ref":"RaxolWeb.CoreComponents.html#flash/1-slots"},{"type":"function","title":"RaxolWeb.CoreComponents.form_group/1","doc":"Renders a form group with a label and input.","ref":"RaxolWeb.CoreComponents.html#form_group/1"},{"type":"function","title":"Attributes - RaxolWeb.CoreComponents.form_group/1","doc":"* `name` (`:string`) (required)\n* `label` (`:string`) (required)\n* `type` (`:string`) - Defaults to `\"text\"`.\n* `value` (`:any`)\n* `placeholder` (`:string`) - Defaults to `nil`.\n* `class` (`:string`) - Defaults to `nil`.\n* `disabled` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. Supports all globals plus: `[\"autocomplete\", \"form\", \"required\"]`.","ref":"RaxolWeb.CoreComponents.html#form_group/1-attributes"},{"type":"function","title":"RaxolWeb.CoreComponents.input/1","doc":"Renders a form input with the given type and options.","ref":"RaxolWeb.CoreComponents.html#input/1"},{"type":"function","title":"Attributes - RaxolWeb.CoreComponents.input/1","doc":"* `type` (`:string`) - Defaults to `\"text\"`.\n* `name` (`:string`) (required)\n* `value` (`:any`)\n* `placeholder` (`:string`) - Defaults to `nil`.\n* `class` (`:string`) - Defaults to `nil`.\n* `disabled` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. Supports all globals plus: `[\"autocomplete\", \"form\", \"required\"]`.","ref":"RaxolWeb.CoreComponents.html#input/1-attributes"},{"type":"function","title":"RaxolWeb.CoreComponents.label/1","doc":"Renders a label for a form input.","ref":"RaxolWeb.CoreComponents.html#label/1"},{"type":"function","title":"Attributes - RaxolWeb.CoreComponents.label/1","doc":"* `for` (`:string`) (required)\n* `class` (`:string`) - Defaults to `nil`.","ref":"RaxolWeb.CoreComponents.html#label/1-attributes"},{"type":"function","title":"Slots - RaxolWeb.CoreComponents.label/1","doc":"* `inner_block` (required)","ref":"RaxolWeb.CoreComponents.html#label/1-slots"},{"type":"module","title":"RaxolWeb.Endpoint","doc":"","ref":"RaxolWeb.Endpoint.html"},{"type":"function","title":"RaxolWeb.Endpoint.broadcast/3","doc":"","ref":"RaxolWeb.Endpoint.html#broadcast/3"},{"type":"function","title":"RaxolWeb.Endpoint.broadcast!/3","doc":"","ref":"RaxolWeb.Endpoint.html#broadcast!/3"},{"type":"function","title":"RaxolWeb.Endpoint.broadcast_from/4","doc":"","ref":"RaxolWeb.Endpoint.html#broadcast_from/4"},{"type":"function","title":"RaxolWeb.Endpoint.broadcast_from!/4","doc":"","ref":"RaxolWeb.Endpoint.html#broadcast_from!/4"},{"type":"function","title":"RaxolWeb.Endpoint.call/2","doc":"","ref":"RaxolWeb.Endpoint.html#call/2"},{"type":"function","title":"RaxolWeb.Endpoint.child_spec/1","doc":"Returns the child specification to start the endpoint\nunder a supervision tree.","ref":"RaxolWeb.Endpoint.html#child_spec/1"},{"type":"function","title":"RaxolWeb.Endpoint.config/2","doc":"Returns the endpoint configuration for `key`\n\nReturns `default` if the key does not exist.","ref":"RaxolWeb.Endpoint.html#config/2"},{"type":"function","title":"RaxolWeb.Endpoint.config_change/2","doc":"Reloads the configuration given the application environment changes.","ref":"RaxolWeb.Endpoint.html#config_change/2"},{"type":"function","title":"RaxolWeb.Endpoint.host/0","doc":"Returns the host for the given endpoint.","ref":"RaxolWeb.Endpoint.html#host/0"},{"type":"function","title":"RaxolWeb.Endpoint.init/1","doc":"","ref":"RaxolWeb.Endpoint.html#init/1"},{"type":"function","title":"RaxolWeb.Endpoint.local_broadcast/3","doc":"","ref":"RaxolWeb.Endpoint.html#local_broadcast/3"},{"type":"function","title":"RaxolWeb.Endpoint.local_broadcast_from/4","doc":"","ref":"RaxolWeb.Endpoint.html#local_broadcast_from/4"},{"type":"function","title":"RaxolWeb.Endpoint.path/1","doc":"Generates the path information when routing to this endpoint.","ref":"RaxolWeb.Endpoint.html#path/1"},{"type":"function","title":"RaxolWeb.Endpoint.script_name/0","doc":"Generates the script name.","ref":"RaxolWeb.Endpoint.html#script_name/0"},{"type":"function","title":"RaxolWeb.Endpoint.server_info/1","doc":"Returns the address and port that the server is running on","ref":"RaxolWeb.Endpoint.html#server_info/1"},{"type":"function","title":"RaxolWeb.Endpoint.start_link/1","doc":"Starts the endpoint supervision tree.\n\nAll other options are merged into the endpoint configuration.","ref":"RaxolWeb.Endpoint.html#start_link/1"},{"type":"function","title":"RaxolWeb.Endpoint.static_integrity/1","doc":"Generates a base64-encoded cryptographic hash (sha512) to a static file\nin `priv/static`. Meant to be used for Subresource Integrity with CDNs.","ref":"RaxolWeb.Endpoint.html#static_integrity/1"},{"type":"function","title":"RaxolWeb.Endpoint.static_lookup/1","doc":"Returns a two item tuple with the first item being the `static_path`\nand the second item being the `static_integrity`.","ref":"RaxolWeb.Endpoint.html#static_lookup/1"},{"type":"function","title":"RaxolWeb.Endpoint.static_path/1","doc":"Generates a route to a static file in `priv/static`.","ref":"RaxolWeb.Endpoint.html#static_path/1"},{"type":"function","title":"RaxolWeb.Endpoint.static_url/0","doc":"Generates the static URL without any path information.\n\nIt uses the configuration under `:static_url` to generate\nsuch. It falls back to `:url` if `:static_url` is not set.","ref":"RaxolWeb.Endpoint.html#static_url/0"},{"type":"function","title":"RaxolWeb.Endpoint.struct_url/0","doc":"Generates the endpoint base URL but as a `URI` struct.\n\nIt uses the configuration under `:url` to generate such.\nUseful for manipulating the URL data and passing it to\nURL helpers.","ref":"RaxolWeb.Endpoint.html#struct_url/0"},{"type":"function","title":"RaxolWeb.Endpoint.subscribe/2","doc":"","ref":"RaxolWeb.Endpoint.html#subscribe/2"},{"type":"function","title":"RaxolWeb.Endpoint.unsubscribe/1","doc":"","ref":"RaxolWeb.Endpoint.html#unsubscribe/1"},{"type":"function","title":"RaxolWeb.Endpoint.url/0","doc":"Generates the endpoint base URL without any path information.\n\nIt uses the configuration under `:url` to generate such.","ref":"RaxolWeb.Endpoint.html#url/0"},{"type":"module","title":"RaxolWeb.Gettext","doc":"A module providing Internationalization with a gettext-based API.","ref":"RaxolWeb.Gettext.html"},{"type":"function","title":"RaxolWeb.Gettext.handle_missing_bindings/2","doc":"","ref":"RaxolWeb.Gettext.html#handle_missing_bindings/2"},{"type":"function","title":"RaxolWeb.Gettext.handle_missing_plural_translation/7","doc":"","ref":"RaxolWeb.Gettext.html#handle_missing_plural_translation/7"},{"type":"function","title":"RaxolWeb.Gettext.handle_missing_translation/5","doc":"","ref":"RaxolWeb.Gettext.html#handle_missing_translation/5"},{"type":"module","title":"RaxolWeb.LoginLive","doc":"","ref":"RaxolWeb.LoginLive.html"},{"type":"function","title":"RaxolWeb.LoginLive.render/1","doc":"","ref":"RaxolWeb.LoginLive.html#render/1"},{"type":"module","title":"RaxolWeb.MonitoringLive","doc":"","ref":"RaxolWeb.MonitoringLive.html"},{"type":"function","title":"RaxolWeb.MonitoringLive.render/1","doc":"","ref":"RaxolWeb.MonitoringLive.html#render/1"},{"type":"module","title":"RaxolWeb.PageController","doc":"","ref":"RaxolWeb.PageController.html"},{"type":"function","title":"RaxolWeb.PageController.home/2","doc":"","ref":"RaxolWeb.PageController.html#home/2"},{"type":"module","title":"RaxolWeb.PageLive","doc":"","ref":"RaxolWeb.PageLive.html"},{"type":"function","title":"RaxolWeb.PageLive.handle_event/3","doc":"","ref":"RaxolWeb.PageLive.html#handle_event/3"},{"type":"function","title":"RaxolWeb.PageLive.handle_params/3","doc":"","ref":"RaxolWeb.PageLive.html#handle_params/3"},{"type":"function","title":"RaxolWeb.PageLive.mount/3","doc":"","ref":"RaxolWeb.PageLive.html#mount/3"},{"type":"module","title":"RaxolWeb.PageView","doc":"View module for pages served by PageController.","ref":"RaxolWeb.PageView.html"},{"type":"module","title":"RaxolWeb.Router","doc":"","ref":"RaxolWeb.Router.html"},{"type":"function","title":"RaxolWeb.Router.api/2","doc":"","ref":"RaxolWeb.Router.html#api/2"},{"type":"function","title":"RaxolWeb.Router.auth/2","doc":"","ref":"RaxolWeb.Router.html#auth/2"},{"type":"function","title":"RaxolWeb.Router.browser/2","doc":"","ref":"RaxolWeb.Router.html#browser/2"},{"type":"function","title":"RaxolWeb.Router.call/2","doc":"Callback invoked by Plug on every request.","ref":"RaxolWeb.Router.html#call/2"},{"type":"function","title":"RaxolWeb.Router.init/1","doc":"Callback required by Plug that initializes the router\nfor serving web requests.","ref":"RaxolWeb.Router.html#init/1"},{"type":"module","title":"RaxolWeb.SettingsLive","doc":"","ref":"RaxolWeb.SettingsLive.html"},{"type":"function","title":"RaxolWeb.SettingsLive.render/1","doc":"","ref":"RaxolWeb.SettingsLive.html#render/1"},{"type":"module","title":"RaxolWeb.Telemetry","doc":"","ref":"RaxolWeb.Telemetry.html"},{"type":"function","title":"RaxolWeb.Telemetry.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"RaxolWeb.Telemetry.html#child_spec/1"},{"type":"function","title":"RaxolWeb.Telemetry.metrics/0","doc":"","ref":"RaxolWeb.Telemetry.html#metrics/0"},{"type":"function","title":"RaxolWeb.Telemetry.start_link/1","doc":"","ref":"RaxolWeb.Telemetry.html#start_link/1"},{"type":"module","title":"RaxolWeb.TerminalChannel","doc":"WebSocket channel for real-time terminal communication.\n\nThis channel handles:\n- Terminal session initialization\n- Real-time input/output\n- Terminal resizing\n- Session management\n- Error handling","ref":"RaxolWeb.TerminalChannel.html"},{"type":"function","title":"RaxolWeb.TerminalChannel.child_spec/1","doc":"","ref":"RaxolWeb.TerminalChannel.html#child_spec/1"},{"type":"function","title":"RaxolWeb.TerminalChannel.start_link/1","doc":"","ref":"RaxolWeb.TerminalChannel.html#start_link/1"},{"type":"type","title":"RaxolWeb.TerminalChannel.t/0","doc":"","ref":"RaxolWeb.TerminalChannel.html#t:t/0"},{"type":"module","title":"RaxolWeb.TerminalLive","doc":"LiveView component for the terminal interface.\n\nThis component provides:\n- Terminal rendering\n- Input handling\n- Resize management\n- Theme customization\n- Scroll management\n- Session management","ref":"RaxolWeb.TerminalLive.html"},{"type":"module","title":"RaxolWeb.ThemeToggleComponent","doc":"","ref":"RaxolWeb.ThemeToggleComponent.html"},{"type":"function","title":"RaxolWeb.ThemeToggleComponent.handle_event/3","doc":"","ref":"RaxolWeb.ThemeToggleComponent.html#handle_event/3"},{"type":"function","title":"RaxolWeb.ThemeToggleComponent.render/1","doc":"","ref":"RaxolWeb.ThemeToggleComponent.html#render/1"},{"type":"module","title":"RaxolWeb.UserAuth","doc":"Provides authentication plugs and helpers.","ref":"RaxolWeb.UserAuth.html"},{"type":"function","title":"RaxolWeb.UserAuth.fetch_current_user/2","doc":"Authenticates the user by looking into the session\nand remember me token.","ref":"RaxolWeb.UserAuth.html#fetch_current_user/2"},{"type":"function","title":"RaxolWeb.UserAuth.log_in_user/3","doc":"Logs the user in.\n\nIt renews the session ID and clears the whole session\nto avoid fixation attacks. See the renew_session\nfunction to customize this behaviour.\n\nIt also sets a `:live_socket_id` key in the session,\nso LiveView sessions are identified and automatically\ndisconnected on log out. The line can be safely removed\nif you are not using LiveView.","ref":"RaxolWeb.UserAuth.html#log_in_user/3"},{"type":"function","title":"RaxolWeb.UserAuth.log_out_user/1","doc":"Logs the user out.\n\nIt clears all session data for safety. See renew_session.","ref":"RaxolWeb.UserAuth.html#log_out_user/1"},{"type":"function","title":"RaxolWeb.UserAuth.redirect_if_user_is_authenticated/2","doc":"Used for routes that require the user to not be authenticated.","ref":"RaxolWeb.UserAuth.html#redirect_if_user_is_authenticated/2"},{"type":"function","title":"RaxolWeb.UserAuth.require_authenticated_user/2","doc":"Used for routes that require the user to be authenticated.\n\nIf you want to enforce the user email is confirmed before\nthey use the application at all, here would be a good place.","ref":"RaxolWeb.UserAuth.html#require_authenticated_user/2"},{"type":"module","title":"RaxolWeb.UserRegistrationController","doc":"Handles user registration.","ref":"RaxolWeb.UserRegistrationController.html"},{"type":"function","title":"RaxolWeb.UserRegistrationController.create/2","doc":"","ref":"RaxolWeb.UserRegistrationController.html#create/2"},{"type":"function","title":"RaxolWeb.UserRegistrationController.new/2","doc":"","ref":"RaxolWeb.UserRegistrationController.html#new/2"},{"type":"module","title":"RaxolWeb.UserSessionController","doc":"Handles user session management (login/logout).","ref":"RaxolWeb.UserSessionController.html"},{"type":"function","title":"RaxolWeb.UserSessionController.create/2","doc":"","ref":"RaxolWeb.UserSessionController.html#create/2"},{"type":"function","title":"RaxolWeb.UserSessionController.delete/2","doc":"","ref":"RaxolWeb.UserSessionController.html#delete/2"},{"type":"function","title":"RaxolWeb.UserSessionController.new/2","doc":"","ref":"RaxolWeb.UserSessionController.html#new/2"},{"type":"extras","title":"Raxol","doc":"# Raxol\n\n[![Hex pm](https://img.shields.io/hexpm/v/raxol.svg)](https://hex.pm/packages/raxol)\n[![License](https://img.shields.io/badge/License-MIT-blue.svg)](LICENSE.md)\n[![GitHub Actions CI](https://github.com/Hydepwns/raxol/actions/workflows/ci.yml/badge.svg)](https://github.com/Hydepwns/raxol/actions/workflows/ci.yml)\n\nA terminal application toolkit for Elixir, providing components and a runtime for building interactive TUI applications.\n\n> **Note:** Raxol is actively developed (pre-1.0). APIs may evolve.\n\n<!-- TODO: Add a screenshot or GIF demo here -->","ref":"readme.html"},{"type":"extras","title":"Features - Raxol","doc":"- **Component Model:** Build UIs with reusable components (`Raxol.Core.Runtime.Application` behaviour).\n- **Declarative View DSL:** Define UIs using `Raxol.View.Elements` macros (`box`, `text`, etc.).\n- **Layout System:** Arrange components using flexible layouts (`panel`, `row`, `column`).\n- **Theming:** Customize appearance with themes via `Raxol.Core.ColorSystem`.\n- **User Preferences:** Persist settings across sessions (`Raxol.Core.UserPreferences`).\n- **Plugin System:** Extend functionality with custom plugins (`Raxol.Core.Runtime.Plugins`).\n- **Terminal Handling:** Robust ANSI/Sixel processing, input handling, double buffering with NIF-based termbox integration.","ref":"readme.html#features"},{"type":"extras","title":"Installation - Raxol","doc":"Add `raxol` to `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:raxol, \"~> 0.1.0\"} # Check Hex for the latest version\n  ]\nend\n```\n\nThen run `mix deps.get`. See [Development Setup](docs/development/DevelopmentSetup.md) for more.","ref":"readme.html#installation"},{"type":"extras","title":"Getting Started - Raxol","doc":"```elixir\ndefmodule MyApp do\n  use Raxol.Core.Runtime.Application # Use the Application behaviour\n  import Raxol.View.Elements         # Import View DSL macros\n\n  @impl true\n  def init(_context), do: {:ok, %{count: 0}} # Initial state\n\n  @impl true\n  def update(message, state) do\n    # Handle UI events (:increment, :decrement)\n    new_state =\n      case message do\n        :increment -> Map.update!(state, :count, &(&1 + 1))\n        :decrement -> Map.update!(state, :count, &(&1 - 1))\n        _ -> state\n      end\n    {:ok, new_state, []} # Return new state, no commands\n  end\n\n  @impl true\n  def view(state) do\n    # Render UI based on state\n    view do\n      panel title: \"Counter\" do\n        row do\n          button(label: \"-\", on_click: :decrement)\n          text(content: \"Count: \\#{state.count}\") # No padding needed\n          button(label: \"+\", on_click: :increment)\n        end\n      end\n    end\n  end\n\n  # Optional callbacks: handle_event/1, handle_tick/1, subscriptions/1\nend\n\n# Typically started via Supervisor or:\n# Raxol.Core.Runtime.Lifecycle.start_application(MyApp)\n```\n\nSee [Getting Started Tutorial](docs/guides/quick_start.md) and `/examples` for more.","ref":"readme.html#getting-started"},{"type":"extras","title":"Documentation - Raxol","doc":"Main documentation index: [docs/README.md](docs/README.md)\n\n- [Architecture Overview](docs/ARCHITECTURE.md)\n- [CHANGELOG](docs/development/changes/CHANGELOG.md)\n- [UI Components & Layout](docs/guides/components/README.md)\n- [Async Operations](docs/guides/async_operations.md)\n- [Runtime Options](docs/guides/runtime_options.md)\n- [Terminal Details](docs/development/terminal/README.md)\n- [Development Setup](docs/development/DevelopmentSetup.md)","ref":"readme.html#documentation"},{"type":"extras","title":"Development - Raxol","doc":"See [Development Setup](docs/development/DevelopmentSetup.md).\n\n> **Note:** The project recently completed a major refactoring. See `CHANGELOG.md` and `docs/development/planning/handoff_prompt.md` for context.\n\nCommon commands:\n\n```bash\nmix deps.get\nmix test\nmix credo\nmix dialyzer\nmix compile # Use --warnings-as-errors for stricter checks\nmix format\n```\n\nHelper scripts are in `/scripts` ([Scripts README](scripts/README.md)).\n\nGitHub Actions details: [.github/workflows/README.md](.github/workflows/README.md).","ref":"readme.html#development"},{"type":"extras","title":"Project Structure - Raxol","doc":"- `/assets` -> Processed web assets -> `/priv/static`\n- `/docker` -> Docker configs (`act`)\n- `/docs` -> Guides, development notes, architecture\n- `/examples` -> Sample code\n- `/extensions` -> IDE integrations (VS Code)\n- `/lib` -> Core Elixir code (`raxol/core`, `raxol/ui`, `raxol/terminal`, etc.)\n- `/priv` -> Compiled assets (`priv/static`), themes, plugins\n- `/scripts` -> Development helper scripts\n- `/test` -> Test suites","ref":"readme.html#project-structure"},{"type":"extras","title":"License - Raxol","doc":"MIT - see [LICENSE](LICENSE.md).","ref":"readme.html#license"},{"type":"extras","title":"quick_start","doc":"---\ntitle: Quick Start Guide\ndescription: Create your first Raxol application\ndate: 2025-04-27\nauthor: Raxol Team\nsection: guides\ntags: [quick start, guide, tutorial, application, components]\n---\n\n# Quick Start Guide: Your First Raxol App\n\nThis guide walks you through creating a simple stateful counter application using Raxol.","ref":"quick_start.html"},{"type":"extras","title":"Prerequisites - quick_start","doc":"Before you start, ensure you have:\n\n1. **Elixir installed:** Raxol requires Elixir. You can find installation instructions on the [official Elixir website](https://elixir-lang.org/install.html).\n2. **A new Mix project (optional):** If you don't have a project, create one:\n\n   ```bash\n   mix new my_raxol_app\n   cd my_raxol_app\n   ```","ref":"quick_start.html#prerequisites"},{"type":"extras","title":"1. Add Raxol Dependency - quick_start","doc":"First, add `raxol` to your project's dependencies. Open your `mix.exs` file and update the `deps` function:\n\n```elixir\ndef deps do\n  [\n    {:raxol, \"~> 0.1.0\"}\n    # Or {:raxol, github: \"Hydepwns/raxol\"} for the latest code\n  ]\nend\n```\n\nThen, fetch the dependency:\n\n```bash\nmix deps.get\n```\n\nFor more details, see the [Development Setup](../development/DevelopmentSetup.md).","ref":"quick_start.html#1-add-raxol-dependency"},{"type":"extras","title":"2. Create Your Application Module - quick_start","doc":"Create a new Elixir file, for example, `lib/my_raxol_app/application.ex`, and define your application module. This module will use `Raxol.Core.Runtime.Application` and implement the `render/1` callback to define the user interface.\n\nRaxol offers two primary ways to define your UI within the `render/1` function:\n\n**Method 1: Using the HEEx Sigil (`~H`)**\n\nThis approach uses a syntax similar to HTML and is often convenient for static structures or when integrating with HEEx templates.\n\n```elixir\n# lib/my_raxol_app/application.ex\ndefmodule MyRaxolApp.Application do\n  use Raxol.Core.Runtime.Application\n\n  # The render/1 callback defines the UI.\n  # It receives assigns (data) and must return rendered content.\n  @impl true\n  def render(assigns) do\n    ~H\"\"\"\n     \n       Hello from HEEx! \n     \n    \"\"\"\n  end\nend\n```\n\n- `use Raxol.Core.Runtime.Application`: Imports necessary functions and defines the behaviour for a Raxol application.\n- `@impl true def render(assigns)`: Implements the required callback to define the UI structure.\n- `~H\"\"\" ... \"\"\"`: The HEEx sigil defines the component-based UI using HTML-like tags.\n\n**Method 2: Using `Raxol.View` and Component Functions**\n\nThis approach uses standard Elixir function calls for components, often providing more flexibility for programmatically building complex UIs. Many examples in the `/examples` directory use this method.\n\n```elixir\n# lib/my_raxol_app/application_view.ex\ndefmodule MyRaxolApp.ApplicationView do\n  use Raxol.Core.Runtime.Application\n  use Raxol.View # Use Raxol.View for this approach\n  import Raxol.View.Elements # Optional: Import elements for cleaner calls\n\n  @impl true\n  def render(assigns) do\n    # Use the view macro and nested component functions\n    view do\n      box border: :single, padding: 1 do\n        text content: \"Hello from Raxol.View!\", color: :cyan, attributes: [:bold]\n      end\n    end\n  end\nend\n\n```\n\n- `use Raxol.View`: Required to enable the `view` macro and component function syntax.\n- `import Raxol.View.Elements`: Allows calling components like `box` and `text` directly, otherwise you might need `Raxol.View.Elements.box(...)`.\n- `view do ... end`: A macro block containing nested component function calls (e.g., `box(...)`, `text(...)`). Note that attributes are passed as keyword lists or maps.\n\nChoose the method that best suits your needs or project style. Both achieve the same goal of defining the UI.","ref":"quick_start.html#2-create-your-application-module"},{"type":"extras","title":"2.5 Adding State and Interactivity (init, update) - quick_start","doc":"Static UIs are useful, but most terminal applications need to manage state and respond to user input. Raxol handles this using the `init/1` and `update/2` callbacks, inspired by the Elm Architecture.\n\n**1. Initialize State with `init/1`**\n\nThe `init/1` callback is called once when the application starts. It should return the initial state of your application.\n\n**2. Handle Messages with `update/2`**\n\nThe `update/2` callback is triggered when a message is sent to your application (e.g., from a button click or a subscription). It receives the message and the current state, and returns the _new_ state. Optionally, it can also return a `Command` for executing background tasks (see `examples/advanced/commands.exs`).\n\n**3. Render State in `render/1`**\n\nThe `render/1` callback receives the current state (as `assigns`) and uses it to draw the UI.\n\n**Example: A Simple Counter**\n\nLet's modify our application to be a counter. We'll use the `Raxol.View` method here for illustration.\n\n```elixir\n# lib/my_raxol_app/counter.ex\ndefmodule MyRaxolApp.Counter do\n  use Raxol.Core.Runtime.Application\n  use Raxol.View\n  import Raxol.View.Elements\n\n  # 1. Define the initial state\n  @impl true\n  def init(_context), do: %{count: 0}\n\n  # 2. Handle messages to update the state\n  @impl true\n  def update(model, message) do\n    case message do\n      :increment ->\n        %{model | count: model.count + 1}\n      _ ->\n        model # Return the unchanged model for other messages\n    end\n  end\n\n  # 3. Render the UI based on the current state\n  @impl true\n  def render(assigns) do\n    view do\n      box border: :single, padding: 1 do\n        # Display the current count from assigns (state)\n        text content: \"Count: \\#{assigns.count}\"\n        # Add a button that sends the :increment message when clicked\n        button label: \"Increment\", on_click: :increment\n      end\n    end\n  end\nend\n```\n\n- `init/1` returns the initial state `%{count: 0}`.\n- `update/2` handles the `:increment` message by returning a new state map with the count increased.\n- `render/1` now uses `assigns.count` to display the value and includes a ` ` component.\n- The `button` has an `on_click: :increment` attribute. When clicked, Raxol sends the `:increment` message to the `update/2` function.\n\n**Subscriptions (`subscribe/1`)**\n\nFor handling external events like timers or keyboard events not tied to specific components, you can implement the `subscribe/1` callback. It returns subscriptions that send messages to `update/2`. See `examples/basic/subscriptions.exs` for details and the [Async Operations Guide](async_operations.md) for a full explanation.","ref":"quick_start.html#2-5-adding-state-and-interactivity-init-update"},{"type":"extras","title":"3. Start the Application - quick_start","doc":"To run your application, you can start it directly in `iex` using the new `Lifecycle` module:\n\n```elixir\n  Raxol.Core.Runtime.Lifecycle.start_application(MyRaxolApp.Counter)\n# {:ok, #PID<0.xxx.0>}\n```\n\nFor long-running applications, you'll typically add the `Raxol.Core.Runtime.Application` to your application's supervision tree (e.g., in `lib/my_raxol_app/application.ex` if you used `mix new --sup`):\n\n```elixir\ndefmodule MyRaxolApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    children = [\n      # Other children...\n      {Raxol.Core.Runtime.Application, app: MyRaxolApp.Counter} # Use the module defined previously\n    ]\n\n    opts = [strategy: :one_for_one, name: MyRaxolApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\nMake sure `MyRaxolApp.Application` is listed in your `mix.exs` `application/0` function.","ref":"quick_start.html#3-start-the-application"},{"type":"extras","title":"Next Steps - quick_start","doc":"Congratulations! You've built and run your first Raxol application.\n\n- Explore the different built-in [UI Components](components.md).\n- Dive deeper into [Asynchronous Operations (Subscriptions & Commands)](async_operations.md).\n- Configure the application startup using [Runtime Options](runtime_options.md).\n- Check out the `/examples` directory in the Raxol repository for more advanced use cases.","ref":"quick_start.html#next-steps"},{"type":"extras","title":"vscode_extension","doc":"---\ntitle: VS Code Extension Guide\ndescription: Integrating Raxol with the VS Code Extension.\ndate: 2025-04-27\nauthor: Raxol Team\nsection: guides\ntags: [vscode, extension, integration, guides]\n---\n\n# Raxol VS Code Extension Guide\n\nThis guide explains how to use and develop with the Raxol VS Code Extension, which aims to enable Raxol applications to run within a VS Code WebView panel.\n\n> **Feature Status: Not Implemented**\n> While the VS Code extension frontend exists (`extensions/vscode/`), the corresponding backend logic in the Raxol Elixir application to handle communication via stdio JSON is **currently missing or incomplete**. This guide describes the existing frontend structure and the _intended_ communication protocol, but the integration **does not function** at this time.","ref":"vscode_extension.html"},{"type":"extras","title":"1. Introduction - vscode_extension","doc":"- **Purpose:** Allow running and interacting with Raxol terminal applications directly within a VS Code panel.\n- **Intended Mechanism:** Uses a VS Code WebView to display the UI and communicates with a Raxol backend process via stdio using a JSON-based protocol.\n- **Potential Benefits:** Integrated development workflow, easier debugging.","ref":"vscode_extension.html#1-introduction"},{"type":"extras","title":"2. User Guide (Intended) - vscode_extension","doc":"- **Installation:** Assumed to be via VS Code Marketplace (if published) or manual installation.\n- **Running:** A command like `Raxol: Show Terminal` (registered in `extension.ts`) would launch the panel.\n- **Interaction:** User input in the panel would be sent to the backend; backend render updates would be displayed in the panel.","ref":"vscode_extension.html#2-user-guide-intended"},{"type":"extras","title":"3. Development Guide (Frontend Structure) - vscode_extension","doc":"- **Location:** `extensions/vscode/`\n- **Architecture:**\n  - **Extension Entry:** `src/extension.ts` handles activation and command registration.\n  - **Panel Management:** `src/RaxolPanelManager.ts` creates/manages the WebView panel, loads HTML (`media/index.html`), JS (`media/main.js`), and CSS (`media/styles.css`), and orchestrates communication between the WebView and the backend manager.\n  - **Backend Process Management:** `src/BackendManager.ts` is responsible for spawning and managing the Raxol Elixir backend process (`mix run --no-halt`) and handling stdio communication with it.\n- **Building Locally:** Requires Node.js/npm. Use `npm install` and standard VS Code extension development workflows (`Run Extension` task).","ref":"vscode_extension.html#3-development-guide-frontend-structure"},{"type":"extras","title":"4. Communication Protocol (Intended) - vscode_extension","doc":"- **Transport:** Standard I/O (stdin/stdout) between `BackendManager.ts` and the Raxol Elixir process.\n- **Backend Identification:** `BackendManager.ts` sets the environment variable `RAXOL_MODE=vscode_ext` when spawning the backend.\n- **Extension -> Backend Messages (Sent to Backend stdin):**\n  - JSON objects, newline-delimited (`JSON.stringify(message) + '\\n'`).\n  - Key types: `initialize` (with workspace info, dimensions), `userInput`, `resize_panel`, `shutdown`.\n- **Backend -> Extension Messages (Expected from Backend stdout):**\n  - JSON objects wrapped in markers: `RAXOL-JSON-BEGIN{...json...}RAXOL-JSON-END`.\n  - Intended types: Render updates (specific type TBD), `log` messages.\n  - Output not wrapped in markers is treated as plain log text by `BackendManager.ts`.\n- **Current Status:** The Elixir backend **does not** currently implement logic to detect `RAXOL_MODE=vscode_ext` or handle the stdio JSON protocol described above. Existing stdio handling (`Terminal.Driver`) is for native terminal interaction.","ref":"vscode_extension.html#4-communication-protocol-intended"},{"type":"extras","title":"5. Raxol Application Considerations (Hypothetical) - vscode_extension","doc":"- **Environment Detection:** Backend would need to check `System.get_env(\"RAXOL_MODE\")`.\n- **I/O Handling:** Backend would need a dedicated I/O loop/process to read JSON from stdin and write marker-wrapped JSON to stdout, bypassing the `Terminal.Driver` used for native mode.\n- **Rendering:** The `Rendering.Engine` has a non-functional `render_to_vscode/2` placeholder.","ref":"vscode_extension.html#5-raxol-application-considerations-hypothetical"},{"type":"extras","title":"6. Troubleshooting - vscode_extension","doc":"- **Backend Logs:** `BackendManager.ts` logs backend stdout/stderr and status messages to the \"Raxol Backend\" Output Channel in VS Code.\n- **Extension Logs:** Standard VS Code developer tools can be used to debug the TypeScript extension code.","ref":"vscode_extension.html#6-troubleshooting"},{"type":"extras","title":"7. Future Development - vscode_extension","doc":"- Implementing the backend stdio JSON communication handler.\n- Defining the specific render update message format.\n- Connecting the rendering engine to the VS Code communication channel.","ref":"vscode_extension.html#7-future-development"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}